<?php
// Include database connection and functions
require_once '../config/database.php';
require_once '../config/functions.php';

// Start session if not already started
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Check if user is admin
if (!isset($_SESSION['is_admin']) || $_SESSION['is_admin'] != 1) {
    header("Location: ../login.php");
    exit;
}

// Get current admin info
$admin_id = $_SESSION['user_id'];
$admin_sql = "SELECT * FROM users WHERE user_id = ? AND is_admin = 1";
$admin_stmt = $conn->prepare($admin_sql);
$admin_stmt->bind_param("i", $admin_id);
$admin_stmt->execute();
$admin_result = $admin_stmt->get_result();

if ($admin_result->num_rows == 0) {
    // If user is not admin, redirect to home
    session_destroy();
    header("Location: ../index.php");
    exit;
}

$admin = $admin_result->fetch_assoc();

// Get current page for active menu highlighting
$current_page = basename($_SERVER['PHP_SELF']);

// Get unread notifications count
$notifications_count = db_get_row(
    "SELECT COUNT(*) as count FROM notifications WHERE is_admin = 1 AND is_read = 0",
    []
)['count'] ?? 0;

// Get pending transactions count
$pending_transactions = db_get_row(
    "SELECT COUNT(*) as count FROM transactions WHERE status = 'pending'",
    []
)['count'] ?? 0;

// Get pending topup count
$pending_topups = db_get_row(
    "SELECT COUNT(*) as count FROM transactions WHERE status = 'pending' AND type = 'deposit'",
    []
)['count'] ?? 0;
?>
<!DOCTYPE html>
<html lang="id">

<head>
    <title><?php echo isset($page_title) ? $page_title : "Admin Panel"; ?> - LelangMobil</title>
    <link rel="icon" href="../images/icon.png" type="image/gif" sizes="16x16">
    <meta content="text/html;charset=utf-8" http-equiv="Content-Type">
    <meta content="width=device-width, initial-scale=1.0" name="viewport">
    
    <!-- CSS Files -->
    <link href="../css/bootstrap.min.css" rel="stylesheet" type="text/css">
    <link href="../css/mdb.min.css" rel="stylesheet" type="text/css">
    <link href="../fonts/font-awesome/css/all.min.css" rel="stylesheet" type="text/css">
    <link href="../css/modern-integrated.css" rel="stylesheet" type="text/css">
    <link href="../css/admin-modern.css" rel="stylesheet" type="text/css">
    <link href="includes/admin-styles.css" rel="stylesheet" type="text/css">
    
    <?php if (isset($page_specific_css)) echo $page_specific_css; ?>
</head>

<body class="dark-scheme">
    <div class="admin-wrapper">
        <!-- Sidebar -->
        <div class="admin-sidebar">
            <div class="admin-sidebar-header">
                <a href="index.php">
                    <img src="../images/logo.png" alt="LelangMobil Admin" style="max-width: 180px;">
                </a>
                <div class="mt-3">
                    <h6 class="mb-0">Admin Panel</h6>
                </div>
            </div>
            
            <div class="admin-sidebar-menu">
                <a href="index.php" class="admin-menu-item <?php echo ($current_page == 'index.php') ? 'active' : ''; ?>">
                    <i class="fa fa-tachometer-alt"></i> Dashboard
                </a>
                <a href="vehicles.php" class="admin-menu-item <?php echo ($current_page == 'vehicles.php' || $current_page == 'vehicle-form.php') ? 'active' : ''; ?>">
                    <i class="fa fa-car"></i> Kendaraan
                </a>
                <a href="users.php" class="admin-menu-item <?php echo ($current_page == 'users.php' || $current_page == 'user-detail.php' || $current_page == 'user-form.php') ? 'active' : ''; ?>">
                    <i class="fa fa-users"></i> Pengguna
                </a>
                <a href="bids.php" class="admin-menu-item <?php echo ($current_page == 'bids.php' || $current_page == 'bid-detail.php') ? 'active' : ''; ?>">
                    <i class="fa fa-gavel"></i> Riwayat Bid
                </a>
                <a href="transactions.php" class="admin-menu-item <?php echo ($current_page == 'transactions.php' || $current_page == 'transaction-detail.php') ? 'active' : ''; ?>">
                    <i class="fa fa-money-bill-wave"></i> Transaksi
                    <?php if ($pending_transactions > 0): ?>
                    <span class="admin-notification-badge"><?php echo $pending_transactions; ?></span>
                    <?php endif; ?>
                </a>
                <a href="transactions.php?status=pending&type=deposit" class="admin-menu-item <?php echo (isset($_GET['status']) && $_GET['status'] == 'pending' && isset($_GET['type']) && $_GET['type'] == 'deposit') ? 'active' : ''; ?>">
                    <i class="fa fa-wallet"></i> Top-up Pending
                    <?php if ($pending_topups > 0): ?>
                    <span class="admin-notification-badge"><?php echo $pending_topups; ?></span>
                    <?php endif; ?>
                </a>
                <a href="settings.php" class="admin-menu-item <?php echo ($current_page == 'settings.php') ? 'active' : ''; ?>">
                    <i class="fa fa-cog"></i> Pengaturan
                </a>
                <a href="../logout.php" class="admin-menu-item">
                    <i class="fa fa-sign-out-alt"></i> Logout
                </a>
            </div>
        </div>
        
        <!-- Main Content -->
        <div class="admin-content">
            <!-- Top Navigation -->
            <nav class="admin-topbar">
                <div class="admin-topbar-left">
                    <button class="admin-sidebar-toggle">
                        <i class="fa fa-bars"></i>
                    </button>
                    <h1 class="admin-topbar-title"><?php echo isset($page_title) ? $page_title : "Dashboard"; ?></h1>
                </div>
                
                <div class="admin-topbar-right">
                    <a href="../index.php" class="admin-btn admin-btn-outline admin-btn-sm" target="_blank">
                        <i class="fa fa-external-link-alt"></i> Lihat Website
                    </a>
                    
                    <div class="admin-notification-icon">
                        <i class="fa fa-bell"></i>
                        <?php if ($notifications_count > 0): ?>
                        <span class="admin-notification-badge"><?php echo $notifications_count; ?></span>
                        <?php endif; ?>
                    </div>
                    
                    <div class="admin-user-dropdown">
                        <div class="admin-user-toggle" id="adminUserToggle">
                            <img src="https://via.placeholder.com/32" class="rounded-circle" height="32" alt="Admin">
                            <span class="ms-2"><?php echo $admin['username']; ?></span>
                            <i class="fa fa-chevron-down ms-2"></i>
                        </div>
                        
                        <div class="admin-user-menu" id="adminUserMenu">
                            <a href="profile.php">
                                <i class="fa fa-user me-2"></i> Profil Saya
                            </a>
                            <a href="settings.php">
                                <i class="fa fa-cog me-2"></i> Pengaturan
                            </a>
                            <hr>
                            <a href="../logout.php">
                                <i class="fa fa-sign-out-alt me-2"></i> Logout
                            </a>
                        </div>
                    </div>
                </div>
            </nav>
            
            <!-- Page Content -->
            <div class="admin-page-content">
                <?php if ($pending_topups > 0 && $current_page != 'transactions.php'): ?>
                <div class="admin-alert admin-alert-warning mb-4">
                    <i class="fa fa-exclamation-circle"></i>
                    <div>
                        <strong>Perhatian!</strong> Terdapat <?php echo $pending_topups; ?> permintaan top-up yang menunggu konfirmasi.
                        <a href="transactions.php?status=pending&type=deposit" class="admin-link">Lihat sekarang</a>
                    </div>
                </div>
                <?php endif; ?>