<?php
/**
 * Auctions Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Set page title
$page_title = "Lelang Aktif - LelangMobil";

// Custom CSS untuk halaman lelang
$page_specific_css = '<link href="css/modern-auctions.css" rel="stylesheet" type="text/css">';

// Get filter parameters
$brand = isset($_GET['brand']) ? trim($_GET['brand']) : '';
$min_price = isset($_GET['min_price']) ? (int)$_GET['min_price'] : 0;
$max_price = isset($_GET['max_price']) ? (int)$_GET['max_price'] : 0;
$sort = isset($_GET['sort']) ? trim($_GET['sort']) : 'end_date_asc';

// Build query
$query = "SELECT 
            vehicle_id, 
            model, 
            COALESCE(brand, make) as brand,
            COALESCE(image_main, image, 'images/no-image.svg') as auction_image,
            COALESCE(starting_price, start_price, 0) as auction_start_price, 
            COALESCE(current_bid, current_price, 0) as auction_current_bid, 
            COALESCE(end_date, auction_end) as auction_end_date,
            year,
            description
            FROM vehicles 
            WHERE status = 'active'";

// Add filters
if (!empty($brand)) {
    $query .= " AND (COALESCE(brand, make) LIKE '%" . $conn->real_escape_string($brand) . "%')";
}

if ($min_price > 0) {
    $query .= " AND COALESCE(current_bid, current_price, starting_price, start_price) >= " . $min_price;
}

if ($max_price > 0) {
    $query .= " AND COALESCE(current_bid, current_price, starting_price, start_price) <= " . $max_price;
}

// Add sorting
switch ($sort) {
    case 'price_asc':
        $query .= " ORDER BY COALESCE(current_bid, current_price, starting_price, start_price) ASC";
        break;
    case 'price_desc':
        $query .= " ORDER BY COALESCE(current_bid, current_price, starting_price, start_price) DESC";
        break;
    case 'end_date_desc':
        $query .= " ORDER BY COALESCE(end_date, auction_end) DESC";
        break;
    case 'end_date_asc':
    default:
        $query .= " ORDER BY COALESCE(end_date, auction_end) ASC";
        break;
}

// Execute query
try {
    $auctions_result = $conn->query($query);
} catch (Throwable $e) {
    error_log("Error fetching auctions: " . $e->getMessage());
    $auctions_result = false;
}

// Get all brands for filter
try {
    $brands_query = "SELECT DISTINCT COALESCE(brand, make) as brand FROM vehicles WHERE status = 'active' ORDER BY brand";
    $brands_result = $conn->query($brands_query);
} catch (Throwable $e) {
    error_log("Error fetching brands: " . $e->getMessage());
    $brands_result = false;
}

// Include header
include("includes/header.php");
?>

<!-- Subheader -->
<section id="subheader" class="text-light">
    <div class="center-y relative text-center">
        <div class="container">
            <div class="row">
                <div class="col-md-12 text-center">
                    <h1>Lelang Aktif</h1>
                </div>
                <div class="clearfix"></div>
            </div>
        </div>
    </div>
</section>

<!-- Auctions Section -->
<section id="section-auctions" class="pt60 pb60">
    <div class="container">
        <div class="row">
            <!-- Filters -->
            <div class="col-lg-3 col-md-4">
                <div class="item_filter_group">
                    <h4>Filter</h4>
                    <form id="filter-form" method="get" action="auctions.php">
                        <div class="de_form">
                            <h5>Brand</h5>
                            <select class="form-control" name="brand">
                                <option value="">Semua Brand</option>
                                <?php
                                if ($brands_result && $brands_result->num_rows > 0) {
                                    while ($brand_row = $brands_result->fetch_assoc()) {
                                        $selected = ($brand == $brand_row['brand']) ? 'selected' : '';
                                        echo '<option value="' . htmlspecialchars($brand_row['brand']) . '" ' . $selected . '>' . htmlspecialchars($brand_row['brand']) . '</option>';
                                    }
                                }
                                ?>
                            </select>
                            
                            <h5>Harga</h5>
                            <div class="row">
                                <div class="col-6">
                                    <input type="number" name="min_price" class="form-control" placeholder="Min" value="<?php echo $min_price; ?>">
                                </div>
                                <div class="col-6">
                                    <input type="number" name="max_price" class="form-control" placeholder="Max" value="<?php echo $max_price; ?>">
                                </div>
                            </div>
                            
                            <h5>Urutkan</h5>
                            <select class="form-control" name="sort">
                                <option value="end_date_asc" <?php echo ($sort == 'end_date_asc') ? 'selected' : ''; ?>>Berakhir Segera</option>
                                <option value="end_date_desc" <?php echo ($sort == 'end_date_desc') ? 'selected' : ''; ?>>Terbaru</option>
                                <option value="price_asc" <?php echo ($sort == 'price_asc') ? 'selected' : ''; ?>>Harga Terendah</option>
                                <option value="price_desc" <?php echo ($sort == 'price_desc') ? 'selected' : ''; ?>>Harga Tertinggi</option>
                            </select>
                            
                            <div class="spacer-10"></div>
                            
                            <button type="submit" class="btn-main btn-fullwidth">Terapkan Filter</button>
                            <a href="auctions.php" class="btn-main btn-fullwidth btn-outline mt-2">Reset Filter</a>
                        </div>
                    </form>
                </div>
            </div>
            
            <!-- Auctions List -->
            <div class="col-lg-9 col-md-8">
                <div class="row">
                    <?php
                    if ($auctions_result && $auctions_result->num_rows > 0) {
                        while ($auction = $auctions_result->fetch_assoc()) {
                            // Calculate time remaining
                            $now = new DateTime();
                            $end_date = new DateTime($auction['auction_end_date']);
                            $interval = $now->diff($end_date);
                            
                            $time_label = "";
                            if ($interval->days > 0) {
                                $time_label = $interval->days . " hari " . $interval->h . " jam";
                            } else if ($interval->h > 0) {
                                $time_label = $interval->h . " jam " . $interval->i . " menit";
                            } else {
                                $time_label = $interval->i . " menit";
                            }
                            
                            // Set bid amount
                            $bid_amount = max($auction['auction_current_bid'], $auction['auction_start_price']);
                            ?>
                            <div class="col-lg-4 col-md-6 mb30">
                                <div class="de-item mb30">
                                    <div class="d-img">
                                        <img src="<?php echo htmlspecialchars($auction['auction_image']); ?>" class="img-fluid" alt="" onerror="this.src='images/no-image.svg';">
                                        <div class="d-countdown"><?php echo $time_label; ?></div>
                                    </div>
                                    <div class="d-info">
                                        <div class="d-text">
                                            <h4><?php echo htmlspecialchars($auction['brand'] . ' ' . $auction['model']); ?></h4>
                                            <div class="d-item_like">
                                                <span>Tahun <?php echo htmlspecialchars($auction['year']); ?></span>
                                            </div>
                                            <div class="d-atr-group">
                                                <span class="d-atr">Bid Saat Ini: Rp<?php echo number_format($bid_amount, 0, ',', '.'); ?></span>
                                            </div>
                                            <div class="d-btn">
                                                <a href="vehicle.php?id=<?php echo $auction['vehicle_id']; ?>" class="btn-main btn-fullwidth">Lihat Detail</a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php
                        }
                    } else {
                        echo '<div class="col-12 text-center"><p>Tidak ada lelang aktif yang sesuai dengan filter Anda.</p></div>';
                    }
                    ?>
                </div>
            </div>
        </div>
    </div>
</section>

<?php include("includes/footer.php"); ?>