<?php
/**
 * Database Check Script
 * LelangMobil Web App - Versi 2025
 */

// Aktifkan error reporting dan logging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include database connection
require_once 'config/database.php';

echo "<h1>Database Check</h1>";

// Check if users table exists
$users_check = $conn->query("SHOW TABLES LIKE 'users'");
if ($users_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'users' exists</p>";
    
    // Check users table structure
    $users_columns = $conn->query("SHOW COLUMNS FROM users");
    $required_columns = [
        'user_id', 'username', 'email', 'password', 'full_name', 'phone', 
        'balance', 'is_verified', 'verification_token', 'token_expiry', 
        'reset_token', 'reset_token_expiry', 'is_admin', 'remember_token'
    ];
    
    $missing_columns = [];
    $existing_columns = [];
    
    while ($column = $users_columns->fetch_assoc()) {
        $existing_columns[] = $column['Field'];
    }
    
    foreach ($required_columns as $column) {
        if (!in_array($column, $existing_columns)) {
            $missing_columns[] = $column;
        }
    }
    
    if (empty($missing_columns)) {
        echo "<p style='color:green'>✓ All required columns exist in 'users' table</p>";
    } else {
        echo "<p style='color:orange'>⚠ Missing columns in 'users' table: " . implode(', ', $missing_columns) . "</p>";
        echo "<p>Run <code>update_db_password_reset.php</code> to add missing columns</p>";
    }
} else {
    echo "<p style='color:red'>✗ Table 'users' does not exist</p>";
    echo "<p>Run <code>database.sql</code> to create the database structure</p>";
}

// Check if vehicles table exists
$vehicles_check = $conn->query("SHOW TABLES LIKE 'vehicles'");
if ($vehicles_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'vehicles' exists</p>";
    
    // Check vehicles table structure
    $vehicles_columns = $conn->query("SHOW COLUMNS FROM vehicles");
    $required_columns = [
        'vehicle_id', 'model', 'make', 'brand', 'year', 'mileage', 'description', 
        'image', 'image_main', 'start_price', 'starting_price', 'current_price', 
        'current_bid', 'auction_start', 'auction_end', 'end_date', 'status', 'seller_id'
    ];
    
    $missing_columns = [];
    $existing_columns = [];
    
    while ($column = $vehicles_columns->fetch_assoc()) {
        $existing_columns[] = $column['Field'];
    }
    
    foreach ($required_columns as $column) {
        if (!in_array($column, $existing_columns)) {
            $missing_columns[] = $column;
        }
    }
    
    if (empty($missing_columns)) {
        echo "<p style='color:green'>✓ All required columns exist in 'vehicles' table</p>";
    } else {
        echo "<p style='color:orange'>⚠ Missing columns in 'vehicles' table: " . implode(', ', $missing_columns) . "</p>";
        echo "<p>Run <code>fix_active_auctions.php</code> to add missing columns</p>";
    }
} else {
    echo "<p style='color:red'>✗ Table 'vehicles' does not exist</p>";
    echo "<p>Run <code>database.sql</code> to create the database structure</p>";
}

// Check if bids table exists
$bids_check = $conn->query("SHOW TABLES LIKE 'bids'");
if ($bids_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'bids' exists</p>";
} else {
    echo "<p style='color:red'>✗ Table 'bids' does not exist</p>";
    echo "<p>Run <code>database.sql</code> to create the database structure</p>";
}

// Check if transactions table exists
$transactions_check = $conn->query("SHOW TABLES LIKE 'transactions'");
if ($transactions_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'transactions' exists</p>";
} else {
    echo "<p style='color:red'>✗ Table 'transactions' does not exist</p>";
    echo "<p>Run <code>database.sql</code> to create the database structure</p>";
}

// Check if vehicle_images table exists
$images_check = $conn->query("SHOW TABLES LIKE 'vehicle_images'");
if ($images_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'vehicle_images' exists</p>";
} else {
    echo "<p style='color:red'>✗ Table 'vehicle_images' does not exist</p>";
    echo "<p>Run <code>database.sql</code> to create the database structure</p>";
}

// Check if user_addresses table exists
$addresses_check = $conn->query("SHOW TABLES LIKE 'user_addresses'");
if ($addresses_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'user_addresses' exists</p>";
} else {
    echo "<p style='color:orange'>⚠ Table 'user_addresses' does not exist</p>";
    echo "<p>Run <code>schema_shipping_addresses.sql</code> to create the table</p>";
}

// Check if settings table exists
$settings_check = $conn->query("SHOW TABLES LIKE 'settings'");
if ($settings_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'settings' exists</p>";
} else {
    echo "<p style='color:orange'>⚠ Table 'settings' does not exist</p>";
    echo "<p>Run <code>database.sql</code> to create the database structure</p>";
}

// Check if notifications table exists
$notifications_check = $conn->query("SHOW TABLES LIKE 'notifications'");
if ($notifications_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'notifications' exists</p>";
} else {
    echo "<p style='color:orange'>⚠ Table 'notifications' does not exist</p>";
    echo "<p>Run <code>database.sql</code> to create the database structure</p>";
}

// Check if admin_notifications table exists
$admin_notifications_check = $conn->query("SHOW TABLES LIKE 'admin_notifications'");
if ($admin_notifications_check->num_rows > 0) {
    echo "<p style='color:green'>✓ Table 'admin_notifications' exists</p>";
} else {
    echo "<p style='color:orange'>⚠ Table 'admin_notifications' does not exist</p>";
    echo "<p>Run <code>database.sql</code> to create the database structure</p>";
}

echo "<h2>File System Check</h2>";

// Check if required directories exist
$required_dirs = [
    'uploads/payment_proof',
    'uploads/vehicles',
    'images/bank-icons',
    'images/no-image.svg'
];

foreach ($required_dirs as $dir) {
    if (is_dir(dirname($dir)) || file_exists($dir)) {
        echo "<p style='color:green'>✓ Directory/file '$dir' exists</p>";
    } else {
        echo "<p style='color:orange'>⚠ Directory/file '$dir' does not exist</p>";
        echo "<p>Create the directory or file manually</p>";
    }
}

echo "<h2>Next Steps</h2>";
echo "<ol>";
echo "<li>Run <code>fix_active_auctions.php</code> to add missing columns to vehicles table</li>";
echo "<li>Run <code>update_db_password_reset.php</code> to add missing columns to users table</li>";
echo "<li>Make sure all required directories exist and are writable</li>";
echo "<li>Check that <code>config/mailer.php</code> and <code>config/email_functions.php</code> are properly configured</li>";
echo "</ol>";

echo "<p><a href='index.php'>Back to Home</a></p>";
?>