<?php
/**
 * Database Connection
 * LelangMobil Web App - Versi 2025
 */

// Database credentials
define('DB_SERVER', 'localhost');
define('DB_USERNAME', 'njjbrqpkca_rz');
define('DB_PASSWORD', 'N6cua;WHgtC]');
define('DB_NAME', 'njjbrqpkca_rz');

// Create connection with error handling
try {
    $conn = new mysqli(DB_SERVER, DB_USERNAME, DB_PASSWORD, DB_NAME);
    
    // Check connection
    if ($conn->connect_error) {
        throw new Exception("Connection failed: " . $conn->connect_error);
    }
    
    // Set charset
    $conn->set_charset("utf8mb4");
    
    // Enable error reporting for prepared statements
    mysqli_report(MYSQLI_REPORT_ERROR | MYSQLI_REPORT_STRICT);
    
} catch (Exception $e) {
    // Log error
    error_log("Database connection error: " . $e->getMessage());
    
    // Show user-friendly message
    die("Tidak dapat terhubung ke database. Silakan coba lagi nanti.");
}

/**
 * Execute database query with error handling
 * 
 * @param string $sql SQL query with placeholders
 * @param array $params Parameters to bind
 * @param string $types Types of parameters (i: integer, d: double, s: string, b: blob)
 * @return mysqli_result|bool Result object or false on failure
 */
function db_query($sql, $params = [], $types = "") {
    global $conn;
    
    try {
        $stmt = $conn->prepare($sql);
        
        if (!empty($params)) {
            // If types string is not provided, generate it
            if (empty($types)) {
                $types = "";
                foreach ($params as $param) {
                    if (is_int($param)) {
                        $types .= "i";
                    } elseif (is_float($param)) {
                        $types .= "d";
                    } elseif (is_string($param)) {
                        $types .= "s";
                    } else {
                        $types .= "b";
                    }
                }
            }
            
            $stmt->bind_param($types, ...$params);
        }
        
        $stmt->execute();
        return $stmt->get_result();
    } catch (Exception $e) {
        error_log("Query error: " . $e->getMessage() . " in query: " . $sql);
        return false;
    }
}

/**
 * Get single row from database
 * 
 * @param string $sql SQL query with placeholders
 * @param array $params Parameters to bind
 * @param string $types Types of parameters
 * @return array|null Row as associative array or null if not found
 */
function db_get_row($sql, $params = [], $types = "") {
    $result = db_query($sql, $params, $types);
    
    if ($result && $result->num_rows > 0) {
        return $result->fetch_assoc();
    }
    
    return null;
}

/**
 * Get multiple rows from database
 * 
 * @param string $sql SQL query with placeholders
 * @param array $params Parameters to bind
 * @param string $types Types of parameters
 * @return array Array of rows as associative arrays
 */
function db_get_rows($sql, $params = [], $types = "") {
    $result = db_query($sql, $params, $types);
    
    if ($result && $result->num_rows > 0) {
        return $result->fetch_all(MYSQLI_ASSOC);
    }
    
    return [];
}

/**
 * Insert data into database
 * 
 * @param string $table Table name
 * @param array $data Associative array of column => value
 * @return int|bool Last insert ID or false on failure
 */
function db_insert($table, $data) {
    global $conn;
    
    try {
        $columns = array_keys($data);
        $values = array_values($data);
        $placeholders = array_fill(0, count($values), '?');
        
        $sql = "INSERT INTO $table (" . implode(', ', $columns) . ") VALUES (" . implode(', ', $placeholders) . ")";
        
        $types = "";
        foreach ($values as $value) {
            if (is_int($value)) {
                $types .= "i";
            } elseif (is_float($value)) {
                $types .= "d";
            } elseif (is_string($value)) {
                $types .= "s";
            } else {
                $types .= "b";
            }
        }
        
        $stmt = $conn->prepare($sql);
        $stmt->bind_param($types, ...$values);
        $stmt->execute();
        
        return $conn->insert_id;
    } catch (Exception $e) {
        error_log("Insert error: " . $e->getMessage());
        return false;
    }
}

/**
 * Update data in database
 * 
 * @param string $table Table name
 * @param array $data Associative array of column => value
 * @param string $where Where clause with placeholders
 * @param array $where_params Parameters for where clause
 * @return int|bool Number of affected rows or false on failure
 */
function db_update($table, $data, $where, $where_params = []) {
    global $conn;
    
    try {
        $set = [];
        $values = [];
        $types = "";
        
        foreach ($data as $column => $value) {
            $set[] = "$column = ?";
            $values[] = $value;
            
            if (is_int($value)) {
                $types .= "i";
            } elseif (is_float($value)) {
                $types .= "d";
            } elseif (is_string($value)) {
                $types .= "s";
            } else {
                $types .= "b";
            }
        }
        
        foreach ($where_params as $param) {
            $values[] = $param;
            
            if (is_int($param)) {
                $types .= "i";
            } elseif (is_float($param)) {
                $types .= "d";
            } elseif (is_string($param)) {
                $types .= "s";
            } else {
                $types .= "b";
            }
        }
        
        $sql = "UPDATE $table SET " . implode(', ', $set) . " WHERE $where";
        
        $stmt = $conn->prepare($sql);
        $stmt->bind_param($types, ...$values);
        $stmt->execute();
        
        return $stmt->affected_rows;
    } catch (Exception $e) {
        error_log("Update error: " . $e->getMessage());
        return false;
    }
}

/**
 * Delete data from database
 * 
 * @param string $table Table name
 * @param string $where Where clause with placeholders
 * @param array $params Parameters for where clause
 * @return int|bool Number of affected rows or false on failure
 */
function db_delete($table, $where, $params = []) {
    global $conn;
    
    try {
        $sql = "DELETE FROM $table WHERE $where";
        
        $types = "";
        foreach ($params as $param) {
            if (is_int($param)) {
                $types .= "i";
            } elseif (is_float($param)) {
                $types .= "d";
            } elseif (is_string($param)) {
                $types .= "s";
            } else {
                $types .= "b";
            }
        }
        
        $stmt = $conn->prepare($sql);
        
        if (!empty($params)) {
            $stmt->bind_param($types, ...$params);
        }
        
        $stmt->execute();
        
        return $stmt->affected_rows;
    } catch (Exception $e) {
        error_log("Delete error: " . $e->getMessage());
        return false;
    }
}
?>