<?php
// Script to create directory structure for vehicle images in LelangMobil system

// Include database connection
require_once 'config/database.php';

// Check if user is admin
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

if (!isset($_SESSION['user_id']) || !isset($_SESSION['is_admin']) || $_SESSION['is_admin'] != 1) {
    die("Akses ditolak. Anda harus login sebagai admin untuk menjalankan script ini.");
}

echo "<h1>LelangMobil - Persiapan Direktori Gambar Kendaraan</h1>";

// Create base directories
$base_dirs = [
    'uploads/vehicles',
    'images/cars'
];

foreach ($base_dirs as $dir) {
    if (!file_exists($dir)) {
        if (mkdir($dir, 0755, true)) {
            echo "<p>✅ Direktori {$dir} berhasil dibuat</p>";
        } else {
            echo "<p>❌ Gagal membuat direktori {$dir}</p>";
        }
    } else {
        echo "<p>✓ Direktori {$dir} sudah ada</p>";
    }
}

// Get all vehicle makes from database
$makes_query = "SELECT DISTINCT make FROM vehicles WHERE make IS NOT NULL";
$makes_result = $conn->query($makes_query);

if ($makes_result && $makes_result->num_rows > 0) {
    echo "<h2>Membuat Direktori untuk Merek Kendaraan</h2>";
    while ($row = $makes_result->fetch_assoc()) {
        $make = $row['make'];
        $make_safe = preg_replace('/[^a-z0-9]+/', '-', strtolower($make));
        
        // Create directories for each make
        $make_dirs = [
            "uploads/vehicles/{$make_safe}",
            "images/cars/{$make_safe}"
        ];
        
        foreach ($make_dirs as $dir) {
            if (!file_exists($dir)) {
                if (mkdir($dir, 0755, true)) {
                    echo "<p>✅ Direktori {$dir} untuk {$make} berhasil dibuat</p>";
                } else {
                    echo "<p>❌ Gagal membuat direktori {$dir} untuk {$make}</p>";
                }
            } else {
                echo "<p>✓ Direktori {$dir} untuk {$make} sudah ada</p>";
            }
        }
    }
} else {
    echo "<p>Tidak ada data merek kendaraan di database</p>";
    
    // Create directories for common makes if no data exists
    $common_makes = ['toyota', 'honda', 'suzuki', 'bmw', 'mercedes', 'mazda', 'mitsubishi', 'wuling'];
    
    echo "<h2>Membuat Direktori untuk Merek Kendaraan Umum</h2>";
    foreach ($common_makes as $make) {
        $make_dirs = [
            "uploads/vehicles/{$make}",
            "images/cars/{$make}"
        ];
        
        foreach ($make_dirs as $dir) {
            if (!file_exists($dir)) {
                if (mkdir($dir, 0755, true)) {
                    echo "<p>✅ Direktori {$dir} untuk {$make} berhasil dibuat</p>";
                } else {
                    echo "<p>❌ Gagal membuat direktori {$dir} untuk {$make}</p>";
                }
            } else {
                echo "<p>✓ Direktori {$dir} untuk {$make} sudah ada</p>";
            }
        }
    }
}

echo "<p><a href='index.php' class='btn btn-primary'>Kembali ke Halaman Utama</a></p>";
echo "<p><a href='run_import.php' class='btn btn-success'>Lanjutkan ke Import Kendaraan</a></p>";
?>
