<?php
/**
 * Error Fix Script
 * LelangMobil Web App - Versi 2025
 * 
 * Script untuk memperbaiki semua error yang mungkin terjadi
 */

// Pesan error dan success
$errors = [];
$success = [];

// Buat direktori logs jika belum ada
$log_dir = __DIR__ . '/logs';
if (!file_exists($log_dir)) {
    if (@mkdir($log_dir, 0755, true)) {
        $success[] = "Direktori logs berhasil dibuat.";
    } else {
        $errors[] = "Gagal membuat direktori logs.";
    }
} else {
    $success[] = "Direktori logs sudah ada.";
}

// Buat file .htaccess untuk melindungi direktori logs
$htaccess_file = $log_dir . '/.htaccess';
if (!file_exists($htaccess_file)) {
    $htaccess_content = "# Deny access to all files in this directory\nDeny from all";
    if (@file_put_contents($htaccess_file, $htaccess_content)) {
        $success[] = "File .htaccess untuk direktori logs berhasil dibuat.";
    } else {
        $errors[] = "Gagal membuat file .htaccess untuk direktori logs.";
    }
} else {
    $success[] = "File .htaccess untuk direktori logs sudah ada.";
}

// Periksa file functions.php
$functions_file = __DIR__ . '/config/functions.php';
if (file_exists($functions_file)) {
    $functions_content = file_get_contents($functions_file);
    
    // Periksa apakah fungsi get_base_url ada
    if (strpos($functions_content, 'function get_base_url') === false) {
        $errors[] = "Fungsi get_base_url tidak ditemukan di functions.php.";
    } else {
        $success[] = "Fungsi get_base_url ditemukan di functions.php.";
    }
    
    // Periksa apakah fungsi clean_input ada
    if (strpos($functions_content, 'function clean_input') === false) {
        $errors[] = "Fungsi clean_input tidak ditemukan di functions.php.";
    } else {
        $success[] = "Fungsi clean_input ditemukan di functions.php.";
    }
} else {
    $errors[] = "File functions.php tidak ditemukan.";
}

// Periksa file init.php
$init_file = __DIR__ . '/config/init.php';
if (file_exists($init_file)) {
    $init_content = file_get_contents($init_file);
    
    // Periksa apakah fungsi format_date ada di init.php (seharusnya tidak ada)
    if (strpos($init_content, 'function format_date') !== false) {
        $errors[] = "Fungsi format_date ditemukan di init.php. Ini seharusnya hanya ada di functions.php.";
    } else {
        $success[] = "Tidak ada fungsi format_date di init.php.";
    }
    
    // Periksa apakah fungsi get_base_url ada di init.php (seharusnya tidak ada)
    if (strpos($init_content, 'function get_base_url') !== false) {
        $errors[] = "Fungsi get_base_url ditemukan di init.php. Ini seharusnya hanya ada di functions.php.";
    } else {
        $success[] = "Tidak ada fungsi get_base_url di init.php.";
    }
    
    // Periksa apakah fungsi clean_input ada di init.php (seharusnya tidak ada)
    if (strpos($init_content, 'function clean_input') !== false) {
        $errors[] = "Fungsi clean_input ditemukan di init.php. Ini seharusnya hanya ada di functions.php.";
    } else {
        $success[] = "Tidak ada fungsi clean_input di init.php.";
    }
} else {
    $errors[] = "File init.php tidak ditemukan.";
}

// Periksa file email_functions.php
$email_functions_file = __DIR__ . '/config/email_functions.php';
if (file_exists($email_functions_file)) {
    $email_functions_content = file_get_contents($email_functions_file);
    
    // Periksa apakah fungsi get_base_url ada di email_functions.php (seharusnya tidak ada)
    if (strpos($email_functions_content, 'function get_base_url') !== false) {
        $errors[] = "Fungsi get_base_url ditemukan di email_functions.php. Ini seharusnya hanya ada di functions.php.";
    } else {
        $success[] = "Tidak ada fungsi get_base_url di email_functions.php.";
    }
    
    // Periksa apakah fungsi send_verification_email memiliki parameter yang benar
    if (strpos($email_functions_content, 'function send_verification_email($conn, $email, $token, $user_id)') === false) {
        $errors[] = "Fungsi send_verification_email di email_functions.php tidak memiliki parameter yang benar.";
    } else {
        $success[] = "Fungsi send_verification_email di email_functions.php memiliki parameter yang benar.";
    }
    
    // Periksa apakah fungsi send_password_reset_email memiliki parameter yang benar
    if (strpos($email_functions_content, 'function send_password_reset_email($conn, $email, $token)') === false) {
        $errors[] = "Fungsi send_password_reset_email di email_functions.php tidak memiliki parameter yang benar.";
    } else {
        $success[] = "Fungsi send_password_reset_email di email_functions.php memiliki parameter yang benar.";
    }
} else {
    $errors[] = "File email_functions.php tidak ditemukan.";
}

// Periksa file resend-verification.php
$resend_verification_file = __DIR__ . '/resend-verification.php';
if (file_exists($resend_verification_file)) {
    $resend_verification_content = file_get_contents($resend_verification_file);
    
    // Periksa apakah file menggunakan clean_input
    if (strpos($resend_verification_content, 'clean_input') === false) {
        $errors[] = "File resend-verification.php tidak menggunakan fungsi clean_input.";
    } else {
        $success[] = "File resend-verification.php menggunakan fungsi clean_input.";
    }
} else {
    $errors[] = "File resend-verification.php tidak ditemukan.";
}

// Periksa file resend_verification.php (file lama)
$old_resend_verification_file = __DIR__ . '/resend_verification.php';
if (file_exists($old_resend_verification_file)) {
    $errors[] = "File resend_verification.php (file lama) masih ada. Sebaiknya dihapus dan gunakan resend-verification.php.";
    
    // Hapus file lama
    if (@unlink($old_resend_verification_file)) {
        $success[] = "File resend_verification.php (file lama) berhasil dihapus.";
    } else {
        $errors[] = "Gagal menghapus file resend_verification.php (file lama).";
    }
}

// Periksa file forgot-password.php
$forgot_password_file = __DIR__ . '/forgot-password.php';
if (file_exists($forgot_password_file)) {
    $forgot_password_content = file_get_contents($forgot_password_file);
    
    // Periksa apakah file menggunakan clean_input
    if (strpos($forgot_password_content, 'clean_input') === false) {
        $errors[] = "File forgot-password.php tidak menggunakan fungsi clean_input.";
    } else {
        $success[] = "File forgot-password.php menggunakan fungsi clean_input.";
    }
    
    // Periksa apakah file menggunakan parameter yang benar untuk send_password_reset_email
    if (strpos($forgot_password_content, 'send_password_reset_email($conn, $email, $reset_token)') === false) {
        $errors[] = "File forgot-password.php tidak menggunakan parameter yang benar untuk fungsi send_password_reset_email.";
    } else {
        $success[] = "File forgot-password.php menggunakan parameter yang benar untuk fungsi send_password_reset_email.";
    }
} else {
    $errors[] = "File forgot-password.php tidak ditemukan.";
}

// Periksa file reset-password.php
$reset_password_file = __DIR__ . '/reset-password.php';
if (file_exists($reset_password_file)) {
    $reset_password_content = file_get_contents($reset_password_file);
    
    // Periksa apakah file menggunakan clean_input
    if (strpos($reset_password_content, 'clean_input') === false) {
        $errors[] = "File reset-password.php tidak menggunakan fungsi clean_input.";
    } else {
        $success[] = "File reset-password.php menggunakan fungsi clean_input.";
    }
} else {
    $errors[] = "File reset-password.php tidak ditemukan.";
}

// Periksa file verify.php
$verify_file = __DIR__ . '/verify.php';
if (file_exists($verify_file)) {
    $verify_content = file_get_contents($verify_file);
    
    // Periksa apakah file menggunakan clean_input
    if (strpos($verify_content, 'clean_input') === false) {
        $errors[] = "File verify.php tidak menggunakan fungsi clean_input.";
    } else {
        $success[] = "File verify.php menggunakan fungsi clean_input.";
    }
} else {
    $errors[] = "File verify.php tidak ditemukan.";
}

// Periksa file error-handler.php
$error_handler_file = __DIR__ . '/error-handler.php';
if (!file_exists($error_handler_file)) {
    $errors[] = "File error-handler.php tidak ditemukan.";
} else {
    $success[] = "File error-handler.php ditemukan.";
}

// Periksa file error.php
$error_page_file = __DIR__ . '/error.php';
if (!file_exists($error_page_file)) {
    $errors[] = "File error.php tidak ditemukan.";
} else {
    $success[] = "File error.php ditemukan.";
}

// Periksa file page-loader.js
$page_loader_file = __DIR__ . '/js/page-loader.js';
if (!file_exists($page_loader_file)) {
    $errors[] = "File page-loader.js tidak ditemukan.";
} else {
    $success[] = "File page-loader.js ditemukan.";
}

// Periksa file error-handler.js
$error_handler_js_file = __DIR__ . '/js/error-handler.js';
if (!file_exists($error_handler_js_file)) {
    $errors[] = "File error-handler.js tidak ditemukan.";
} else {
    $success[] = "File error-handler.js ditemukan.";
}

// Periksa file cleanup.js
$cleanup_js_file = __DIR__ . '/js/cleanup.js';
if (!file_exists($cleanup_js_file)) {
    $errors[] = "File cleanup.js tidak ditemukan.";
} else {
    $success[] = "File cleanup.js ditemukan.";
}

// Periksa file cleanup.css
$cleanup_css_file = __DIR__ . '/css/cleanup.css';
if (!file_exists($cleanup_css_file)) {
    $errors[] = "File cleanup.css tidak ditemukan.";
} else {
    $success[] = "File cleanup.css ditemukan.";
}

// Periksa file login-modern.css
$login_modern_css_file = __DIR__ . '/css/login-modern.css';
if (!file_exists($login_modern_css_file)) {
    $errors[] = "File login-modern.css tidak ditemukan.";
} else {
    $success[] = "File login-modern.css ditemukan.";
}

// Periksa file dashboard-modern.css
$dashboard_modern_css_file = __DIR__ . '/css/dashboard-modern.css';
if (!file_exists($dashboard_modern_css_file)) {
    $errors[] = "File dashboard-modern.css tidak ditemukan.";
} else {
    $success[] = "File dashboard-modern.css ditemukan.";
}

// Periksa file global-modern.css
$global_modern_css_file = __DIR__ . '/css/global-modern.css';
if (!file_exists($global_modern_css_file)) {
    $errors[] = "File global-modern.css tidak ditemukan.";
} else {
    $success[] = "File global-modern.css ditemukan.";
}

// Periksa file animations.css
$animations_css_file = __DIR__ . '/css/animations.css';
if (!file_exists($animations_css_file)) {
    $errors[] = "File animations.css tidak ditemukan.";
} else {
    $success[] = "File animations.css ditemukan.";
}

// Periksa file back-to-top.css
$back_to_top_css_file = __DIR__ . '/css/back-to-top.css';
if (!file_exists($back_to_top_css_file)) {
    $errors[] = "File back-to-top.css tidak ditemukan.";
} else {
    $success[] = "File back-to-top.css ditemukan.";
}

// Periksa file modern-index.css
$modern_index_css_file = __DIR__ . '/css/modern-index.css';
if (!file_exists($modern_index_css_file)) {
    $errors[] = "File modern-index.css tidak ditemukan.";
} else {
    $success[] = "File modern-index.css ditemukan.";
}

// Periksa file back-to-top.js
$back_to_top_js_file = __DIR__ . '/js/back-to-top.js';
if (!file_exists($back_to_top_js_file)) {
    $errors[] = "File back-to-top.js tidak ditemukan.";
} else {
    $success[] = "File back-to-top.js ditemukan.";
}

// Periksa file modern-effects.js
$modern_effects_js_file = __DIR__ . '/js/modern-effects.js';
if (!file_exists($modern_effects_js_file)) {
    $errors[] = "File modern-effects.js tidak ditemukan.";
} else {
    $success[] = "File modern-effects.js ditemukan.";
}

// Periksa file index.php
$index_file = __DIR__ . '/index.php';
if (file_exists($index_file)) {
    $index_content = file_get_contents($index_file);
    
    // Periksa apakah file menggunakan error-handler.php
    if (strpos($index_content, 'require_once \'error-handler.php\';') === false) {
        $errors[] = "File index.php tidak menggunakan error-handler.php.";
    } else {
        $success[] = "File index.php menggunakan error-handler.php.";
    }
    
    // Periksa apakah file menggunakan modern-index.css
    if (strpos($index_content, 'css/modern-index.css') === false) {
        $errors[] = "File index.php tidak menggunakan modern-index.css.";
    } else {
        $success[] = "File index.php menggunakan modern-index.css.";
    }
} else {
    $errors[] = "File index.php tidak ditemukan.";
}

// Periksa file header.php
$header_file = __DIR__ . '/includes/header.php';
if (file_exists($header_file)) {
    $header_content = file_get_contents($header_file);
    
    // Periksa apakah file menggunakan cleanup.css
    if (strpos($header_content, 'css/cleanup.css') === false) {
        $errors[] = "File header.php tidak menggunakan cleanup.css.";
    } else {
        $success[] = "File header.php menggunakan cleanup.css.";
    }
} else {
    $errors[] = "File header.php tidak ditemukan.";
}

// Periksa file footer.php
$footer_file = __DIR__ . '/includes/footer.php';
if (file_exists($footer_file)) {
    $footer_content = file_get_contents($footer_file);
    
    // Periksa apakah file menggunakan error-handler.js
    if (strpos($footer_content, 'js/error-handler.js') === false) {
        $errors[] = "File footer.php tidak menggunakan error-handler.js.";
    } else {
        $success[] = "File footer.php menggunakan error-handler.js.";
    }
    
    // Periksa apakah file menggunakan page-loader.js
    if (strpos($footer_content, 'js/page-loader.js') === false) {
        $errors[] = "File footer.php tidak menggunakan page-loader.js.";
    } else {
        $success[] = "File footer.php menggunakan page-loader.js.";
    }
    
    // Periksa apakah file menggunakan cleanup.js
    if (strpos($footer_content, 'js/cleanup.js') === false) {
        $errors[] = "File footer.php tidak menggunakan cleanup.js.";
    } else {
        $success[] = "File footer.php menggunakan cleanup.js.";
    }
} else {
    $errors[] = "File footer.php tidak ditemukan.";
}

// Set page title
$page_title = "Error Fix - LelangMobil";

// Include header
include("includes/header.php");
?>

<div class="container py-5">
    <div class="row">
        <div class="col-lg-8 offset-lg-2">
            <div class="modern-card">
                <div class="modern-card-header">
                    <h2>Error Fix</h2>
                </div>
                <div class="modern-card-body">
                    <?php if (count($errors) > 0): ?>
                        <div class="modern-alert modern-alert-danger mb-4">
                            <i class="fa fa-exclamation-circle"></i>
                            <div>
                                <h5>Ditemukan <?php echo count($errors); ?> error:</h5>
                                <ul class="mb-0">
                                    <?php foreach ($errors as $error): ?>
                                        <li><?php echo $error; ?></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    <?php endif; ?>
                    
                    <?php if (count($success) > 0): ?>
                        <div class="modern-alert modern-alert-success mb-4">
                            <i class="fa fa-check-circle"></i>
                            <div>
                                <h5>Berhasil memeriksa <?php echo count($success); ?> item:</h5>
                                <ul class="mb-0">
                                    <?php foreach ($success as $item): ?>
                                        <li><?php echo $item; ?></li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    <?php endif; ?>
                    
                    <p>Script ini memeriksa semua file yang diperlukan untuk memastikan tidak ada error.</p>
                    
                    <div class="mt-4">
                        <a href="index.php" class="modern-btn modern-btn-primary">Kembali ke Beranda</a>
                        <?php if (count($errors) > 0): ?>
                            <a href="fix-functions.php" class="modern-btn modern-btn-danger ms-2">Perbaiki Fungsi</a>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include("includes/footer.php"); ?>