<?php
/**
 * Fix All Issues Script
 * LelangMobil Web App - Versi 2025
 */

// Aktifkan error reporting dan logging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Include database connection
require_once 'config/database.php';

echo "<h1>LelangMobil System Repair</h1>";
echo "<p>Memperbaiki semua masalah yang terdeteksi...</p>";

// 1. Fix database structure
echo "<h2>1. Memperbaiki Struktur Database</h2>";

// Check and fix users table
$users_check = $conn->query("SHOW TABLES LIKE 'users'");
if ($users_check->num_rows == 0) {
    echo "<p>Membuat tabel users...</p>";
    $create_users = "CREATE TABLE `users` (
        `user_id` INT AUTO_INCREMENT PRIMARY KEY,
        `username` VARCHAR(50) NOT NULL UNIQUE,
        `email` VARCHAR(100) NOT NULL UNIQUE,
        `password` VARCHAR(255) NOT NULL,
        `full_name` VARCHAR(100),
        `phone` VARCHAR(20),
        `address` TEXT,
        `balance` DECIMAL(10, 2) DEFAULT 0.00,
        `pending_balance` DECIMAL(10, 2) DEFAULT 0.00,
        `is_verified` BOOLEAN DEFAULT FALSE,
        `verification_token` VARCHAR(100),
        `token_expiry` DATETIME,
        `reset_token` VARCHAR(100),
        `reset_token_expiry` DATETIME,
        `is_admin` BOOLEAN DEFAULT FALSE,
        `profile_photo` VARCHAR(255),
        `remember_token` VARCHAR(100),
        `last_login` DATETIME,
        `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        `updated_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
    )";
    if ($conn->query($create_users)) {
        echo "<p style='color:green'>✓ Tabel users berhasil dibuat</p>";
    } else {
        echo "<p style='color:red'>✗ Gagal membuat tabel users: " . $conn->error . "</p>";
    }
} else {
    echo "<p>Tabel users sudah ada, memeriksa kolom...</p>";
    
    // Check and add missing columns to users table
    $columns_to_check = [
        'verification_token' => "ALTER TABLE users ADD COLUMN verification_token VARCHAR(100) NULL",
        'token_expiry' => "ALTER TABLE users ADD COLUMN token_expiry DATETIME NULL",
        'reset_token' => "ALTER TABLE users ADD COLUMN reset_token VARCHAR(100) NULL",
        'reset_token_expiry' => "ALTER TABLE users ADD COLUMN reset_token_expiry DATETIME NULL",
        'is_verified' => "ALTER TABLE users ADD COLUMN is_verified BOOLEAN DEFAULT FALSE",
        'remember_token' => "ALTER TABLE users ADD COLUMN remember_token VARCHAR(100) NULL",
        'last_login' => "ALTER TABLE users ADD COLUMN last_login DATETIME NULL"
    ];
    
    $users_columns = $conn->query("SHOW COLUMNS FROM users");
    $existing_columns = [];
    while ($column = $users_columns->fetch_assoc()) {
        $existing_columns[] = $column['Field'];
    }
    
    foreach ($columns_to_check as $column => $sql) {
        if (!in_array($column, $existing_columns)) {
            echo "<p>Menambahkan kolom $column ke tabel users...</p>";
            if ($conn->query($sql)) {
                echo "<p style='color:green'>✓ Kolom $column berhasil ditambahkan</p>";
            } else {
                echo "<p style='color:red'>✗ Gagal menambahkan kolom $column: " . $conn->error . "</p>";
            }
        }
    }
    
    // Set all existing users as verified
    $conn->query("UPDATE users SET is_verified = TRUE WHERE is_verified IS NULL OR is_verified = FALSE");
    echo "<p style='color:green'>✓ Semua pengguna yang ada diatur sebagai terverifikasi</p>";
}

// Check and fix vehicles table
$vehicles_check = $conn->query("SHOW TABLES LIKE 'vehicles'");
if ($vehicles_check->num_rows == 0) {
    echo "<p>Membuat tabel vehicles...</p>";
    $create_vehicles = "CREATE TABLE `vehicles` (
        `vehicle_id` INT AUTO_INCREMENT PRIMARY KEY,
        `model` VARCHAR(100) NOT NULL,
        `make` VARCHAR(50),
        `brand` VARCHAR(50),
        `year` INT,
        `mileage` INT,
        `condition_rating` INT,
        `description` TEXT,
        `image` VARCHAR(255),
        `image_main` VARCHAR(255),
        `start_price` DECIMAL(10, 2) NOT NULL,
        `starting_price` DECIMAL(10, 2),
        `reserve_price` DECIMAL(10, 2),
        `current_price` DECIMAL(10, 2),
        `current_bid` DECIMAL(10, 2),
        `auction_start` DATETIME NOT NULL,
        `auction_end` DATETIME NOT NULL,
        `end_date` DATETIME,
        `status` ENUM('upcoming', 'active', 'ended', 'sold', 'not_sold') DEFAULT 'upcoming',
        `seller_id` INT,
        `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        `updated_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (`seller_id`) REFERENCES `users`(`user_id`)
    )";
    if ($conn->query($create_vehicles)) {
        echo "<p style='color:green'>✓ Tabel vehicles berhasil dibuat</p>";
    } else {
        echo "<p style='color:red'>✗ Gagal membuat tabel vehicles: " . $conn->error . "</p>";
    }
} else {
    echo "<p>Tabel vehicles sudah ada, memeriksa kolom...</p>";
    
    // Check and add missing columns to vehicles table
    $columns_to_check = [
        'brand' => "ALTER TABLE vehicles ADD COLUMN brand VARCHAR(50) DEFAULT NULL AFTER make",
        'image_main' => "ALTER TABLE vehicles ADD COLUMN image_main VARCHAR(255) DEFAULT NULL AFTER image",
        'starting_price' => "ALTER TABLE vehicles ADD COLUMN starting_price DECIMAL(10, 2) DEFAULT NULL AFTER start_price",
        'current_bid' => "ALTER TABLE vehicles ADD COLUMN current_bid DECIMAL(10, 2) DEFAULT NULL AFTER current_price",
        'end_date' => "ALTER TABLE vehicles ADD COLUMN end_date DATETIME DEFAULT NULL AFTER auction_end"
    ];
    
    $vehicles_columns = $conn->query("SHOW COLUMNS FROM vehicles");
    $existing_columns = [];
    while ($column = $vehicles_columns->fetch_assoc()) {
        $existing_columns[] = $column['Field'];
    }
    
    foreach ($columns_to_check as $column => $sql) {
        if (!in_array($column, $existing_columns)) {
            echo "<p>Menambahkan kolom $column ke tabel vehicles...</p>";
            if ($conn->query($sql)) {
                echo "<p style='color:green'>✓ Kolom $column berhasil ditambahkan</p>";
            } else {
                echo "<p style='color:red'>✗ Gagal menambahkan kolom $column: " . $conn->error . "</p>";
            }
        }
    }
    
    // Update values for new columns
    if (in_array('brand', $existing_columns) || $conn->query("SHOW COLUMNS FROM vehicles LIKE 'brand'")->num_rows > 0) {
        $conn->query("UPDATE vehicles SET brand = make WHERE brand IS NULL AND make IS NOT NULL");
        echo "<p style='color:green'>✓ Kolom brand diperbarui dari make</p>";
    }
    
    if (in_array('image_main', $existing_columns) || $conn->query("SHOW COLUMNS FROM vehicles LIKE 'image_main'")->num_rows > 0) {
        $conn->query("UPDATE vehicles SET image_main = image WHERE image_main IS NULL AND image IS NOT NULL");
        echo "<p style='color:green'>✓ Kolom image_main diperbarui dari image</p>";
    }
    
    if (in_array('starting_price', $existing_columns) || $conn->query("SHOW COLUMNS FROM vehicles LIKE 'starting_price'")->num_rows > 0) {
        $conn->query("UPDATE vehicles SET starting_price = start_price WHERE starting_price IS NULL AND start_price IS NOT NULL");
        echo "<p style='color:green'>✓ Kolom starting_price diperbarui dari start_price</p>";
    }
    
    if (in_array('current_bid', $existing_columns) || $conn->query("SHOW COLUMNS FROM vehicles LIKE 'current_bid'")->num_rows > 0) {
        $conn->query("UPDATE vehicles SET current_bid = current_price WHERE current_bid IS NULL AND current_price IS NOT NULL");
        echo "<p style='color:green'>✓ Kolom current_bid diperbarui dari current_price</p>";
    }
    
    if (in_array('end_date', $existing_columns) || $conn->query("SHOW COLUMNS FROM vehicles LIKE 'end_date'")->num_rows > 0) {
        $conn->query("UPDATE vehicles SET end_date = auction_end WHERE end_date IS NULL AND auction_end IS NOT NULL");
        echo "<p style='color:green'>✓ Kolom end_date diperbarui dari auction_end</p>";
    }
}

// Check and create other necessary tables
$tables_to_check = [
    'bids' => "CREATE TABLE `bids` (
        `bid_id` INT AUTO_INCREMENT PRIMARY KEY,
        `vehicle_id` INT,
        `bidder_id` INT,
        `bid_amount` DECIMAL(10, 2) NOT NULL,
        `bid_time` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        `is_winning` BIT DEFAULT 0,
        FOREIGN KEY (`vehicle_id`) REFERENCES `vehicles`(`vehicle_id`) ON DELETE CASCADE,
        FOREIGN KEY (`bidder_id`) REFERENCES `users`(`user_id`)
    )",
    'transactions' => "CREATE TABLE `transactions` (
        `transaction_id` INT AUTO_INCREMENT PRIMARY KEY,
        `user_id` INT,
        `amount` DECIMAL(10, 2) NOT NULL,
        `type` ENUM('deposit', 'withdrawal', 'bid_hold', 'bid_release', 'bid_win') NOT NULL,
        `status` ENUM('pending', 'verification', 'completed', 'rejected', 'cancelled') DEFAULT 'pending',
        `reference_number` VARCHAR(50),
        `payment_proof` VARCHAR(255),
        `bank_name` VARCHAR(50),
        `account_number` VARCHAR(50),
        `account_name` VARCHAR(100),
        `notes` TEXT,
        `admin_id` INT,
        `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        `updated_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (`user_id`) REFERENCES `users`(`user_id`),
        FOREIGN KEY (`admin_id`) REFERENCES `users`(`user_id`)
    )",
    'vehicle_images' => "CREATE TABLE `vehicle_images` (
        `image_id` INT AUTO_INCREMENT PRIMARY KEY,
        `vehicle_id` INT,
        `image_url` VARCHAR(255) NOT NULL,
        `is_main` BOOLEAN DEFAULT FALSE,
        `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        FOREIGN KEY (`vehicle_id`) REFERENCES `vehicles`(`vehicle_id`) ON DELETE CASCADE
    )",
    'settings' => "CREATE TABLE `settings` (
        `setting_key` VARCHAR(100) PRIMARY KEY,
        `setting_value` TEXT,
        `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        `updated_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
    )",
    'notifications' => "CREATE TABLE `notifications` (
        `notification_id` INT AUTO_INCREMENT PRIMARY KEY,
        `user_id` INT,
        `type` VARCHAR(50) NOT NULL,
        `message` TEXT NOT NULL,
        `url` VARCHAR(255),
        `is_read` BOOLEAN DEFAULT FALSE,
        `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        FOREIGN KEY (`user_id`) REFERENCES `users`(`user_id`) ON DELETE CASCADE
    )",
    'admin_notifications' => "CREATE TABLE `admin_notifications` (
        `id` INT AUTO_INCREMENT PRIMARY KEY,
        `type` VARCHAR(50) NOT NULL,
        `title` VARCHAR(100) NOT NULL,
        `message` TEXT NOT NULL,
        `link` VARCHAR(255),
        `is_read` BOOLEAN DEFAULT FALSE,
        `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP
    )",
    'user_addresses' => "CREATE TABLE `user_addresses` (
        `address_id` INT AUTO_INCREMENT PRIMARY KEY,
        `user_id` INT NOT NULL,
        `recipient_name` VARCHAR(100) NOT NULL,
        `phone` VARCHAR(20) NOT NULL,
        `address_line1` VARCHAR(255) NOT NULL,
        `address_line2` VARCHAR(255),
        `city` VARCHAR(100) NOT NULL,
        `province` VARCHAR(100) NOT NULL,
        `postal_code` VARCHAR(20) NOT NULL,
        `is_default` BOOLEAN DEFAULT FALSE,
        `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        `updated_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (`user_id`) REFERENCES `users`(`user_id`) ON DELETE CASCADE
    )"
];

foreach ($tables_to_check as $table => $sql) {
    $table_check = $conn->query("SHOW TABLES LIKE '$table'");
    if ($table_check->num_rows == 0) {
        echo "<p>Membuat tabel $table...</p>";
        if ($conn->query($sql)) {
            echo "<p style='color:green'>✓ Tabel $table berhasil dibuat</p>";
        } else {
            echo "<p style='color:red'>✗ Gagal membuat tabel $table: " . $conn->error . "</p>";
        }
    } else {
        echo "<p style='color:green'>✓ Tabel $table sudah ada</p>";
    }
}

// 2. Create required directories
echo "<h2>2. Membuat Direktori yang Diperlukan</h2>";

$directories = [
    'uploads',
    'uploads/payment_proof',
    'uploads/vehicles',
    'uploads/temp',
    'images/bank-icons'
];

foreach ($directories as $dir) {
    if (!file_exists($dir)) {
        echo "<p>Membuat direktori $dir...</p>";
        if (mkdir($dir, 0755, true)) {
            echo "<p style='color:green'>✓ Direktori $dir berhasil dibuat</p>";
        } else {
            echo "<p style='color:red'>✗ Gagal membuat direktori $dir</p>";
        }
    } else {
        echo "<p style='color:green'>✓ Direktori $dir sudah ada</p>";
    }
}

// 3. Create placeholder image if not exists
echo "<h2>3. Membuat Gambar Placeholder</h2>";

$placeholder_image = 'images/no-image.svg';
if (!file_exists($placeholder_image)) {
    echo "<p>Membuat gambar placeholder...</p>";
    $svg_content = '<?xml version="1.0" encoding="UTF-8"?>
    <svg width="800px" height="600px" viewBox="0 0 800 600" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
        <rect fill="#f0f0f0" x="0" y="0" width="800" height="600"></rect>
        <g transform="translate(346.000000, 275.000000)" fill="#cccccc">
            <path d="M54,0 C83.8233333,0 108,24.1766667 108,54 C108,83.8233333 83.8233333,108 54,108 C24.1766667,108 0,83.8233333 0,54 C0,24.1766667 24.1766667,0 54,0 Z M54,12 C30.804,12 12,30.804 12,54 C12,77.196 30.804,96 54,96 C77.196,96 96,77.196 96,54 C96,30.804 77.196,12 54,12 Z"></path>
            <path d="M41.4,45 L66.6,45 C68.4777681,45 70,46.5222319 70,48.4 L70,73.6 C70,75.4777681 68.4777681,77 66.6,77 L41.4,77 C39.5222319,77 38,75.4777681 38,73.6 L38,48.4 C38,46.5222319 39.5222319,45 41.4,45 Z M59.3333333,52.3333333 C59.3333333,54.3584 57.6917333,56 55.6666667,56 C53.6416,56 52,54.3584 52,52.3333333 C52,50.3082667 53.6416,48.6666667 55.6666667,48.6666667 C57.6917333,48.6666667 59.3333333,50.3082667 59.3333333,52.3333333 Z M66.5,73.5 L66.5,63.5 L60.5,57.5 L49,69 L45,65 L41.5,68.5 L41.5,73.5 L66.5,73.5 Z"></path>
        </g>
    </svg>';
    
    if (file_put_contents($placeholder_image, $svg_content)) {
        echo "<p style='color:green'>✓ Gambar placeholder berhasil dibuat</p>";
    } else {
        echo "<p style='color:red'>✗ Gagal membuat gambar placeholder</p>";
    }
} else {
    echo "<p style='color:green'>✓ Gambar placeholder sudah ada</p>";
}

// 4. Create default admin user if not exists
echo "<h2>4. Membuat Pengguna Admin Default</h2>";

$admin_check = $conn->query("SELECT * FROM users WHERE username = 'admin' OR email = 'admin@lelangmobil.com'");
if ($admin_check->num_rows == 0) {
    echo "<p>Membuat pengguna admin default...</p>";
    $admin_password = password_hash('password', PASSWORD_DEFAULT);
    $admin_sql = "INSERT INTO users (username, email, password, full_name, is_verified, is_admin, balance) 
                 VALUES ('admin', 'admin@lelangmobil.com', '$admin_password', 'Administrator', 1, 1, 0)";
    if ($conn->query($admin_sql)) {
        echo "<p style='color:green'>✓ Pengguna admin default berhasil dibuat</p>";
    } else {
        echo "<p style='color:red'>✗ Gagal membuat pengguna admin default: " . $conn->error . "</p>";
    }
} else {
    echo "<p style='color:green'>✓ Pengguna admin default sudah ada</p>";
}

// 5. Create default settings if not exists
echo "<h2>5. Membuat Pengaturan Default</h2>";

$settings = [
    'site_title' => 'LelangMobil - Platform Lelang Mobil Online Terpercaya',
    'site_description' => 'Platform lelang mobil online terpercaya di Indonesia',
    'admin_email' => 'admin@lelangmobil.com',
    'currency' => 'Rp',
    'min_bid_increment_percent' => '5',
    'smtp_host' => 'mail.spacemail.com',
    'smtp_port' => '465',
    'smtp_username' => 'support@zap-hosting.pro',
    'smtp_password' => 'Arunk@123',
    'smtp_secure' => 'ssl',
    'smtp_from_email' => 'support@zap-hosting.pro',
    'smtp_from_name' => 'LelangMobil',
    'notify_admin_new_topup' => '1'
];

foreach ($settings as $key => $value) {
    $setting_check = $conn->query("SELECT * FROM settings WHERE setting_key = '$key'");
    if ($setting_check->num_rows == 0) {
        echo "<p>Membuat pengaturan $key...</p>";
        $setting_sql = "INSERT INTO settings (setting_key, setting_value) VALUES ('$key', '$value')";
        if ($conn->query($setting_sql)) {
            echo "<p style='color:green'>✓ Pengaturan $key berhasil dibuat</p>";
        } else {
            echo "<p style='color:red'>✗ Gagal membuat pengaturan $key: " . $conn->error . "</p>";
        }
    } else {
        echo "<p style='color:green'>✓ Pengaturan $key sudah ada</p>";
    }
}

echo "<h2>Perbaikan Selesai!</h2>";
echo "<p>Semua masalah telah diperbaiki. Aplikasi sekarang siap digunakan.</p>";
echo "<p><a href='index.php'>Kembali ke Beranda</a></p>";
?>