<?php
/**
 * Forgot Password Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if already logged in
if (is_logged_in()) {
    header("Location: account-modern.php");
    exit;
}

$error = '';
$success = '';

// Process form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['forgot_password'])) {
    $email = clean_input($_POST['email'] ?? '');
    
    // Validate email
    if (empty($email)) {
        $error = "Email tidak boleh kosong.";
    } elseif (!is_valid_email($email)) {
        $error = "Format email tidak valid.";
    } else {
        // Check if email exists
        $email_sql = "SELECT * FROM users WHERE email = ?";
        $email_stmt = $conn->prepare($email_sql);
        $email_stmt->bind_param("s", $email);
        $email_stmt->execute();
        $email_result = $email_stmt->get_result();
        
        if ($email_result->num_rows > 0) {
            $user = $email_result->fetch_assoc();
            
            // Generate reset token
            $reset_token = generate_token();
            $expiry = date('Y-m-d H:i:s', strtotime('+1 hour'));
            
            // Save reset token to database
            $update_sql = "UPDATE users SET reset_token = ?, reset_token_expiry = ? WHERE user_id = ?";
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param("ssi", $reset_token, $expiry, $user['user_id']);
            
            if ($update_stmt->execute()) {
                // Send reset password email
                if (function_exists('send_password_reset_email') && send_password_reset_email($conn, $email, $reset_token)) {
                    $success = "Link reset password telah dikirim ke email Anda. Silakan periksa kotak masuk Anda.";
                } else {
                    $error = "Gagal mengirim email reset password. Silakan coba lagi nanti.";
                }
            } else {
                $error = "Terjadi kesalahan. Silakan coba lagi.";
            }
        } else {
            // Don't reveal that email doesn't exist for security reasons
            $success = "Jika email terdaftar, link reset password akan dikirim ke email tersebut.";
        }
    }
}

// Aktifkan flag untuk halaman login
$page_title = "Lupa Password";
$is_auth_page = true;
$use_modern_auth = true;

// Custom CSS untuk halaman auth
$page_specific_css = '<link href="css/login-modern.css" rel="stylesheet" type="text/css">';

// Include header
include("includes/header.php");
?>

<div class="auth-container">
    <div class="auth-card animate">
        <div class="auth-card-header text-center">
            <h2><i class="fa fa-unlock-alt"></i> Lupa Password</h2>
            <p class="text-muted">Masukkan email Anda untuk menerima link reset password</p>
        </div>
        
        <div class="auth-card-body">
            <?php if (!empty($error)): ?>
                <div class="auth-alert auth-alert-danger">
                    <i class="fa fa-exclamation-circle me-2"></i><?php echo $error; ?>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($success)): ?>
                <div class="auth-alert auth-alert-success">
                    <i class="fa fa-check-circle me-2"></i><?php echo $success; ?>
                </div>
                
                <div class="text-center mt-4">
                    <div class="mb-4">
                        <i class="fa fa-envelope fa-3x text-primary"></i>
                    </div>
                    <h4>Email Terkirim!</h4>
                    <p>Silakan periksa kotak masuk email Anda untuk instruksi reset password.</p>
                    <p class="text-muted">Jika Anda tidak menerima email dalam beberapa menit, periksa folder spam atau coba lagi.</p>
                    
                    <div class="mt-4">
                        <a href="login.php" class="auth-btn auth-btn-primary">
                            <i class="fa fa-arrow-left me-2"></i>Kembali ke Login
                        </a>
                    </div>
                </div>
            <?php else: ?>
                <form method="post" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" class="stagger-animate">
                    <div class="auth-form-group">
                        <label for="email" class="auth-form-label">Email</label>
                        <div class="input-group">
                            <span class="input-group-text"><i class="fa fa-envelope"></i></span>
                            <input type="email" class="auth-form-control" id="email" name="email" placeholder="Masukkan email Anda" required>
                        </div>
                    </div>
                    
                    <div class="d-grid mb-4">
                        <button type="submit" name="forgot_password" class="auth-btn auth-btn-primary">
                            <i class="fa fa-paper-plane me-2"></i>Kirim Link Reset Password
                        </button>
                    </div>
                    
                    <div class="text-center">
                        <a href="login.php" class="auth-link">
                            <i class="fa fa-arrow-left me-1"></i> Kembali ke Login
                        </a>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>
</div>

<?php include("includes/footer.php"); ?>