<?php
// Badge Image Generator for Trust Indicators
// This file generates placeholder badge images for the certification section

// Set content type header
header('Content-Type: image/png');

// Create badge images with different colors and icons
$badge_types = [
    'secure-payment' => [
        'color' => [52, 152, 219], // Blue
        'icon' => 'lock',
        'text' => 'SECURE'
    ],
    'certified-dealer' => [
        'color' => [46, 204, 113], // Green
        'icon' => 'certificate',
        'text' => 'CERTIFIED'
    ],
    'verified-vehicles' => [
        'color' => [155, 89, 182], // Purple
        'icon' => 'check',
        'text' => 'VERIFIED'
    ],
    'money-back' => [
        'color' => [230, 126, 34], // Orange
        'icon' => 'shield',
        'text' => 'GUARANTEE'
    ]
];

// Get badge type from query string
$type = isset($_GET['type']) ? $_GET['type'] : 'secure-payment';
$badge_info = isset($badge_types[$type]) ? $badge_types[$type] : $badge_types['secure-payment'];

// Image dimensions
$width = 100;
$height = 100;

// Create image
$image = imagecreatetruecolor($width, $height);

// Enable alpha blending
imagealphablending($image, true);
imagesavealpha($image, true);

// Create colors
$bg_color = imagecolorallocatealpha($image, 255, 255, 255, 127); // Transparent background
$main_color = imagecolorallocate($image, $badge_info['color'][0], $badge_info['color'][1], $badge_info['color'][2]);
$border_color = imagecolorallocate($image, intval($badge_info['color'][0] * 0.8), intval($badge_info['color'][1] * 0.8), intval($badge_info['color'][2] * 0.8));
$text_color = imagecolorallocate($image, 255, 255, 255);
$shadow_color = imagecolorallocate($image, intval($badge_info['color'][0] * 0.7), intval($badge_info['color'][1] * 0.7), intval($badge_info['color'][2] * 0.7));

// Fill background with transparent color
imagefill($image, 0, 0, $bg_color);

// Draw circular badge
$center_x = $width / 2;
$center_y = $height / 2;
$radius = ($width / 2) - 5;

// Draw shadow/glow effect
imagefilledellipse($image, $center_x + 2, $center_y + 2, $radius * 2, $radius * 2, $shadow_color);

// Draw main circle
imagefilledellipse($image, $center_x, $center_y, $radius * 2, $radius * 2, $main_color);

// Draw border
imageellipse($image, $center_x, $center_y, $radius * 2, $radius * 2, $border_color);

// Draw text at the bottom
$badge_text = $badge_info['text'];
$font_size = 3;
$text_width = imagefontwidth($font_size) * strlen($badge_text);
$text_height = imagefontheight($font_size);
$text_x = intval($center_x - ($text_width / 2));
$text_y = intval($center_y + ($radius / 2));

// Add text shadow
imagestring($image, $font_size, $text_x + 1, $text_y + 1, $badge_text, $shadow_color);
// Add text
imagestring($image, $font_size, $text_x, $text_y, $badge_text, $text_color);

// Draw icon symbol based on type
switch ($badge_info['icon']) {
    case 'lock':
        // Lock icon (simplified)
        $lock_width = $radius * 0.8;
        $lock_height = $lock_width * 1.2;
        $lock_x = $center_x - ($lock_width / 2);
        $lock_y = $center_y - $lock_height * 0.7;
        
        // Lock body
        imagefilledrectangle($image, 
            intval($lock_x), 
            intval($lock_y + $lock_height * 0.4), 
            intval($lock_x + $lock_width), 
            intval($lock_y + $lock_height), 
            $text_color);
        
        // Lock shackle
        imagefilledarc($image, 
            intval($center_x), 
            intval($lock_y + $lock_height * 0.4), 
            intval($lock_width), 
            intval($lock_height * 0.7), 
            180, 0, 
            $text_color, 
            IMG_ARC_PIE);
        break;

    case 'certificate':
        // Certificate icon (simplified)
        $cert_size = $radius * 0.8;
        $cert_x = $center_x - ($cert_size / 2);
        $cert_y = $center_y - $cert_size * 0.7;
        
        // Certificate body
        imagefilledrectangle($image, 
            intval($cert_x), 
            intval($cert_y), 
            intval($cert_x + $cert_size), 
            intval($cert_y + $cert_size), 
            $text_color);
        
        // Lines on certificate
        $line_spacing = $cert_size / 4;
        for($i = 1; $i <= 3; $i++) {
            imageline($image, 
                intval($cert_x + $cert_size * 0.2), 
                intval($cert_y + $line_spacing * $i), 
                intval($cert_x + $cert_size * 0.8), 
                intval($cert_y + $line_spacing * $i), 
                $main_color);
        }
        break;

    case 'check':
        // Check mark (simplified)
        $check_size = $radius * 0.8;
        $points = [
            // First point (bottom left of check)
            intval($center_x - $check_size * 0.5), intval($center_y),
            // Middle point (bottom of check)
            intval($center_x - $check_size * 0.1), intval($center_y + $check_size * 0.3),
            // Last point (top right of check)
            intval($center_x + $check_size * 0.5), intval($center_y - $check_size * 0.5)
        ];
        imagesetthickness($image, 3);
        imagepolygon($image, $points, 3, $text_color);
        break;

    case 'shield':
        // Shield icon (simplified)
        $shield_width = $radius * 0.8;
        $shield_height = $shield_width * 1.2;
        $shield_x = $center_x - ($shield_width / 2);
        $shield_y = $center_y - $shield_height * 0.7;
        
        // Shield body
        $shield_points = [
            // Top left
            intval($shield_x), intval($shield_y),
            // Top right
            intval($shield_x + $shield_width), intval($shield_y),
            // Bottom right
            intval($shield_x + $shield_width), intval($shield_y + $shield_height * 0.7),
            // Bottom (middle point)
            intval($center_x), intval($shield_y + $shield_height),
            // Bottom left
            intval($shield_x), intval($shield_y + $shield_height * 0.7)
        ];
        imagefilledpolygon($image, $shield_points, 5, $text_color);
        
        // Shield inner detail
        $inner_points = [
            intval($center_x - $shield_width * 0.3), intval($shield_y + $shield_height * 0.3),
            intval($center_x), intval($shield_y + $shield_height * 0.6),
            intval($center_x + $shield_width * 0.3), intval($shield_y + $shield_height * 0.3)
        ];
        imagefilledpolygon($image, $inner_points, 3, $main_color);
        break;
}

// Output image
imagepng($image);

// Clean up
imagedestroy($image);
?>
