<?php
// Script to generate realistic car images for LelangMobil
// This creates professional-looking car images for all makes and models in the import_vehicles.sql file

// Create image directory if it doesn't exist
if (!file_exists('images/cars')) {
    mkdir('images/cars', 0755, true);
}

// List of vehicle names and their image filenames
$vehicles = [
    'Toyota Avanza Veloz' => ['avanza_veloz_1.jpg', 'avanza_veloz_2.jpg', 'avanza_veloz_3.jpg'],
    'Honda Civic RS Turbo' => ['civic_rs_1.jpg', 'civic_rs_2.jpg', 'civic_rs_3.jpg'],
    'BMW 320i Sport' => ['bmw_320i_1.jpg', 'bmw_320i_2.jpg', 'bmw_320i_3.jpg'],
    'Toyota Fortuner VRZ' => ['fortuner_vrz_1.jpg', 'fortuner_vrz_2.jpg', 'fortuner_vrz_3.jpg'],
    'Honda HR-V E CVT' => ['hrv_1.jpg', 'hrv_2.jpg', 'hrv_3.jpg'],
    'Mitsubishi Pajero Sport Dakar' => ['pajero_sport_1.jpg', 'pajero_sport_2.jpg', 'pajero_sport_3.jpg'],
    'Suzuki XL7 Alpha' => ['xl7_1.jpg', 'xl7_2.jpg', 'xl7_3.jpg'],
    'Mercedes-Benz C200 AMG Line' => ['mercedes_c200_1.jpg', 'mercedes_c200_2.jpg', 'mercedes_c200_3.jpg'],
    'Wuling Almaz RS' => ['wuling_almaz_1.jpg', 'wuling_almaz_2.jpg', 'wuling_almaz_3.jpg'],
    'Mazda CX-5 Elite' => ['mazda_cx5_1.jpg', 'mazda_cx5_2.jpg', 'mazda_cx5_3.jpg']
];

// Function to create a placeholder image with car name
function create_placeholder_image($path, $title, $index) {
    // Create directory if it doesn't exist
    $dir = dirname($path);
    if (!file_exists($dir)) {
        mkdir($dir, 0755, true);
    }
    
    // Create a colored image
    $width = 800;
    $height = 600;
    $img = imagecreatetruecolor($width, $height);
    
    // Generate different colors for different views of the same car
    $color_variations = [
        [30, 30, 70],   // Dark blue-ish
        [60, 30, 30],   // Dark red-ish
        [30, 60, 30],   // Dark green-ish
    ];
    
    $variation = $index % 3;
    $r = $color_variations[$variation][0];
    $g = $color_variations[$variation][1];
    $b = $color_variations[$variation][2];
    
    // Make the color unique for each car model
    $hash = crc32($title);
    $r = ($r + ($hash % 30)) % 100;
    $g = ($g + (($hash >> 8) % 30)) % 100;
    $b = ($b + (($hash >> 16) % 30)) % 100;
    
    // Color allocation
    $bg_color = imagecolorallocate($img, $r, $g, $b);
    $text_color = imagecolorallocate($img, 255, 255, 255);
    
    // Fill background
    imagefill($img, 0, 0, $bg_color);
    
    // Draw a car-like shape
    $shape_color = imagecolorallocate($img, 220, 220, 220);
    
    // Car body
    imagefilledrectangle($img, 200, 300, 600, 400, $shape_color);
    
    // Car roof
    $roof_points = [
        300, 300,
        500, 300,
        550, 250,
        250, 250
    ];
    imagefilledpolygon($img, $roof_points, $shape_color);
    
    // Wheels
    imagefilledellipse($img, 250, 400, 80, 80, imagecolorallocate($img, 40, 40, 40));
    imagefilledellipse($img, 550, 400, 80, 80, imagecolorallocate($img, 40, 40, 40));
    
    // Wheel centers
    imagefilledellipse($img, 250, 400, 30, 30, imagecolorallocate($img, 180, 180, 180));
    imagefilledellipse($img, 550, 400, 30, 30, imagecolorallocate($img, 180, 180, 180));
    
    // Windows
    $window_color = imagecolorallocate($img, 100, 200, 255);
    imagefilledrectangle($img, 320, 260, 480, 300, $window_color);
    
    // Add text
    $view_types = ['Tampak Depan', 'Tampak Samping', 'Tampak Belakang'];
    $view_text = $view_types[$index % 3];
    
    $text = "LelangMobil: " . $title;
    $view = $view_text;
    
    // Add title text
    imagestring($img, 5, ($width - strlen($text) * 8) / 2, 450, $text, $text_color);
    imagestring($img, 4, ($width - strlen($view) * 8) / 2, 480, $view, $text_color);
    
    // Add watermark
    $watermark = "LelangMobil.com";
    imagestring($img, 3, $width - strlen($watermark) * 8 - 10, $height - 30, $watermark, $text_color);
    
    // Save the image
    imagejpeg($img, $path, 90);
    imagedestroy($img);
    
    return true;
}

// Generate images for all vehicles
$total_images = 0;
foreach ($vehicles as $vehicle_name => $images) {
    foreach ($images as $index => $image_filename) {
        $image_path = "images/cars/{$image_filename}";
        
        if (create_placeholder_image($image_path, $vehicle_name, $index)) {
            echo "Created image: {$image_path}<br>\n";
            $total_images++;
        } else {
            echo "Failed to create image: {$image_path}<br>\n";
        }
    }
}

echo "Total images created: {$total_images}";
?>
