<?php
// Generate professional menu images for LelangMobil
// This script creates visually appealing images for the stylish menu

// Menu image configurations
$menu_images = [
    [
        'name' => 'home-menu.jpg',
        'title' => 'Beranda',
        'color' => [20, 40, 80], // Dark blue
        'icon' => '🏠'
    ],
    [
        'name' => 'auction-menu.jpg',
        'title' => 'Lelang Aktif',
        'color' => [30, 80, 40], // Green
        'icon' => '🔨'
    ],
    [
        'name' => 'premium-menu.jpg',
        'title' => 'Mobil Premium',
        'color' => [120, 20, 30], // Red
        'icon' => '⭐'
    ],
    [
        'name' => 'sell-menu.jpg',
        'title' => 'Jual Mobil',
        'color' => [80, 60, 20], // Orange-ish
        'icon' => '🚗'
    ],
    [
        'name' => 'how-menu.jpg',
        'title' => 'Cara Kerja',
        'color' => [60, 30, 80], // Purple
        'icon' => 'ℹ️'
    ]
];

// Create menu image directory if it doesn't exist
$menu_dir = 'images/menu';
if (!file_exists($menu_dir)) {
    mkdir($menu_dir, 0755, true);
}

// Function to generate visually appealing menu images
function generate_menu_image($config, $dir) {
    $width = 800;
    $height = 400;
    $img = imagecreatetruecolor($width, $height);
    
    // Extract color from config
    $r = $config['color'][0];
    $g = $config['color'][1];
    $b = $config['color'][2];
    
    // Create gradient effect (dark to light)
    $steps = $height;
    for ($i = 0; $i < $steps; $i++) {
        // Adjust color values based on position
        $ratio = $i / $steps;
        $curr_r = min(255, $r + (50 * $ratio));
        $curr_g = min(255, $g + (50 * $ratio));
        $curr_b = min(255, $b + (50 * $ratio));
        
        $line_color = imagecolorallocate($img, $curr_r, $curr_g, $curr_b);
        imageline($img, 0, $i, $width, $i, $line_color);
    }
    
    // Add some design elements - diagonal lines
    $accent_color = imagecolorallocate($img, 255, 255, 255);
    $accent_alpha = 30; // Alpha transparency (0-127, 0 = opaque, 127 = transparent)
    
    for ($i = 0; $i < $width * 2; $i += 30) {
        // Diagonal lines from top left to bottom right
        imageline($img, $i, 0, 0, $i, $accent_color);
    }
    
    // Add automotive graphics
    $graphic_color = imagecolorallocate($img, 255, 255, 255);
    $graphic_alpha = 30;
    
    // Simple car silhouette
    $car_points = [
        $width * 0.6, $height * 0.6,  // Car top right
        $width * 0.8, $height * 0.7,  // Car back
        $width * 0.8, $height * 0.8,  // Car bottom back
        $width * 0.2, $height * 0.8,  // Car bottom front
        $width * 0.3, $height * 0.7,  // Car front
        $width * 0.4, $height * 0.6   // Car top left
    ];
    
    // Fill car silhouette
    imagefilledpolygon($img, $car_points, 6, $graphic_color);
    
    // Add wheels
    imagefilledellipse($img, $width * 0.3, $height * 0.8, $width * 0.1, $height * 0.1, imagecolorallocate($img, 50, 50, 50));
    imagefilledellipse($img, $width * 0.7, $height * 0.8, $width * 0.1, $height * 0.1, imagecolorallocate($img, 50, 50, 50));
    
    // Add title text
    $title = $config['title'];
    $text_color = imagecolorallocate($img, 255, 255, 255);
    $shadow_color = imagecolorallocate($img, 0, 0, 0);
    
    // Use larger built-in font
    $font_size = 5;
    $icon = $config['icon'];
    
    // Calculate text position for center alignment
    $text_width = strlen($title) * imagefontwidth($font_size);
    $text_x = ($width - $text_width) / 2;
    
    // Add text shadow
    imagestring($img, $font_size, $text_x + 2, 92, $title, $shadow_color);
    
    // Add text
    imagestring($img, $font_size, $text_x, 90, $title, $text_color);
    
    // Add icon (simplified as we can't use emoji directly)
    $icon_text = $icon . " ";
    imagestring($img, 5, $text_x - 30, 90, $icon_text, $text_color);
    
    // Add LelangMobil watermark
    $watermark = "LelangMobil";
    $watermark_width = strlen($watermark) * imagefontwidth(3);
    $watermark_x = ($width - $watermark_width) / 2;
    imagestring($img, 3, $watermark_x, $height - 30, $watermark, $text_color);
    
    // Save the image
    $output_path = $dir . '/' . $config['name'];
    imagejpeg($img, $output_path, 90);
    imagedestroy($img);
    
    return $output_path;
}

// Generate all menu images
$generated = [];
foreach ($menu_images as $config) {
    $path = generate_menu_image($config, $menu_dir);
    $generated[] = $path;
}

// Output results
echo "<h1>LelangMobil - Menu Image Generator</h1>";
echo "<p>Generated " . count($generated) . " menu images:</p>";
echo "<ul>";
foreach ($generated as $path) {
    echo "<li>{$path} - <span style='color: green;'>✓</span></li>";
}
echo "</ul>";
echo "<p><a href='index.php'>Kembali ke Halaman Utama</a></p>";
?>
