<?php
// Import script for adding vehicle data from various auction listings
// This script will add vehicle data to the LelangMobil system
require_once 'config/database.php';
require_once 'config/functions.php';

// Start session if not already started
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Verify admin privileges
if (!isset($_SESSION['user_id']) || !isset($_SESSION['is_admin']) || $_SESSION['is_admin'] != 1) {
    die("Access denied. Admin privileges required.");
}

// Prepare response
$response = [
    'success' => true,
    'message' => '',
    'vehicles_added' => 0,
    'errors' => []
];

// Function to import vehicles
function import_vehicles($conn) {
    global $response;
    
    // Sample vehicle data based on typical auction listings
    $vehicles = [
        [
            'title' => 'Toyota Avanza Veloz 1.5 AT 2022',
            'description' => 'Toyota Avanza Veloz 1.5 AT 2022 dalam kondisi sangat baik. Mobil ini memiliki transmisi otomatis, AC dingin, interior terawat, dan eksterior mulus tanpa goresan. Surat-surat lengkap, pajak aktif, dan servis rutin di bengkel resmi Toyota.',
            'make' => 'Toyota',
            'model' => 'Avanza Veloz',
            'year' => 2022,
            'mileage' => 25000,
            'condition_rating' => 9,
            'body_type' => 'MPV',
            'fuel_type' => 'Bensin',
            'transmission' => 'Otomatis',
            'color' => 'Hitam',
            'engine_size' => 1496,
            'starting_price' => 195000000,
            'reserve_price' => 210000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+7 days')),
            'location' => 'Jakarta',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror'],
            'specs' => [
                ['Kapasitas Mesin', '1496 cc'],
                ['Tenaga Maksimum', '106 PS'],
                ['Jumlah Tempat Duduk', '7'],
                ['Kapasitas Tangki', '43 Liter']
            ],
            'images' => [
                'images/cars/avanza_veloz_1.jpg',
                'images/cars/avanza_veloz_2.jpg',
                'images/cars/avanza_veloz_3.jpg'
            ]
        ],
        [
            'title' => 'Honda Civic RS Turbo 2021',
            'description' => 'Honda Civic RS Turbo 2021 dengan fitur canggih dan performa tinggi. Mobil sport dengan mesin turbo 1.5L bertenaga 173 PS yang responsif. Interior premium dengan layar sentuh dan Apple CarPlay/Android Auto. Kondisi seperti baru dan siap pakai.',
            'make' => 'Honda',
            'model' => 'Civic RS Turbo',
            'year' => 2021,
            'mileage' => 15000,
            'condition_rating' => 9,
            'body_type' => 'Sedan',
            'fuel_type' => 'Bensin',
            'transmission' => 'Otomatis',
            'color' => 'Merah',
            'engine_size' => 1498,
            'starting_price' => 385000000,
            'reserve_price' => 400000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+5 days')),
            'location' => 'Surabaya',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera', 'Keyless Entry', 'Push Start Button'],
            'specs' => [
                ['Kapasitas Mesin', '1498 cc'],
                ['Tenaga Maksimum', '173 PS'],
                ['Torsi Maksimum', '220 Nm'],
                ['Jumlah Tempat Duduk', '5'],
                ['Kapasitas Tangki', '47 Liter']
            ],
            'images' => [
                'images/cars/civic_rs_1.jpg',
                'images/cars/civic_rs_2.jpg',
                'images/cars/civic_rs_3.jpg'
            ]
        ],
        [
            'title' => 'BMW 320i Sport 2020',
            'description' => 'BMW 320i Sport 2020 dengan performa premium dan fitur mewah. Mobil sport sedan dengan mesin 2.0L bertenaga 184 HP yang responsif. Interior premium dengan layar sentuh dan sistem navigasi. Kondisi seperti baru dan siap pakai.',
            'make' => 'BMW',
            'model' => '320i Sport',
            'year' => 2020,
            'mileage' => 18000,
            'condition_rating' => 9,
            'body_type' => 'Sedan',
            'fuel_type' => 'Bensin',
            'transmission' => 'Otomatis',
            'color' => 'Putih',
            'engine_size' => 1998,
            'starting_price' => 680000000,
            'reserve_price' => 700000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+6 days')),
            'location' => 'Jakarta',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera', 'Keyless Entry', 'Push Start Button', 'Navigation System', 'Bluetooth Connection'],
            'specs' => [
                ['Kapasitas Mesin', '1998 cc'],
                ['Tenaga Maksimum', '184 HP'],
                ['Torsi Maksimum', '300 Nm'],
                ['Jumlah Tempat Duduk', '5'],
                ['Kapasitas Tangki', '59 Liter']
            ],
            'images' => [
                'images/cars/bmw_320i_1.jpg',
                'images/cars/bmw_320i_2.jpg',
                'images/cars/bmw_320i_3.jpg'
            ]
        ],
        [
            'title' => 'Toyota Fortuner VRZ 2.4 2021',
            'description' => 'Toyota Fortuner VRZ 2.4 2021 hadir dengan desain tangguh dan performa handal. SUV premium dengan mesin diesel 2.4L bertenaga 149 PS. Interior mewah dengan 7 tempat duduk nyaman. Fitur lengkap dan kondisi terawat.',
            'make' => 'Toyota',
            'model' => 'Fortuner VRZ',
            'year' => 2021,
            'mileage' => 32000,
            'condition_rating' => 8,
            'body_type' => 'SUV',
            'fuel_type' => 'Solar',
            'transmission' => 'Otomatis',
            'color' => 'Hitam',
            'engine_size' => 2393,
            'starting_price' => 490000000,
            'reserve_price' => 510000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+4 days')),
            'location' => 'Bandung',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera', 'Keyless Entry', 'Push Start Button', 'Navigation System'],
            'specs' => [
                ['Kapasitas Mesin', '2393 cc'],
                ['Tenaga Maksimum', '149 PS'],
                ['Torsi Maksimum', '400 Nm'],
                ['Jumlah Tempat Duduk', '7'],
                ['Kapasitas Tangki', '80 Liter']
            ],
            'images' => [
                'images/cars/fortuner_vrz_1.jpg',
                'images/cars/fortuner_vrz_2.jpg',
                'images/cars/fortuner_vrz_3.jpg'
            ]
        ],
        [
            'title' => 'Honda HR-V 1.5 E CVT 2022',
            'description' => 'Honda HR-V 1.5 E CVT 2022 dengan desain modern dan efisiensi bahan bakar tinggi. SUV kompak dengan performa handal dan fitur canggih. Interior nyaman dengan layar sentuh dan konektivitas smartphone. Kondisi sangat terawat.',
            'make' => 'Honda',
            'model' => 'HR-V E CVT',
            'year' => 2022,
            'mileage' => 12000,
            'condition_rating' => 9,
            'body_type' => 'SUV',
            'fuel_type' => 'Bensin',
            'transmission' => 'CVT',
            'color' => 'Abu-abu',
            'engine_size' => 1498,
            'starting_price' => 345000000,
            'reserve_price' => 360000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+8 days')),
            'location' => 'Surabaya',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera', 'Keyless Entry'],
            'specs' => [
                ['Kapasitas Mesin', '1498 cc'],
                ['Tenaga Maksimum', '121 PS'],
                ['Torsi Maksimum', '145 Nm'],
                ['Jumlah Tempat Duduk', '5'],
                ['Kapasitas Tangki', '40 Liter']
            ],
            'images' => [
                'images/cars/hrv_1.jpg',
                'images/cars/hrv_2.jpg',
                'images/cars/hrv_3.jpg'
            ]
        ],
        [
            'title' => 'Mitsubishi Pajero Sport Dakar 2020',
            'description' => 'Mitsubishi Pajero Sport Dakar 2020 dengan tampilan gagah dan fitur lengkap. SUV tangguh dengan mesin diesel 2.4L bertenaga 178 PS. Interior premium dengan 7 tempat duduk nyaman. Kondisi sangat baik dan siap digunakan.',
            'make' => 'Mitsubishi',
            'model' => 'Pajero Sport Dakar',
            'year' => 2020,
            'mileage' => 38000,
            'condition_rating' => 8,
            'body_type' => 'SUV',
            'fuel_type' => 'Solar',
            'transmission' => 'Otomatis',
            'color' => 'Putih',
            'engine_size' => 2442,
            'starting_price' => 475000000,
            'reserve_price' => 495000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+3 days')),
            'location' => 'Jakarta',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera', 'Keyless Entry', 'Push Start Button', 'Navigation System'],
            'specs' => [
                ['Kapasitas Mesin', '2442 cc'],
                ['Tenaga Maksimum', '178 PS'],
                ['Torsi Maksimum', '430 Nm'],
                ['Jumlah Tempat Duduk', '7'],
                ['Kapasitas Tangki', '68 Liter']
            ],
            'images' => [
                'images/cars/pajero_sport_1.jpg',
                'images/cars/pajero_sport_2.jpg',
                'images/cars/pajero_sport_3.jpg'
            ]
        ],
        [
            'title' => 'Suzuki XL7 Alpha 2021',
            'description' => 'Suzuki XL7 Alpha 2021 dengan desain sporty dan kabin lapang. Crossover 7-seater dengan mesin 1.5L bertenaga 104 PS. Interior nyaman dengan layar sentuh dan konektivitas smartphone. Kondisi sangat baik dan siap digunakan.',
            'make' => 'Suzuki',
            'model' => 'XL7 Alpha',
            'year' => 2021,
            'mileage' => 22000,
            'condition_rating' => 8,
            'body_type' => 'SUV',
            'fuel_type' => 'Bensin',
            'transmission' => 'Otomatis',
            'color' => 'Merah',
            'engine_size' => 1462,
            'starting_price' => 240000000,
            'reserve_price' => 255000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+6 days')),
            'location' => 'Bandung',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera'],
            'specs' => [
                ['Kapasitas Mesin', '1462 cc'],
                ['Tenaga Maksimum', '104 PS'],
                ['Torsi Maksimum', '138 Nm'],
                ['Jumlah Tempat Duduk', '7'],
                ['Kapasitas Tangki', '45 Liter']
            ],
            'images' => [
                'images/cars/xl7_1.jpg',
                'images/cars/xl7_2.jpg',
                'images/cars/xl7_3.jpg'
            ]
        ],
        [
            'title' => 'Mercedes-Benz C200 AMG Line 2021',
            'description' => 'Mercedes-Benz C200 AMG Line 2021 dengan tampilan mewah dan performa tinggi. Sedan premium dengan mesin 1.5L turbo bertenaga 184 HP. Interior premium dengan layar digital dan fitur canggih. Kondisi istimewa dengan kilometer rendah.',
            'make' => 'Mercedes-Benz',
            'model' => 'C200 AMG Line',
            'year' => 2021,
            'mileage' => 9000,
            'condition_rating' => 10,
            'body_type' => 'Sedan',
            'fuel_type' => 'Bensin',
            'transmission' => 'Otomatis',
            'color' => 'Hitam',
            'engine_size' => 1497,
            'starting_price' => 850000000,
            'reserve_price' => 875000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+10 days')),
            'location' => 'Jakarta',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera', 'Keyless Entry', 'Push Start Button', 'Navigation System', 'Bluetooth Connection'],
            'specs' => [
                ['Kapasitas Mesin', '1497 cc'],
                ['Tenaga Maksimum', '184 HP'],
                ['Torsi Maksimum', '280 Nm'],
                ['Jumlah Tempat Duduk', '5'],
                ['Kapasitas Tangki', '66 Liter']
            ],
            'images' => [
                'images/cars/mercedes_c200_1.jpg',
                'images/cars/mercedes_c200_2.jpg',
                'images/cars/mercedes_c200_3.jpg'
            ]
        ],
        [
            'title' => 'Wuling Almaz RS 2022',
            'description' => 'Wuling Almaz RS 2022 dengan fitur canggih dan teknologi terdepan. SUV premium dengan mesin 1.5L turbo bertenaga 140 PS. Interior mewah dengan voice command dan smart connectivity. Kondisi sangat terawat dan siap pakai.',
            'make' => 'Wuling',
            'model' => 'Almaz RS',
            'year' => 2022,
            'mileage' => 15000,
            'condition_rating' => 9,
            'body_type' => 'SUV',
            'fuel_type' => 'Bensin',
            'transmission' => 'CVT',
            'color' => 'Putih',
            'engine_size' => 1451,
            'starting_price' => 275000000,
            'reserve_price' => 290000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+5 days')),
            'location' => 'Semarang',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera', 'Keyless Entry', 'Push Start Button', 'Navigation System', 'Voice Command'],
            'specs' => [
                ['Kapasitas Mesin', '1451 cc'],
                ['Tenaga Maksimum', '140 PS'],
                ['Torsi Maksimum', '250 Nm'],
                ['Jumlah Tempat Duduk', '7'],
                ['Kapasitas Tangki', '60 Liter']
            ],
            'images' => [
                'images/cars/wuling_almaz_1.jpg',
                'images/cars/wuling_almaz_2.jpg',
                'images/cars/wuling_almaz_3.jpg'
            ]
        ],
        [
            'title' => 'Mazda CX-5 Elite 2020',
            'description' => 'Mazda CX-5 Elite 2020 dengan desain elegan dan performa prima. SUV premium dengan mesin 2.5L bertenaga 187 HP. Interior mewah dengan material berkualitas tinggi. Kilometer rendah dan kondisi sangat baik.',
            'make' => 'Mazda',
            'model' => 'CX-5 Elite',
            'year' => 2020,
            'mileage' => 21000,
            'condition_rating' => 9,
            'body_type' => 'SUV',
            'fuel_type' => 'Bensin',
            'transmission' => 'Otomatis',
            'color' => 'Merah',
            'engine_size' => 2488,
            'starting_price' => 420000000,
            'reserve_price' => 440000000,
            'auction_end' => date('Y-m-d H:i:s', strtotime('+7 days')),
            'location' => 'Jakarta',
            'features' => ['AC', 'Power Steering', 'Power Window', 'Central Lock', 'Audio System', 'Airbag', 'Electric Mirror', 'Parking Camera', 'Keyless Entry', 'Push Start Button', 'Navigation System'],
            'specs' => [
                ['Kapasitas Mesin', '2488 cc'],
                ['Tenaga Maksimum', '187 HP'],
                ['Torsi Maksimum', '252 Nm'],
                ['Jumlah Tempat Duduk', '5'],
                ['Kapasitas Tangki', '58 Liter']
            ],
            'images' => [
                'images/cars/mazda_cx5_1.jpg',
                'images/cars/mazda_cx5_2.jpg',
                'images/cars/mazda_cx5_3.jpg'
            ]
        ]
    ];
    
    // Create vehicle images directory if it doesn't exist
    if (!file_exists('images/cars')) {
        mkdir('images/cars', 0755, true);
    }
    
    // Create placeholder images with car names
    foreach ($vehicles as $vehicle) {
        foreach ($vehicle['images'] as $image_path) {
            create_placeholder_image($image_path, $vehicle['title']);
        }
    }
    
    // Start transaction
    $conn->begin_transaction();
    
    try {
        // Check if feature and specs tables exist
        $check_features_table = $conn->query("SHOW TABLES LIKE 'vehicle_features'");
        $has_features_table = $check_features_table->num_rows > 0;
        
        // Add vehicles one by one
        foreach ($vehicles as $vehicle_data) {
            // Check if table has new columns
            $check_body_type = $conn->query("SHOW COLUMNS FROM vehicles LIKE 'body_type'");
            $has_new_columns = $check_body_type->num_rows > 0;
            
            // Prepare SQL query based on available columns
            if ($has_new_columns) {
                $sql = "INSERT INTO vehicles (
                        title, description, make, model, year, mileage, condition_rating,
                        body_type, fuel_type, transmission, color, engine_size,
                        starting_price, reserve_price, auction_start, auction_end,
                        status, seller_id, location
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), ?, 'active', ?, ?)";
                
                $stmt = $conn->prepare($sql);
                $stmt->bind_param(
                    "ssssiisissiiddsis",
                    $vehicle_data['title'],
                    $vehicle_data['description'],
                    $vehicle_data['make'],
                    $vehicle_data['model'],
                    $vehicle_data['year'],
                    $vehicle_data['mileage'],
                    $vehicle_data['condition_rating'],
                    $vehicle_data['body_type'],
                    $vehicle_data['fuel_type'],
                    $vehicle_data['transmission'],
                    $vehicle_data['color'],
                    $vehicle_data['engine_size'],
                    $vehicle_data['starting_price'],
                    $vehicle_data['reserve_price'],
                    $vehicle_data['auction_end'],
                    $_SESSION['user_id'],
                    $vehicle_data['location']
                );
            } else {
                $sql = "INSERT INTO vehicles (
                        title, description, make, model, year, mileage, condition_rating,
                        starting_price, reserve_price, auction_start, auction_end,
                        status, seller_id
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), ?, 'active', ?)";
                
                $stmt = $conn->prepare($sql);
                $stmt->bind_param(
                    "ssssiiiidsi",
                    $vehicle_data['title'],
                    $vehicle_data['description'],
                    $vehicle_data['make'],
                    $vehicle_data['model'],
                    $vehicle_data['year'],
                    $vehicle_data['mileage'],
                    $vehicle_data['condition_rating'],
                    $vehicle_data['starting_price'],
                    $vehicle_data['reserve_price'],
                    $vehicle_data['auction_end'],
                    $_SESSION['user_id']
                );
            }
            
            $stmt->execute();
            $vehicle_id = $conn->insert_id;
            
            // Add features if the table exists
            if ($has_features_table && !empty($vehicle_data['features'])) {
                $feature_sql = "INSERT INTO vehicle_features (vehicle_id, feature_name, feature_icon, is_highlighted) VALUES (?, ?, ?, ?)";
                $feature_stmt = $conn->prepare($feature_sql);
                
                foreach ($vehicle_data['features'] as $index => $feature) {
                    $icon = 'fa-check';
                    $highlighted = $index < 3 ? 1 : 0; // Highlight first 3 features
                    $feature_stmt->bind_param("issi", $vehicle_id, $feature, $icon, $highlighted);
                    $feature_stmt->execute();
                }
            }
            
            // Add specs
            $spec_sql = "INSERT INTO vehicle_specs (vehicle_id, spec_name, spec_value) VALUES (?, ?, ?)";
            $spec_stmt = $conn->prepare($spec_sql);
            
            foreach ($vehicle_data['specs'] as $spec) {
                $spec_stmt->bind_param("iss", $vehicle_id, $spec[0], $spec[1]);
                $spec_stmt->execute();
            }
            
            // Add images
            $image_sql = "INSERT INTO vehicle_images (vehicle_id, image_url, is_main) VALUES (?, ?, ?)";
            $image_stmt = $conn->prepare($image_sql);
            
            foreach ($vehicle_data['images'] as $index => $image_path) {
                $is_main = ($index == 0) ? 1 : 0; // First image is main
                $image_stmt->bind_param("isi", $vehicle_id, $image_path, $is_main);
                $image_stmt->execute();
            }
            
            $response['vehicles_added']++;
        }
        
        // Commit transaction
        $conn->commit();
        $response['message'] = "Successfully added {$response['vehicles_added']} vehicles to the system.";
        
    } catch (Exception $e) {
        // Rollback on error
        $conn->rollback();
        $response['success'] = false;
        $response['message'] = "Error: " . $e->getMessage();
        $response['errors'][] = $e->getMessage();
    }
    
    return $response;
}

// Function to create a placeholder image with car name
function create_placeholder_image($path, $title) {
    // Create directory if it doesn't exist
    $dir = dirname($path);
    if (!file_exists($dir)) {
        mkdir($dir, 0755, true);
    }
    
    // Only create if file doesn't exist
    if (!file_exists($path)) {
        // Create a black image
        $width = 800;
        $height = 600;
        $img = imagecreatetruecolor($width, $height);
        
        // Color allocation
        $bg_color = imagecolorallocate($img, rand(0, 100), rand(0, 100), rand(0, 100));
        $text_color = imagecolorallocate($img, 255, 255, 255);
        
        // Fill background
        imagefill($img, 0, 0, $bg_color);
        
        // Add text
        $font_size = 20;
        $text = "Lelang Mobil: " . $title;
        
        // Center the text
        $text_box = imagettfbbox($font_size, 0, 'arial.ttf', $text);
        
        // Use simple text if TTF not available
        imagestring($img, 5, ($width - strlen($text) * 8) / 2, $height / 2, $text, $text_color);
        
        // Save the image
        imagejpeg($img, $path, 90);
        imagedestroy($img);
    }
}

// Run the vehicle import
$result = import_vehicles($conn);

// Output the result
header('Content-Type: application/json');
echo json_encode($result, JSON_PRETTY_PRINT);
?>
