<?php
/**
 * Bids Tab Component
 * LelangMobil Web App - Versi 2025
 */

// Get recent bids if not already available
if (!isset($recent_bids)) {
    try {
// Ganti query di bids-tab.php
$recent_bids_sql = "SELECT b.*, v.brand, v.model, v.year, v.current_bid, v.end_date, v.image as main_image
                   FROM bids b
                   JOIN vehicles v ON b.vehicle_id = v.vehicle_id
                   WHERE b.bidder_id = ?
                   ORDER BY b.bid_time DESC
                   LIMIT 5";

        $recent_bids_stmt = $conn->prepare($recent_bids_sql);
        $recent_bids_stmt->bind_param("i", $user_id);
        $recent_bids_stmt->execute();
        $recent_bids_result = $recent_bids_stmt->get_result();
        $recent_bids = [];
        while ($row = $recent_bids_result->fetch_assoc()) {
            $recent_bids[] = $row;
        }
    } catch (Throwable $e) {
        // Handle error silently
    }
}
?>

<div class="tab-header d-flex justify-content-between align-items-center mb-4">
    <h4>Riwayat Bid Terbaru</h4>
    <a href="bids-modern.php" class="btn-2025 btn-2025-primary btn-2025-sm">
        <i class="fa fa-list me-2"></i>Lihat Semua
    </a>
</div>

<?php if (empty($recent_bids)): ?>
<div class="empty-state text-center py-5">
    <i class="fa fa-gavel fa-4x text-muted mb-3"></i>
    <h5>Belum Ada Bid</h5>
    <p class="text-muted">Anda belum melakukan bid pada lelang apapun.</p>
    <a href="auctions.php" class="btn-2025 btn-2025-primary mt-3">
        <i class="fa fa-search me-2"></i>Cari Lelang
    </a>
</div>
<?php else: ?>
<div class="table-responsive">
    <table class="table-2025">
        <thead>
            <tr>
                <th>Kendaraan</th>
                <th>Jumlah Bid</th>
                <th>Waktu</th>
                <th>Status</th>
                <th>Aksi</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($recent_bids as $bid): ?>
            <tr>
                <td>
                    <div class="d-flex align-items-center">
                        <?php if (!empty($bid['main_image'])): ?>
                        <img src="<?php echo $bid['main_image']; ?>" alt="<?php echo $bid['brand'] . ' ' . $bid['model']; ?>" class="bid-vehicle-image me-3">
                        <?php else: ?>
                        <div class="bid-vehicle-placeholder me-3">
                            <i class="fa fa-car"></i>
                        </div>
                        <?php endif; ?>
                        <div>
                            <div class="bid-vehicle-name"><?php echo $bid['brand'] . ' ' . $bid['model'] . ' ' . $bid['year']; ?></div>
                            <div class="bid-vehicle-id">ID: <?php echo $bid['vehicle_id']; ?></div>
                        </div>
                    </div>
                </td>
                <td>
                    <div class="bid-amount"><?php echo format_money($bid['bid_amount']); ?></div>
                </td>
                <td>
                    <div class="bid-time"><?php echo date('d M Y H:i', strtotime($bid['bid_time'])); ?></div>
                </td>
                <td>
                    <?php if ($bid['is_winning']): ?>
                    <span class="badge-2025 badge-2025-soft-success">Tertinggi</span>
                    <?php elseif (strtotime($bid['end_date']) < time()): ?>
                    <span class="badge-2025 badge-2025-soft-danger">Kalah</span>
                    <?php else: ?>
                    <span class="badge-2025 badge-2025-soft-warning">Aktif</span>
                    <?php endif; ?>
                </td>
                <td>
                    <a href="vehicle.php?id=<?php echo $bid['vehicle_id']; ?>" class="btn-2025 btn-2025-sm btn-2025-outline">
                        <i class="fa fa-eye"></i>
                    </a>
                </td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>
<?php endif; ?>

<style>
.bid-vehicle-image {
    width: 50px;
    height: 50px;
    border-radius: var(--border-radius);
    object-fit: cover;
}

.bid-vehicle-placeholder {
    width: 50px;
    height: 50px;
    border-radius: var(--border-radius);
    background-color: rgba(0,0,0,0.05);
    display: flex;
    align-items: center;
    justify-content: center;
    color: var(--text-color-light);
}

.bid-vehicle-name {
    font-weight: 600;
    font-size: 0.9rem;
}

.bid-vehicle-id {
    font-size: 0.8rem;
    color: var(--text-color-light);
}

.bid-amount {
    font-weight: 600;
    color: var(--primary);
}

.bid-time {
    font-size: 0.85rem;
    color: var(--text-color-light);
}

.empty-state {
    padding: 30px;
    text-align: center;
}

.empty-state i {
    color: #ccc;
}
</style>