<?php
/**
 * Dashboard Stats
 * LelangMobil Web App - Versi 2025
 */

// Get user information
$user_id = $_SESSION['user_id'];

try {
    // Get user balance
    $balance_sql = "SELECT balance, pending_balance FROM users WHERE user_id = ?";
    $balance_stmt = $conn->prepare($balance_sql);
    $balance_stmt->bind_param("i", $user_id);
    $balance_stmt->execute();
    $balance_result = $balance_stmt->get_result();
    $balance_data = $balance_result->fetch_assoc();
    
    $balance = $balance_data['balance'] ?? 0;
    $pending_balance = $balance_data['pending_balance'] ?? 0;
    
    // Get active bids count
    $active_bids_sql = "SELECT COUNT(*) as count FROM bids b 
                        JOIN vehicles v ON b.vehicle_id = v.vehicle_id 
                        WHERE b.bidder_id = ? AND v.status = 'active'";
    $active_bids_stmt = $conn->prepare($active_bids_sql);
    $active_bids_stmt->bind_param("i", $user_id);
    $active_bids_stmt->execute();
    $active_bids_result = $active_bids_stmt->get_result();
    $active_bids_count = $active_bids_result->fetch_assoc()['count'];
    
    // Get won auctions count
    $won_auctions_sql = "SELECT COUNT(*) as count FROM vehicles 
                         WHERE current_bidder = ? AND status = 'sold'";
    $won_auctions_stmt = $conn->prepare($won_auctions_sql);
    $won_auctions_stmt->bind_param("i", $user_id);
    $won_auctions_stmt->execute();
    $won_auctions_result = $won_auctions_stmt->get_result();
    $won_auctions_count = $won_auctions_result->fetch_assoc()['count'];
    
    // Get pending transactions count
    $pending_transactions_sql = "SELECT COUNT(*) as count FROM transactions 
                                WHERE user_id = ? AND status IN ('pending', 'verification')";
    $pending_transactions_stmt = $conn->prepare($pending_transactions_sql);
    $pending_transactions_stmt->bind_param("i", $user_id);
    $pending_transactions_stmt->execute();
    $pending_transactions_result = $pending_transactions_stmt->get_result();
    $pending_transactions_count = $pending_transactions_result->fetch_assoc()['count'];
} catch (Exception $e) {
    error_log("Error in dashboard-stats.php: " . $e->getMessage());
    $balance = 0;
    $pending_balance = 0;
    $active_bids_count = 0;
    $won_auctions_count = 0;
    $pending_transactions_count = 0;
}
?>

<!-- Wallet Widget -->
<div class="wallet-widget mb-4 animate">
    <div class="wallet-balance">
        <div class="wallet-label">Saldo Tersedia</div>
        <div class="wallet-amount"><?php echo format_money($balance); ?></div>
        
        <?php if ($pending_balance > 0): ?>
        <div class="wallet-label">Saldo Tertahan</div>
        <div class="wallet-amount"><?php echo format_money($pending_balance); ?></div>
        <?php endif; ?>
    </div>
    
    <div class="wallet-actions">
        <a href="topup-modern.php" class="wallet-action-btn">
            <i class="fa fa-plus"></i> Top Up
        </a>
        <a href="withdraw-modern.php" class="wallet-action-btn">
            <i class="fa fa-money-bill-wave"></i> Tarik
        </a>
    </div>
</div>

<!-- Dashboard Stats -->
<div class="dashboard-stats">
    <div class="stat-card stat-card-primary animate">
        <div class="stat-card-icon">
            <i class="fa fa-gavel"></i>
        </div>
        <div class="stat-card-value"><?php echo number_format($active_bids_count); ?></div>
        <div class="stat-card-label">Bid Aktif</div>
    </div>
    
    <div class="stat-card stat-card-success animate">
        <div class="stat-card-icon">
            <i class="fa fa-trophy"></i>
        </div>
        <div class="stat-card-value"><?php echo number_format($won_auctions_count); ?></div>
        <div class="stat-card-label">Lelang Dimenangkan</div>
    </div>
    
    <div class="stat-card stat-card-warning animate">
        <div class="stat-card-icon">
            <i class="fa fa-clock"></i>
        </div>
        <div class="stat-card-value"><?php echo number_format($pending_transactions_count); ?></div>
        <div class="stat-card-label">Transaksi Pending</div>
    </div>
</div>

<!-- Recent Activity -->
<div class="widget-card mb-4 animate">
    <div class="widget-card-header">
        <h5 class="widget-card-title">Aktivitas Terbaru</h5>
        <a href="#" class="modern-btn modern-btn-outline btn-sm">Lihat Semua</a>
    </div>
    <div class="widget-card-body">
        <ul class="activity-list">
            <?php
            // Get recent activities (bids and transactions)
            try {
                $activities_sql = "(SELECT 'bid' as type, b.bid_time as time, 
                                   CONCAT('Bid sebesar ', FORMAT(b.bid_amount, 0), ' untuk ', COALESCE(v.brand, v.make), ' ', v.model) as description,
                                   'bids-modern.php' as link
                                   FROM bids b 
                                   JOIN vehicles v ON b.vehicle_id = v.vehicle_id 
                                   WHERE b.bidder_id = ?)
                                   UNION
                                   (SELECT 'transaction' as type, t.created_at as time,
                                   CONCAT(CASE 
                                       WHEN t.type = 'deposit' THEN 'Top up '
                                       WHEN t.type = 'withdrawal' THEN 'Penarikan '
                                       WHEN t.type = 'bid_hold' THEN 'Hold bid '
                                       WHEN t.type = 'bid_release' THEN 'Release bid '
                                       WHEN t.type = 'bid_win' THEN 'Menang lelang '
                                       ELSE t.type
                                   END, FORMAT(t.amount, 0)) as description,
                                   'transactions-modern.php' as link
                                   FROM transactions t 
                                   WHERE t.user_id = ?)
                                   ORDER BY time DESC
                                   LIMIT 5";
                $activities_stmt = $conn->prepare($activities_sql);
                $activities_stmt->bind_param("ii", $user_id, $user_id);
                $activities_stmt->execute();
                $activities_result = $activities_stmt->get_result();
                
                if ($activities_result->num_rows > 0) {
                    while ($activity = $activities_result->fetch_assoc()) {
                        $icon_class = $activity['type'] == 'bid' ? 'activity-icon-primary' : 'activity-icon-success';
                        $icon = $activity['type'] == 'bid' ? 'fa-gavel' : 'fa-money-bill-wave';
                        $time_ago = format_time_ago(strtotime($activity['time']));
                        ?>
                        <li class="activity-item">
                            <div class="activity-icon <?php echo $icon_class; ?>">
                                <i class="fa <?php echo $icon; ?>"></i>
                            </div>
                            <div class="activity-content">
                                <div class="activity-title"><?php echo htmlspecialchars($activity['description']); ?></div>
                                <div class="activity-time"><?php echo $time_ago; ?></div>
                            </div>
                        </li>
                        <?php
                    }
                } else {
                    echo '<li class="activity-item">
                            <div class="activity-content text-center py-3">
                                <div class="activity-title text-muted">Belum ada aktivitas</div>
                            </div>
                          </li>';
                }
            } catch (Exception $e) {
                error_log("Error fetching activities: " . $e->getMessage());
                echo '<li class="activity-item">
                        <div class="activity-content text-center py-3">
                            <div class="activity-title text-muted">Gagal memuat aktivitas</div>
                        </div>
                      </li>';
            }
            ?>
        </ul>
    </div>
</div>

<?php
// Helper function to format time ago
function format_time_ago($timestamp) {
    $current_time = time();
    $time_difference = $current_time - $timestamp;
    
    if ($time_difference < 60) {
        return 'baru saja';
    } elseif ($time_difference < 3600) {
        $minutes = round($time_difference / 60);
        return $minutes . ' menit yang lalu';
    } elseif ($time_difference < 86400) {
        $hours = round($time_difference / 3600);
        return $hours . ' jam yang lalu';
    } elseif ($time_difference < 604800) {
        $days = round($time_difference / 86400);
        return $days . ' hari yang lalu';
    } elseif ($time_difference < 2592000) {
        $weeks = round($time_difference / 604800);
        return $weeks . ' minggu yang lalu';
    } elseif ($time_difference < 31536000) {
        $months = round($time_difference / 2592000);
        return $months . ' bulan yang lalu';
    } else {
        $years = round($time_difference / 31536000);
        return $years . ' tahun yang lalu';
    }
}
?>