<?php
/**
 * Modern Notification Component
 * LelangMobil Web App - Versi 2025
 */

// Get unread notifications count
$unread_count = 0;
if (function_exists('count_unread_notifications') && isset($_SESSION['user_id'])) {
    $unread_count = count_unread_notifications($_SESSION['user_id']);
}

// Get recent notifications
$recent_notifications = [];
try {
    $notifications_sql = "SELECT * FROM notifications 
                         WHERE user_id = ? 
                         ORDER BY created_at DESC 
                         LIMIT 5";
    $notifications_stmt = $conn->prepare($notifications_sql);
    $notifications_stmt->bind_param("i", $_SESSION['user_id']);
    $notifications_stmt->execute();
    $notifications_result = $notifications_stmt->get_result();
    
    while ($row = $notifications_result->fetch_assoc()) {
        $recent_notifications[] = $row;
    }
} catch (Throwable $e) {
    // Handle error silently
}
?>

<!-- Notification Bell -->
<div class="notification-bell-2025">
    <i class="fa fa-bell"></i>
    <?php if ($unread_count > 0): ?>
    <span class="notification-badge-2025"><?php echo $unread_count > 99 ? '99+' : $unread_count; ?></span>
    <?php endif; ?>
    
    <!-- Notification Dropdown -->
    <div class="notification-dropdown-2025">
        <div class="notification-dropdown-2025-header">
            <h5 class="notification-dropdown-2025-title">Notifikasi</h5>
            <div class="notification-dropdown-2025-actions">
                <a href="#" class="mark-all-read">Tandai semua dibaca</a>
            </div>
        </div>
        <div class="notification-dropdown-2025-body">
            <?php if (empty($recent_notifications)): ?>
            <div class="notification-empty-2025">
                <i class="fa fa-bell-slash"></i>
                <p>Tidak ada notifikasi</p>
            </div>
            <?php else: ?>
                <?php foreach ($recent_notifications as $notification): ?>
                <div class="notification-dropdown-2025-item <?php echo $notification['is_read'] ? '' : 'unread'; ?>" 
                     data-id="<?php echo $notification['notification_id']; ?>"
                     <?php echo !empty($notification['link']) ? 'data-link="' . $notification['link'] . '"' : ''; ?>>
                    <div class="notification-dropdown-2025-item-icon <?php echo $notification['type']; ?>">
                        <?php
                        switch ($notification['type']) {
                            case 'transaction':
                                echo '<i class="fa fa-exchange-alt"></i>';
                                break;
                            case 'payment':
                                echo '<i class="fa fa-credit-card"></i>';
                                break;
                            case 'alert':
                                echo '<i class="fa fa-exclamation-circle"></i>';
                                break;
                            case 'system':
                                echo '<i class="fa fa-cog"></i>';
                                break;
                            default:
                                echo '<i class="fa fa-bell"></i>';
                        }
                        ?>
                    </div>
                    <div class="notification-dropdown-2025-item-content">
                        <div class="notification-dropdown-2025-item-title"><?php echo htmlspecialchars($notification['title']); ?></div>
                        <div class="notification-dropdown-2025-item-message"><?php echo htmlspecialchars($notification['message']); ?></div>
                        <div class="notification-dropdown-2025-item-time"><?php echo format_time_ago($notification['created_at']); ?></div>
                    </div>
                </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
        <div class="notification-dropdown-2025-footer">
            <a href="notifications.php">Lihat Semua Notifikasi</a>
        </div>
    </div>
</div>

<?php
/**
 * Format time ago function
 */
function format_time_ago($timestamp) {
    $time_ago = strtotime($timestamp);
    $current_time = time();
    $time_difference = $current_time - $time_ago;
    $seconds = $time_difference;
    
    $minutes = round($seconds / 60);
    $hours = round($seconds / 3600);
    $days = round($seconds / 86400);
    $weeks = round($seconds / 604800);
    $months = round($seconds / 2629440);
    $years = round($seconds / 31553280);
    
    if ($seconds <= 60) {
        return "baru saja";
    } else if ($minutes <= 60) {
        return $minutes == 1 ? "1 menit yang lalu" : "$minutes menit yang lalu";
    } else if ($hours <= 24) {
        return $hours == 1 ? "1 jam yang lalu" : "$hours jam yang lalu";
    } else if ($days <= 7) {
        return $days == 1 ? "kemarin" : "$days hari yang lalu";
    } else if ($weeks <= 4.3) {
        return $weeks == 1 ? "1 minggu yang lalu" : "$weeks minggu yang lalu";
    } else if ($months <= 12) {
        return $months == 1 ? "1 bulan yang lalu" : "$months bulan yang lalu";
    } else {
        return $years == 1 ? "1 tahun yang lalu" : "$years tahun yang lalu";
    }
}
?>