<?php
/**
 * Transactions Tab Component
 * LelangMobil Web App - Versi 2025
 */

// Get recent transactions if not already available
if (!isset($recent_transactions)) {
    try {
        $recent_transactions_sql = "SELECT *
                                  FROM transactions
                                  WHERE user_id = ?
                                  ORDER BY created_at DESC
                                  LIMIT 5";
        $recent_transactions_stmt = $conn->prepare($recent_transactions_sql);
        $recent_transactions_stmt->bind_param("i", $user_id);
        $recent_transactions_stmt->execute();
        $recent_transactions_result = $recent_transactions_stmt->get_result();
        $recent_transactions = [];
        while ($row = $recent_transactions_result->fetch_assoc()) {
            $recent_transactions[] = $row;
        }
    } catch (Throwable $e) {
        // Handle error silently
    }
}
?>

<div class="tab-header d-flex justify-content-between align-items-center mb-4">
    <h4>Riwayat Transaksi</h4>
    <a href="transactions-modern.php" class="btn-2025 btn-2025-primary btn-2025-sm">
        <i class="fa fa-list me-2"></i>Lihat Semua
    </a>
</div>

<?php if (empty($recent_transactions)): ?>
<div class="empty-state text-center py-5">
    <i class="fa fa-exchange-alt fa-4x text-muted mb-3"></i>
    <h5>Belum Ada Transaksi</h5>
    <p class="text-muted">Anda belum memiliki riwayat transaksi.</p>
</div>
<?php else: ?>
<div class="table-responsive">
    <table class="table-2025">
        <thead>
            <tr>
                <th>ID</th>
                <th>Tanggal</th>
                <th>Jenis</th>
                <th>Jumlah</th>
                <th>Status</th>
                <th>Aksi</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($recent_transactions as $transaction): ?>
            <tr>
                <td>
                    <div class="transaction-id">#<?php echo $transaction['transaction_id']; ?></div>
                </td>
                <td>
                    <div class="transaction-date"><?php echo date('d M Y H:i', strtotime($transaction['created_at'])); ?></div>
                </td>
                <td>
                    <?php
                    switch ($transaction['type']) {
                        case 'deposit':
                            echo '<span class="badge-2025 badge-2025-soft-success">Top Up</span>';
                            break;
                        case 'withdrawal':
                            echo '<span class="badge-2025 badge-2025-soft-warning">Penarikan</span>';
                            break;
                        case 'bid':
                            echo '<span class="badge-2025 badge-2025-soft-primary">Bid</span>';
                            break;
                        case 'win':
                            echo '<span class="badge-2025 badge-2025-soft-info">Menang Lelang</span>';
                            break;
                        default:
                            echo '<span class="badge-2025 badge-2025-soft-secondary">' . ucfirst($transaction['type']) . '</span>';
                    }
                    ?>
                </td>
                <td>
                    <?php
                    $amount_class = in_array($transaction['type'], ['deposit', 'win']) ? 'text-success' : 'text-danger';
                    $prefix = in_array($transaction['type'], ['deposit', 'win']) ? '+' : '-';
                    echo '<div class="transaction-amount ' . $amount_class . '">' . $prefix . ' ' . format_money($transaction['amount']) . '</div>';
                    ?>
                </td>
                <td>
                    <?php
                    switch ($transaction['status']) {
                        case 'completed':
                            echo '<span class="badge-2025 badge-2025-soft-success">Selesai</span>';
                            break;
                        case 'pending':
                            echo '<span class="badge-2025 badge-2025-soft-warning">Menunggu</span>';
                            break;
                        case 'failed':
                            echo '<span class="badge-2025 badge-2025-soft-danger">Gagal</span>';
                            break;
                        default:
                            echo '<span class="badge-2025 badge-2025-soft-secondary">' . ucfirst($transaction['status']) . '</span>';
                    }
                    ?>
                </td>
                <td>
                    <a href="transactions-modern.php?id=<?php echo $transaction['transaction_id']; ?>" class="btn-2025 btn-2025-sm btn-2025-outline">
                        <i class="fa fa-eye"></i>
                    </a>
                    
                    <?php if ($transaction['type'] == 'deposit' && $transaction['status'] == 'pending' && empty($transaction['payment_proof'])): ?>
                    <a href="upload-payment.php?id=<?php echo $transaction['transaction_id']; ?>" class="btn-2025 btn-2025-sm btn-2025-primary ms-1">
                        <i class="fa fa-upload"></i>
                    </a>
                    <?php endif; ?>
                </td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>
<?php endif; ?>

<style>
.transaction-id {
    font-weight: 600;
    font-size: 0.9rem;
}

.transaction-date {
    font-size: 0.85rem;
    color: var(--text-color-light);
}

.transaction-amount {
    font-weight: 600;
}

.transaction-amount.text-success {
    color: var(--success) !important;
}

.transaction-amount.text-danger {
    color: var(--danger) !important;
}

.empty-state {
    padding: 30px;
    text-align: center;
}

.empty-state i {
    color: #ccc;
}
</style>