<?php
/**
 * Modern Wallet Widget Component
 * LelangMobil Web App - Versi 2025
 */

// Get user balance if not already available
if (!isset($user) && isset($_SESSION['user_id'])) {
    $user_id = $_SESSION['user_id'];
    $user_sql = "SELECT balance FROM users WHERE user_id = ?";
    $user_stmt = $conn->prepare($user_sql);
    $user_stmt->bind_param("i", $user_id);
    $user_stmt->execute();
    $user_result = $user_stmt->get_result();
    $user = $user_result->fetch_assoc();
}

// Get recent transactions
$recent_wallet_transactions = [];
try {
    $transactions_sql = "SELECT * FROM transactions 
                        WHERE user_id = ? AND (type = 'deposit' OR type = 'withdrawal') 
                        ORDER BY created_at DESC LIMIT 3";
    $transactions_stmt = $conn->prepare($transactions_sql);
    $transactions_stmt->bind_param("i", $_SESSION['user_id']);
    $transactions_stmt->execute();
    $transactions_result = $transactions_stmt->get_result();
    
    while ($row = $transactions_result->fetch_assoc()) {
        $recent_wallet_transactions[] = $row;
    }
} catch (Throwable $e) {
    // Handle error silently
}
?>

<div class="modern-card wallet-widget hover-lift">
    <div class="modern-card-header">
        <h3 class="modern-card-title"><i class="fa fa-wallet"></i> Saldo Saya</h3>
        <div class="wallet-actions">
            <a href="topup-modern.php" class="btn btn-sm btn-primary me-2">
                <i class="fa fa-plus-circle"></i>
            </a>
            <a href="withdraw-modern.php" class="btn btn-sm btn-outline-primary">
                <i class="fa fa-minus-circle"></i>
            </a>
        </div>
    </div>
    <div class="modern-card-body">
        <div class="wallet-balance">
            <div class="balance-amount"><?php echo format_money($user['balance'] ?? 0); ?></div>
            <div class="balance-label">Saldo Tersedia</div>
        </div>
        
        <?php if (!empty($recent_wallet_transactions)): ?>
        <div class="wallet-transactions mt-3">
            <h6 class="transactions-title">Transaksi Terbaru</h6>
            <div class="transaction-list">
                <?php foreach ($recent_wallet_transactions as $transaction): ?>
                <div class="transaction-item">
                    <div class="transaction-icon <?php echo $transaction['type'] == 'deposit' ? 'deposit' : 'withdraw'; ?>">
                        <i class="fa <?php echo $transaction['type'] == 'deposit' ? 'fa-arrow-down' : 'fa-arrow-up'; ?>"></i>
                    </div>
                    <div class="transaction-details">
                        <div class="transaction-type">
                            <?php echo $transaction['type'] == 'deposit' ? 'Top Up' : 'Penarikan'; ?>
                            <span class="transaction-date"><?php echo date('d M Y', strtotime($transaction['created_at'])); ?></span>
                        </div>
                        <div class="transaction-amount <?php echo $transaction['type'] == 'deposit' ? 'text-success' : 'text-danger'; ?>">
                            <?php echo $transaction['type'] == 'deposit' ? '+' : '-'; ?> <?php echo format_money($transaction['amount']); ?>
                        </div>
                    </div>
                    <div class="transaction-status">
                        <span class="badge bg-<?php 
                            echo $transaction['status'] == 'completed' ? 'success' : 
                                ($transaction['status'] == 'pending' ? 'warning' : 'danger'); 
                        ?>">
                            <?php 
                            echo $transaction['status'] == 'completed' ? 'Selesai' : 
                                ($transaction['status'] == 'pending' ? 'Proses' : 'Ditolak'); 
                            ?>
                        </span>
                    </div>
                </div>
                <?php endforeach; ?>
            </div>
            <div class="text-center mt-3">
                <a href="transactions-modern.php" class="btn btn-sm btn-outline-primary w-100">Lihat Semua Transaksi</a>
            </div>
        </div>
        <?php else: ?>
        <div class="empty-transactions text-center mt-4">
            <i class="fa fa-receipt fa-3x text-muted mb-3"></i>
            <p class="mb-3">Belum ada transaksi saldo</p>
            <a href="topup-modern.php" class="btn btn-sm btn-primary">Top Up Sekarang</a>
        </div>
        <?php endif; ?>
    </div>
</div>

<style>
.wallet-widget {
    border-radius: 12px;
    overflow: hidden;
}

.wallet-balance {
    text-align: center;
    padding: 15px 0;
}

.balance-amount {
    font-size: 2rem;
    font-weight: 700;
    color: var(--primary);
    margin-bottom: 5px;
}

.balance-label {
    color: var(--secondary);
    font-size: 0.9rem;
}

.transactions-title {
    font-size: 0.9rem;
    font-weight: 600;
    margin-bottom: 15px;
    padding-bottom: 10px;
    border-bottom: 1px solid rgba(0,0,0,0.05);
}

.transaction-list {
    display: flex;
    flex-direction: column;
    gap: 15px;
}

.transaction-item {
    display: flex;
    align-items: center;
}

.transaction-icon {
    width: 36px;
    height: 36px;
    border-radius: 50%;
    display: flex;
    align-items: center;
    justify-content: center;
    margin-right: 12px;
    flex-shrink: 0;
}

.transaction-icon.deposit {
    background-color: rgba(40, 167, 69, 0.1);
    color: #28a745;
}

.transaction-icon.withdraw {
    background-color: rgba(220, 53, 69, 0.1);
    color: #dc3545;
}

.transaction-details {
    flex: 1;
}

.transaction-type {
    font-size: 0.9rem;
    font-weight: 500;
    display: flex;
    justify-content: space-between;
}

.transaction-date {
    font-size: 0.75rem;
    color: var(--secondary);
    font-weight: normal;
}

.transaction-amount {
    font-size: 0.9rem;
    font-weight: 600;
}

.transaction-status {
    margin-left: 10px;
}

.transaction-status .badge {
    font-size: 0.7rem;
    padding: 0.25em 0.6em;
}

.empty-transactions i {
    opacity: 0.3;
}

.empty-transactions p {
    color: var(--secondary);
    font-size: 0.9rem;
}
</style>