/**
 * Account Dashboard JavaScript
 * Kumpulan fungsi JavaScript untuk halaman account.php
 * Version: 2.0 (3 Mei 2025)
 * Fitur baru: efek visual, animasi, interaksi pengguna yang lebih baik
 */

document.addEventListener("DOMContentLoaded", function() {
    // Tab switching - Fixed selector untuk match dengan HTML structure
    const triggerTabList = document.querySelectorAll("#accountTabs button");
    triggerTabList.forEach(triggerEl => {
        triggerEl.addEventListener("click", event => {
            event.preventDefault();
            const tabTarget = document.querySelector(triggerEl.getAttribute("data-bs-target"));
            
            // Remove active class from all tabs
            document.querySelectorAll(".tab-pane").forEach(pane => {
                pane.classList.remove("show", "active");
            });
            document.querySelectorAll("#accountTabs button").forEach(btn => {
                btn.classList.remove("active");
                btn.setAttribute("aria-selected", "false");
            });
            
            // Add active class to selected tab
            triggerEl.classList.add("active");
            triggerEl.setAttribute("aria-selected", "true");
            tabTarget.classList.add("show", "active");
            
            // Tambahkan efek animasi untuk tab aktif
            animateTabTransition(tabTarget);
        });
    });
    
    // Fungsi untuk menganimasikan transisi tab
    function animateTabTransition(tabElement) {
        tabElement.style.opacity = '0';
        tabElement.style.transform = 'translateY(10px)';
        
        setTimeout(() => {
            tabElement.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
            tabElement.style.opacity = '1';
            tabElement.style.transform = 'translateY(0)';
            
            // Reset transition setelah animasi
            setTimeout(() => {
                tabElement.style.transition = '';
            }, 500);
        }, 50);
    }
    
    // Efek tilt 3D untuk card
    const premiumCards = document.querySelectorAll('.premium-card:not(.no-tilt)');
    premiumCards.forEach(card => {
        card.addEventListener('mousemove', handleTilt);
        card.addEventListener('mouseleave', resetTilt);
    });
    
    function handleTilt(e) {
        const card = this;
        const cardRect = card.getBoundingClientRect();
        const cardWidth = cardRect.width;
        const cardHeight = cardRect.height;
        
        // Posisi kursor relatif terhadap card
        const mouseX = e.clientX - cardRect.left; 
        const mouseY = e.clientY - cardRect.top;
        
        // Konversi ke persentase dari tengah card (-50% hingga 50%)
        const rotateY = ((mouseX / cardWidth) - 0.5) * 10; // max 5 derajat
        const rotateX = ((0.5 - (mouseY / cardHeight)) * 10); // max 5 derajat
        
        // Terapkan transformasi
        card.style.transform = `perspective(1000px) rotateX(${rotateX}deg) rotateY(${rotateY}deg) scale3d(1.02, 1.02, 1.02)`;
        card.style.transition = 'transform 0.1s ease';
        
        // Efek shadow mengikuti arah tilt
        const shadowX = rotateY * 2;
        const shadowY = -rotateX * 2;
        card.style.boxShadow = `${shadowX}px ${shadowY}px 20px rgba(0,0,0,0.1)`;
    }
    
    function resetTilt() {
        this.style.transform = 'perspective(1000px) rotateX(0) rotateY(0) scale3d(1, 1, 1)';
        this.style.boxShadow = '0 5px 15px rgba(0,0,0,0.1)';
        this.style.transition = 'transform 0.5s ease, box-shadow 0.5s ease';
    }
    
    // Animasi angka untuk saldo dan statistik
    const countElements = document.querySelectorAll('.ultra-stat-value');
    countElements.forEach(element => {
        let targetValue = element.innerText;
        
        // Periksa apakah mengandung mata uang
        if (targetValue.includes('Rp')) {
            const numericValue = parseInt(targetValue.replace(/[^0-9]/g, ''));
            animateCurrencyCounter(element, 0, numericValue);
        }
    });
    
    function animateCurrencyCounter(element, start, end) {
        const duration = 1500;
        const frameDuration = 1000/60;
        const totalFrames = Math.round(duration / frameDuration);
        const originalText = element.innerText;
        const currencyPrefix = originalText.includes('Rp') ? 'Rp ' : '';
        
        let currentFrame = 0;
        const increment = (end - start) / totalFrames;
        
        const counter = setInterval(() => {
            currentFrame++;
            const progress = Math.min(currentFrame / totalFrames, 1);
            const easedProgress = easeOutQuart(progress);
            const current = Math.floor(start + (end - start) * easedProgress);
            
            element.innerText = `${currencyPrefix}${formatNumber(current)}`;
            
            if (currentFrame === totalFrames) {
                clearInterval(counter);
                element.innerText = originalText; // Pastikan nilai akhir tepat
            }
        }, frameDuration);
    }
    
    // Format angka dengan pemisah ribuan
    function formatNumber(number) {
        return number.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ".");
    }
    
    // Fungsi easing untuk animasi
    function easeOutQuart(x) {
        return 1 - Math.pow(1 - x, 4);
    }
    
    // Tambahkan event listener untuk tombol lihat semua di dashboard
    const viewAllButtons = document.querySelectorAll('[id$="-tab"].btn');
    viewAllButtons.forEach(button => {
        button.addEventListener("click", function(e) {
            e.preventDefault();
            // Ambil ID tab dari button ID 
            const tabId = this.id;
            // Cari tab nav item dengan id yang sama dan trigger click
            document.querySelector(`button[id="${tabId}"][role="tab"]`).click();
        });
    });

    // Toggle password visibility
    document.querySelectorAll(".toggle-password").forEach(button => {
        button.addEventListener("click", function() {
            const targetId = this.getAttribute("data-target");
            const input = document.getElementById(targetId);
            const icon = this.querySelector("i");
            
            if (input.type === "password") {
                input.type = "text";
                icon.classList.remove("fa-eye");
                icon.classList.add("fa-eye-slash");
            } else {
                input.type = "password";
                icon.classList.remove("fa-eye-slash");
                icon.classList.add("fa-eye");
            }
        });
    });

    // Password validation
    const newPassword = document.getElementById("new_password");
    if (newPassword) {
        newPassword.addEventListener("input", function() {
            const value = this.value;
            
            // Check all password requirements
            document.getElementById("length").classList.toggle("valid", value.length >= 8);
            document.getElementById("uppercase").classList.toggle("valid", /[A-Z]/.test(value));
            document.getElementById("lowercase").classList.toggle("valid", /[a-z]/.test(value));
            document.getElementById("number").classList.toggle("valid", /[0-9]/.test(value));
            document.getElementById("special").classList.toggle("valid", /[^A-Za-z0-9]/.test(value));
        });
    }

    // Preset topup buttons
    const presetButtons = document.querySelectorAll(".preset-btn");
    if (presetButtons.length > 0) {
        presetButtons.forEach(button => {
            button.addEventListener("click", function() {
                const amount = this.getAttribute("data-value");
                document.getElementById("amount").value = amount;
            });
        });
    }

    console.log("Account page loaded with all premium features.");
    
    // Observe elements for animation
    const animateElements = document.querySelectorAll(".animate-on-scroll");
    if (animateElements.length > 0) {
        const observer = new IntersectionObserver(entries => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    entry.target.classList.add("animated");
                    observer.unobserve(entry.target);
                }
            });
        }, { threshold: 0.1 });
        
        animateElements.forEach(el => observer.observe(el));
    }
    
    // Inisialisasi efek 3D tilt pada card
    if (typeof VanillaTilt !== "undefined") {
        VanillaTilt.init(document.querySelectorAll(".card"), {
            max: 5,
            speed: 400,
            glare: true,
            "max-glare": 0.2,
            scale: 1.03,
            perspective: 1000,
            transition: true,
            gyroscope: true,
            easing: "cubic-bezier(.03,.98,.52,.99)"
        });
        
        // Tambahkan kelas untuk mengaktifkan efek tilt
        document.querySelectorAll(".card").forEach(card => {
            card.classList.add("js-tilt-card");
            Array.from(card.querySelectorAll(".card-body > *")).forEach(el => {
                el.classList.add("tilt-child");
            });
        });
    }

    // Implementasi fungsionalitas filter untuk tab Bid History
    const bidCards = document.querySelectorAll('.bid-card');
    const applyFilterBtn = document.getElementById('apply-bid-filter');
    const bidStatusSelect = document.getElementById('bid-status');
    const bidSortSelect = document.getElementById('bid-sort');
    const noBidsMessage = document.querySelector('.no-bids-message');
    
    if (applyFilterBtn && bidCards.length > 0) {
        applyFilterBtn.addEventListener('click', function() {
            const statusFilter = bidStatusSelect ? bidStatusSelect.value : '';
            const sortOption = bidSortSelect ? bidSortSelect.value : 'newest';
            
            // Hide all cards first
            let visibleCards = 0;
            bidCards.forEach(card => {
                const cardStatus = card.getAttribute('data-status');
                const isVisible = statusFilter === '' || cardStatus === statusFilter;
                
                card.style.display = isVisible ? 'block' : 'none';
                if (isVisible) visibleCards++;
            });
            
            // Show/hide no results message
            if (noBidsMessage) {
                noBidsMessage.style.display = visibleCards === 0 ? 'block' : 'none';
            }
            
            // Sorting logic
            const bidCardsContainer = document.querySelector('.bid-cards-container');
            if (bidCardsContainer) {
                const visibleBidCards = Array.from(bidCards).filter(card => card.style.display !== 'none');
                
                // Sort the visible cards
                visibleBidCards.sort((a, b) => {
                    if (sortOption === 'newest') {
                        return new Date(b.getAttribute('data-time')) - new Date(a.getAttribute('data-time'));
                    } else if (sortOption === 'highest') {
                        return parseFloat(b.getAttribute('data-amount')) - parseFloat(a.getAttribute('data-amount'));
                    } else if (sortOption === 'closing') {
                        return new Date(a.getAttribute('data-end')) - new Date(b.getAttribute('data-end'));
                    }
                    return 0;
                });
                
                // Reposition cards in the DOM
                visibleBidCards.forEach(card => {
                    bidCardsContainer.appendChild(card);
                });
            }
        });
    }
    
    // Auto-refresh countdown timers
    const countdownElements = document.querySelectorAll('.countdown:not(.ended)');
    if (countdownElements.length > 0) {
        setInterval(() => {
            countdownElements.forEach(element => {
                const endTimeStr = element.getAttribute('data-end');
                if (endTimeStr) {
                    const endTime = new Date(endTimeStr).getTime();
                    const now = new Date().getTime();
                    const timeLeft = endTime - now;
                    
                    if (timeLeft <= 0) {
                        element.innerHTML = '<i class="fa fa-check-circle me-1"></i>Lelang Berakhir';
                        element.classList.add('ended');
                    } else {
                        const days = Math.floor(timeLeft / (1000 * 60 * 60 * 24));
                        const hours = Math.floor((timeLeft % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
                        const minutes = Math.floor((timeLeft % (1000 * 60 * 60)) / (1000 * 60));
                        const seconds = Math.floor((timeLeft % (1000 * 60)) / 1000);
                        
                        let displayText = '';
                        if (days > 0) displayText += `${days}h `;
                        displayText += `${hours.toString().padStart(2, '0')}:${minutes.toString().padStart(2, '0')}:${seconds.toString().padStart(2, '0')}`;
                        
                        element.innerHTML = `<i class="fa fa-clock me-1"></i>${displayText}`;
                    }
                }
            });
        }, 1000);
    }
    
    // Toggle View Controls (Grid/List) untuk tampilan kendaraan
    const gridViewBtn = document.getElementById('grid-view');
    const listViewBtn = document.getElementById('list-view');
    const bidCardsContainer = document.querySelector('.bid-cards-container');
    
    if (gridViewBtn && listViewBtn && bidCardsContainer) {
        // Set grid view sebagai default
        gridViewBtn.classList.add('active');
        
        // Fungsi untuk toggle ke grid view
        gridViewBtn.addEventListener('click', function() {
            bidCardsContainer.classList.remove('bid-cards-list');
            bidCardsContainer.classList.add('bid-cards-grid');
            gridViewBtn.classList.add('active');
            listViewBtn.classList.remove('active');
            
            // Simpan preferensi user
            localStorage.setItem('bidViewPreference', 'grid');
        });
        
        // Fungsi untuk toggle ke list view
        listViewBtn.addEventListener('click', function() {
            bidCardsContainer.classList.remove('bid-cards-grid');
            bidCardsContainer.classList.add('bid-cards-list');
            listViewBtn.classList.add('active');
            gridViewBtn.classList.remove('active');
            
            // Simpan preferensi user
            localStorage.setItem('bidViewPreference', 'list');
        });
        
        // Periksa preferensi yang tersimpan
        const savedPreference = localStorage.getItem('bidViewPreference');
        if (savedPreference === 'list') {
            listViewBtn.click();
        }
    }
    
    // Preload gambar kendaraan untuk performa lebih baik
    const vehicleImages = document.querySelectorAll('.vehicle-image');
    if (vehicleImages.length > 0) {
        vehicleImages.forEach(img => {
            if (img.complete) {
                img.classList.add('loaded');
            } else {
                img.addEventListener('load', function() {
                    this.classList.add('loaded');
                });
            }
        });
    }
});
