/**
 * Image Lazy Loader
 * LelangMobil Web App - Versi 2025
 * 
 * Script untuk memuat gambar secara lazy loading
 */

document.addEventListener('DOMContentLoaded', function() {
    // Check if IntersectionObserver is supported
    if ('IntersectionObserver' in window) {
        // Create new IntersectionObserver
        const imageObserver = new IntersectionObserver((entries, observer) => {
            entries.forEach(entry => {
                // If image is in viewport
                if (entry.isIntersecting) {
                    const image = entry.target;
                    
                    // Set src attribute from data-src
                    if (image.dataset.src) {
                        image.src = image.dataset.src;
                        image.removeAttribute('data-src');
                    }
                    
                    // Set srcset attribute from data-srcset
                    if (image.dataset.srcset) {
                        image.srcset = image.dataset.srcset;
                        image.removeAttribute('data-srcset');
                    }
                    
                    // Add loaded class
                    image.classList.add('loaded');
                    
                    // Stop observing image
                    observer.unobserve(image);
                }
            });
        }, {
            rootMargin: '50px 0px',
            threshold: 0.01
        });
        
        // Get all images with data-src attribute
        const lazyImages = document.querySelectorAll('img[data-src]');
        
        // Observe each image
        lazyImages.forEach(image => {
            imageObserver.observe(image);
        });
    } else {
        // Fallback for browsers that don't support IntersectionObserver
        const lazyImages = document.querySelectorAll('img[data-src]');
        
        lazyImages.forEach(image => {
            if (image.dataset.src) {
                image.src = image.dataset.src;
                image.removeAttribute('data-src');
            }
            
            if (image.dataset.srcset) {
                image.srcset = image.dataset.srcset;
                image.removeAttribute('data-srcset');
            }
            
            image.classList.add('loaded');
        });
    }
});

/**
 * Convert images to lazy loading
 * 
 * @param {string} selector CSS selector for images
 */
function convertToLazyLoad(selector = 'img:not(.loaded):not([data-src])') {
    const images = document.querySelectorAll(selector);
    
    images.forEach(image => {
        // Skip if already processed
        if (image.classList.contains('loaded') || image.hasAttribute('data-src')) {
            return;
        }
        
        // Set data-src attribute
        if (image.src) {
            image.dataset.src = image.src;
            image.src = 'data:image/svg+xml,%3Csvg xmlns=\'http://www.w3.org/2000/svg\' viewBox=\'0 0 1 1\'%3E%3C/svg%3E';
        }
        
        // Set data-srcset attribute
        if (image.srcset) {
            image.dataset.srcset = image.srcset;
            image.srcset = '';
        }
        
        // Add lazy-load class
        image.classList.add('lazy-load');
    });
    
    // Trigger lazy loading
    if ('IntersectionObserver' in window) {
        const imageObserver = new IntersectionObserver((entries, observer) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    const image = entry.target;
                    
                    if (image.dataset.src) {
                        image.src = image.dataset.src;
                        image.removeAttribute('data-src');
                    }
                    
                    if (image.dataset.srcset) {
                        image.srcset = image.dataset.srcset;
                        image.removeAttribute('data-srcset');
                    }
                    
                    image.classList.add('loaded');
                    observer.unobserve(image);
                }
            });
        }, {
            rootMargin: '50px 0px',
            threshold: 0.01
        });
        
        const lazyImages = document.querySelectorAll('.lazy-load:not(.loaded)');
        lazyImages.forEach(image => {
            imageObserver.observe(image);
        });
    } else {
        const lazyImages = document.querySelectorAll('.lazy-load:not(.loaded)');
        
        lazyImages.forEach(image => {
            if (image.dataset.src) {
                image.src = image.dataset.src;
                image.removeAttribute('data-src');
            }
            
            if (image.dataset.srcset) {
                image.srcset = image.dataset.srcset;
                image.removeAttribute('data-srcset');
            }
            
            image.classList.add('loaded');
        });
    }
}