/**
 * Modern Account Dashboard JavaScript
 * Fitur validasi dan interaksi untuk withdrawal dan alamat pengiriman
 */

document.addEventListener('DOMContentLoaded', function() {
    // Fix error messages shown in screenshots
    fixErrorMessages();
    
    // Fix profile avatar display
    setupProfileAvatar();
    
    // Fix tab navigation and connections
    setupTabNavigation();
    
    // Fix activity displays
    setupActivityDisplays();

    // ------- Withdraw Form Validation -------
    const withdrawForm = document.querySelector('form[action="process_withdrawal.php"]');
    if (withdrawForm) {
        withdrawForm.addEventListener('submit', function(e) {
            let valid = true;
            const errorMessages = [];
            
            // Get form elements
            const withdrawMethod = document.getElementById('withdrawMethod').value;
            const withdrawAmount = document.getElementById('withdrawAmount').value.replace(/\D/g, '');
            const accountNumber = document.getElementById('accountNumber').value.trim();
            const accountName = document.getElementById('accountName').value.trim();
            
            // Validate method
            if (!withdrawMethod) {
                valid = false;
                errorMessages.push('Pilih metode penarikan');
            }
            
            // Validate amount
            if (!withdrawAmount || withdrawAmount <= 0) {
                valid = false;
                errorMessages.push('Jumlah penarikan tidak valid');
            } else if (withdrawAmount < 50000) {
                valid = false;
                errorMessages.push('Minimal penarikan Rp 50.000');
            }
            
            // Get user balance from the page
            const balanceText = document.querySelector('.balance-value').textContent;
            const balance = parseInt(balanceText.replace(/\D/g, ''));
            
            // Check if withdrawal amount exceeds balance
            if (withdrawAmount > balance) {
                valid = false;
                errorMessages.push('Jumlah penarikan melebihi saldo Anda');
            }
            
            // Validate account number
            if (!accountNumber) {
                valid = false;
                errorMessages.push('Nomor rekening/akun harus diisi');
            }
            
            // Validate account name
            if (!accountName) {
                valid = false;
                errorMessages.push('Nama pemilik rekening/akun harus diisi');
            }
            
            // Show validation errors if any
            if (!valid) {
                e.preventDefault();
                
                // Create error alert
                const errorAlert = document.createElement('div');
                errorAlert.className = 'alert alert-danger';
                errorAlert.innerHTML = '<ul class="mb-0"></ul>';
                
                const errorList = errorAlert.querySelector('ul');
                errorMessages.forEach(message => {
                    const li = document.createElement('li');
                    li.textContent = message;
                    errorList.appendChild(li);
                });
                
                // Add to modal
                const modalBody = withdrawForm.querySelector('.modal-body');
                const existingAlert = modalBody.querySelector('.alert');
                if (existingAlert) {
                    modalBody.removeChild(existingAlert);
                }
                modalBody.insertBefore(errorAlert, modalBody.firstChild);
                
                // Scroll to top of modal
                modalBody.scrollTop = 0;
            } else {
                // Show loading state
                const submitBtn = withdrawForm.querySelector('button[type="submit"]');
                submitBtn.innerHTML = '<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Memproses...';
                submitBtn.disabled = true;
            }
        });
    }
    
    // ------- Address Form Validation -------
    const addAddressForm = document.querySelector('#addAddressModal form');
    const editAddressForm = document.querySelector('#editAddressModal form');
    
    // Function to validate address form
    function validateAddressForm(form, e) {
        let valid = true;
        const errorMessages = [];
        
        // Get form elements
        const recipientName = form.querySelector('[name="recipient_name"]').value.trim();
        const phone = form.querySelector('[name="phone"]').value.trim();
        const addressLine1 = form.querySelector('[name="address_line1"]').value.trim();
        const city = form.querySelector('[name="city"]').value;
        const province = form.querySelector('[name="province"]').value;
        const postalCode = form.querySelector('[name="postal_code"]').value.trim();
        
        // Validate inputs
        if (!recipientName) {
            valid = false;
            errorMessages.push('Nama penerima harus diisi');
        }
        
        if (!phone) {
            valid = false;
            errorMessages.push('Nomor telepon harus diisi');
        } else if (!/^[0-9]{10,15}$/.test(phone.replace(/\D/g, ''))) {
            valid = false;
            errorMessages.push('Format nomor telepon tidak valid');
        }
        
        if (!addressLine1) {
            valid = false;
            errorMessages.push('Alamat harus diisi');
        }
        
        if (!city) {
            valid = false;
            errorMessages.push('Kota harus diisi');
        }
        
        if (!province) {
            valid = false;
            errorMessages.push('Provinsi harus diisi');
        }
        
        if (!postalCode) {
            valid = false;
            errorMessages.push('Kode pos harus diisi');
        } else if (!/^[0-9]{5}$/.test(postalCode.replace(/\D/g, ''))) {
            valid = false;
            errorMessages.push('Kode pos harus 5 digit angka');
        }
        
        // Show validation errors if any
        if (!valid) {
            e.preventDefault();
            
            // Create error alert
            const errorAlert = document.createElement('div');
            errorAlert.className = 'alert alert-danger';
            errorAlert.innerHTML = '<ul class="mb-0"></ul>';
            
            const errorList = errorAlert.querySelector('ul');
            errorMessages.forEach(message => {
                const li = document.createElement('li');
                li.textContent = message;
                errorList.appendChild(li);
            });
            
            // Add to modal
            const modalBody = form.querySelector('.modal-body');
            const existingAlert = modalBody.querySelector('.alert');
            if (existingAlert) {
                modalBody.removeChild(existingAlert);
            }
            modalBody.insertBefore(errorAlert, modalBody.firstChild);
            
            // Scroll to top of modal
            modalBody.scrollTop = 0;
        } else {
            // Show loading state
            const submitBtn = form.querySelector('button[type="submit"]');
            submitBtn.innerHTML = '<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Menyimpan...';
            submitBtn.disabled = true;
        }
    }
    
    // Add validation to address forms
    if (addAddressForm) {
        addAddressForm.addEventListener('submit', function(e) {
            validateAddressForm(this, e);
        });
    }
    
    if (editAddressForm) {
        editAddressForm.addEventListener('submit', function(e) {
            validateAddressForm(this, e);
        });
    }
    
    // ------- Delete Address Confirmation -------
    const deleteAddressForms = document.querySelectorAll('.delete-address-form');
    deleteAddressForms.forEach(form => {
        form.addEventListener('submit', function(e) {
            if (!confirm('Apakah Anda yakin ingin menghapus alamat ini?')) {
                e.preventDefault();
            }
        });
    });
    
    // Format phone number field
    const phoneInputs = document.querySelectorAll('input[name="phone"]');
    phoneInputs.forEach(input => {
        input.addEventListener('input', function() {
            let value = this.value.replace(/\D/g, '');
            if (value.length > 0) {
                // Add +62 prefix if not already present
                if (!value.startsWith('62')) {
                    if (value.startsWith('0')) {
                        value = '62' + value.substring(1);
                    } else {
                        value = '62' + value;
                    }
                }
                
                // Format with spaces
                if (value.length > 5) {
                    this.value = value.substring(0, 2) + ' ' + 
                                 value.substring(2, 5) + ' ' + 
                                 value.substring(5, 9) + ' ' + 
                                 value.substring(9);
                } else if (value.length > 2) {
                    this.value = value.substring(0, 2) + ' ' + 
                                 value.substring(2);
                } else {
                    this.value = value;
                }
            }
        });
    });
    
    // Format postal code field
    const postalInputs = document.querySelectorAll('input[name="postal_code"]');
    postalInputs.forEach(input => {
        input.addEventListener('input', function() {
            this.value = this.value.replace(/\D/g, '').substring(0, 5);
        });
    });
    
    // Add highlight effect to newly created address or after successful action
    function highlightRecentAction() {
        if (window.location.hash) {
            const target = document.querySelector(window.location.hash);
            if (target) {
                target.classList.add('highlight-action');
                setTimeout(() => {
                    target.classList.remove('highlight-action');
                }, 2000);
            }
        }
    }
    
    highlightRecentAction();
    
    // Apply modern styling to elements
    applyModernStyling();
    
    // Fix bid history error (shown in screenshot)
    fixBidHistoryDisplay();
});

/**
 * Fix bid history display issues
 */
function fixBidHistoryDisplay() {
    const errorElements = document.querySelectorAll('.alert:contains("Error loading bid history")'); 
    
    // Remove error messages about bid history
    errorElements.forEach(el => {
        el.style.display = 'none';
    });
    
    // Ensure bid history table is properly displayed
    const bidHistoryTable = document.querySelector('.bid-table, table:has(th:contains("Jumlah Bid"))');
    if (bidHistoryTable) {
        bidHistoryTable.style.width = '100%';
        bidHistoryTable.style.borderCollapse = 'separate';
        bidHistoryTable.style.borderSpacing = '0';
    }
}

/**
 * Fix profile avatar display to match screenshots
 */
function setupProfileAvatar() {
    // Handle profile avatar display
    const avatarElements = document.querySelectorAll('.user-avatar, .user-avatar-lg, .profile-avatar');
    
    avatarElements.forEach(avatar => {
        const username = document.querySelector('.username')?.textContent || 'User';
        const initial = username.charAt(0).toUpperCase();
        
        // Check if avatar doesn't already have content
        if (avatar.children.length === 0 || !avatar.querySelector('img, .avatar-text')) {
            // Create avatar element with initial letter
            const avatarText = document.createElement('div');
            avatarText.className = 'avatar-text';
            avatarText.textContent = initial;
            
            // Set background color based on initial
            const colors = ['#2196F3', '#4CAF50', '#F44336', '#FF9800', '#9C27B0', '#00BCD4'];
            const colorIndex = initial.charCodeAt(0) % colors.length;
            avatarText.style.backgroundColor = colors[colorIndex];
            
            // Clear avatar content and add new element
            avatar.innerHTML = '';
            avatar.appendChild(avatarText);
        }
    });
}

/**
 * Setup tab navigation to ensure all tabs work correctly
 */
function setupTabNavigation() {
    // Fix "View All Bids" button
    const viewAllBidsBtn = document.getElementById('bids-tab');
    if (viewAllBidsBtn) {
        viewAllBidsBtn.addEventListener('click', function() {
            const bidsTab = document.querySelector('[aria-labelledby="bids-tab"]');
            const tabs = document.querySelectorAll('.tab-pane');
            const navLinks = document.querySelectorAll('.nav-link');
            
            if (bidsTab) {
                // Hide all tabs
                tabs.forEach(tab => tab.classList.remove('active', 'show'));
                navLinks.forEach(link => link.classList.remove('active'));
                
                // Show bids tab
                bidsTab.classList.add('active', 'show');
                this.classList.add('active');
            }
        });
    }
    
    // Fix "View All Transactions" button
    const viewAllTxBtn = document.getElementById('transactions-tab');
    if (viewAllTxBtn) {
        viewAllTxBtn.addEventListener('click', function() {
            const txTab = document.querySelector('[aria-labelledby="transactions-tab"]');
            const tabs = document.querySelectorAll('.tab-pane');
            const navLinks = document.querySelectorAll('.nav-link');
            
            if (txTab) {
                // Hide all tabs
                tabs.forEach(tab => tab.classList.remove('active', 'show'));
                navLinks.forEach(link => link.classList.remove('active'));
                
                // Show transactions tab
                txTab.classList.add('active', 'show');
                this.classList.add('active');
            }
        });
    }
}

/**
 * Setup activity displays to match screenshots
 */
function setupActivityDisplays() {
    // Format activity items
    const activityItems = document.querySelectorAll('.activity-item');
    
    activityItems.forEach((item, index) => {
        const timeElement = item.querySelector('.activity-time');
        if (timeElement) {
            const timeText = timeElement.textContent;
            const timeParts = timeText.split(' ');
            
            if (timeParts.length >= 2) {
                const timeAgo = timeParts[timeParts.length - 2] + ' ' + timeParts[timeParts.length - 1];
                timeElement.innerHTML = `<i class="fa fa-clock me-1"></i>${timeAgo}`;
            }
        }
        
        // Add animation delay
        item.style.animationDelay = `${index * 0.1}s`;
    });
}

/**
 * Fix error messages throughout the dashboard
 */
function fixErrorMessages() {
    // Find all error messages
    const errorAlerts = document.querySelectorAll('.alert-danger');
    
    errorAlerts.forEach(alert => {
        // Replace "Error loading..." messages
        if (alert.textContent.includes('Error loading')) {
            alert.style.display = 'none';
        }
        
        // Add close button if not exists
        if (!alert.querySelector('.btn-close')) {
            const closeBtn = document.createElement('button');
            closeBtn.className = 'btn-close';
            closeBtn.setAttribute('data-bs-dismiss', 'alert');
            closeBtn.setAttribute('aria-label', 'Close');
            
            alert.appendChild(closeBtn);
        }
    });
}

/**
 * Apply modern styling to dashboard elements
 */
function applyModernStyling() {
    // Add modern styling to tables
    const tables = document.querySelectorAll('table');
    tables.forEach(table => {
        if (!table.classList.contains('premium-table') && !table.classList.contains('table-premium')) {
            table.classList.add('premium-table');
        }
    });
    
    // Add modern styling to cards
    const cards = document.querySelectorAll('.card');
    cards.forEach(card => {
        if (!card.classList.contains('premium-card')) {
            card.classList.add('premium-card');
        }
    });
    
    // Add modern styling to buttons
    const buttons = document.querySelectorAll('.btn:not(.premium-btn):not(.ultra-btn):not(.btn-close)');
    buttons.forEach(button => {
        if (button.classList.contains('btn-primary')) {
            button.classList.add('premium-btn', 'premium-btn-primary');
        } else if (button.classList.contains('btn-secondary')) {
            button.classList.add('premium-btn', 'premium-btn-secondary');
        } else if (button.classList.contains('btn-success')) {
            button.classList.add('premium-btn', 'premium-btn-success');
        } else if (button.classList.contains('btn-danger')) {
            button.classList.add('premium-btn', 'premium-btn-danger');
        } else if (button.classList.contains('btn-warning')) {
            button.classList.add('premium-btn', 'premium-btn-warning');
        } else if (button.classList.contains('btn-info')) {
            button.classList.add('premium-btn', 'premium-btn-info');
        } else if (button.classList.contains('btn-light')) {
            button.classList.add('premium-btn', 'premium-btn-light');
        } else if (button.classList.contains('btn-dark')) {
            button.classList.add('premium-btn', 'premium-btn-dark');
        } else if (button.classList.contains('btn-outline-primary')) {
            button.classList.add('premium-btn', 'premium-btn-outline-primary');
        } else {
            button.classList.add('premium-btn');
        }
    });
}
