/**
 * Modern Background Effects
 * Menambahkan efek background modern secara dinamis
 * Tanggal: 2025-05-03
 */

document.addEventListener('DOMContentLoaded', function() {
    // Buat elemen grain overlay
    const grainOverlay = document.createElement('div');
    grainOverlay.className = 'grain-overlay';
    
    // Tambahkan ke body sebagai child pertama
    document.body.insertBefore(grainOverlay, document.body.firstChild);
    
    // Tambahkan class ke body untuk mengaktifkan efek
    document.body.classList.add('modern-background');
    
    // Tambahkan efek latar belakang yang bergerak pada scroll
    document.addEventListener('scroll', function() {
        const scrollY = window.scrollY;
        const parallaxSpeed = 0.05;
        
        // Efek parallax pada background gradient
        document.body.style.backgroundPosition = `0 ${scrollY * parallaxSpeed}px`;
    });
    
    // Efek cahaya bergerak mengikuti kursor
    document.addEventListener('mousemove', function(e) {
        // Hanya jalankan animasi pada perangkat non-mobile
        if (window.innerWidth > 768) {
            const x = e.clientX / window.innerWidth;
            const y = e.clientY / window.innerHeight;
            
            // Update posisi radial gradients di background
            document.body.style.setProperty('--mouse-x', x.toFixed(2));
            document.body.style.setProperty('--mouse-y', y.toFixed(2));
            
            // Tambahkan efek spotlight mengikuti kursor
            document.documentElement.style.setProperty('--cursor-x', e.clientX + 'px');
            document.documentElement.style.setProperty('--cursor-y', e.clientY + 'px');
        }
    });

    // Tambahkan spotlight yang mengikuti kursor
    const spotlight = document.createElement('div');
    spotlight.className = 'cursor-spotlight';
    document.body.appendChild(spotlight);
    
    // Efek card hover elevation pada semua premium card
    const cards = document.querySelectorAll('.premium-card');
    cards.forEach(card => {
        card.addEventListener('mouseenter', function() {
            this.classList.add('card-elevated');
        });
        
        card.addEventListener('mouseleave', function() {
            this.classList.remove('card-elevated');
        });
    });
    
    // Tambahkan efek animasi untuk konten saat scrolling
    const animateOnScrollElements = document.querySelectorAll('.animated-heading, .premium-card, .tab-pane');
    
    // Observer untuk animasi scroll
    const scrollObserver = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                entry.target.classList.add('animate-in');
                scrollObserver.unobserve(entry.target);
            }
        });
    }, {
        threshold: 0.2
    });
    
    // Observe semua elemen
    animateOnScrollElements.forEach(el => {
        el.classList.add('will-animate');
        scrollObserver.observe(el);
    });
});
