/**
 * Modern Theme Activator
 * LelangMobil Web App - Versi 2025
 * 
 * Script untuk mengaktifkan tema modern dan fitur-fiturnya
 */

document.addEventListener('DOMContentLoaded', function() {
    // Aktifkan animasi pada elemen dengan class 'animate'
    activateAnimations();
    
    // Aktifkan dropdown
    activateDropdowns();
    
    // Aktifkan toggle password
    activatePasswordToggles();
    
    // Aktifkan validasi form
    activateFormValidation();
    
    // Aktifkan tooltips
    activateTooltips();
    
    // Aktifkan modals
    activateModals();
    
    // Aktifkan tabs
    activateTabs();
    
    // Aktifkan theme toggle
    activateThemeToggle();
    
    console.log('Modern theme activated');
});

/**
 * Aktifkan animasi pada elemen dengan class 'animate'
 */
function activateAnimations() {
    const animateElements = document.querySelectorAll('.animate');
    
    if (animateElements.length > 0 && 'IntersectionObserver' in window) {
        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    entry.target.classList.add('fade-in');
                    observer.unobserve(entry.target);
                }
            });
        }, {
            threshold: 0.1
        });
        
        animateElements.forEach(element => {
            observer.observe(element);
        });
    } else {
        // Fallback jika IntersectionObserver tidak didukung
        animateElements.forEach(element => {
            element.classList.add('fade-in');
        });
    }
    
    // Stagger animation for forms
    const staggerForms = document.querySelectorAll('.stagger-animate');
    staggerForms.forEach(form => {
        const formElements = form.querySelectorAll('.modern-form-group, .auth-form-group');
        formElements.forEach((element, index) => {
            element.style.animationDelay = `${index * 0.1}s`;
            element.classList.add('slide-in');
        });
    });
}

/**
 * Aktifkan dropdown
 */
function activateDropdowns() {
    const dropdownToggles = document.querySelectorAll('.dropdown-toggle');
    
    dropdownToggles.forEach(toggle => {
        toggle.addEventListener('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            
            const parent = this.parentNode;
            const dropdown = parent.querySelector('.dropdown-menu');
            
            if (dropdown) {
                dropdown.classList.toggle('show');
            }
        });
    });
    
    // Close dropdown when clicking outside
    document.addEventListener('click', function(e) {
        if (!e.target.matches('.dropdown-toggle') && !e.target.closest('.dropdown-menu')) {
            document.querySelectorAll('.dropdown-menu.show').forEach(function(dropdown) {
                dropdown.classList.remove('show');
            });
        }
    });
}

/**
 * Aktifkan toggle password
 */
function activatePasswordToggles() {
    const toggleButtons = document.querySelectorAll('.toggle-password');
    
    toggleButtons.forEach(button => {
        button.addEventListener('click', function() {
            const input = this.previousElementSibling;
            const icon = this.querySelector('i');
            
            if (input && input.type === 'password') {
                input.type = 'text';
                if (icon) {
                    icon.classList.remove('fa-eye');
                    icon.classList.add('fa-eye-slash');
                }
            } else if (input) {
                input.type = 'password';
                if (icon) {
                    icon.classList.remove('fa-eye-slash');
                    icon.classList.add('fa-eye');
                }
            }
        });
    });
}

/**
 * Aktifkan validasi form
 */
function activateFormValidation() {
    const forms = document.querySelectorAll('.needs-validation');
    
    forms.forEach(form => {
        form.addEventListener('submit', function(event) {
            if (!form.checkValidity()) {
                event.preventDefault();
                event.stopPropagation();
            }
            
            form.classList.add('was-validated');
        }, false);
    });
}

/**
 * Aktifkan tooltips
 */
function activateTooltips() {
    const tooltips = document.querySelectorAll('[data-bs-toggle="tooltip"]');
    
    tooltips.forEach(tooltip => {
        new bootstrap.Tooltip(tooltip);
    });
}

/**
 * Aktifkan modals
 */
function activateModals() {
    const modalTriggers = document.querySelectorAll('[data-bs-toggle="modal"]');
    
    modalTriggers.forEach(trigger => {
        trigger.addEventListener('click', function(e) {
            e.preventDefault();
            
            const modalId = this.getAttribute('data-bs-target');
            const modal = document.querySelector(modalId);
            
            if (modal) {
                const bsModal = new bootstrap.Modal(modal);
                bsModal.show();
            }
        });
    });
}

/**
 * Aktifkan tabs
 */
function activateTabs() {
    const tabTriggers = document.querySelectorAll('[data-bs-toggle="tab"]');
    
    tabTriggers.forEach(trigger => {
        trigger.addEventListener('click', function(e) {
            e.preventDefault();
            
            const tabId = this.getAttribute('data-bs-target');
            const tab = document.querySelector(tabId);
            
            if (tab) {
                // Remove active class from all tabs
                document.querySelectorAll('.tab-pane').forEach(tab => {
                    tab.classList.remove('active', 'show');
                });
                
                // Remove active class from all triggers
                document.querySelectorAll('[data-bs-toggle="tab"]').forEach(trigger => {
                    trigger.classList.remove('active');
                });
                
                // Add active class to selected tab and trigger
                tab.classList.add('active', 'show');
                this.classList.add('active');
            }
        });
    });
}

/**
 * Aktifkan theme toggle
 */
function activateThemeToggle() {
    const themeToggle = document.querySelector('.theme-toggle');
    
    if (themeToggle) {
        // Check if dark mode is enabled in localStorage
        const isDarkMode = localStorage.getItem('theme') === 'dark';
        
        // Set initial theme
        if (isDarkMode) {
            document.body.classList.add('dark-mode');
        }
        
        // Toggle theme on click
        themeToggle.addEventListener('click', function() {
            document.body.classList.toggle('dark-mode');
            
            // Save theme preference to localStorage
            if (document.body.classList.contains('dark-mode')) {
                localStorage.setItem('theme', 'dark');
            } else {
                localStorage.setItem('theme', 'light');
            }
        });
    }
}