/**
 * Premium Animations JavaScript
 * Animasi dan efek premium untuk LelangMobil
 * Versi: 1.0 (2 Mei 2025)
 */

document.addEventListener('DOMContentLoaded', function() {
    // Inisialisasi animasi premium
    initPremiumAnimations();
    
    // Inisialisasi efek particle background
    initParticleBackground();
    
    // Inisialisasi animasi counter
    initCounterAnimation();
    
    // Inisialisasi speedometer efek
    initSpeedometerEffects();
});

/**
 * Inisialisasi animasi premium untuk elemen-elemen UI
 */
function initPremiumAnimations() {
    // Animasi untuk card elements dengan class .premium-card
    const premiumCards = document.querySelectorAll('.premium-card, .ultra-glass');
    
    premiumCards.forEach(card => {
        // Tambahkan animasi masuk saat scroll
        if (!card.classList.contains('animated')) {
            card.classList.add('animated');
            
            const observer = new IntersectionObserver((entries) => {
                entries.forEach(entry => {
                    if (entry.isIntersecting) {
                        entry.target.classList.add('fade-in-up');
                        observer.unobserve(entry.target);
                    }
                });
            }, { threshold: 0.1 });
            
            observer.observe(card);
        }
        
        // Tambahkan efek hover premium dengan shadow gradient
        card.addEventListener('mouseenter', function() {
            this.style.transform = 'translateY(-5px)';
            this.style.boxShadow = '0 15px 35px rgba(0,0,0,0.3), 0 5px 15px rgba(67, 97, 238, 0.2)';
        });
        
        card.addEventListener('mouseleave', function() {
            this.style.transform = '';
            this.style.boxShadow = '';
        });
    });
    
    // Efek ripple untuk tombol
    const premiumButtons = document.querySelectorAll('.ultra-btn, .btn-premium');
    
    premiumButtons.forEach(button => {
        button.addEventListener('click', function(e) {
            const rect = this.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;
            
            // Buat elemen ripple
            const ripple = document.createElement('span');
            ripple.classList.add('ripple-effect');
            ripple.style.left = x + 'px';
            ripple.style.top = y + 'px';
            
            this.appendChild(ripple);
            
            // Hapus elemen ripple setelah animasi selesai
            setTimeout(() => {
                ripple.remove();
            }, 600);
        });
    });
    
    // Animasi float untuk icon-icon
    const floatIcons = document.querySelectorAll('.float-icon, .float');
    
    floatIcons.forEach((icon, index) => {
        // Beri delay berbeda untuk setiap icon agar tidak bergerak bersamaan
        icon.style.animation = `float 3s ease-in-out ${index * 0.2}s infinite`;
    });
}

/**
 * Inisialisasi efek particle background untuk header
 */
function initParticleBackground() {
    const headerSection = document.querySelector('.dashboard-header');
    
    if (headerSection) {
        // Buat canvas untuk particle
        const canvas = document.createElement('canvas');
        canvas.classList.add('particle-canvas');
        canvas.style.position = 'absolute';
        canvas.style.top = '0';
        canvas.style.left = '0';
        canvas.style.width = '100%';
        canvas.style.height = '100%';
        canvas.style.pointerEvents = 'none';
        canvas.style.zIndex = '0';
        
        // Masukkan canvas ke header
        headerSection.style.position = 'relative';
        headerSection.insertBefore(canvas, headerSection.firstChild);
        
        // Set size canvas
        canvas.width = headerSection.offsetWidth;
        canvas.height = headerSection.offsetHeight;
        
        // Inisialisasi particle
        const ctx = canvas.getContext('2d');
        const particles = [];
        
        // Buat particles
        for (let i = 0; i < 30; i++) {
            particles.push({
                x: Math.random() * canvas.width,
                y: Math.random() * canvas.height,
                radius: Math.random() * 3 + 1,
                speedX: Math.random() * 0.5 - 0.25,
                speedY: Math.random() * 0.5 - 0.25,
                color: `rgba(255, 255, 255, ${Math.random() * 0.2})`
            });
        }
        
        // Animasi particles
        function animateParticles() {
            ctx.clearRect(0, 0, canvas.width, canvas.height);
            
            particles.forEach(particle => {
                ctx.beginPath();
                ctx.arc(particle.x, particle.y, particle.radius, 0, Math.PI * 2);
                ctx.fillStyle = particle.color;
                ctx.fill();
                
                // Perbarui posisi
                particle.x += particle.speedX;
                particle.y += particle.speedY;
                
                // Batasi dalam canvas
                if (particle.x < 0 || particle.x > canvas.width) {
                    particle.speedX *= -1;
                }
                
                if (particle.y < 0 || particle.y > canvas.height) {
                    particle.speedY *= -1;
                }
            });
            
            requestAnimationFrame(animateParticles);
        }
        
        // Mulai animasi
        animateParticles();
        
        // Sesuaikan ukuran canvas saat resize window
        window.addEventListener('resize', function() {
            canvas.width = headerSection.offsetWidth;
            canvas.height = headerSection.offsetHeight;
        });
    }
}

/**
 * Inisialisasi animasi counter untuk angka-angka statistik
 */
function initCounterAnimation() {
    const counterElements = document.querySelectorAll('.count-number');
    
    counterElements.forEach(element => {
        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    const target = parseInt(entry.target.getAttribute('data-target'));
                    const duration = 2000; // 2 detik
                    let start = 0;
                    let current = 0;
                    const startTime = Date.now();
                    
                    const updateCounter = () => {
                        const elapsedTime = Date.now() - startTime;
                        const progress = Math.min(elapsedTime / duration, 1);
                        
                        // Fungsi easing
                        const easeOutCubic = progress => 1 - Math.pow(1 - progress, 3);
                        
                        current = Math.floor(easeOutCubic(progress) * target);
                        entry.target.textContent = current.toLocaleString();
                        
                        if (progress < 1) {
                            requestAnimationFrame(updateCounter);
                        } else {
                            entry.target.textContent = target.toLocaleString();
                        }
                    };
                    
                    updateCounter();
                    observer.unobserve(entry.target);
                }
            });
        }, { threshold: 0.1 });
        
        observer.observe(element);
    });
}

/**
 * Inisialisasi efek speedometer 
 */
function initSpeedometerEffects() {
    // Animasi efek speedometer pada background dashboard
    const dashboardContainer = document.querySelector('.dashboard-container');
    
    if (dashboardContainer) {
        let speedValue = 0;
        let direction = 1;
        
        function updateSpeedometer() {
            speedValue += 0.2 * direction;
            
            // Batasi nilai dan ubah arah
            if (speedValue > 100) {
                direction = -1;
            } else if (speedValue < 0) {
                direction = 1;
            }
            
            // Terapkan efek rotasi pada gauge speedometer (jika ada)
            const speedGauge = document.querySelector('.speedometer-gauge');
            if (speedGauge) {
                const rotation = (speedValue / 100) * 180 - 90; // -90 to 90 degrees
                speedGauge.style.transform = `rotate(${rotation}deg)`;
            }
            
            // Animasi latar belakang
            dashboardContainer.style.backgroundPosition = `${speedValue}px ${speedValue/2}px`;
            
            requestAnimationFrame(updateSpeedometer);
        }
        
        // Mulai animasi
        updateSpeedometer();
    }
    
    // Efek speedometer pada scroll
    window.addEventListener('scroll', function() {
        const scrollTop = window.pageYOffset || document.documentElement.scrollTop;
        const maxScroll = document.body.scrollHeight - window.innerHeight;
        const scrollPercentage = (scrollTop / maxScroll) * 100;
        
        // Update speedometer gauge jika ada
        const gaugeElements = document.querySelectorAll('.speed-gauge');
        gaugeElements.forEach(gauge => {
            const rotation = (scrollPercentage / 100) * 180 - 90;
            gauge.style.transform = `rotate(${rotation}deg)`;
        });
    });
}
