<?php
/**
 * Process Address Form
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Check if form is submitted
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get form data
    $address_type = clean_input($_POST['address_type']);
    $address_label = clean_input($_POST['address_label']);
    $recipient_name = clean_input($_POST['recipient_name']);
    $phone = clean_input($_POST['phone']);
    $province = clean_input($_POST['province']);
    $city = clean_input($_POST['city']);
    $district = clean_input($_POST['district']);
    $postal_code = clean_input($_POST['postal_code']);
    $full_address = clean_input($_POST['full_address']);
    $is_default = isset($_POST['is_default']) ? 1 : 0;
    
    // Validate required fields
    if (empty($recipient_name) || empty($phone) || empty($province) || empty($city) || empty($full_address)) {
        $_SESSION['error'] = "Semua field yang bertanda * wajib diisi.";
        header("Location: shipping-address.php");
        exit;
    }
    
    // Validate phone number
    if (!preg_match('/^[0-9+\-\s]{8,15}$/', $phone)) {
        $_SESSION['error'] = "Format nomor telepon tidak valid.";
        header("Location: shipping-address.php");
        exit;
    }
    
    try {
        // If this is set as default, unset all other default addresses
        if ($is_default) {
            $unset_default_sql = "UPDATE user_addresses SET is_default = 0 WHERE user_id = ?";
            $unset_default_stmt = $conn->prepare($unset_default_sql);
            $unset_default_stmt->bind_param("i", $user_id);
            $unset_default_stmt->execute();
        }
        
        // Check if we're editing an existing address
        if (isset($_POST['address_id']) && !empty($_POST['address_id'])) {
            $address_id = intval($_POST['address_id']);
            
            // Verify that the address belongs to the user
            $check_sql = "SELECT id FROM user_addresses WHERE id = ? AND user_id = ?";
            $check_stmt = $conn->prepare($check_sql);
            $check_stmt->bind_param("ii", $address_id, $user_id);
            $check_stmt->execute();
            $check_result = $check_stmt->get_result();
            
            if ($check_result->num_rows == 0) {
                $_SESSION['error'] = "Alamat tidak ditemukan atau Anda tidak memiliki akses.";
                header("Location: shipping-address.php");
                exit;
            }
            
            // Update existing address
            $update_sql = "UPDATE user_addresses SET 
                            address_type = ?, 
                            address_label = ?, 
                            recipient_name = ?, 
                            phone = ?, 
                            province = ?, 
                            city = ?, 
                            district = ?, 
                            postal_code = ?, 
                            full_address = ?, 
                            is_default = ? 
                          WHERE id = ? AND user_id = ?";
            
            $update_stmt = $conn->prepare($update_sql);
            $update_stmt->bind_param("sssssssssiis", 
                $address_type, 
                $address_label, 
                $recipient_name, 
                $phone, 
                $province, 
                $city, 
                $district, 
                $postal_code, 
                $full_address, 
                $is_default,
                $address_id,
                $user_id
            );
            
            if ($update_stmt->execute()) {
                $_SESSION['success'] = "Alamat berhasil diperbarui.";
            } else {
                $_SESSION['error'] = "Gagal memperbarui alamat: " . $conn->error;
            }
        } else {
            // Insert new address
            $insert_sql = "INSERT INTO user_addresses 
                          (user_id, address_type, address_label, recipient_name, phone, province, city, district, postal_code, full_address, is_default) 
                          VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
            
            $insert_stmt = $conn->prepare($insert_sql);
            $insert_stmt->bind_param("isssssssssi", 
                $user_id, 
                $address_type, 
                $address_label, 
                $recipient_name, 
                $phone, 
                $province, 
                $city, 
                $district, 
                $postal_code, 
                $full_address, 
                $is_default
            );
            
            if ($insert_stmt->execute()) {
                $_SESSION['success'] = "Alamat baru berhasil ditambahkan.";
            } else {
                $_SESSION['error'] = "Gagal menambahkan alamat: " . $conn->error;
            }
        }
    } catch (Throwable $e) {
        $_SESSION['error'] = "Terjadi kesalahan: " . $e->getMessage();
    }
    
    // Redirect back to shipping address page
    header("Location: shipping-address.php");
    exit;
} else {
    // If not POST request, redirect to shipping address page
    header("Location: shipping-address.php");
    exit;
}
?>