<?php
/**
 * Modern Account Dashboard
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Get user information
try {
    $user_sql = "SELECT * FROM users WHERE user_id = ?";
    $user_stmt = $conn->prepare($user_sql);
    $user_stmt->bind_param("i", $user_id);
    $user_stmt->execute();
    $user_result = $user_stmt->get_result();
    $user = $user_result->fetch_assoc();
} catch (Throwable $e) {
    die("Error fetching user data: " . $e->getMessage());
}

// Get user statistics
try {
    // Get bid statistics
    $bid_stats_sql = "SELECT 
                        COUNT(*) as total_bids,
                        SUM(CASE WHEN is_winning = 1 THEN 1 ELSE 0 END) as winning_bids,
                        MAX(bid_amount) as highest_bid
                      FROM bids 
                      WHERE bidder_id = ?";
    $bid_stats_stmt = $conn->prepare($bid_stats_sql);
    $bid_stats_stmt->bind_param("i", $user_id);
    $bid_stats_stmt->execute();
    $bid_stats_result = $bid_stats_stmt->get_result();
    $bid_stats = $bid_stats_result->fetch_assoc();
    
    // Get transaction statistics
    $transaction_stats_sql = "SELECT 
                                SUM(CASE WHEN type = 'deposit' AND status = 'completed' THEN amount ELSE 0 END) as total_deposit,
                                SUM(CASE WHEN type = 'withdrawal' AND status = 'completed' THEN amount ELSE 0 END) as total_withdrawal,
                                COUNT(CASE WHEN status = 'pending' THEN 1 END) as pending_transactions
                              FROM transactions 
                              WHERE user_id = ?";
    $transaction_stats_stmt = $conn->prepare($transaction_stats_sql);
    $transaction_stats_stmt->bind_param("i", $user_id);
    $transaction_stats_stmt->execute();
    $transaction_stats_result = $transaction_stats_stmt->get_result();
    $transaction_stats = $transaction_stats_result->fetch_assoc();
    
    // Get active auctions user is participating in
    $active_auctions_sql = "SELECT COUNT(DISTINCT v.vehicle_id) as active_auctions
                           FROM bids b
                           JOIN vehicles v ON b.vehicle_id = v.vehicle_id
                           WHERE b.bidder_id = ? AND v.status = 'active'";
    $active_auctions_stmt = $conn->prepare($active_auctions_sql);
    $active_auctions_stmt->bind_param("i", $user_id);
    $active_auctions_stmt->execute();
    $active_auctions_result = $active_auctions_stmt->get_result();
    $active_auctions = $active_auctions_result->fetch_assoc()['active_auctions'];
    
} catch (Throwable $e) {
    error_log("Error fetching user statistics: " . $e->getMessage());
}

// Get recent bids
try {
$recent_bids_sql = "SELECT b.*, v.brand, v.model, v.year, v.current_bid, v.end_date, v.image as main_image
                   FROM bids b
                   JOIN vehicles v ON b.vehicle_id = v.vehicle_id
                   WHERE b.bidder_id = ?
                   ORDER BY b.bid_time DESC
                   LIMIT 5";

    $recent_bids_stmt = $conn->prepare($recent_bids_sql);
    $recent_bids_stmt->bind_param("i", $user_id);
    $recent_bids_stmt->execute();
    $recent_bids_result = $recent_bids_stmt->get_result();
    $recent_bids = [];
    while ($row = $recent_bids_result->fetch_assoc()) {
        $recent_bids[] = $row;
    }
} catch (Throwable $e) {
    error_log("Error fetching recent bids: " . $e->getMessage());
}

// Get recent transactions
try {
    $recent_transactions_sql = "SELECT *
                              FROM transactions
                              WHERE user_id = ?
                              ORDER BY created_at DESC
                              LIMIT 5";
    $recent_transactions_stmt = $conn->prepare($recent_transactions_sql);
    $recent_transactions_stmt->bind_param("i", $user_id);
    $recent_transactions_stmt->execute();
    $recent_transactions_result = $recent_transactions_stmt->get_result();
    $recent_transactions = [];
    while ($row = $recent_transactions_result->fetch_assoc()) {
        $recent_transactions[] = $row;
    }
} catch (Throwable $e) {
    error_log("Error fetching recent transactions: " . $e->getMessage());
}

// Set page title and flags
$page_title = "Dashboard";
$is_dashboard_page = true;
$use_modern_dashboard = true;
$page_specific_css = '<link href="css/modern-effects.css" rel="stylesheet">';

// Include header
include("includes/header-2025.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($success)): ?>
    <div class="alert-2025 alert-2025-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($error)): ?>
    <div class="alert-2025 alert-2025-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php include("includes/account-navbar.php"); ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <!-- Welcome Section -->
            <div class="card-2025 mb-4 slide-down">
                <div class="card-2025-body">
                    <div class="d-flex align-items-center">
                        <div class="welcome-icon me-4">
                            <i class="fa fa-user-circle fa-3x text-primary"></i>
                        </div>
                        <div>
                            <h2 class="mb-1 gradient-text">Selamat Datang, <?php echo $user['username']; ?>!</h2>
                            <p class="text-muted mb-0">Terakhir login: <?php echo date('d M Y H:i', strtotime($user['last_login'])); ?></p>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Statistics Cards -->
            <div class="row mb-4">
                <div class="col-md-3 mb-3">
                    <div class="card-2025 hover-lift slide-up delay-1">
                        <div class="card-2025-body text-center py-4">
                            <div class="stat-icon mb-3">
                                <i class="fa fa-wallet"></i>
                            </div>
                            <h3 class="stat-value"><?php echo format_money($user['balance']); ?></h3>
                            <p class="stat-label">Saldo Anda</p>
                        </div>
                    </div>
                </div>
                <div class="col-md-3 mb-3">
                    <div class="card-2025 hover-lift slide-up delay-2">
                        <div class="card-2025-body text-center py-4">
                            <div class="stat-icon mb-3">
                                <i class="fa fa-gavel"></i>
                            </div>
                            <h3 class="stat-value"><?php echo number_format($bid_stats['total_bids'] ?? 0); ?></h3>
                            <p class="stat-label">Total Bid</p>
                        </div>
                    </div>
                </div>
                <div class="col-md-3 mb-3">
                    <div class="card-2025 hover-lift slide-up delay-3">
                        <div class="card-2025-body text-center py-4">
                            <div class="stat-icon mb-3">
                                <i class="fa fa-trophy"></i>
                            </div>
                            <h3 class="stat-value"><?php echo number_format($bid_stats['winning_bids'] ?? 0); ?></h3>
                            <p class="stat-label">Bid Tertinggi</p>
                        </div>
                    </div>
                </div>
                <div class="col-md-3 mb-3">
                    <div class="card-2025 hover-lift slide-up delay-4">
                        <div class="card-2025-body text-center py-4">
                            <div class="stat-icon mb-3">
                                <i class="fa fa-car"></i>
                            </div>
                            <h3 class="stat-value"><?php echo number_format($active_auctions ?? 0); ?></h3>
                            <p class="stat-label">Lelang Aktif</p>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Quick Actions -->
            <div class="card-2025 mb-4 slide-left">
                <div class="card-2025-header">
                    <h3 class="card-2025-title"><i class="fa fa-bolt"></i> Aksi Cepat</h3>
                </div>
                <div class="card-2025-body">
                    <div class="row">
                        <div class="col-md-3 col-6 mb-3 mb-md-0">
                            <a href="topup-modern.php" class="quick-action-card hover-scale">
                                <div class="quick-action-icon">
                                    <i class="fa fa-plus-circle"></i>
                                </div>
                                <h5>Top Up</h5>
                                <p>Tambah saldo</p>
                            </a>
                        </div>
                        <div class="col-md-3 col-6 mb-3 mb-md-0">
                            <a href="withdraw-modern.php" class="quick-action-card hover-scale">
                                <div class="quick-action-icon">
                                    <i class="fa fa-minus-circle"></i>
                                </div>
                                <h5>Tarik</h5>
                                <p>Tarik saldo</p>
                            </a>
                        </div>
                        <div class="col-md-3 col-6">
                            <a href="auctions.php" class="quick-action-card hover-scale">
                                <div class="quick-action-icon">
                                    <i class="fa fa-search"></i>
                                </div>
                                <h5>Lelang</h5>
                                <p>Cari lelang</p>
                            </a>
                        </div>
                        <div class="col-md-3 col-6">
                            <a href="shipping-address.php" class="quick-action-card hover-scale">
                                <div class="quick-action-icon">
                                    <i class="fa fa-map-marker-alt"></i>
                                </div>
                                <h5>Alamat</h5>
                                <p>Kelola alamat</p>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Tabs for Recent Activities -->
            <div class="card-2025 slide-right">
                <div class="card-2025-header">
                    <h3 class="card-2025-title"><i class="fa fa-history"></i> Aktivitas Terbaru</h3>
                </div>
                <div class="card-2025-body">
                    <ul class="tabs-2025" id="activityTabs" role="tablist">
                        <li class="tab-2025 active" id="bids-tab-btn" data-bs-toggle="tab" data-bs-target="#bids-tab" role="tab" aria-controls="bids-tab" aria-selected="true">
                            <i class="fa fa-gavel me-2"></i>Bid Terbaru
                        </li>
                        <li class="tab-2025" id="transactions-tab-btn" data-bs-toggle="tab" data-bs-target="#transactions-tab" role="tab" aria-controls="transactions-tab" aria-selected="false">
                            <i class="fa fa-exchange-alt me-2"></i>Transaksi
                        </li>
                        <li class="tab-2025" id="wallet-tab-btn" data-bs-toggle="tab" data-bs-target="#wallet-tab" role="tab" aria-controls="wallet-tab" aria-selected="false">
                            <i class="fa fa-wallet me-2"></i>Saldo
                        </li>
                        <li class="tab-2025" id="shipping-tab-btn" data-bs-toggle="tab" data-bs-target="#shipping-tab" role="tab" aria-controls="shipping-tab" aria-selected="false">
                            <i class="fa fa-map-marker-alt me-2"></i>Alamat
                        </li>
                    </ul>
                    
                    <div class="tab-content-2025" id="activityTabsContent">
                        <!-- Bids Tab -->
                        <div class="tab-pane-2025 active" id="bids-tab" role="tabpanel" aria-labelledby="bids-tab">
                            <?php include("includes/bids-tab.php"); ?>
                        </div>
                        
                        <!-- Transactions Tab -->
                        <div class="tab-pane-2025" id="transactions-tab" role="tabpanel" aria-labelledby="transactions-tab">
                            <?php include("includes/transactions-tab.php"); ?>
                        </div>
                        
                        <!-- Wallet Tab -->
                        <div class="tab-pane-2025" id="wallet-tab" role="tabpanel" aria-labelledby="wallet-tab">
                            <?php include("includes/wallet-tab.php"); ?>
                        </div>
                        
                        <!-- Shipping Tab -->
                        <div class="tab-pane-2025" id="shipping-tab" role="tabpanel" aria-labelledby="shipping-tab">
                            <?php include("includes/shipping-tab.php"); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
/* Welcome Section */
.welcome-icon {
    width: 70px;
    height: 70px;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 50%;
    background-color: rgba(74, 110, 224, 0.1);
    color: var(--primary);
}

/* Quick Action Cards */
.quick-action-card {
    display: block;
    text-align: center;
    padding: 20px;
    border-radius: var(--border-radius);
    background-color: var(--card-bg);
    box-shadow: 0 3px 10px rgba(0,0,0,0.05);
    color: var(--text-color);
    text-decoration: none;
    transition: all 0.3s ease;
    height: 100%;
}

.quick-action-card:hover {
    color: var(--text-color);
    text-decoration: none;
}

.quick-action-icon {
    width: 50px;
    height: 50px;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 50%;
    background-color: rgba(74, 110, 224, 0.1);
    color: var(--primary);
    font-size: 1.25rem;
    margin: 0 auto 15px;
}

.quick-action-card h5 {
    font-size: 1rem;
    font-weight: 600;
    margin-bottom: 5px;
}

.quick-action-card p {
    font-size: 0.85rem;
    color: var(--secondary);
    margin-bottom: 0;
}

/* Responsive */
@media (max-width: 768px) {
    .quick-action-card {
        margin-bottom: 15px;
    }
}
</style>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Tab functionality
    const tabs = document.querySelectorAll('.tab-2025');
    const tabPanes = document.querySelectorAll('.tab-pane-2025');
    
    tabs.forEach(tab => {
        tab.addEventListener('click', function() {
            // Remove active class from all tabs and tab panes
            tabs.forEach(t => t.classList.remove('active'));
            tabPanes.forEach(p => p.classList.remove('active'));
            
            // Add active class to current tab
            this.classList.add('active');
            
            // Get target tab pane
            const target = document.querySelector(this.getAttribute('data-bs-target'));
            if (target) {
                target.classList.add('active');
            }
        });
    });
});
</script>

<?php include("includes/footer-2025.php"); ?>