<?php
// Set page title
$page_title = "Dashboard";

// Include header
include 'includes/header.php';

// Get statistics for dashboard using the new db_query functions
$stats = [
    'users' => db_get_row("SELECT COUNT(*) as total FROM users")['total'] ?? 0,
    'vehicles' => db_get_row("SELECT COUNT(*) as total FROM vehicles")['total'] ?? 0,
    'active_auctions' => db_get_row("SELECT COUNT(*) as total FROM vehicles WHERE status = 'active'")['total'] ?? 0,
    'pending_transactions' => db_get_row("SELECT COUNT(*) as total FROM transactions WHERE status = 'pending'")['total'] ?? 0,
    'total_bids' => db_get_row("SELECT COUNT(*) as total FROM bids")['total'] ?? 0,
    'total_revenue' => db_get_row("SELECT SUM(amount) as total FROM transactions WHERE type = 'deposit' AND status = 'completed'")['total'] ?? 0
];

// Get recent activities
$recent = [
    'users' => db_get_rows("SELECT * FROM users ORDER BY created_at DESC LIMIT 5"),
    'transactions' => db_get_rows("SELECT t.*, u.username FROM transactions t JOIN users u ON t.user_id = u.user_id ORDER BY t.created_at DESC LIMIT 5"),
    'auctions' => db_get_rows("SELECT v.*, u.username FROM vehicles v LEFT JOIN users u ON v.seller_id = u.user_id ORDER BY v.created_at DESC LIMIT 5")
];
?>

<div class="admin-stats">
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-users"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo number_format($stats['users']); ?></h3>
            <p>Total Pengguna</p>
        </div>
    </div>
    
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-car"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo number_format($stats['vehicles']); ?></h3>
            <p>Total Kendaraan</p>
        </div>
    </div>
    
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-gavel"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo number_format($stats['active_auctions']); ?></h3>
            <p>Lelang Aktif</p>
        </div>
    </div>
    
    <div class="admin-stat-card">
        <div class="admin-stat-icon">
            <i class="fa fa-money-bill-wave"></i>
        </div>
        <div class="admin-stat-info">
            <h3><?php echo format_money($stats['total_revenue']); ?></h3>
            <p>Total Pendapatan</p>
        </div>
    </div>
</div>

<div class="row">
    <div class="col-lg-8">
        <div class="admin-card">
            <div class="admin-card-header">
                <h2>Transaksi Terbaru</h2>
                <a href="transactions.php" class="admin-btn admin-btn-outline admin-btn-sm">Lihat Semua</a>
            </div>
            <div class="admin-card-body">
                <div class="table-responsive">
                    <table class="admin-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>Pengguna</th>
                                <th>Jumlah</th>
                                <th>Tipe</th>
                                <th>Status</th>
                                <th>Tanggal</th>
                                <th>Aksi</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($recent['transactions']) > 0): ?>
                                <?php foreach ($recent['transactions'] as $transaction): ?>
                                    <tr>
                                        <td>#<?php echo $transaction['transaction_id']; ?></td>
                                        <td><?php echo htmlspecialchars($transaction['username']); ?></td>
                                        <td><?php echo format_money($transaction['amount']); ?></td>
                                        <td>
                                            <?php
                                            switch ($transaction['type']) {
                                                case 'deposit':
                                                    echo '<span class="badge bg-success">Top-up</span>';
                                                    break;
                                                case 'withdrawal':
                                                    echo '<span class="badge bg-warning">Penarikan</span>';
                                                    break;
                                                case 'bid_hold':
                                                    echo '<span class="badge bg-info">Hold Bid</span>';
                                                    break;
                                                case 'bid_release':
                                                    echo '<span class="badge bg-primary">Release Bid</span>';
                                                    break;
                                                case 'winning_payment':
                                                    echo '<span class="badge bg-dark">Pembayaran Menang</span>';
                                                    break;
                                                default:
                                                    echo $transaction['type'];
                                            }
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            switch ($transaction['status']) {
                                                case 'pending':
                                                    echo '<span class="badge bg-warning">Pending</span>';
                                                    break;
                                                case 'completed':
                                                    echo '<span class="badge bg-success">Selesai</span>';
                                                    break;
                                                case 'rejected':
                                                    echo '<span class="badge bg-danger">Ditolak</span>';
                                                    break;
                                                default:
                                                    echo $transaction['status'];
                                            }
                                            ?>
                                        </td>
                                        <td><?php echo date('d M Y H:i', strtotime($transaction['created_at'])); ?></td>
                                        <td>
                                            <a href="transaction-detail.php?id=<?php echo $transaction['transaction_id']; ?>" class="admin-btn admin-btn-primary admin-btn-sm admin-btn-icon">
                                                <i class="fa fa-eye"></i>
                                            </a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="7" class="text-center">Belum ada transaksi</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
    
    <div class="col-lg-4">
        <div class="admin-card">
            <div class="admin-card-header">
                <h2>Pengguna Terbaru</h2>
                <a href="users.php" class="admin-btn admin-btn-outline admin-btn-sm">Lihat Semua</a>
            </div>
            <div class="admin-card-body p-0">
                <ul class="list-group list-group-flush">
                    <?php if (count($recent['users']) > 0): ?>
                        <?php foreach ($recent['users'] as $user): ?>
                            <li class="list-group-item d-flex justify-content-between align-items-center">
                                <div>
                                    <h6 class="mb-0"><?php echo htmlspecialchars($user['username']); ?></h6>
                                    <small class="text-muted"><?php echo htmlspecialchars($user['email']); ?></small>
                                </div>
                                <a href="user-detail.php?id=<?php echo $user['user_id']; ?>" class="admin-btn admin-btn-primary admin-btn-sm admin-btn-icon">
                                    <i class="fa fa-eye"></i>
                                </a>
                            </li>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <li class="list-group-item text-center">Belum ada pengguna</li>
                    <?php endif; ?>
                </ul>
            </div>
        </div>
        
        <div class="admin-card mt-4">
            <div class="admin-card-header">
                <h2>Aktivitas Sistem</h2>
            </div>
            <div class="admin-card-body">
                <div class="activity-timeline">
                    <div class="activity-item">
                        <div class="activity-icon bg-success">
                            <i class="fa fa-check"></i>
                        </div>
                        <div class="activity-content">
                            <h6 class="mb-1">Database Terhubung</h6>
                            <p class="text-muted mb-0">Koneksi database aktif dan berfungsi dengan baik</p>
                        </div>
                    </div>
                    
                    <div class="activity-item">
                        <div class="activity-icon bg-info">
                            <i class="fa fa-sync"></i>
                        </div>
                        <div class="activity-content">
                            <h6 class="mb-1">Auto-Update Status Lelang</h6>
                            <p class="text-muted mb-0">Sistem auto-update status lelang berjalan normal</p>
                        </div>
                    </div>
                    
                    <div class="activity-item">
                        <div class="activity-icon bg-warning">
                            <i class="fa fa-bell"></i>
                        </div>
                        <div class="activity-content">
                            <h6 class="mb-1">Notifikasi</h6>
                            <p class="text-muted mb-0">Sistem notifikasi aktif dan berfungsi dengan baik</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="admin-card mt-4">
    <div class="admin-card-header">
        <h2>Kendaraan Terbaru</h2>
        <a href="vehicles.php" class="admin-btn admin-btn-outline admin-btn-sm">Lihat Semua</a>
    </div>
    <div class="admin-card-body">
        <div class="table-responsive">
            <table class="admin-table">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th>Kendaraan</th>
                        <th>Penjual</th>
                        <th>Harga Awal</th>
                        <th>Current Bid</th>
                        <th>Status</th>
                        <th>Tanggal Berakhir</th>
                        <th>Aksi</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (count($recent['auctions']) > 0): ?>
                        <?php foreach ($recent['auctions'] as $vehicle): ?>
                            <tr>
                                <td>#<?php echo $vehicle['vehicle_id']; ?></td>
                                <td><?php echo htmlspecialchars($vehicle['title'] ?? $vehicle['make'] . ' ' . $vehicle['model']); ?></td>
                                <td><?php echo htmlspecialchars($vehicle['username'] ?? 'Admin'); ?></td>
                                <td><?php echo format_money($vehicle['starting_price']); ?></td>
                                <td>
                                    <?php echo $vehicle['current_bid'] ? format_money($vehicle['current_bid']) : '-'; ?>
                                </td>
                                <td>
                                    <?php
                                    switch ($vehicle['status']) {
                                        case 'upcoming':
                                            echo '<span class="badge bg-info">Akan Datang</span>';
                                            break;
                                        case 'active':
                                            echo '<span class="badge bg-success">Aktif</span>';
                                            break;
                                        case 'ended':
                                            echo '<span class="badge bg-secondary">Selesai</span>';
                                            break;
                                        case 'sold':
                                            echo '<span class="badge bg-primary">Terjual</span>';
                                            break;
                                        case 'not_sold':
                                            echo '<span class="badge bg-danger">Tidak Terjual</span>';
                                            break;
                                        default:
                                            echo $vehicle['status'];
                                    }
                                    ?>
                                </td>
                                <td><?php echo date('d M Y H:i', strtotime($vehicle['auction_end'])); ?></td>
                                <td>
                                    <a href="vehicle-form.php?id=<?php echo $vehicle['vehicle_id']; ?>" class="admin-btn admin-btn-primary admin-btn-sm admin-btn-icon">
                                        <i class="fa fa-edit"></i>
                                    </a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="8" class="text-center">Belum ada kendaraan</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<style>
.activity-timeline {
    position: relative;
    padding-left: 30px;
}

.activity-timeline::before {
    content: '';
    position: absolute;
    top: 0;
    left: 15px;
    height: 100%;
    width: 2px;
    background-color: rgba(0,0,0,0.1);
}

.activity-item {
    position: relative;
    padding-bottom: 20px;
}

.activity-icon {
    position: absolute;
    left: -30px;
    width: 30px;
    height: 30px;
    border-radius: 50%;
    display: flex;
    align-items: center;
    justify-content: center;
    color: white;
    z-index: 1;
}

.activity-content {
    padding-left: 15px;
}
</style>

<?php
// Include footer
include 'includes/footer.php';
?>