<?php
/**
 * Comment API Endpoint
 */

require_once '../config/init.php';

// Ensure request is POST
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    echo json_encode(['error' => 'Method not allowed']);
    exit;
}

// Ensure user is logged in
if (!isset($_SESSION['user_id'])) {
    http_response_code(401);
    echo json_encode(['error' => 'Unauthorized']);
    exit;
}

// Get JSON input
$input = json_decode(file_get_contents('php://input'), true);
$user_id = $_SESSION['user_id'];
$vehicle_id = isset($input['vehicle_id']) ? (int)$input['vehicle_id'] : 0;
$comment = isset($input['comment']) ? trim($input['comment']) : '';

if (!$vehicle_id || empty($comment)) {
    http_response_code(400);
    echo json_encode(['error' => 'Invalid input parameters']);
    exit;
}

try {
    // Insert comment
    $sql = "INSERT INTO vehicle_comments (vehicle_id, user_id, comment, status) VALUES (?, ?, ?, 'pending')";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("iis", $vehicle_id, $user_id, $comment);
    $stmt->execute();
    
    // Get user info for response
    $user_sql = "SELECT username, full_name FROM users WHERE user_id = ?";
    $user_stmt = $conn->prepare($user_sql);
    $user_stmt->bind_param("i", $user_id);
    $user_stmt->execute();
    $user = $user_stmt->get_result()->fetch_assoc();
    
    echo json_encode([
        'success' => true,
        'message' => 'Komentar berhasil dikirim dan sedang menunggu moderasi',
        'comment' => [
            'user_name' => $user['full_name'] ?: $user['username'],
            'comment' => $comment,
            'created_at' => date('Y-m-d H:i:s')
        ]
    ]);
    
} catch (Throwable $e) {
    error_log("Comment error: " . $e->getMessage());
    
    http_response_code(500);
    echo json_encode([
        'error' => 'Failed to submit comment',
        'message' => $e->getMessage()
    ]);
}