<?php
/**
 * Generate Test Notifications
 * Script untuk membuat notifikasi dummy untuk pengujian
 * LelangMobil - Modern Web App 2025
 */

// Include database connection
require_once '../config/database.php';

// Start session if not already started
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Ensure this script can be run only when logged in
if (!isset($_SESSION['user_id'])) {
    die('Error: Please login first to generate test notifications.');
}

$user_id = $_SESSION['user_id'];

// Check if notifications table exists
$tableCheckResult = $conn->query("SHOW TABLES LIKE 'notifications'");
$tableExists = $tableCheckResult->num_rows > 0;

// Create table if it doesn't exist
if (!$tableExists) {
    $createTableSQL = "
    CREATE TABLE notifications (
        notification_id INT AUTO_INCREMENT PRIMARY KEY,
        user_id INT NOT NULL,
        type VARCHAR(50) NOT NULL,
        message TEXT NOT NULL,
        url VARCHAR(255) DEFAULT NULL,
        is_read TINYINT(1) DEFAULT 0,
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        read_at TIMESTAMP NULL DEFAULT NULL,
        entity_type VARCHAR(50) DEFAULT NULL,
        entity_id INT DEFAULT NULL,
        INDEX (user_id),
        INDEX (type),
        INDEX (is_read)
    )";
    
    if ($conn->query($createTableSQL)) {
        echo "Tabel notifikasi berhasil dibuat.<br>";
    } else {
        die("Error creating table: " . $conn->error);
    }
}

// Sample notification types and messages
$notificationTypes = [
    'bid' => [
        'message' => 'Anda telah memenangkan lelang untuk kendaraan {vehicle_name}!',
        'url' => 'vehicle.php?id={vehicle_id}'
    ],
    'outbid' => [
        'message' => 'Tawaran Anda untuk {vehicle_name} telah dikalahkan oleh pengguna lain.',
        'url' => 'vehicle.php?id={vehicle_id}'
    ],
    'payment' => [
        'message' => 'Pembayaran Anda sebesar Rp {amount} telah dikonfirmasi.',
        'url' => 'transactions-menu.php'
    ],
    'auction_end' => [
        'message' => 'Lelang untuk {vehicle_name} telah berakhir.',
        'url' => 'vehicle.php?id={vehicle_id}'
    ],
    'system' => [
        'message' => 'Sistem lelang telah diperbarui. Fitur baru tersedia!',
        'url' => 'new-features.php'
    ]
];

// Sample vehicle names and IDs
$vehicles = [
    ['id' => 1, 'name' => 'Toyota Avanza 2018'],
    ['id' => 2, 'name' => 'Honda Jazz RS 2019'],
    ['id' => 3, 'name' => 'Mitsubishi Xpander 2020'],
    ['id' => 4, 'name' => 'Daihatsu Terios 2017'],
    ['id' => 5, 'name' => 'Suzuki Ertiga 2019']
];

// Sample payment amounts
$amounts = [
    '1,500,000',
    '2,750,000',
    '4,250,000',
    '3,125,000',
    '5,000,000'
];

// Generate random notifications
$notificationCount = isset($_GET['count']) ? intval($_GET['count']) : 5;
$notificationCount = min(max($notificationCount, 1), 10); // Limit between 1-10

$insertedCount = 0;
for ($i = 0; $i < $notificationCount; $i++) {
    // Select random notification type
    $type = array_rand($notificationTypes);
    $notificationTemplate = $notificationTypes[$type];
    
    // Prepare message and URL
    $message = $notificationTemplate['message'];
    $url = $notificationTemplate['url'];
    
    // Replace placeholders for bid and auction notifications
    if ($type == 'bid' || $type == 'outbid' || $type == 'auction_end') {
        $randomVehicle = $vehicles[array_rand($vehicles)];
        $message = str_replace('{vehicle_name}', $randomVehicle['name'], $message);
        $url = str_replace('{vehicle_id}', $randomVehicle['id'], $url);
        $entity_type = 'vehicle';
        $entity_id = $randomVehicle['id'];
    } 
    // Replace placeholders for payment notifications
    elseif ($type == 'payment') {
        $randomAmount = $amounts[array_rand($amounts)];
        $message = str_replace('{amount}', $randomAmount, $message);
        $entity_type = 'transaction';
        $entity_id = rand(1000, 9999);
    } 
    // System notifications don't need replacements
    else {
        $entity_type = 'system';
        $entity_id = null;
    }
    
    // Create notification timestamp (within the last 24 hours)
    $hoursAgo = rand(0, 24);
    $minutesAgo = rand(0, 59);
    $secondsAgo = rand(0, 59);
    $timestamp = date('Y-m-d H:i:s', strtotime("-{$hoursAgo} hours -{$minutesAgo} minutes -{$secondsAgo} seconds"));
    
    // Insert notification into database
    $stmt = $conn->prepare("
        INSERT INTO notifications 
        (user_id, type, message, url, created_at, entity_type, entity_id) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");
    
    $stmt->bind_param("isssssi", 
        $user_id, 
        $type, 
        $message, 
        $url, 
        $timestamp, 
        $entity_type, 
        $entity_id
    );
    
    if ($stmt->execute()) {
        $insertedCount++;
    }
}

// Mark some as read (about 30% of them)
$readCount = round($insertedCount * 0.3);
if ($readCount > 0) {
    $stmt = $conn->prepare("
        UPDATE notifications 
        SET is_read = 1, read_at = NOW() 
        WHERE user_id = ? 
        ORDER BY RAND() 
        LIMIT ?
    ");
    $stmt->bind_param("ii", $user_id, $readCount);
    $stmt->execute();
}

// Output results
echo "Berhasil membuat {$insertedCount} notifikasi uji untuk user ID: {$user_id}<br>";
echo "({$readCount} notifikasi ditandai sebagai telah dibaca)<br><br>";
echo "<a href='../index.php'>Kembali ke Halaman Utama</a>";
?>
