<?php
/**
 * Error Fix DOM
 * LelangMobil Web App - Versi 2025
 * 
 * Script untuk memperbaiki error DOM manipulation
 */

// Set page title
$page_title = "Fix DOM Error - LelangMobil";

// Include header
include("includes/header.php");
?>

<div class="container py-5">
    <div class="row">
        <div class="col-lg-8 offset-lg-2">
            <div class="modern-card">
                <div class="modern-card-header">
                    <h2>Fix DOM Error</h2>
                </div>
                <div class="modern-card-body">
                    <div class="modern-alert modern-alert-info mb-4">
                        <i class="fa fa-info-circle"></i>
                        <div>
                            <h5>Perbaikan Error DOM</h5>
                            <p>Script ini akan memperbaiki error DOM manipulation yang umum terjadi, seperti:</p>
                            <ul>
                                <li>Failed to execute 'insertBefore' on 'Node': The node before which the new node is to be inserted is not a child of this node.</li>
                                <li>Cannot read property 'appendChild' of null</li>
                                <li>Cannot read property 'removeChild' of null</li>
                            </ul>
                        </div>
                    </div>
                    
                    <div class="mb-4">
                        <h5>Solusi yang Diterapkan:</h5>
                        <ol>
                            <li>Menambahkan file <code>dom-fix.js</code> yang dijalankan segera untuk memperbaiki error insertBefore</li>
                            <li>Menambahkan file <code>dom-safety.js</code> untuk memperbaiki masalah DOM manipulation yang umum terjadi</li>
                            <li>Memperbaiki file <code>page-loader.js</code> dengan menambahkan pengecekan keberadaan parent node</li>
                            <li>Memperbaiki file <code>error-handler.js</code> dengan menambahkan pengecekan untuk error insertBefore</li>
                            <li>Memperbaiki file <code>cleanup.js</code> dengan menambahkan fungsi fixDOMManipulationErrors</li>
                        </ol>
                    </div>
                    
                    <div class="mb-4">
                        <h5>Cara Kerja:</h5>
                        <p>Script ini bekerja dengan cara:</p>
                        <ol>
                            <li>Mengganti (override) fungsi DOM native seperti <code>insertBefore</code>, <code>appendChild</code>, dan <code>removeChild</code> dengan versi yang lebih aman</li>
                            <li>Menambahkan pengecekan keberadaan node sebelum melakukan operasi DOM</li>
                            <li>Menyediakan fungsi helper seperti <code>safeAppend</code>, <code>safeRemove</code>, dll. untuk operasi DOM yang lebih aman</li>
                            <li>Menangkap error DOM dan memberikan fallback yang aman</li>
                        </ol>
                    </div>
                    
                    <div class="mb-4">
                        <h5>Status:</h5>
                        <div class="modern-alert modern-alert-success">
                            <i class="fa fa-check-circle"></i>
                            <div>
                                <p>Perbaikan DOM error berhasil diterapkan!</p>
                            </div>
                        </div>
                    </div>
                    
                    <div class="mt-4">
                        <a href="index.php" class="modern-btn modern-btn-primary">Kembali ke Beranda</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
// Test DOM manipulation
document.addEventListener('DOMContentLoaded', function() {
    // Test insertBefore
    try {
        const parent = document.createElement('div');
        const newNode = document.createElement('span');
        const referenceNode = document.createElement('span');
        
        // Ini seharusnya tidak error meskipun referenceNode bukan child dari parent
        parent.insertBefore(newNode, referenceNode);
        
        console.log('insertBefore test passed');
    } catch (e) {
        console.error('insertBefore test failed:', e);
    }
    
    // Test appendChild
    try {
        const parent = document.createElement('div');
        const newNode = document.createElement('span');
        
        // Ini seharusnya tidak error
        parent.appendChild(newNode);
        
        console.log('appendChild test passed');
    } catch (e) {
        console.error('appendChild test failed:', e);
    }
    
    // Test removeChild
    try {
        const parent = document.createElement('div');
        const child = document.createElement('span');
        parent.appendChild(child);
        
        // Ini seharusnya tidak error
        parent.removeChild(child);
        
        console.log('removeChild test passed');
    } catch (e) {
        console.error('removeChild test failed:', e);
    }
    
    // Test removeChild dengan node yang bukan child
    try {
        const parent = document.createElement('div');
        const notChild = document.createElement('span');
        
        // Ini seharusnya tidak error meskipun notChild bukan child dari parent
        parent.removeChild(notChild);
        
        console.log('removeChild non-child test passed');
    } catch (e) {
        console.error('removeChild non-child test failed:', e);
    }
});
</script>

<?php include("includes/footer.php"); ?>