<?php
// Get current page for active menu highlighting
$current_page = basename($_SERVER['PHP_SELF']);

// Get user information if not already available
if (!isset($user) && isset($_SESSION['user_id'])) {
    $user_id = $_SESSION['user_id'];
    $user_sql = "SELECT * FROM users WHERE user_id = ?";
    $user_stmt = $conn->prepare($user_sql);
    $user_stmt->bind_param("i", $user_id);
    $user_stmt->execute();
    $user_result = $user_stmt->get_result();
    $user = $user_result->fetch_assoc();
}

// Get unread notifications count
$unread_notifications = 0;
if (function_exists('count_unread_notifications') && isset($_SESSION['user_id'])) {
    $unread_notifications = count_unread_notifications($_SESSION['user_id']);
}

// Get pending transactions count
$pending_transactions = 0;
if (isset($_SESSION['user_id'])) {
    $pending_sql = "SELECT COUNT(*) as count FROM transactions WHERE user_id = ? AND status = 'pending'";
    $pending_stmt = $conn->prepare($pending_sql);
    $pending_stmt->bind_param("i", $_SESSION['user_id']);
    $pending_stmt->execute();
    $pending_result = $pending_stmt->get_result();
    $pending_transactions = $pending_result->fetch_assoc()['count'];
}
?>

<div class="dashboard-sidebar mb-4">
    <div class="user-profile text-center mb-4">
        <div class="user-avatar mb-3">
            <?php if (!empty($user['profile_image'])): ?>
                <img src="<?php echo $user['profile_image']; ?>" alt="<?php echo $user['username']; ?>" class="rounded-circle">
            <?php else: ?>
                <div class="default-avatar">
                    <?php echo strtoupper(substr($user['username'], 0, 1)); ?>
                </div>
            <?php endif; ?>
        </div>
        <h5 class="mb-1"><?php echo $user['username']; ?></h5>
        <p class="text-muted small mb-2"><?php echo $user['email']; ?></p>
        <div class="user-balance">
            <span class="balance-label">Saldo:</span>
            <span class="balance-amount">Rp<?php echo number_format($user['balance'], 0, ',', '.'); ?></span>
        </div>
    </div>
    
    <div class="dashboard-nav">
        <a href="account-modern.php" class="dashboard-nav-item <?php echo ($current_page == 'account-modern.php') ? 'active' : ''; ?>">
            <i class="fa fa-tachometer-alt"></i> Dashboard
        </a>
        <a href="profile-modern.php" class="dashboard-nav-item <?php echo ($current_page == 'profile-modern.php') ? 'active' : ''; ?>">
            <i class="fa fa-user"></i> Profil Saya
        </a>
        <a href="bids-modern.php" class="dashboard-nav-item <?php echo ($current_page == 'bids-modern.php') ? 'active' : ''; ?>">
            <i class="fa fa-gavel"></i> Riwayat Bid
        </a>
        <a href="transactions-modern.php" class="dashboard-nav-item <?php echo ($current_page == 'transactions-modern.php') ? 'active' : ''; ?>">
            <i class="fa fa-history"></i> Riwayat Transaksi
        </a>
        <a href="topup-modern.php" class="dashboard-nav-item <?php echo ($current_page == 'topup-modern.php' || $current_page == 'upload-payment.php') ? 'active' : ''; ?>">
            <i class="fa fa-plus-circle"></i> Top Up Saldo
            <?php if ($pending_transactions > 0): ?>
                <span class="badge bg-warning rounded-pill ms-auto"><?php echo $pending_transactions; ?></span>
            <?php endif; ?>
        </a>
        <a href="withdraw-modern.php" class="dashboard-nav-item <?php echo ($current_page == 'withdraw-modern.php') ? 'active' : ''; ?>">
            <i class="fa fa-minus-circle"></i> Penarikan Saldo
        </a>
        <a href="shipping-address.php" class="dashboard-nav-item <?php echo ($current_page == 'shipping-address.php') ? 'active' : ''; ?>">
            <i class="fa fa-map-marker-alt"></i> Alamat Pengiriman
        </a>
        <a href="notifications.php" class="dashboard-nav-item <?php echo ($current_page == 'notifications.php') ? 'active' : ''; ?>">
            <i class="fa fa-bell"></i> Notifikasi
            <?php if ($unread_notifications > 0): ?>
                <span class="badge bg-danger rounded-pill ms-auto"><?php echo $unread_notifications; ?></span>
            <?php endif; ?>
        </a>
        <a href="settings-modern.php" class="dashboard-nav-item <?php echo ($current_page == 'settings-modern.php') ? 'active' : ''; ?>">
            <i class="fa fa-cog"></i> Pengaturan
        </a>
        <a href="logout.php" class="dashboard-nav-item">
            <i class="fa fa-sign-out-alt"></i> Logout
        </a>
    </div>
</div>

<style>
.user-profile {
    padding: 20px 0;
    border-bottom: 1px solid rgba(0,0,0,0.05);
}

.user-avatar {
    width: 80px;
    height: 80px;
    margin: 0 auto;
    position: relative;
}

.user-avatar img {
    width: 100%;
    height: 100%;
    object-fit: cover;
    border: 2px solid var(--primary);
}

.default-avatar {
    width: 100%;
    height: 100%;
    background-color: var(--primary);
    color: white;
    font-size: 2rem;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 50%;
}

.user-balance {
    background-color: rgba(74, 110, 224, 0.1);
    padding: 8px 15px;
    border-radius: 20px;
    display: inline-block;
    margin-top: 10px;
}

.balance-label {
    font-size: 0.85rem;
    color: var(--secondary);
    margin-right: 5px;
}

.balance-amount {
    font-weight: 700;
    color: var(--primary);
}

.dashboard-nav-item {
    display: flex;
    align-items: center;
    padding: 12px 15px;
    color: var(--text-color);
    text-decoration: none;
    border-radius: var(--border-radius);
    margin-bottom: 5px;
    transition: all 0.3s ease;
}

.dashboard-nav-item:hover {
    background-color: rgba(74, 110, 224, 0.1);
    color: var(--primary);
}

.dashboard-nav-item.active {
    background-color: var(--primary);
    color: white;
}

.dashboard-nav-item i {
    margin-right: 10px;
    width: 20px;
    text-align: center;
}

@media (max-width: 992px) {
    .dashboard-sidebar {
        margin-bottom: 30px;
    }
}
</style>