/**
 * JavaScript untuk popup alamat dan interaktivitas halaman akun
 * LelangMobil
 * Tanggal: 2025-05-03
 */

document.addEventListener("DOMContentLoaded", function() {
    // Menangani tab switching
    const tabs = document.querySelectorAll("#accountTabs button");
    tabs.forEach(tab => {
        tab.addEventListener("click", function() {
            // Reset semua tab
            document.querySelectorAll(".tab-pane").forEach(pane => {
                pane.classList.remove("show", "active");
            });
            
            // Aktifkan tab yang dipilih
            const target = this.getAttribute("data-bs-target");
            document.querySelector(target).classList.add("show", "active");
        });
    });
    
    // Auto-reload jika ada error loading bid history
    const errorEl = document.querySelector(".alert-danger");
    if (errorEl && errorEl.textContent.includes("Error pada sistem")) {
        setTimeout(() => {
            location.reload();
        }, 5000); // Reload after 5 seconds
    }
    
    // Tambahkan tombol untuk menampilkan modal alamat
    const addAddressBtn = document.querySelector('.add-address-btn');
    if (addAddressBtn) {
        addAddressBtn.addEventListener('click', function(e) {
            e.preventDefault();
            const addressModal = new bootstrap.Modal(document.getElementById('addressModal'));
            addressModal.show();
        });
    }
    
    // Menangani pemilihan tipe alamat
    const addressTypes = document.querySelectorAll('.address-type');
    if (addressTypes.length > 0) {
        addressTypes.forEach(type => {
            type.addEventListener('click', function() {
                // Hapus kelas aktif dari semua tipe
                addressTypes.forEach(t => t.classList.remove('active'));
                // Tambahkan kelas aktif ke tipe yang dipilih
                this.classList.add('active');
                // Update nilai input hidden
                document.getElementById('addressType').value = this.getAttribute('data-type');
            });
        });
    }
    
    // Handler untuk tombol simpan alamat
    const saveAddressBtn = document.getElementById('saveAddressBtn');
    if (saveAddressBtn) {
        saveAddressBtn.addEventListener('click', function() {
            const form = document.getElementById('addressForm');
            if (form.checkValidity()) {
                // Tampilkan loading state
                this.innerHTML = '<i class="fa fa-spinner fa-spin me-2"></i>Menyimpan...';
                this.disabled = true;
                
                // Submit form
                form.submit();
            } else {
                // Trigger validasi HTML5
                form.reportValidity();
            }
        });
    }
    
    // Untuk provinsi & kota dropdown
    const provinceSelect = document.getElementById('province');
    const citySelect = document.getElementById('city');
    const districtSelect = document.getElementById('district');
    
    if (provinceSelect && citySelect) {
        // Data kota berdasarkan provinsi (contoh sederhana)
        const cityData = {
            'DKI Jakarta': ['Jakarta Pusat', 'Jakarta Utara', 'Jakarta Barat', 'Jakarta Selatan', 'Jakarta Timur'],
            'Jawa Barat': ['Bandung', 'Bogor', 'Depok', 'Bekasi', 'Cimahi'],
            'Jawa Tengah': ['Semarang', 'Solo', 'Magelang', 'Pekalongan', 'Tegal'],
            'Jawa Timur': ['Surabaya', 'Malang', 'Sidoarjo', 'Gresik', 'Kediri'],
            'Bali': ['Denpasar', 'Badung', 'Gianyar', 'Tabanan', 'Karangasem']
        };
        
        // Ketika provinsi berubah, update pilihan kota
        provinceSelect.addEventListener('change', function() {
            const selectedProvince = this.value;
            citySelect.innerHTML = '<option value="">Pilih Kota/Kabupaten</option>';
            
            if (selectedProvince && cityData[selectedProvince]) {
                cityData[selectedProvince].forEach(city => {
                    const option = document.createElement('option');
                    option.value = city;
                    option.textContent = city;
                    citySelect.appendChild(option);
                });
            }
        });
    }
    
    // Tambahkan efek tilt 3D pada card
    const cards = document.querySelectorAll('.premium-card');
    cards.forEach(card => {
        card.addEventListener('mousemove', function(e) {
            const rect = this.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;
            
            const centerX = rect.width / 2;
            const centerY = rect.height / 2;
            
            const deltaX = (x - centerX) / 20;
            const deltaY = (y - centerY) / 20;
            
            this.style.transform = `perspective(1000px) rotateX(${-deltaY}deg) rotateY(${deltaX}deg) scale3d(1.02, 1.02, 1.02)`;
        });
        
        card.addEventListener('mouseleave', function() {
            this.style.transform = 'perspective(1000px) rotateX(0) rotateY(0) scale3d(1, 1, 1)';
        });
    });
});
