/**
 * Form Validator
 * LelangMobil Web App - Versi 2025
 * 
 * File ini berisi fungsi-fungsi untuk validasi form
 */

document.addEventListener('DOMContentLoaded', function() {
    // Validasi form login
    const loginForm = document.getElementById('loginForm');
    if (loginForm) {
        loginForm.addEventListener('submit', validateLoginForm);
    }
    
    // Validasi form registrasi
    const registerForm = document.getElementById('registerForm');
    if (registerForm) {
        registerForm.addEventListener('submit', validateRegisterForm);
    }
    
    // Validasi form ubah password
    const changePasswordForm = document.getElementById('changePasswordForm');
    if (changePasswordForm) {
        changePasswordForm.addEventListener('submit', validateChangePasswordForm);
    }
    
    // Validasi form edit profil
    const editProfileForm = document.getElementById('editProfileForm');
    if (editProfileForm) {
        editProfileForm.addEventListener('submit', validateEditProfileForm);
    }
    
    // Validasi form top up
    const topupForm = document.getElementById('topupForm');
    if (topupForm) {
        topupForm.addEventListener('submit', validateTopupForm);
    }
    
    // Validasi form withdraw
    const withdrawForm = document.getElementById('withdrawForm');
    if (withdrawForm) {
        withdrawForm.addEventListener('submit', validateWithdrawForm);
    }
    
    // Validasi form bid
    const bidForm = document.getElementById('bidForm');
    if (bidForm) {
        bidForm.addEventListener('submit', validateBidForm);
    }
    
    // Validasi form upload bukti pembayaran
    const paymentProofForm = document.getElementById('paymentProofForm');
    if (paymentProofForm) {
        paymentProofForm.addEventListener('submit', validatePaymentProofForm);
    }
    
    // Validasi form tambah alamat
    const addressForm = document.getElementById('addressForm');
    if (addressForm) {
        addressForm.addEventListener('submit', validateAddressForm);
    }
});

/**
 * Validasi form login
 */
function validateLoginForm(e) {
    const username = document.getElementById('username').value.trim();
    const password = document.getElementById('password').value.trim();
    
    if (username === '') {
        e.preventDefault();
        showError('username', 'Username atau email harus diisi');
        return false;
    }
    
    if (password === '') {
        e.preventDefault();
        showError('password', 'Password harus diisi');
        return false;
    }
    
    return true;
}

/**
 * Validasi form registrasi
 */
function validateRegisterForm(e) {
    const username = document.getElementById('username').value.trim();
    const email = document.getElementById('email').value.trim();
    const password = document.getElementById('password').value.trim();
    const confirmPassword = document.getElementById('confirm_password').value.trim();
    const terms = document.getElementById('terms');
    
    let isValid = true;
    
    if (username === '') {
        showError('username', 'Username harus diisi');
        isValid = false;
    } else if (username.length < 3) {
        showError('username', 'Username minimal 3 karakter');
        isValid = false;
    }
    
    if (email === '') {
        showError('email', 'Email harus diisi');
        isValid = false;
    } else if (!isValidEmail(email)) {
        showError('email', 'Format email tidak valid');
        isValid = false;
    }
    
    if (password === '') {
        showError('password', 'Password harus diisi');
        isValid = false;
    } else if (password.length < 8) {
        showError('password', 'Password minimal 8 karakter');
        isValid = false;
    }
    
    if (confirmPassword === '') {
        showError('confirm_password', 'Konfirmasi password harus diisi');
        isValid = false;
    } else if (password !== confirmPassword) {
        showError('confirm_password', 'Password dan konfirmasi password tidak cocok');
        isValid = false;
    }
    
    if (terms && !terms.checked) {
        showError('terms', 'Anda harus menyetujui syarat dan ketentuan');
        isValid = false;
    }
    
    if (!isValid) {
        e.preventDefault();
    }
    
    return isValid;
}

/**
 * Validasi form ubah password
 */
function validateChangePasswordForm(e) {
    const currentPassword = document.getElementById('current_password').value.trim();
    const newPassword = document.getElementById('new_password').value.trim();
    const confirmPassword = document.getElementById('confirm_password').value.trim();
    
    let isValid = true;
    
    if (currentPassword === '') {
        showError('current_password', 'Password saat ini harus diisi');
        isValid = false;
    }
    
    if (newPassword === '') {
        showError('new_password', 'Password baru harus diisi');
        isValid = false;
    } else if (newPassword.length < 8) {
        showError('new_password', 'Password baru minimal 8 karakter');
        isValid = false;
    }
    
    if (confirmPassword === '') {
        showError('confirm_password', 'Konfirmasi password harus diisi');
        isValid = false;
    } else if (newPassword !== confirmPassword) {
        showError('confirm_password', 'Password baru dan konfirmasi password tidak cocok');
        isValid = false;
    }
    
    if (!isValid) {
        e.preventDefault();
    }
    
    return isValid;
}

/**
 * Validasi form edit profil
 */
function validateEditProfileForm(e) {
    const fullName = document.getElementById('full_name').value.trim();
    const email = document.getElementById('email').value.trim();
    
    let isValid = true;
    
    if (fullName === '') {
        showError('full_name', 'Nama lengkap harus diisi');
        isValid = false;
    }
    
    if (email === '') {
        showError('email', 'Email harus diisi');
        isValid = false;
    } else if (!isValidEmail(email)) {
        showError('email', 'Format email tidak valid');
        isValid = false;
    }
    
    if (!isValid) {
        e.preventDefault();
    }
    
    return isValid;
}

/**
 * Validasi form top up
 */
function validateTopupForm(e) {
    const amount = document.getElementById('amount').value.trim();
    const bankName = document.getElementById('bank_name').value.trim();
    
    let isValid = true;
    
    if (amount === '') {
        showError('amount', 'Jumlah harus diisi');
        isValid = false;
    } else if (isNaN(amount) || parseFloat(amount) <= 0) {
        showError('amount', 'Jumlah harus berupa angka positif');
        isValid = false;
    }
    
    if (bankName === '') {
        showError('bank_name', 'Bank tujuan harus dipilih');
        isValid = false;
    }
    
    if (!isValid) {
        e.preventDefault();
    }
    
    return isValid;
}

/**
 * Validasi form withdraw
 */
function validateWithdrawForm(e) {
    const amount = document.getElementById('amount').value.trim();
    const bankName = document.getElementById('bank_name').value.trim();
    const accountNumber = document.getElementById('account_number').value.trim();
    const accountName = document.getElementById('account_name').value.trim();
    
    let isValid = true;
    
    if (amount === '') {
        showError('amount', 'Jumlah harus diisi');
        isValid = false;
    } else if (isNaN(amount) || parseFloat(amount) <= 0) {
        showError('amount', 'Jumlah harus berupa angka positif');
        isValid = false;
    }
    
    if (bankName === '') {
        showError('bank_name', 'Bank tujuan harus diisi');
        isValid = false;
    }
    
    if (accountNumber === '') {
        showError('account_number', 'Nomor rekening harus diisi');
        isValid = false;
    }
    
    if (accountName === '') {
        showError('account_name', 'Nama pemilik rekening harus diisi');
        isValid = false;
    }
    
    if (!isValid) {
        e.preventDefault();
    }
    
    return isValid;
}

/**
 * Validasi form bid
 */
function validateBidForm(e) {
    const bidAmount = document.getElementById('bid_amount').value.trim();
    const minBid = document.getElementById('bid_amount').getAttribute('min');
    
    let isValid = true;
    
    if (bidAmount === '') {
        showError('bid_amount', 'Jumlah bid harus diisi');
        isValid = false;
    } else if (isNaN(bidAmount) || parseFloat(bidAmount) <= 0) {
        showError('bid_amount', 'Jumlah bid harus berupa angka positif');
        isValid = false;
    } else if (minBid && parseFloat(bidAmount) < parseFloat(minBid)) {
        showError('bid_amount', 'Jumlah bid minimal ' + minBid);
        isValid = false;
    }
    
    if (!isValid) {
        e.preventDefault();
    }
    
    return isValid;
}

/**
 * Validasi form upload bukti pembayaran
 */
function validatePaymentProofForm(e) {
    const paymentProof = document.getElementById('payment_proof');
    
    let isValid = true;
    
    if (!paymentProof || !paymentProof.files || paymentProof.files.length === 0) {
        showError('payment_proof', 'Bukti pembayaran harus diunggah');
        isValid = false;
    } else {
        const file = paymentProof.files[0];
        const fileType = file.type;
        const validTypes = ['image/jpeg', 'image/png', 'image/jpg'];
        
        if (!validTypes.includes(fileType)) {
            showError('payment_proof', 'Format file harus JPG atau PNG');
            isValid = false;
        } else if (file.size > 2 * 1024 * 1024) { // 2MB
            showError('payment_proof', 'Ukuran file maksimal 2MB');
            isValid = false;
        }
    }
    
    if (!isValid) {
        e.preventDefault();
    }
    
    return isValid;
}

/**
 * Validasi form tambah alamat
 */
function validateAddressForm(e) {
    const recipientName = document.getElementById('recipient_name').value.trim();
    const phone = document.getElementById('phone').value.trim();
    const addressLine1 = document.getElementById('address_line1').value.trim();
    const city = document.getElementById('city').value.trim();
    const province = document.getElementById('province').value.trim();
    const postalCode = document.getElementById('postal_code').value.trim();
    
    let isValid = true;
    
    if (recipientName === '') {
        showError('recipient_name', 'Nama penerima harus diisi');
        isValid = false;
    }
    
    if (phone === '') {
        showError('phone', 'Nomor telepon harus diisi');
        isValid = false;
    }
    
    if (addressLine1 === '') {
        showError('address_line1', 'Alamat harus diisi');
        isValid = false;
    }
    
    if (city === '') {
        showError('city', 'Kota harus diisi');
        isValid = false;
    }
    
    if (province === '') {
        showError('province', 'Provinsi harus diisi');
        isValid = false;
    }
    
    if (postalCode === '') {
        showError('postal_code', 'Kode pos harus diisi');
        isValid = false;
    }
    
    if (!isValid) {
        e.preventDefault();
    }
    
    return isValid;
}

/**
 * Fungsi helper untuk menampilkan pesan error
 */
function showError(inputId, message) {
    const input = document.getElementById(inputId);
    
    if (input) {
        input.classList.add('is-invalid');
        
        // Cek apakah sudah ada pesan error
        let errorDiv = input.nextElementSibling;
        if (!errorDiv || !errorDiv.classList.contains('invalid-feedback')) {
            errorDiv = document.createElement('div');
            errorDiv.className = 'invalid-feedback';
            input.parentNode.insertBefore(errorDiv, input.nextSibling);
        }
        
        errorDiv.textContent = message;
    }
}

/**
 * Fungsi helper untuk validasi email
 */
function isValidEmail(email) {
    const re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(email);
}