/**
 * Live Notifications System - LelangMobil
 * Menampilkan notifikasi transaksi palsu untuk meningkatkan kepercayaan pengunjung
 */

document.addEventListener('DOMContentLoaded', function() {
    // Periksa apakah container notifikasi ada di halaman
    const notificationContainer = document.getElementById('live-notifications');
    if (!notificationContainer) return;

    // Fungsi untuk mendapatkan data transaksi palsu
    function getFakeTransactionData() {
        return window.fakeTransactions || [];
    }

    // Fungsi untuk membuat elemen notifikasi baru
    function createNotificationElement(transaction) {
        const notificationItem = document.createElement('div');
        notificationItem.className = 'notification-item';
        
        let content = `
            <span class="notification-name">${transaction.name}</span>
            <span class="notification-action"> ${transaction.action}`;
            
        if (transaction.item) {
            content += ` <span class="notification-item-name">${transaction.item}</span>`;
        }
        
        if (transaction.amount) {
            content += ` senilai <span class="notification-amount">Rp ${transaction.amount}</span>`;
        }
        
        content += `</span>
            <span class="notification-time">${transaction.time} yang lalu</span>`;
            
        notificationItem.innerHTML = content;
        return notificationItem;
    }

    // Fungsi untuk menampilkan notifikasi
    function showNotification(transaction) {
        const notificationElement = createNotificationElement(transaction);
        notificationContainer.prepend(notificationElement);
        
        // Batasi jumlah notifikasi yang ditampilkan (maksimal 5)
        while (notificationContainer.children.length > 5) {
            notificationContainer.removeChild(notificationContainer.lastChild);
        }
        
        // Atur waktu kemunculan notifikasi berikutnya (antara 5-15 detik)
        const nextNotificationTime = Math.floor(Math.random() * 10000) + 5000;
        setTimeout(showRandomNotification, nextNotificationTime);
    }

    // Fungsi untuk menampilkan notifikasi acak
    function showRandomNotification() {
        const transactions = getFakeTransactionData();
        if (!transactions.length) return;
        
        // Pilih transaksi acak
        const randomIndex = Math.floor(Math.random() * transactions.length);
        const transaction = transactions[randomIndex];
        
        showNotification(transaction);
    }

    // Fungsi untuk menginisialisasi sistem notifikasi
    function initNotificationSystem() {
        // Tampilkan notifikasi pertama setelah 3 detik
        setTimeout(function() {
            // Tampilkan 2 notifikasi awal
            showRandomNotification();
            setTimeout(showRandomNotification, 2000);
        }, 3000);
    }

    // Inisialisasi sistem notifikasi
    initNotificationSystem();
});
