/**
 * Enhanced Modern Index JavaScript
 * LelangMobil Web App - 2025
 */

document.addEventListener('DOMContentLoaded', function() {
    // Initialize AOS (Animate on Scroll)
    AOS.init({
        duration: 800,
        easing: 'ease-in-out',
        once: true,
        mirror: false
    });

    // Initialize Swiper for hero carousel
    const heroSwiper = new Swiper('.hero-swiper', {
        effect: 'fade',
        autoplay: {
            delay: 5000,
            disableOnInteraction: false,
        },
        pagination: {
            el: '.swiper-pagination',
            clickable: true,
        },
        navigation: {
            nextEl: '.swiper-button-next',
            prevEl: '.swiper-button-prev',
        },
    });

    // Initialize Swiper for testimonials
    const testimonialSwiper = new Swiper('.testimonial-swiper', {
        slidesPerView: 1,
        spaceBetween: 30,
        autoplay: {
            delay: 4000,
            disableOnInteraction: false,
        },
        pagination: {
            el: '.testimonial-pagination',
            clickable: true,
        },
        navigation: {
            nextEl: '.testimonial-button-next',
            prevEl: '.testimonial-button-prev',
        },
        breakpoints: {
            768: {
                slidesPerView: 2,
            },
            1024: {
                slidesPerView: 3,
            },
        }
    });

    // Initialize Owl Carousel for featured auctions
    $('.featured-carousel').owlCarousel({
        loop: true,
        margin: 20,
        nav: true,
        dots: true,
        autoplay: true,
        autoplayTimeout: 5000,
        autoplayHoverPause: true,
        navText: [
            '<i class="fas fa-chevron-left"></i>',
            '<i class="fas fa-chevron-right"></i>'
        ],
        responsive: {
            0: {
                items: 1
            },
            576: {
                items: 2
            },
            992: {
                items: 3
            },
            1200: {
                items: 4
            }
        }
    });

    // Category tabs functionality
    const categoryTabs = document.querySelectorAll('.category-tab');
    const auctionContainers = document.querySelectorAll('.auction-category-container');

    if (categoryTabs.length > 0) {
        categoryTabs.forEach(tab => {
            tab.addEventListener('click', function() {
                const category = this.getAttribute('data-category');
                
                // Remove active class from all tabs
                categoryTabs.forEach(t => t.classList.remove('active'));
                
                // Add active class to clicked tab
                this.classList.add('active');
                
                // Hide all auction containers
                auctionContainers.forEach(container => {
                    container.classList.remove('active');
                    container.classList.add('d-none');
                });
                
                // Show selected auction container
                const selectedContainer = document.querySelector(`.auction-category-container[data-category="${category}"]`);
                if (selectedContainer) {
                    selectedContainer.classList.add('active');
                    selectedContainer.classList.remove('d-none');
                }
            });
        });
    }

    // Counter animation
    const counters = document.querySelectorAll('.counter');
    const speed = 200;
    
    counters.forEach(counter => {
        const target = +counter.getAttribute('data-count');
        const increment = target / speed;
        let current = 0;
        
        const updateCount = () => {
            if (current < target) {
                current += increment;
                counter.innerText = Math.ceil(current).toLocaleString('id-ID');
                setTimeout(updateCount, 1);
            } else {
                counter.innerText = parseInt(target).toLocaleString('id-ID');
            }
        };
        
        updateCount();
    });

    // Live Notification System
    const notifications = window.fakeTransactions || [];
    const liveNotificationsContainer = document.getElementById('live-notifications');
    let currentIndex = 0;

    if (liveNotificationsContainer && notifications.length > 0) {
        function showNotification() {
            // Create notification element
            const notification = document.createElement('div');
            notification.className = 'live-notification animate__animated animate__fadeInRight';
            
            // Get current transaction
            const transaction = notifications[currentIndex];
            
            // Create notification content
            let content = '';
            if (transaction.action === 'mengajukan bid') {
                content = `<strong>${transaction.name}</strong> ${transaction.action} <strong>Rp ${transaction.amount}</strong> untuk <strong>${transaction.item}</strong>`;
            } else if (transaction.action === 'memenangkan lelang') {
                content = `<strong>${transaction.name}</strong> ${transaction.action} <strong>${transaction.item}</strong> seharga <strong>Rp ${transaction.amount}</strong>`;
            } else if (transaction.action === 'melakukan top up') {
                content = `<strong>${transaction.name}</strong> ${transaction.action} saldo <strong>Rp ${transaction.amount}</strong>`;
            }
            
            // Set notification content
            notification.innerHTML = `
                <div class="notification-content">
                    <div class="notification-icon">
                        <i class="fas ${transaction.action === 'mengajukan bid' ? 'fa-gavel' : transaction.action === 'memenangkan lelang' ? 'fa-trophy' : 'fa-wallet'}"></i>
                    </div>
                    <div class="notification-text">
                        <p>${content}</p>
                        <span class="notification-time">${transaction.time} yang lalu</span>
                    </div>
                </div>
            `;
            
            // Add to container
            liveNotificationsContainer.appendChild(notification);
            
            // Remove after 5 seconds
            setTimeout(() => {
                notification.classList.remove('animate__fadeInRight');
                notification.classList.add('animate__fadeOutRight');
                
                setTimeout(() => {
                    notification.remove();
                }, 500);
            }, 5000);
            
            // Increment index
            currentIndex = (currentIndex + 1) % notifications.length;
            
            // Schedule next notification
            setTimeout(showNotification, 8000);
        }
        
        // Start showing notifications after a delay
        setTimeout(showNotification, 3000);
    }

    // Back to top button functionality
    const backToTopBtn = document.getElementById('back-to-top');
    
    if (backToTopBtn) {
        window.addEventListener('scroll', function() {
            if (window.pageYOffset > 300) {
                backToTopBtn.classList.add('visible');
            } else {
                backToTopBtn.classList.remove('visible');
            }
        });
        
        backToTopBtn.addEventListener('click', function(e) {
            e.preventDefault();
            window.scrollTo({top: 0, behavior: 'smooth'});
        });
    }

    // Parallax effect on hero section
    window.addEventListener('scroll', function() {
        const scrollPosition = window.pageYOffset;
        const heroElements = document.querySelectorAll('.parallax-element');
        
        heroElements.forEach(element => {
            const speed = element.getAttribute('data-speed') || 0.5;
            element.style.transform = `translateY(${scrollPosition * speed}px)`;
        });
    });

    // Initialize tooltips
    const tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
    tooltipTriggerList.map(function(tooltipTriggerEl) {
        return new bootstrap.Tooltip(tooltipTriggerEl);
    });

    // Preloader
    const preloader = document.querySelector('.preloader');
    if (preloader) {
        setTimeout(function() {
            preloader.classList.add('preloader-hide');
        }, 1000);
    }

    // Dynamic countdown timers for auctions
    const countdownTimers = document.querySelectorAll('.auction-countdown');
    
    function updateCountdowns() {
        countdownTimers.forEach(timer => {
            const endTime = new Date(timer.getAttribute('data-end-time')).getTime();
            const now = new Date().getTime();
            const distance = endTime - now;
            
            if (distance < 0) {
                timer.innerHTML = '<span class="ended">Lelang Berakhir</span>';
                return;
            }
            
            const days = Math.floor(distance / (1000 * 60 * 60 * 24));
            const hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
            const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
            const seconds = Math.floor((distance % (1000 * 60)) / 1000);
            
            let countdownText = '';
            
            if (days > 0) {
                countdownText += `${days}h `;
            }
            
            countdownText += `${hours.toString().padStart(2, '0')}:${minutes.toString().padStart(2, '0')}:${seconds.toString().padStart(2, '0')}`;
            
            timer.innerHTML = countdownText;
        });
    }
    
    // Update countdowns every second
    setInterval(updateCountdowns, 1000);
    
    // Initial update
    updateCountdowns();
});
