/**
 * Modern Settings JavaScript
 * LelangMobil Web App - Versi 2025
 */

document.addEventListener('DOMContentLoaded', function() {
    // Initialize tooltips
    var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
    var tooltipList = tooltipTriggerList.map(function(tooltipTriggerEl) {
        return new bootstrap.Tooltip(tooltipTriggerEl);
    });

    // Password toggle visibility
    const togglePasswordButtons = document.querySelectorAll('.toggle-password');
    togglePasswordButtons.forEach(button => {
        button.addEventListener('click', function() {
            const input = this.closest('.input-group').querySelector('input');
            const icon = this.querySelector('i');
            
            if (input.type === 'password') {
                input.type = 'text';
                icon.classList.remove('fa-eye');
                icon.classList.add('fa-eye-slash');
            } else {
                input.type = 'password';
                icon.classList.remove('fa-eye-slash');
                icon.classList.add('fa-eye');
            }
        });
    });

    // Password strength meter
    const newPasswordInput = document.getElementById('new_password');
    const confirmPasswordInput = document.getElementById('confirm_password');
    
    if (newPasswordInput) {
        newPasswordInput.addEventListener('input', function() {
            const password = this.value;
            const strengthMeter = document.querySelector('.strength-meter-fill');
            const strengthText = document.querySelector('.strength-text span');
            
            // Calculate password strength
            let strength = 0;
            
            if (password.length >= 8) strength += 1;
            if (password.match(/[A-Z]/)) strength += 1;
            if (password.match(/[0-9]/)) strength += 1;
            if (password.match(/[^A-Za-z0-9]/)) strength += 1;
            
            // Update strength meter
            strengthMeter.setAttribute('data-strength', strength);
            
            // Update strength text
            const strengthLabels = ['Sangat Lemah', 'Lemah', 'Sedang', 'Kuat', 'Sangat Kuat'];
            strengthText.textContent = password.length > 0 ? strengthLabels[strength] : 'Belum diisi';
        });
    }
    
    if (confirmPasswordInput && newPasswordInput) {
        confirmPasswordInput.addEventListener('input', function() {
            if (this.value !== newPasswordInput.value) {
                this.setCustomValidity('Passwords do not match');
            } else {
                this.setCustomValidity('');
            }
        });
    }

    // Email frequency selection
    const emailFrequencyOptions = document.querySelectorAll('input[name="emailFrequency"]');
    const weeklyOptions = document.querySelector('.weekly-options');
    const dailyWeeklyOptions = document.querySelector('.daily-weekly-options');
    
    if (emailFrequencyOptions.length > 0) {
        emailFrequencyOptions.forEach(option => {
            option.addEventListener('change', function() {
                if (this.value === 'weekly') {
                    weeklyOptions.classList.remove('d-none');
                    dailyWeeklyOptions.classList.remove('d-none');
                } else if (this.value === 'daily') {
                    weeklyOptions.classList.add('d-none');
                    dailyWeeklyOptions.classList.remove('d-none');
                } else {
                    weeklyOptions.classList.add('d-none');
                    dailyWeeklyOptions.classList.add('d-none');
                }
            });
        });
    }

    // Day selector
    const dayItems = document.querySelectorAll('.day-item');
    if (dayItems.length > 0) {
        dayItems.forEach(day => {
            day.addEventListener('click', function() {
                dayItems.forEach(d => d.classList.remove('active'));
                this.classList.add('active');
            });
        });
    }

    // Payment method selection
    const paymentMethodCards = document.querySelectorAll('.payment-method-card');
    if (paymentMethodCards.length > 0) {
        paymentMethodCards.forEach(card => {
            card.addEventListener('click', function() {
                const radioInput = this.querySelector('input[type="radio"]');
                if (radioInput) {
                    radioInput.checked = true;
                    
                    // Update selected state
                    paymentMethodCards.forEach(c => c.classList.remove('selected'));
                    this.classList.add('selected');
                }
            });
        });
    }

    // Credit card form
    const ccNumberInput = document.getElementById('cc-number');
    if (ccNumberInput) {
        ccNumberInput.addEventListener('input', function(e) {
            // Format credit card number with spaces
            let value = this.value.replace(/\s+/g, '').replace(/[^0-9]/gi, '');
            let formattedValue = '';
            
            for (let i = 0; i < value.length; i++) {
                if (i > 0 && i % 4 === 0) {
                    formattedValue += ' ';
                }
                formattedValue += value[i];
            }
            
            this.value = formattedValue;
            
            // Update credit card display
            document.querySelector('.cc-number').textContent = formattedValue || '•••• •••• •••• ••••';
            
            // Detect card type and update logo
            const ccLogo = document.querySelector('.cc-logo');
            if (value.startsWith('4')) {
                ccLogo.innerHTML = '<i class="fab fa-cc-visa"></i>';
            } else if (/^5[1-5]/.test(value)) {
                ccLogo.innerHTML = '<i class="fab fa-cc-mastercard"></i>';
            } else if (/^3[47]/.test(value)) {
                ccLogo.innerHTML = '<i class="fab fa-cc-amex"></i>';
            } else if (/^6(?:011|5)/.test(value)) {
                ccLogo.innerHTML = '<i class="fab fa-cc-discover"></i>';
            } else {
                ccLogo.innerHTML = '<i class="far fa-credit-card"></i>';
            }
        });
    }

    const ccNameInput = document.getElementById('cc-name');
    if (ccNameInput) {
        ccNameInput.addEventListener('input', function() {
            document.querySelector('.cc-holder-name').textContent = this.value || 'NAMA PEMEGANG KARTU';
        });
    }

    const ccExpMonthInput = document.getElementById('cc-exp-month');
    const ccExpYearInput = document.getElementById('cc-exp-year');
    
    if (ccExpMonthInput && ccExpYearInput) {
        const updateExpiry = function() {
            const month = ccExpMonthInput.value || 'MM';
            const year = ccExpYearInput.value ? ccExpYearInput.value.substr(-2) : 'YY';
            document.querySelector('.cc-exp-value').textContent = `${month}/${year}`;
        };
        
        ccExpMonthInput.addEventListener('change', updateExpiry);
        ccExpYearInput.addEventListener('change', updateExpiry);
    }

    // Form validation
    const forms = document.querySelectorAll('.needs-validation');
    Array.from(forms).forEach(form => {
        form.addEventListener('submit', event => {
            if (!form.checkValidity()) {
                event.preventDefault();
                event.stopPropagation();
            }
            
            form.classList.add('was-validated');
        }, false);
    });

    // File upload preview
    const profilePictureInput = document.getElementById('profilePictureInput');
    if (profilePictureInput) {
        profilePictureInput.addEventListener('change', function() {
            if (this.files && this.files[0]) {
                const reader = new FileReader();
                
                reader.onload = function(e) {
                    const profilePicture = document.querySelector('.profile-picture');
                    const initialElement = profilePicture.querySelector('.profile-initial');
                    let imgElement = profilePicture.querySelector('img');
                    
                    if (initialElement) {
                        initialElement.style.display = 'none';
                    }
                    
                    if (imgElement) {
                        imgElement.src = e.target.result;
                    } else {
                        imgElement = document.createElement('img');
                        imgElement.src = e.target.result;
                        imgElement.alt = 'Profile Picture';
                        imgElement.className = 'rounded-circle';
                        profilePicture.appendChild(imgElement);
                    }
                    
                    // Auto submit form
                    document.getElementById('profilePictureForm').submit();
                };
                
                reader.readAsDataURL(this.files[0]);
            }
        });
    }

    // Animate on scroll initialization
    AOS.init({
        duration: 800,
        easing: 'ease-in-out',
        once: true
    });
});
