/**
 * Notification System
 * LelangMobil Web App - Versi 2025
 */

document.addEventListener('DOMContentLoaded', function() {
    initNotificationSystem();
    
    // Check for new notifications every 30 seconds
    setInterval(checkNewNotifications, 30000);
});

function initNotificationSystem() {
    // Add notification dropdown to navbar if user is logged in
    const userDropdown = document.querySelector('.dropdown-toggle i.fa-user-circle');
    if (userDropdown) {
        addNotificationBell();
        loadInitialNotifications();
    }
}

function addNotificationBell() {
    const navbarNav = document.querySelector('.navbar-nav');
    if (!navbarNav) return;
    
    // Create notification dropdown
    const notificationItem = document.createElement('li');
    notificationItem.className = 'nav-item dropdown notification-dropdown';
    notificationItem.innerHTML = `
        <a class="nav-link dropdown-toggle" href="#" id="notificationDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
            <i class="fa fa-bell"></i>
            <span class="notification-badge" style="display: none;">0</span>
        </a>
        <div class="dropdown-menu dropdown-menu-end notification-menu" aria-labelledby="notificationDropdown">
            <div class="notification-header">
                <h6 class="m-0">Notifikasi</h6>
                <button class="btn btn-sm mark-all-read">Tandai Semua Dibaca</button>
            </div>
            <div class="notification-list">
                <div class="text-center p-3">Memuat notifikasi...</div>
            </div>
            <div class="notification-footer">
                <a href="notifications.php" class="btn btn-sm btn-primary w-100">Lihat Semua</a>
            </div>
        </div>
    `;
    
    // Insert before user dropdown
    const userDropdownItem = document.querySelector('.dropdown');
    if (userDropdownItem) {
        navbarNav.insertBefore(notificationItem, userDropdownItem);
    } else {
        navbarNav.appendChild(notificationItem);
    }
    
    // Add event listeners
    const markAllReadBtn = document.querySelector('.mark-all-read');
    if (markAllReadBtn) {
        markAllReadBtn.addEventListener('click', markAllNotificationsRead);
    }
    
    // Initialize dropdown
    const notificationDropdown = document.getElementById('notificationDropdown');
    if (notificationDropdown) {
        notificationDropdown.addEventListener('click', function(e) {
            e.preventDefault();
            loadNotifications();
        });
    }
}

function loadInitialNotifications() {
    fetch('api/notifications.php?action=count')
        .then(response => response.json())
        .then(data => {
            if (data.success && data.count > 0) {
                updateNotificationBadge(data.count);
            }
        })
        .catch(error => console.error('Error checking notifications:', error));
}

function loadNotifications() {
    const notificationList = document.querySelector('.notification-list');
    if (!notificationList) return;
    
    fetch('api/notifications.php?action=get')
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                renderNotifications(data.notifications);
            } else {
                notificationList.innerHTML = '<div class="text-center p-3">Gagal memuat notifikasi</div>';
            }
        })
        .catch(error => {
            console.error('Error loading notifications:', error);
            notificationList.innerHTML = '<div class="text-center p-3">Gagal memuat notifikasi</div>';
        });
}

function renderNotifications(notifications) {
    const notificationList = document.querySelector('.notification-list');
    if (!notificationList) return;
    
    if (notifications.length === 0) {
        notificationList.innerHTML = '<div class="text-center p-3">Tidak ada notifikasi</div>';
        return;
    }
    
    let html = '';
    notifications.forEach(notification => {
        const isRead = notification.is_read == 1;
        html += `
            <div class="notification-item ${isRead ? '' : 'unread'}" data-id="${notification.notification_id}">
                <div class="notification-icon">
                    <i class="fa ${getNotificationIcon(notification.type)}"></i>
                </div>
                <div class="notification-content">
                    <div class="notification-title">${notification.title}</div>
                    <div class="notification-message">${notification.message}</div>
                    <div class="notification-time">${formatTimeAgo(notification.created_at)}</div>
                </div>
                ${isRead ? '' : '<button class="btn btn-sm mark-read" data-id="' + notification.notification_id + '">Tandai Dibaca</button>'}
            </div>
        `;
    });
    
    notificationList.innerHTML = html;
    
    // Add event listeners to mark read buttons
    document.querySelectorAll('.mark-read').forEach(button => {
        button.addEventListener('click', function() {
            const notificationId = this.getAttribute('data-id');
            markNotificationRead(notificationId);
        });
    });
    
    // Add event listeners to notification items
    document.querySelectorAll('.notification-item').forEach(item => {
        item.addEventListener('click', function(e) {
            if (!e.target.classList.contains('mark-read')) {
                const notificationId = this.getAttribute('data-id');
                const url = notification.url || '#';
                markNotificationRead(notificationId);
                if (url !== '#') {
                    window.location.href = url;
                }
            }
        });
    });
}

function markNotificationRead(notificationId) {
    fetch('api/notifications.php?action=mark_read&id=' + notificationId)
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                const notificationItem = document.querySelector(`.notification-item[data-id="${notificationId}"]`);
                if (notificationItem) {
                    notificationItem.classList.remove('unread');
                    const markReadBtn = notificationItem.querySelector('.mark-read');
                    if (markReadBtn) {
                        markReadBtn.remove();
                    }
                }
                updateNotificationBadge(data.unread_count);
            }
        })
        .catch(error => console.error('Error marking notification read:', error));
}

function markAllNotificationsRead() {
    fetch('api/notifications.php?action=mark_all_read')
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                document.querySelectorAll('.notification-item').forEach(item => {
                    item.classList.remove('unread');
                    const markReadBtn = item.querySelector('.mark-read');
                    if (markReadBtn) {
                        markReadBtn.remove();
                    }
                });
                updateNotificationBadge(0);
            }
        })
        .catch(error => console.error('Error marking all notifications read:', error));
}

function checkNewNotifications() {
    fetch('api/notifications.php?action=count')
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                updateNotificationBadge(data.count);
            }
        })
        .catch(error => console.error('Error checking notifications:', error));
}

function updateNotificationBadge(count) {
    const badge = document.querySelector('.notification-badge');
    if (badge) {
        if (count > 0) {
            badge.textContent = count > 99 ? '99+' : count;
            badge.style.display = 'block';
        } else {
            badge.style.display = 'none';
        }
    }
}

function getNotificationIcon(type) {
    const icons = {
        'bid': 'fa-gavel',
        'transaction': 'fa-money-bill-wave',
        'system': 'fa-cog',
        'auction': 'fa-car',
        'auto_bid': 'fa-robot',
        'payment': 'fa-credit-card',
        'withdrawal': 'fa-wallet'
    };
    
    return icons[type] || 'fa-bell';
}

function formatTimeAgo(datetime) {
    const now = new Date();
    const date = new Date(datetime);
    const seconds = Math.floor((now - date) / 1000);
    
    let interval = Math.floor(seconds / 31536000);
    if (interval >= 1) {
        return interval + " tahun yang lalu";
    }
    
    interval = Math.floor(seconds / 2592000);
    if (interval >= 1) {
        return interval + " bulan yang lalu";
    }
    
    interval = Math.floor(seconds / 86400);
    if (interval >= 1) {
        return interval + " hari yang lalu";
    }
    
    interval = Math.floor(seconds / 3600);
    if (interval >= 1) {
        return interval + " jam yang lalu";
    }
    
    interval = Math.floor(seconds / 60);
    if (interval >= 1) {
        return interval + " menit yang lalu";
    }
    
    return "baru saja";
}