<?php
/**
 * Login Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if already logged in
if (is_logged_in()) {
    header("Location: account-modern.php");
    exit;
}

$error = '';
$success = '';

// Process login form
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['login'])) {
    // Get form data
    $username = trim($_POST['username'] ?? '');
    $password = trim($_POST['password'] ?? '');
    $remember = isset($_POST['remember']) ? true : false;
    
    // Validate input
    if (empty($username) || empty($password)) {
        $error = "Username dan password harus diisi.";
    } else {
        // Check if username exists (can be username or email)
        $login_sql = "SELECT * FROM users WHERE username = ? OR email = ?";
        $login_stmt = $conn->prepare($login_sql);
        $login_stmt->bind_param("ss", $username, $username);
        $login_stmt->execute();
        $login_result = $login_stmt->get_result();
        
        if ($login_result->num_rows > 0) {
            $user = $login_result->fetch_assoc();
            
            // Verify password
            if (password_verify($password, $user['password'])) {
                // Check if account is verified
                if ($user['is_verified'] == 0) {
                    $error = "Akun Anda belum diverifikasi. Silakan periksa email Anda atau <a href='resend-verification.php'>kirim ulang email verifikasi</a>.";
                } else {
                    // Set session variables
                    $_SESSION['user_id'] = $user['user_id'];
                    $_SESSION['username'] = $user['username'];
                    $_SESSION['is_admin'] = $user['is_admin'];
                    
                    // Set remember me cookie if checked
                    if ($remember) {
                        $token = bin2hex(random_bytes(32));
                        $expires = time() + (30 * 24 * 60 * 60); // 30 days
                        
                        // Store token in database
                        $token_sql = "UPDATE users SET remember_token = ? WHERE user_id = ?";
                        $token_stmt = $conn->prepare($token_sql);
                        $token_stmt->bind_param("si", $token, $user['user_id']);
                        $token_stmt->execute();
                        
                        // Set cookie
                        setcookie('remember_token', $token, $expires, '/');
                        setcookie('remember_user', $user['user_id'], $expires, '/');
                    }
                    
                    // Update last login time
                    $update_sql = "UPDATE users SET last_login = NOW() WHERE user_id = ?";
                    $update_stmt = $conn->prepare($update_sql);
                    $update_stmt->bind_param("i", $user['user_id']);
                    $update_stmt->execute();
                    
                    // Redirect to account page
                    header("Location: account-modern.php");
                    exit;
                }
            } else {
                $error = "Password salah. Silakan coba lagi.";
            }
        } else {
            $error = "Username atau email tidak ditemukan.";
        }
    }
}

// Check for success message from other pages
if (isset($_GET['success'])) {
    switch ($_GET['success']) {
        case 'registered':
            $success = "Pendaftaran berhasil! Silakan login dengan akun Anda.";
            break;
        case 'verified':
            $success = "Email berhasil diverifikasi! Silakan login dengan akun Anda.";
            break;
        case 'password_reset':
            $success = "Password berhasil diubah! Silakan login dengan password baru Anda.";
            break;
    }
}

// Aktifkan flag untuk halaman login
$page_title = "Login";
$is_auth_page = true;
$use_modern_auth = true;

// Custom CSS untuk halaman auth
$page_specific_css = '<link href="css/login-modern.css" rel="stylesheet" type="text/css">';

// Include header
include("includes/header.php");
?>

<div class="auth-container">
    <div class="auth-card login-card animate">
        <div class="auth-card-header text-center">
            <h2><i class="fa fa-sign-in-alt"></i> Login</h2>
            <p class="text-muted">Masuk ke akun Anda untuk mengikuti lelang</p>
        </div>
        
        <div class="auth-card-body">
            <?php if (!empty($error)): ?>
                <div class="auth-alert auth-alert-danger">
                    <i class="fa fa-exclamation-circle me-2"></i><?php echo $error; ?>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($success)): ?>
                <div class="auth-alert auth-alert-success">
                    <i class="fa fa-check-circle me-2"></i><?php echo $success; ?>
                </div>
            <?php endif; ?>
            
            <form method="post" action="" class="stagger-animate">
                <div class="auth-form-group">
                    <label for="username" class="auth-form-label">Username atau Email</label>
                    <div class="input-group">
                        <span class="input-group-text"><i class="fa fa-user"></i></span>
                        <input type="text" class="auth-form-control" id="username" name="username" placeholder="Masukkan username atau email" required>
                    </div>
                </div>
                
                <div class="auth-form-group">
                    <label for="password" class="auth-form-label">Password</label>
                    <div class="input-group">
                        <span class="input-group-text"><i class="fa fa-lock"></i></span>
                        <input type="password" class="auth-form-control" id="password" name="password" placeholder="Masukkan password" required>
                        <button class="btn btn-outline-secondary toggle-password" type="button">
                            <i class="fa fa-eye"></i>
                        </button>
                    </div>
                </div>
                
                <div class="d-flex justify-content-between mb-4">
                    <div class="auth-form-check">
                        <input type="checkbox" class="auth-form-check-input" id="remember" name="remember">
                        <label class="auth-form-check-label" for="remember">Ingat saya</label>
                    </div>
                    <div>
                        <a href="forgot-password.php" class="auth-link">Lupa password?</a>
                    </div>
                </div>
                
                <div class="d-grid mb-4">
                    <button type="submit" name="login" class="auth-btn auth-btn-primary">
                        <i class="fa fa-sign-in-alt me-2"></i>Login
                    </button>
                </div>
                
                <div class="auth-social-login">
                    <div class="auth-social-login-divider">
                        <span>atau login dengan</span>
                    </div>
                    <div>
                        <a href="#" class="auth-social-btn auth-social-btn-facebook">
                            <i class="fab fa-facebook-f"></i>
                        </a>
                        <a href="#" class="auth-social-btn auth-social-btn-google">
                            <i class="fab fa-google"></i>
                        </a>
                        <a href="#" class="auth-social-btn auth-social-btn-twitter">
                            <i class="fab fa-twitter"></i>
                        </a>
                    </div>
                </div>
                
                <div class="text-center mt-4">
                    Belum punya akun? <a href="register.php" class="auth-link">Daftar di sini</a>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Toggle password visibility
    const toggleButton = document.querySelector('.toggle-password');
    
    if (toggleButton) {
        toggleButton.addEventListener('click', function() {
            const input = this.previousElementSibling;
            const icon = this.querySelector('i');
            
            if (input.type === 'password') {
                input.type = 'text';
                icon.classList.remove('fa-eye');
                icon.classList.add('fa-eye-slash');
            } else {
                input.type = 'password';
                icon.classList.remove('fa-eye-slash');
                icon.classList.add('fa-eye');
            }
        });
    }
});
</script>

<?php include("includes/footer.php"); ?>