<?php
/**
 * Resend Verification Email
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

$error = '';
$success = '';

// Process resend verification form
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Validate input
    $email = clean_input($_POST['email']);
    
    // Check if email exists and is not verified
    $sql = "SELECT * FROM users WHERE email = ? AND is_verified = 0";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $user = $result->fetch_assoc();
        
        // Generate new token
        $verification_token = generate_token();
        $token_expiry = date('Y-m-d H:i:s', strtotime('+24 hours'));
        
        // Update token in database
        $update_sql = "UPDATE users SET verification_token = ?, token_expiry = ? WHERE user_id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param("ssi", $verification_token, $token_expiry, $user['user_id']);
        
        if ($update_stmt->execute()) {
            // Send verification email
            if (send_verification_email($conn, $email, $verification_token, $user['user_id'])) {
                $success = "Email verifikasi telah dikirim ulang. Silakan periksa email Anda (termasuk folder spam).";
            } else {
                $error = "Gagal mengirim email verifikasi. Silakan coba lagi nanti.";
            }
        } else {
            $error = "Terjadi kesalahan. Silakan coba lagi nanti.";
        }
    } else {
        // Check if email exists but is already verified
        $check_sql = "SELECT * FROM users WHERE email = ? AND is_verified = 1";
        $check_stmt = $conn->prepare($check_sql);
        $check_stmt->bind_param("s", $email);
        $check_stmt->execute();
        $check_result = $check_stmt->get_result();
        
        if ($check_result->num_rows > 0) {
            $success = "Akun Anda sudah diverifikasi. Silakan login.";
        } else {
            $error = "Email tidak ditemukan atau belum terdaftar.";
        }
    }
}

// Page title
$page_title = "Kirim Ulang Verifikasi - LelangMobil";
$use_modern_auth = true;

// Custom CSS untuk halaman auth
$page_specific_css = '<link href="css/login-modern.css" rel="stylesheet" type="text/css">';

// Include header
include("includes/header.php");
?>

<div class="auth-container">
    <div class="auth-card animate">
        <div class="auth-card-header text-center">
            <h2><i class="fa fa-envelope"></i> Kirim Ulang Verifikasi</h2>
            <p class="text-muted">Masukkan email Anda untuk menerima link verifikasi baru</p>
        </div>
        
        <div class="auth-card-body">
            <?php if(!empty($error)): ?>
                <div class="auth-alert auth-alert-danger">
                    <i class="fa fa-exclamation-circle me-2"></i><?php echo $error; ?>
                </div>
            <?php endif; ?>
            
            <?php if(!empty($success)): ?>
                <div class="auth-alert auth-alert-success">
                    <i class="fa fa-check-circle me-2"></i><?php echo $success; ?>
                </div>
                <div class="text-center mt-4">
                    <a href="login.php" class="auth-link">Kembali ke Login</a>
                </div>
            <?php else: ?>
                <form method="post" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" class="stagger-animate">
                    <div class="auth-form-group">
                        <label for="email" class="auth-form-label">Email</label>
                        <div class="input-group">
                            <span class="input-group-text"><i class="fa fa-envelope"></i></span>
                            <input type="email" class="auth-form-control" id="email" name="email" placeholder="Masukkan email Anda" required>
                        </div>
                    </div>
                    
                    <div class="d-grid mb-4">
                        <button type="submit" class="auth-btn auth-btn-primary">
                            <i class="fa fa-paper-plane me-2"></i>Kirim Email Verifikasi
                        </button>
                    </div>
                    
                    <div class="text-center">
                        <p>Sudah memiliki akun? <a href="login.php" class="auth-link">Login di sini</a></p>
                        <p>Belum punya akun? <a href="register.php" class="auth-link">Daftar di sini</a></p>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>
</div>

<?php include("includes/footer.php"); ?>