<?php
/**
 * Settings Modern Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Get user information
$user_query = "SELECT * FROM users WHERE user_id = ?";
$user_stmt = $conn->prepare($user_query);
$user_stmt->bind_param("i", $user_id);
$user_stmt->execute();
$user_result = $user_stmt->get_result();
$user = $user_result->fetch_assoc();

// Process profile update
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    $action = $_POST['action'];
    
    if ($action == 'update_profile') {
        // Get form data
        $fullname = clean_input($_POST['fullname']);
        $email = clean_input($_POST['email']);
        $phone = clean_input($_POST['phone']);
        $bio = clean_input($_POST['bio']);
        
        // Validate data
        $errors = [];
        
        if (empty($fullname)) {
            $errors[] = "Nama lengkap wajib diisi";
        }
        
        if (empty($email)) {
            $errors[] = "Email wajib diisi";
        } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            $errors[] = "Format email tidak valid";
        }
        
        // Check if email already exists (except for current user)
        $check_email_query = "SELECT user_id FROM users WHERE email = ? AND user_id != ?";
        $check_email_stmt = $conn->prepare($check_email_query);
        $check_email_stmt->bind_param("si", $email, $user_id);
        $check_email_stmt->execute();
        $check_email_result = $check_email_stmt->get_result();
        
        if ($check_email_result->num_rows > 0) {
            $errors[] = "Email sudah digunakan oleh pengguna lain";
        }
        
        // If no errors, update profile
        if (empty($errors)) {
            $update_query = "UPDATE users SET fullname = ?, email = ?, phone = ?, bio = ? WHERE user_id = ?";
            $update_stmt = $conn->prepare($update_query);
            $update_stmt->bind_param("ssssi", $fullname, $email, $phone, $bio, $user_id);
            
            if ($update_stmt->execute()) {
                $success = "Profil berhasil diperbarui";
                
                // Update session data
                $_SESSION['fullname'] = $fullname;
                
                // Refresh user data
                $user_stmt->execute();
                $user_result = $user_stmt->get_result();
                $user = $user_result->fetch_assoc();
            } else {
                $error = "Gagal memperbarui profil: " . $conn->error;
            }
        } else {
            $error = implode("<br>", $errors);
        }
    } elseif ($action == 'update_password') {
        // Process password update
        $current_password = $_POST['current_password'];
        $new_password = $_POST['new_password'];
        $confirm_password = $_POST['confirm_password'];
        
        // Validate passwords
        $errors = [];
        
        if (empty($current_password)) {
            $errors[] = "Password saat ini wajib diisi";
        }
        
        if (empty($new_password)) {
            $errors[] = "Password baru wajib diisi";
        } elseif (strlen($new_password) < 8) {
            $errors[] = "Password baru minimal 8 karakter";
        }
        
        if ($new_password != $confirm_password) {
            $errors[] = "Konfirmasi password tidak sesuai";
        }
        
        // Verify current password
        if (empty($errors)) {
            $check_password_query = "SELECT password FROM users WHERE user_id = ?";
            $check_password_stmt = $conn->prepare($check_password_query);
            $check_password_stmt->bind_param("i", $user_id);
            $check_password_stmt->execute();
            $check_password_result = $check_password_stmt->get_result();
            $user_password = $check_password_result->fetch_assoc()['password'];
            
            if (!password_verify($current_password, $user_password)) {
                $errors[] = "Password saat ini tidak sesuai";
            }
        }
        
        // If no errors, update password
        if (empty($errors)) {
            $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);
            $update_password_query = "UPDATE users SET password = ? WHERE user_id = ?";
            $update_password_stmt = $conn->prepare($update_password_query);
            $update_password_stmt->bind_param("si", $hashed_password, $user_id);
            
            if ($update_password_stmt->execute()) {
                $success = "Password berhasil diperbarui";
            } else {
                $error = "Gagal memperbarui password: " . $conn->error;
            }
        } else {
            $error = implode("<br>", $errors);
        }
    } elseif ($action == 'update_notification_settings') {
        // Process notification settings update
        $email_notifications = isset($_POST['email_notifications']) ? 1 : 0;
        $sms_notifications = isset($_POST['sms_notifications']) ? 1 : 0;
        $push_notifications = isset($_POST['push_notifications']) ? 1 : 0;
        $auction_alerts = isset($_POST['auction_alerts']) ? 1 : 0;
        $payment_alerts = isset($_POST['payment_alerts']) ? 1 : 0;
        $marketing_alerts = isset($_POST['marketing_alerts']) ? 1 : 0;
        
        // Update notification settings
        $update_notifications_query = "UPDATE user_settings SET 
                                       email_notifications = ?, 
                                       sms_notifications = ?, 
                                       push_notifications = ?, 
                                       auction_alerts = ?, 
                                       payment_alerts = ?, 
                                       marketing_alerts = ? 
                                       WHERE user_id = ?";
        
        // Check if user_settings record exists
        $check_settings_query = "SELECT * FROM user_settings WHERE user_id = ?";
        $check_settings_stmt = $conn->prepare($check_settings_query);
        $check_settings_stmt->bind_param("i", $user_id);
        $check_settings_stmt->execute();
        $settings_exists = ($check_settings_stmt->get_result()->num_rows > 0);
        
        if ($settings_exists) {
            // Update existing record
            $update_stmt = $conn->prepare($update_notifications_query);
            $update_stmt->bind_param("iiiiiii", $email_notifications, $sms_notifications, $push_notifications, $auction_alerts, $payment_alerts, $marketing_alerts, $user_id);
            
            if ($update_stmt->execute()) {
                $success = "Pengaturan notifikasi berhasil diperbarui";
            } else {
                $error = "Gagal memperbarui pengaturan notifikasi: " . $conn->error;
            }
        } else {
            // Insert new record
            $insert_query = "INSERT INTO user_settings (user_id, email_notifications, sms_notifications, push_notifications, auction_alerts, payment_alerts, marketing_alerts) VALUES (?, ?, ?, ?, ?, ?, ?)";
            $insert_stmt = $conn->prepare($insert_query);
            $insert_stmt->bind_param("iiiiiii", $user_id, $email_notifications, $sms_notifications, $push_notifications, $auction_alerts, $payment_alerts, $marketing_alerts);
            
            if ($insert_stmt->execute()) {
                $success = "Pengaturan notifikasi berhasil diperbarui";
            } else {
                $error = "Gagal memperbarui pengaturan notifikasi: " . $conn->error;
            }
        }
    }
}

// Get user's notification settings
$notification_settings_query = "SELECT * FROM user_settings WHERE user_id = ?";
$notification_settings_stmt = $conn->prepare($notification_settings_query);
$notification_settings_stmt->bind_param("i", $user_id);
$notification_settings_stmt->execute();
$notification_settings_result = $notification_settings_stmt->get_result();

if ($notification_settings_result->num_rows > 0) {
    $notification_settings = $notification_settings_result->fetch_assoc();
} else {
    // Default settings if not set
    $notification_settings = [
        'email_notifications' => 1,
        'sms_notifications' => 1,
        'push_notifications' => 1,
        'auction_alerts' => 1,
        'payment_alerts' => 1,
        'marketing_alerts' => 0
    ];
}

// Page title and settings
$page_title = "Pengaturan Akun";
$is_dashboard_page = true;
$use_modern_dashboard = true;

// Custom CSS
$page_specific_css = '
<link href="css/modern-settings.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet">
<link href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" rel="stylesheet">
';

// Include header
include("includes/header.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($success)): ?>
    <div class="modern-alert modern-alert-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($error)): ?>
    <div class="modern-alert modern-alert-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php include("includes/account-navbar.php"); ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <div class="d-flex justify-content-between align-items-center mb-4">
                <div class="fade-in">
                    <h2 class="mb-1"><?php echo $page_title; ?></h2>
                    <p class="text-muted">Kelola informasi pribadi dan preferensi akun Anda</p>
                </div>
            </div>

            
            <!-- Settings Tabs Navigation -->
            <div class="settings-nav-container mb-4">
                <ul class="settings-nav" id="settingsTabs" role="tablist">
                    <li class="settings-nav-item" role="presentation">
                        <button class="settings-nav-link active" id="profile-tab" data-bs-toggle="tab" data-bs-target="#profile" type="button" role="tab" aria-controls="profile" aria-selected="true">
                            <i class="fas fa-user-circle"></i>
                            <span>Profil</span>
                        </button>
                    </li>
                    <li class="settings-nav-item" role="presentation">
                        <button class="settings-nav-link" id="security-tab" data-bs-toggle="tab" data-bs-target="#security" type="button" role="tab" aria-controls="security" aria-selected="false">
                            <i class="fas fa-shield-alt"></i>
                            <span>Keamanan</span>
                        </button>
                    </li>
                    <li class="settings-nav-item" role="presentation">
                        <button class="settings-nav-link" id="notifications-tab" data-bs-toggle="tab" data-bs-target="#notifications" type="button" role="tab" aria-controls="notifications" aria-selected="false">
                            <i class="fas fa-bell"></i>
                            <span>Notifikasi</span>
                        </button>
                    </li>
                    <li class="settings-nav-item" role="presentation">
                        <button class="settings-nav-link" id="payment-tab" data-bs-toggle="tab" data-bs-target="#payment" type="button" role="tab" aria-controls="payment" aria-selected="false">
                            <i class="fas fa-credit-card"></i>
                            <span>Pembayaran</span>
                        </button>
                    </li>
                    <li class="settings-nav-item" role="presentation">
                        <button class="settings-nav-link" id="connected-tab" data-bs-toggle="tab" data-bs-target="#connected" type="button" role="tab" aria-controls="connected" aria-selected="false">
                            <i class="fas fa-link"></i>
                            <span>Integrasi</span>
                        </button>
                    </li>
                </ul>
            </div>
            
            <!-- Tab Content -->
            <div class="tab-content settings-content" id="settingsTabContent">
                <!-- Profile Tab -->
                <div class="tab-pane fade show active" id="profile" role="tabpanel" aria-labelledby="profile-tab">
                    <div class="settings-container animate__animated animate__fadeIn">
                        <div class="row">
                            <!-- Profile Picture Column -->
                            <div class="col-md-4 mb-4">
                                <div class="modern-card h-100">
                                    <div class="modern-card-body text-center p-4">
                                        <div class="profile-picture-container mb-3">
                                            <div class="profile-picture">
                                                <?php if (!empty($user['profile_picture'])): ?>
                                                    <img src="uploads/profile/<?php echo htmlspecialchars($user['profile_picture']); ?>" alt="Profile Picture" class="rounded-circle">
                                                <?php else: ?>
                                                    <div class="profile-initial">
                                                        <span><?php echo strtoupper(substr($user['fullname'] ?? 'U', 0, 1)); ?></span>
                                                    </div>
                                                <?php endif; ?>
                                                <div class="upload-overlay">
                                                    <i class="fas fa-camera"></i>
                                                </div>
                                            </div>
                                        </div>
                                        <h4 class="user-name mb-1"><?php echo htmlspecialchars($user['fullname'] ?? ''); ?></h4>
                                        <p class="user-email text-muted mb-3"><?php echo htmlspecialchars($user['email'] ?? ''); ?></p>
                                        
                                        <!-- User Badges -->
                                        <div class="user-badges mb-3">
                                            <?php if (isset($user['is_verified']) && $user['is_verified']): ?>
                                                <span class="user-badge verified" data-bs-toggle="tooltip" title="Akun Terverifikasi">
                                                    <i class="fas fa-check-circle"></i> Terverifikasi
                                                </span>
                                            <?php endif; ?>
                                            
                                            <?php if (isset($user['premium_level']) && $user['premium_level'] > 0): ?>
                                                <span class="user-badge premium" data-bs-toggle="tooltip" title="Akun Premium">
                                                    <i class="fas fa-crown"></i> Premium
                                                </span>
                                            <?php endif; ?>
                                        </div>
                                        
                                        <!-- Account Info -->
                                        <div class="account-info">
                                            <div class="info-item">
                                                <span class="info-label">Anggota Sejak</span>
                                                <span class="info-value"><?php echo date('d M Y', strtotime($user['created_at'] ?? 'now')); ?></span>
                                            </div>
                                            <div class="info-item">
                                                <span class="info-label">Terakhir Login</span>
                                                <span class="info-value"><?php echo date('d M Y H:i', strtotime($user['last_login'] ?? 'now')); ?></span>
                                            </div>
                                            <div class="info-item">
                                                <span class="info-label">Status</span>
                                                <span class="info-value status-active"><i class="fas fa-circle"></i> Aktif</span>
                                            </div>
                                        </div>
                                        
                                        <!-- Upload Profile Picture Button -->
                                        <form action="upload-profile-picture.php" method="post" enctype="multipart/form-data" id="profilePictureForm" class="mt-3">
                                            <div class="upload-btn-wrapper">
                                                <button class="btn btn-outline-primary btn-sm w-100"><i class="fas fa-upload me-2"></i>Ubah Foto Profil</button>
                                                <input type="file" name="profile_picture" id="profilePictureInput" accept="image/*">
                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>
                            
                            <!-- Profile Form Column -->
                            <div class="col-md-8 mb-4">
                                <div class="modern-card h-100">
                                    <div class="modern-card-header">
                                        <h5 class="card-title mb-0"><i class="fas fa-user-edit me-2"></i>Informasi Pribadi</h5>
                                    </div>
                                    <div class="modern-card-body p-4">
                                        <form action="" method="post" id="profileForm" class="needs-validation" novalidate>
                                            <input type="hidden" name="action" value="update_profile">
                                            
                                            <div class="row mb-3">
                                                <div class="col-md-6">
                                                    <label for="fullname" class="form-label">Nama Lengkap <span class="text-danger">*</span></label>
                                                    <div class="input-group">
                                                        <span class="input-group-text"><i class="fas fa-user"></i></span>
                                                        <input type="text" class="form-control" id="fullname" name="fullname" value="<?php echo htmlspecialchars($user['fullname'] ?? ''); ?>" required>
                                                        <div class="invalid-feedback">Nama lengkap wajib diisi</div>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="username" class="form-label">Username</label>
                                                    <div class="input-group">
                                                        <span class="input-group-text"><i class="fas fa-at"></i></span>
                                                        <input type="text" class="form-control" id="username" value="<?php echo htmlspecialchars($user['username'] ?? ''); ?>" readonly disabled>
                                                    </div>
                                                    <small class="text-muted">Username tidak dapat diubah</small>
                                                </div>
                                            </div>
                                            
                                            <div class="row mb-3">
                                                <div class="col-md-6">
                                                    <label for="email" class="form-label">Email <span class="text-danger">*</span></label>
                                                    <div class="input-group">
                                                        <span class="input-group-text"><i class="fas fa-envelope"></i></span>
                                                        <input type="email" class="form-control" id="email" name="email" value="<?php echo htmlspecialchars($user['email'] ?? ''); ?>" required>
                                                        <div class="invalid-feedback">Email valid wajib diisi</div>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="phone" class="form-label">Nomor Telepon</label>
                                                    <div class="input-group">
                                                        <span class="input-group-text"><i class="fas fa-phone-alt"></i></span>
                                                        <input type="tel" class="form-control" id="phone" name="phone" value="<?php echo htmlspecialchars($user['phone'] ?? ''); ?>" placeholder="08xxxxxxxxxx">
                                                        <div class="invalid-feedback">Format nomor telepon tidak valid</div>
                                                    </div>
                                                </div>
                                            </div>
                                            
                                            <div class="mb-3">
                                                <label for="bio" class="form-label">Bio</label>
                                                <textarea class="form-control" id="bio" name="bio" rows="3" placeholder="Ceritakan sedikit tentang diri Anda..."><?php echo htmlspecialchars($user['bio'] ?? ''); ?></textarea>
                                            </div>
                                            
                                            <div class="text-end">
                                                <button type="submit" class="btn btn-primary"><i class="fas fa-save me-2"></i>Simpan Perubahan</button>
                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                
                <!-- Security Tab -->
                <div class="tab-pane fade" id="security" role="tabpanel" aria-labelledby="security-tab">
                    <div class="settings-container animate__animated animate__fadeIn">
                        <div class="row">
                            <!-- Password Change Column -->
                            <div class="col-md-6 mb-4">
                                <div class="modern-card h-100">
                                    <div class="modern-card-header">
                                        <h5 class="card-title mb-0"><i class="fas fa-key me-2"></i>Ubah Password</h5>
                                    </div>
                                    <div class="modern-card-body p-4">
                                        <form action="" method="post" id="passwordForm" class="needs-validation" novalidate>
                                            <input type="hidden" name="action" value="update_password">
                                            
                                            <div class="mb-3">
                                                <label for="current_password" class="form-label">Password Saat Ini <span class="text-danger">*</span></label>
                                                <div class="password-container">
                                                    <div class="input-group">
                                                        <span class="input-group-text"><i class="fas fa-lock"></i></span>
                                                        <input type="password" class="form-control" id="current_password" name="current_password" required>
                                                        <button type="button" class="btn btn-outline-secondary toggle-password" tabindex="-1">
                                                            <i class="fas fa-eye"></i>
                                                        </button>
                                                    </div>
                                                    <div class="invalid-feedback">Password saat ini wajib diisi</div>
                                                </div>
                                            </div>
                                            
                                            <div class="mb-3">
                                                <label for="new_password" class="form-label">Password Baru <span class="text-danger">*</span></label>
                                                <div class="password-container">
                                                    <div class="input-group">
                                                        <span class="input-group-text"><i class="fas fa-lock"></i></span>
                                                        <input type="password" class="form-control" id="new_password" name="new_password" required>
                                                        <button type="button" class="btn btn-outline-secondary toggle-password" tabindex="-1">
                                                            <i class="fas fa-eye"></i>
                                                        </button>
                                                    </div>
                                                    <div class="invalid-feedback">Password baru minimal 8 karakter</div>
                                                </div>
                                                <div class="password-strength mt-2">
                                                    <div class="strength-meter">
                                                        <div class="strength-meter-fill" data-strength="0"></div>
                                                    </div>
                                                    <div class="strength-text">Kekuatan: <span>Belum diisi</span></div>
                                                </div>
                                            </div>
                                            
                                            <div class="mb-3">
                                                <label for="confirm_password" class="form-label">Konfirmasi Password <span class="text-danger">*</span></label>
                                                <div class="password-container">
                                                    <div class="input-group">
                                                        <span class="input-group-text"><i class="fas fa-lock"></i></span>
                                                        <input type="password" class="form-control" id="confirm_password" name="confirm_password" required>
                                                        <button type="button" class="btn btn-outline-secondary toggle-password" tabindex="-1">
                                                            <i class="fas fa-eye"></i>
                                                        </button>
                                                    </div>
                                                    <div class="invalid-feedback">Konfirmasi password tidak sesuai</div>
                                                </div>
                                            </div>
                                            
                                            <div class="password-tips mb-3">
                                                <p class="mb-2">Tips Password Kuat:</p>
                                                <ul class="ps-4 mb-0">
                                                    <li>Minimal 8 karakter</li>
                                                    <li>Kombinasi huruf besar dan kecil</li>
                                                    <li>Sertakan angka dan karakter khusus</li>
                                                    <li>Hindari informasi pribadi</li>
                                                </ul>
                                            </div>
                                            
                                            <div class="text-end">
                                                <button type="submit" class="btn btn-primary"><i class="fas fa-key me-2"></i>Ubah Password</button>
                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>
                            
                            <!-- Two Factor & Security Column -->
                            <div class="col-md-6 mb-4">
                                <div class="modern-card mb-4">
                                    <div class="modern-card-header">
                                        <h5 class="card-title mb-0"><i class="fas fa-shield-alt me-2"></i>Verifikasi Dua Faktor</h5>
                                    </div>
                                    <div class="modern-card-body p-4">
                                        <div class="two-factor-container">
                                            <div class="d-flex justify-content-between align-items-center mb-3">
                                                <div>
                                                    <h6 class="mb-1">Verifikasi SMS</h6>
                                                    <p class="text-muted mb-0">Verifikasi melalui kode SMS</p>
                                                </div>
                                                <div class="form-check form-switch">
                                                    <input class="form-check-input" type="checkbox" id="smsVerification" <?php echo (isset($user['sms_verification']) && $user['sms_verification']) ? 'checked' : ''; ?>>
                                                </div>
                                            </div>
                                            
                                            <div class="d-flex justify-content-between align-items-center mb-3">
                                                <div>
                                                    <h6 class="mb-1">Verifikasi Email</h6>
                                                    <p class="text-muted mb-0">Verifikasi melalui link email</p>
                                                </div>
                                                <div class="form-check form-switch">
                                                    <input class="form-check-input" type="checkbox" id="emailVerification" <?php echo (isset($user['email_verification']) && $user['email_verification']) ? 'checked' : ''; ?>>
                                                </div>
                                            </div>
                                            
                                            <div class="d-flex justify-content-between align-items-center">
                                                <div>
                                                    <h6 class="mb-1">Otentikasi Aplikasi</h6>
                                                    <p class="text-muted mb-0">Gunakan aplikasi autentikator</p>
                                                </div>
                                                <div class="form-check form-switch">
                                                    <input class="form-check-input" type="checkbox" id="appVerification" <?php echo (isset($user['app_verification']) && $user['app_verification']) ? 'checked' : ''; ?>>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                
                                <div class="modern-card">
                                    <div class="modern-card-header">
                                        <h5 class="card-title mb-0"><i class="fas fa-history me-2"></i>Riwayat Login</h5>
                                    </div>
                                    <div class="modern-card-body p-4">
                                        <div class="login-history">
                                            <div class="login-item">
                                                <div class="login-icon">
                                                    <i class="fas fa-desktop"></i>
                                                </div>
                                                <div class="login-details">
                                                    <div class="login-device">Windows - Chrome</div>
                                                    <div class="login-location">Jakarta, Indonesia</div>
                                                    <div class="login-time">Hari ini, 09:45</div>
                                                </div>
                                                <div class="login-status current">
                                                    <i class="fas fa-circle"></i>
                                                </div>
                                            </div>
                                            
                                            <div class="login-item">
                                                <div class="login-icon">
                                                    <i class="fas fa-mobile-alt"></i>
                                                </div>
                                                <div class="login-details">
                                                    <div class="login-device">Android - App</div>
                                                    <div class="login-location">Jakarta, Indonesia</div>
                                                    <div class="login-time">Kemarin, 18:30</div>
                                                </div>
                                                <div class="login-status">
                                                    <i class="fas fa-check-circle"></i>
                                                </div>
                                            </div>
                                            
                                            <div class="login-item">
                                                <div class="login-icon">
                                                    <i class="fas fa-tablet-alt"></i>
                                                </div>
                                                <div class="login-details">
                                                    <div class="login-device">iPad - Safari</div>
                                                    <div class="login-location">Bandung, Indonesia</div>
                                                    <div class="login-time">21 May 2025, 14:15</div>
                                                </div>
                                                <div class="login-status">
                                                    <i class="fas fa-check-circle"></i>
                                                </div>
                                            </div>
                                        </div>
                                        
                                        <div class="text-center mt-3">
                                            <a href="login-history.php" class="btn btn-outline-primary btn-sm"><i class="fas fa-history me-2"></i>Lihat Semua Riwayat</a>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
