<?php
/**
 * Shipping Address Management Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Process form submission for adding/editing address
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['action']) && $_POST['action'] == 'add_address') {
        $address_type = clean_input($_POST['address_type']);
        $address_label = clean_input($_POST['address_label']);
        $recipient_name = clean_input($_POST['recipient_name']);
        $phone = clean_input($_POST['phone']);
        $province = clean_input($_POST['province']);
        $city = clean_input($_POST['city']);
        $district = clean_input($_POST['district']);
        $postal_code = clean_input($_POST['postal_code']);
        $full_address = clean_input($_POST['full_address']);
        $is_default = isset($_POST['is_default']) ? 1 : 0;
        
        // Validate required fields
        if (empty($recipient_name) || empty($phone) || empty($province) || empty($city) || empty($full_address)) {
            $error = "Semua field yang bertanda * wajib diisi.";
        } else {
            try {
                // If this is set as default, unset all other default addresses
                if ($is_default) {
                    $unset_default_sql = "UPDATE user_addresses SET is_default = 0 WHERE user_id = ?";
                    $unset_default_stmt = $conn->prepare($unset_default_sql);
                    $unset_default_stmt->bind_param("i", $user_id);
                    $unset_default_stmt->execute();
                }
                
                // Check if we're editing an existing address
                if (isset($_POST['address_id']) && !empty($_POST['address_id'])) {
                    $address_id = intval($_POST['address_id']);
                    
                    // Update existing address
                    $update_sql = "UPDATE user_addresses SET 
                                    address_type = ?, 
                                    address_label = ?, 
                                    recipient_name = ?, 
                                    phone = ?, 
                                    province = ?, 
                                    city = ?, 
                                    district = ?, 
                                    postal_code = ?, 
                                    full_address = ?, 
                                    is_default = ? 
                                  WHERE id = ? AND user_id = ?";
                    
                    $update_stmt = $conn->prepare($update_sql);
                    $update_stmt->bind_param("sssssssssiis", 
                        $address_type, 
                        $address_label, 
                        $recipient_name, 
                        $phone, 
                        $province, 
                        $city, 
                        $district, 
                        $postal_code, 
                        $full_address, 
                        $is_default,
                        $address_id,
                        $user_id
                    );
                    
                    if ($update_stmt->execute()) {
                        $success = "Alamat berhasil diperbarui.";
                    } else {
                        $error = "Gagal memperbarui alamat: " . $conn->error;
                    }
                } else {
                    // Insert new address
                    $insert_sql = "INSERT INTO user_addresses 
                                  (user_id, address_type, address_label, recipient_name, phone, province, city, district, postal_code, full_address, is_default) 
                                  VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
                    
                    $insert_stmt = $conn->prepare($insert_sql);
                    $insert_stmt->bind_param("isssssssssi", 
                        $user_id, 
                        $address_type, 
                        $address_label, 
                        $recipient_name, 
                        $phone, 
                        $province, 
                        $city, 
                        $district, 
                        $postal_code, 
                        $full_address, 
                        $is_default
                    );
                    
                    if ($insert_stmt->execute()) {
                        $success = "Alamat baru berhasil ditambahkan.";
                    } else {
                        $error = "Gagal menambahkan alamat: " . $conn->error;
                    }
                }
            } catch (Throwable $e) {
                $error = "Terjadi kesalahan: " . $e->getMessage();
            }
        }
    } elseif (isset($_POST['action']) && $_POST['action'] == 'delete_address') {
        $address_id = intval($_POST['address_id']);
        
        try {
            $delete_sql = "DELETE FROM user_addresses WHERE id = ? AND user_id = ?";
            $delete_stmt = $conn->prepare($delete_sql);
            $delete_stmt->bind_param("ii", $address_id, $user_id);
            
            if ($delete_stmt->execute()) {
                $success = "Alamat berhasil dihapus.";
            } else {
                $error = "Gagal menghapus alamat: " . $conn->error;
            }
        } catch (Throwable $e) {
            $error = "Terjadi kesalahan: " . $e->getMessage();
        }
    } elseif (isset($_POST['action']) && $_POST['action'] == 'set_default') {
        $address_id = intval($_POST['address_id']);
        
        try {
            // Unset all default addresses
            $unset_default_sql = "UPDATE user_addresses SET is_default = 0 WHERE user_id = ?";
            $unset_default_stmt = $conn->prepare($unset_default_sql);
            $unset_default_stmt->bind_param("i", $user_id);
            $unset_default_stmt->execute();
            
            // Set the selected address as default
            $set_default_sql = "UPDATE user_addresses SET is_default = 1 WHERE id = ? AND user_id = ?";
            $set_default_stmt = $conn->prepare($set_default_sql);
            $set_default_stmt->bind_param("ii", $address_id, $user_id);
            
            if ($set_default_stmt->execute()) {
                $success = "Alamat utama berhasil diubah.";
            } else {
                $error = "Gagal mengubah alamat utama: " . $conn->error;
            }
        } catch (Throwable $e) {
            $error = "Terjadi kesalahan: " . $e->getMessage();
        }
    }
}

// Get user addresses
$addresses = [];
try {
    $addresses_sql = "SELECT * FROM user_addresses WHERE user_id = ? ORDER BY is_default DESC, created_at DESC";
    $addresses_stmt = $conn->prepare($addresses_sql);
    $addresses_stmt->bind_param("i", $user_id);
    $addresses_stmt->execute();
    $addresses_result = $addresses_stmt->get_result();
    
    while ($row = $addresses_result->fetch_assoc()) {
        $addresses[] = $row;
    }
} catch (Throwable $e) {
    $error = "Gagal mengambil data alamat: " . $e->getMessage();
}

// Get provinces for dropdown
$provinces = [
    'Aceh', 'Sumatera Utara', 'Sumatera Barat', 'Riau', 'Jambi', 'Sumatera Selatan', 
    'Bengkulu', 'Lampung', 'Kepulauan Bangka Belitung', 'Kepulauan Riau', 'DKI Jakarta', 
    'Jawa Barat', 'Jawa Tengah', 'DI Yogyakarta', 'Jawa Timur', 'Banten', 'Bali', 
    'Nusa Tenggara Barat', 'Nusa Tenggara Timur', 'Kalimantan Barat', 'Kalimantan Tengah', 
    'Kalimantan Selatan', 'Kalimantan Timur', 'Kalimantan Utara', 'Sulawesi Utara', 
    'Sulawesi Tengah', 'Sulawesi Selatan', 'Sulawesi Tenggara', 'Gorontalo', 
    'Sulawesi Barat', 'Maluku', 'Maluku Utara', 'Papua', 'Papua Barat'
];

// Set page title and flags
$page_title = "Kelola Alamat Pengiriman";
$is_dashboard_page = true;
$use_modern_dashboard = true;

// Custom CSS untuk halaman alamat yang ditingkatkan
$page_specific_css = '<link href="css/modern-address-enhanced.css" rel="stylesheet" type="text/css">
<link href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/4.1.1/animate.min.css" rel="stylesheet">';

// Include header
include("includes/header.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($success)): ?>
    <div class="modern-alert modern-alert-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($error)): ?>
    <div class="modern-alert modern-alert-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php include("includes/account-navbar.php"); ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <div class="d-flex justify-content-between align-items-center mb-4">
                <div class="fade-in">
                    <h2 class="mb-1"><?php echo $page_title; ?></h2>
                    <p class="text-muted">Kelola alamat pengiriman untuk kemudahan transaksi Anda</p>
                </div>
                <button type="button" class="modern-button modern-button-primary pulse-animation d-flex align-items-center shadow-sm" data-bs-toggle="modal" data-bs-target="#addAddressModal">
                    <i class="fa fa-map-marker-alt me-2"></i><span>Tambah Alamat Baru</span>
                    <div class="button-badge ms-2">+</div>
                </button>
            </div>
            
            <!-- Address List -->
            <div class="row">
                <?php if (empty($addresses)): ?>
                <div class="col-12">
                    <div class="modern-card fade-in">
                        <div class="modern-card-body text-center py-5">
                            <div class="empty-state">
                                <i class="fa fa-map-marker-alt fa-4x text-muted mb-3"></i>
                                <h4>Belum Ada Alamat</h4>
                                <p class="text-muted">Anda belum menambahkan alamat pengiriman. Tambahkan alamat untuk memudahkan proses pengiriman.</p>
                                <button type="button" class="modern-button modern-button-primary mt-3 pulse-animation d-flex align-items-center shadow-sm mx-auto" data-bs-toggle="modal" data-bs-target="#addAddressModal">
                                    <i class="fa fa-map-marker-alt me-2"></i><span>Tambah Alamat Sekarang</span>
                                    <div class="button-badge ms-2">+</div>
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
                <?php else: ?>
                    <?php foreach ($addresses as $address): ?>
                    <div class="col-md-6 mb-4">
                        <div class="modern-card address-card fade-in <?php echo $address['is_default'] ? 'address-card-default' : ''; ?>">
                            <?php if ($address['is_default']): ?>
                            <div class="default-badge">
                                <i class="fa fa-check-circle me-1"></i> Utama
                            </div>
                            <?php endif; ?>
                            
                            <div class="modern-card-body">
                                <div class="d-flex justify-content-between align-items-start mb-3">
                                    <div>
                                        <h5 class="address-name"><?php echo htmlspecialchars($address['recipient_name']); ?></h5>
                                        <p class="address-phone mb-0"><?php echo htmlspecialchars($address['phone']); ?></p>
                                    </div>
                                    <span class="address-type-badge <?php echo $address['address_type']; ?>">
                                        <?php 
                                        switch($address['address_type']) {
                                            case 'home':
                                                echo '<i class="fa fa-home me-1"></i> Rumah';
                                                break;
                                            case 'office':
                                                echo '<i class="fa fa-building me-1"></i> Kantor';
                                                break;
                                            default:
                                                echo '<i class="fa fa-map-marker-alt me-1"></i> ' . htmlspecialchars($address['address_label']);
                                        }
                                        ?>
                                    </span>
                                </div>
                                
                                <div class="address-details">
                                    <p class="mb-1"><?php echo htmlspecialchars($address['full_address']); ?></p>
                                    <p class="mb-1">
                                        <?php 
                                        echo htmlspecialchars($address['district'] ? $address['district'] . ', ' : '');
                                        echo htmlspecialchars($address['city'] . ', ' . $address['province']); 
                                        ?>
                                    </p>
                                    <?php if (!empty($address['postal_code'])): ?>
                                    <p class="mb-0"><?php echo htmlspecialchars($address['postal_code']); ?></p>
                                    <?php endif; ?>
                                </div>
                                
                                <div class="address-actions mt-3">
                                    <div class="btn-group w-100">
                                        <button type="button" class="btn btn-sm btn-outline-primary edit-address" 
                                                data-address='<?php echo json_encode($address); ?>'
                                                data-bs-toggle="modal" data-bs-target="#addAddressModal">
                                            <i class="fa fa-edit me-1"></i> Edit
                                        </button>
                                        
                                        <?php if (!$address['is_default']): ?>
                                        <form method="post" class="d-inline">
                                            <input type="hidden" name="action" value="set_default">
                                            <input type="hidden" name="address_id" value="<?php echo $address['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-outline-success">
                                                <i class="fa fa-check-circle me-1"></i> Jadikan Utama
                                            </button>
                                        </form>
                                        
                                        <form method="post" class="d-inline delete-address-form">
                                            <input type="hidden" name="action" value="delete_address">
                                            <input type="hidden" name="address_id" value="<?php echo $address['id']; ?>">
                                            <button type="submit" class="btn btn-sm btn-outline-danger">
                                                <i class="fa fa-trash me-1"></i> Hapus
                                            </button>
                                        </form>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
            
            <!-- Address Information -->
            <div class="modern-card mt-4 fade-in">
                <div class="modern-card-header">
                    <h3 class="modern-card-title"><i class="fa fa-info-circle"></i> Informasi Alamat</h3>
                </div>
                <div class="modern-card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-home"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Alamat Utama</h5>
                                    <p>Alamat utama akan digunakan sebagai alamat default untuk pengiriman.</p>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="info-item">
                                <div class="info-icon">
                                    <i class="fa fa-edit"></i>
                                </div>
                                <div class="info-content">
                                    <h5>Pengelolaan Alamat</h5>
                                    <p>Anda dapat menambah, mengubah, atau menghapus alamat sesuai kebutuhan.</p>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Add/Edit Address Modal -->
<div class="modal fade" id="addAddressModal" tabindex="-1" aria-labelledby="addAddressModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content animate__animated animate__fadeInUp">
            <div class="modal-header">
                <h5 class="modal-title" id="addAddressModalLabel"><i class="fas fa-plus"></i> Tambah Alamat Baru</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <!-- Form steps indicator -->
                <div class="form-steps mb-4">
                    <div class="step active" id="step1">
                        <div class="step-number">1</div>
                        <div class="step-label">Informasi Kontak</div>
                    </div>
                    <div class="step" id="step2">
                        <div class="step-number">2</div>
                        <div class="step-label">Detail Alamat</div>
                    </div>
                    <div class="step" id="step3">
                        <div class="step-number">3</div>
                        <div class="step-label">Konfirmasi</div>
                    </div>
                </div>
                
                <form id="addressForm" method="post" action="" class="needs-validation" novalidate>
                    <input type="hidden" name="action" value="add_address">
                    <input type="hidden" name="address_id" id="address_id" value="">
                    
                    <!-- Step 1: Contact Information -->
                    <div class="form-step" id="formStep1">
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="address_type" class="form-label">Tipe Alamat <span class="text-danger">*</span></label>
                                <select class="form-select" id="address_type" name="address_type" required>
                                    <option value="home">Rumah</option>
                                    <option value="office">Kantor</option>
                                    <option value="other">Lainnya</option>
                                </select>
                                <div class="invalid-feedback">Silakan pilih tipe alamat</div>
                            </div>
                            <div class="col-md-6">
                                <label for="address_label" class="form-label">Label Alamat</label>
                                <input type="text" class="form-control" id="address_label" name="address_label" placeholder="Contoh: Rumah Orang Tua">
                                <small class="text-muted">Opsional untuk tipe alamat ini</small>
                            </div>
                        </div>
                        
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="recipient_name" class="form-label">Nama Penerima <span class="text-danger">*</span></label>
                                <input type="text" class="form-control" id="recipient_name" name="recipient_name" required>
                                <div class="invalid-feedback">Nama penerima wajib diisi</div>
                            </div>
                            <div class="col-md-6">
                                <label for="phone" class="form-label">Nomor Telepon <span class="text-danger">*</span></label>
                                <div class="input-group">
                                    <span class="input-group-text">+62</span>
                                    <input type="text" class="form-control" id="phone" name="phone" placeholder="8123456789" required>
                                </div>
                                <div class="invalid-feedback">Nomor telepon wajib diisi</div>
                                <small class="text-muted">Format: 8123456789 (tanpa awalan 0)</small>
                            </div>
                        </div>
                        
                        <div class="text-end mt-4">
                            <button type="button" class="btn btn-primary next-step">Lanjutkan <i class="fas fa-arrow-right ms-1"></i></button>
                        </div>
                    </div>
                    
                    <!-- Step 2: Address Details -->
                    <div class="form-step d-none" id="formStep2">
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="province" class="form-label">Provinsi <span class="text-danger">*</span></label>
                                <select class="form-select" id="province" name="province" required>
                                    <option value="">Pilih Provinsi</option>
                                    <?php foreach ($provinces as $province): ?>
                                    <option value="<?php echo $province; ?>"><?php echo $province; ?></option>
                                    <?php endforeach; ?>
                                </select>
                                <div class="invalid-feedback">Provinsi wajib dipilih</div>
                            </div>
                            <div class="col-md-6">
                                <label for="city" class="form-label">Kota/Kabupaten <span class="text-danger">*</span></label>
                                <input type="text" class="form-control" id="city" name="city" required>
                                <div class="invalid-feedback">Kota/Kabupaten wajib diisi</div>
                            </div>
                        </div>
                        
                        <div class="row mb-3">
                            <div class="col-md-6">
                                <label for="district" class="form-label">Kecamatan</label>
                                <input type="text" class="form-control" id="district" name="district">
                            </div>
                            <div class="col-md-6">
                                <label for="postal_code" class="form-label">Kode Pos</label>
                                <input type="text" class="form-control" id="postal_code" name="postal_code" maxlength="5" placeholder="12345">
                                <small class="text-muted">Format: 5 digit angka</small>
                            </div>
                        </div>
                        
                        <div class="mb-3">
                            <label for="full_address" class="form-label">Alamat Lengkap <span class="text-danger">*</span></label>
                            <textarea class="form-control" id="full_address" name="full_address" rows="3" placeholder="Masukkan nama jalan, nomor rumah, RT/RW, dan detail lainnya" required></textarea>
                            <div class="invalid-feedback">Alamat lengkap wajib diisi</div>
                        </div>
                        
                        <div class="text-end mt-4">
                            <button type="button" class="btn btn-outline-secondary prev-step"><i class="fas fa-arrow-left me-1"></i> Kembali</button>
                            <button type="button" class="btn btn-primary next-step">Lanjutkan <i class="fas fa-arrow-right ms-1"></i></button>
                        </div>
                    </div>
                    
                    <!-- Step 3: Confirmation -->
                    <div class="form-step d-none" id="formStep3">
                        <div class="address-preview p-3 rounded border mb-4">
                            <h6 class="mb-3">Pratinjau Alamat</h6>
                            <div class="row">
                                <div class="col-md-6">
                                    <p class="address-preview-name mb-1"><i class="fas fa-user me-2"></i> <span id="preview-name">-</span></p>
                                    <p class="address-preview-phone mb-3"><i class="fas fa-phone me-2"></i> <span id="preview-phone">-</span></p>
                                </div>
                                <div class="col-md-6 text-md-end">
                                    <span class="address-preview-type">-</span>
                                </div>
                            </div>
                            <p class="address-preview-full mb-1"><i class="fas fa-map-marker-alt me-2"></i> <span id="preview-address">-</span></p>
                            <p class="address-preview-city mb-0"><span id="preview-district">-</span>, <span id="preview-city">-</span>, <span id="preview-province">-</span> <span id="preview-postal">-</span></p>
                        </div>
                        
                        <div class="mb-3 form-check">
                            <input type="checkbox" class="form-check-input" id="is_default" name="is_default">
                            <label class="form-check-label" for="is_default"><i class="fas fa-check-circle me-1"></i> Jadikan sebagai alamat utama</label>
                        </div>
                        
                        <div class="text-end mt-4">
                            <button type="button" class="btn btn-outline-secondary prev-step"><i class="fas fa-arrow-left me-1"></i> Kembali</button>
                            <button type="submit" class="btn btn-primary"><i class="fas fa-save me-1"></i> Simpan Alamat</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<style>
.address-card {
    position: relative;
    transition: all 0.3s ease;
    border: 1px solid #dee2e6;
}

.address-card:hover {
    transform: translateY(-5px);
    box-shadow: 0 10px 20px rgba(0,0,0,0.1);
}

.address-card-default {
    border: 2px solid var(--success);
}

.default-badge {
    position: absolute;
    top: 10px;
    right: 10px;
    background-color: var(--success);
    color: white;
    padding: 3px 10px;
    border-radius: 20px;
    font-size: 0.75rem;
    font-weight: 600;
}

.address-type-badge {
    padding: 3px 10px;
    border-radius: 20px;
    font-size: 0.75rem;
    font-weight: 600;
}

.address-type-badge.home {
    background-color: rgba(74, 110, 224, 0.1);
    color: var(--primary);
}

.address-type-badge.office {
    background-color: rgba(40, 167, 69, 0.1);
    color: var(--success);
}

.address-type-badge.other {
    background-color: rgba(108, 117, 125, 0.1);
    color: var(--secondary);
}

.address-name {
    font-weight: 600;
    margin-bottom: 5px;
}

.address-phone {
    color: var(--secondary);
    font-size: 0.9rem;
}

.address-details {
    margin-top: 15px;
    padding-top: 15px;
    border-top: 1px solid #eee;
    color: var(--secondary);
    font-size: 0.9rem;
}

.address-actions {
    margin-top: 15px;
    padding-top: 15px;
    border-top: 1px solid #eee;
}

.address-actions .btn-group {
    display: flex;
}

.address-actions .btn {
    flex: 1;
}

.empty-state {
    padding: 30px;
    text-align: center;
}

.empty-state i {
    color: #ccc;
}
</style>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Handle edit address button
    const editButtons = document.querySelectorAll('.edit-address');
    const addressForm = document.getElementById('addressForm');
    const modalTitle = document.getElementById('addAddressModalLabel');
    
    editButtons.forEach(button => {
        button.addEventListener('click', function() {
            const addressData = JSON.parse(this.getAttribute('data-address'));
            
            // Update modal title
            modalTitle.textContent = 'Edit Alamat';
            
            // Fill form with address data
            document.getElementById('address_id').value = addressData.id;
            document.getElementById('address_type').value = addressData.address_type;
            document.getElementById('address_label').value = addressData.address_label || '';
            document.getElementById('recipient_name').value = addressData.recipient_name;
            document.getElementById('phone').value = addressData.phone;
            document.getElementById('province').value = addressData.province;
            document.getElementById('city').value = addressData.city;
            document.getElementById('district').value = addressData.district || '';
            document.getElementById('postal_code').value = addressData.postal_code || '';
            document.getElementById('full_address').value = addressData.full_address;
            document.getElementById('is_default').checked = addressData.is_default == 1;
        });
    });
    
    // Reset form when adding new address
    const addAddressModal = document.getElementById('addAddressModal');
    addAddressModal.addEventListener('hidden.bs.modal', function() {
        addressForm.reset();
        document.getElementById('address_id').value = '';
        modalTitle.textContent = 'Tambah Alamat Baru';
    });
    
    // Show/hide address label based on address type
    const addressType = document.getElementById('address_type');
    const addressLabelGroup = document.getElementById('address_label').parentNode;
    
    addressType.addEventListener('change', function() {
        if (this.value === 'other') {
            document.getElementById('address_label').setAttribute('required', 'required');
        } else {
            document.getElementById('address_label').removeAttribute('required');
        }
    });
    
    // Confirm delete address
    const deleteAddressForms = document.querySelectorAll('.delete-address-form');
    deleteAddressForms.forEach(form => {
        form.addEventListener('submit', function(e) {
            if (!confirm('Apakah Anda yakin ingin menghapus alamat ini?')) {
                e.preventDefault();
            }
        });
    });
});
</script>

<script>
// Script untuk mengelola form alamat
document.addEventListener('DOMContentLoaded', function() {
    // Fix untuk tombol tambah alamat
    document.querySelector('button[data-bs-toggle="modal"]').addEventListener('click', function() {
        // Pastikan form direset saat menambah alamat baru
        document.getElementById('addressForm').reset();
        document.getElementById('address_id').value = '';
        document.getElementById('addAddressModalLabel').textContent = 'Tambah Alamat Baru';
        document.querySelector('input[name="action"]').value = 'add_address';
    });
    
    // Tangani klik tombol edit
    document.querySelectorAll('.edit-address-btn').forEach(function(btn) {
        btn.addEventListener('click', function() {
            var addressId = this.getAttribute('data-id');
            var addressType = this.getAttribute('data-type');
            var addressLabel = this.getAttribute('data-label');
            var recipientName = this.getAttribute('data-recipient');
            var phone = this.getAttribute('data-phone');
            var province = this.getAttribute('data-province');
            var city = this.getAttribute('data-city');
            var district = this.getAttribute('data-district');
            var postalCode = this.getAttribute('data-postal');
            var fullAddress = this.getAttribute('data-address');
            var isDefault = this.getAttribute('data-default') === '1';
            
            // Set nilai form untuk edit
            document.getElementById('address_id').value = addressId;
            document.getElementById('address_type').value = addressType;
            document.getElementById('address_label').value = addressLabel;
            document.getElementById('recipient_name').value = recipientName;
            document.getElementById('phone').value = phone;
            document.getElementById('province').value = province;
            document.getElementById('city').value = city;
            document.getElementById('district').value = district;
            document.getElementById('postal_code').value = postalCode;
            document.getElementById('full_address').value = fullAddress;
            document.getElementById('is_default').checked = isDefault;
            
            // Ubah judul modal
            document.getElementById('addAddressModalLabel').textContent = 'Edit Alamat';
            document.querySelector('input[name="action"]').value = 'add_address';
            
            // Tampilkan modal menggunakan Bootstrap
            var modal = new bootstrap.Modal(document.getElementById('addAddressModal'));
            modal.show();
        });
    });
    
    // Validasi form sebelum submit
    document.getElementById('addressForm').addEventListener('submit', function(e) {
        var addressType = document.getElementById('address_type').value;
        var addressLabel = document.getElementById('address_label').value;
        
        if (addressType === 'other' && addressLabel.trim() === '') {
            e.preventDefault();
            alert('Label alamat wajib diisi jika tipe alamat adalah Lainnya');
            return false;
        }
    });
});
</script>

<?php include("includes/footer.php"); ?>