<?php
/**
 * Modern Withdraw Page
 * LelangMobil Web App - Versi 2025
 */

// Start session if not already started
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Include database connection and functions
require_once 'config/database.php';
require_once 'config/functions.php';

// Redirect if not logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit;
}

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Get user information
try {
    $user_sql = "SELECT * FROM users WHERE user_id = ?";
    $user_stmt = $conn->prepare($user_sql);
    $user_stmt->bind_param("i", $user_id);
    $user_stmt->execute();
    $user_result = $user_stmt->get_result();
    $user = $user_result->fetch_assoc();
} catch (Throwable $e) {
    die("Error fetching user data: " . $e->getMessage());
}

// Process withdrawal request
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['withdraw'])) {
    $amount = (float)$_POST['amount'];
    $bank_name = trim($_POST['bank_name'] ?? '');
    $account_number = trim($_POST['account_number'] ?? '');
    $account_name = trim($_POST['account_name'] ?? '');
    
    if ($amount <= 0) {
        $error = "Jumlah penarikan harus lebih dari 0.";
    } elseif ($amount > $user['balance']) {
        $error = "Saldo Anda tidak mencukupi untuk melakukan penarikan ini.";
    } elseif (empty($bank_name) || empty($account_number) || empty($account_name)) {
        $error = "Semua field harus diisi.";
    } else {
        // Generate reference number
        $reference = 'WD' . date('YmdHis') . rand(100, 999);
        
        // Insert transaction
        $transaction_sql = "INSERT INTO transactions (user_id, amount, type, status, reference_number, bank_name, account_number, account_name, created_at) 
                          VALUES (?, ?, 'withdrawal', 'pending', ?, ?, ?, ?, NOW())";
        $transaction_stmt = $conn->prepare($transaction_sql);
        $transaction_stmt->bind_param("idssss", $user_id, $amount, $reference, $bank_name, $account_number, $account_name);
        
        if ($transaction_stmt->execute()) {
            $success = "Permintaan penarikan berhasil dibuat. Silakan tunggu proses verifikasi.";
            
            // Redirect with success message
            header("Location: withdraw-modern.php?success=1");
            exit;
        } else {
            $error = "Gagal membuat permintaan penarikan: " . $conn->error;
        }
    }
}

// Check for success message
if (isset($_GET['success']) && $_GET['success'] == 1) {
    $success = "Permintaan penarikan berhasil dibuat. Silakan tunggu proses verifikasi.";
}

// Get recent withdrawal transactions
try {
    $transactions_sql = "SELECT * FROM transactions 
                        WHERE user_id = ? AND type = 'withdrawal' 
                        ORDER BY created_at DESC 
                        LIMIT 5";
    $transactions_stmt = $conn->prepare($transactions_sql);
    $transactions_stmt->bind_param("i", $user_id);
    $transactions_stmt->execute();
    $transactions_result = $transactions_stmt->get_result();
} catch (Throwable $e) {
    error_log("Error fetching transactions: " . $e->getMessage());
}

// Set page title and flags
$page_title = "Penarikan Saldo";
$is_dashboard_page = true;
$use_ultra_modern = true;

// Include header
include("includes/header.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($error)): ?>
    <div class="modern-alert modern-alert-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($success)): ?>
    <div class="modern-alert modern-alert-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php 
            try {
                include("includes/account-navbar.php"); 
            } catch (Throwable $e) {
                echo '<div class="modern-alert modern-alert-danger mb-4">
                    <i class="fa fa-exclamation-circle"></i>
                    <div>Error memuat navigasi: ' . htmlspecialchars($e->getMessage()) . '</div>
                </div>';
                
                // Tampilkan navbar alternatif simple
                echo '<div class="list-group mb-4">
                    <a href="account-modern.php" class="list-group-item list-group-item-action">Dashboard</a>
                    <a href="profile-modern.php" class="list-group-item list-group-item-action">Profil</a>
                    <a href="bids-modern.php" class="list-group-item list-group-item-action">Riwayat Bid</a>
                    <a href="transactions-modern.php" class="list-group-item list-group-item-action">Transaksi</a>
                    <a href="topup-modern.php" class="list-group-item list-group-item-action">Top Up</a>
                    <a href="withdraw-modern.php" class="list-group-item list-group-item-action active">Penarikan</a>
                </div>';
            }
            ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <h2 class="mb-4 fade-in">Penarikan Saldo</h2>
            
            <div class="row">
                <!-- Withdrawal Form -->
                <div class="col-lg-6 mb-4">
                    <div class="modern-card fade-in shadow-sm">
                        <div class="modern-card-header bg-gradient-primary text-white">
                            <h3 class="modern-card-title"><i class="fa fa-money-bill-wave"></i> Penarikan Dana</h3>
                        </div>
                        <div class="modern-card-body">
                            <!-- Balance Card -->
                            <div class="balance-card mb-4">
                                <div class="balance-card-inner">
                                    <div class="balance-label">Saldo Tersedia</div>
                                    <div class="balance-amount">Rp<?php echo number_format($user['balance'], 0, ',', '.'); ?></div>
                                    <div class="balance-card-icon"><i class="fa fa-wallet"></i></div>
                                </div>
                            </div>
                            
                            <!-- Withdrawal Process Info -->
                            <div class="alert alert-info mb-4">
                                <div class="d-flex">
                                    <div class="me-3"><i class="fa fa-info-circle fa-2x"></i></div>
                                    <div>
                                        <strong>Penarikan Dana yang Lebih Aman</strong><br>
                                        Saldo Anda tidak akan terpotong sampai penarikan disetujui oleh admin. Proses persetujuan biasanya membutuhkan waktu 1x24 jam kerja.
                                    </div>
                                </div>
                            </div>
                            
                            <form method="post" action="process_withdrawal.php" class="withdrawal-form">
                                <div class="modern-form-group">
                                    <label class="modern-form-label" for="amount">Jumlah Penarikan</label>
                                    <div class="input-group amount-input">
                                        <div class="input-group-prepend">
                                            <span class="input-group-text">Rp</span>
                                        </div>
                                        <input type="number" class="modern-form-control" id="amount" name="amount" placeholder="Masukkan jumlah" max="<?php echo $user['balance']; ?>" required>
                                    </div>
                                    <small class="form-text text-muted">Minimal penarikan: Rp50.000 | Maksimal: Rp<?php echo number_format($user['balance'], 0, ',', '.'); ?></small>
                                </div>
                                
                                <div class="modern-form-group">
                                    <label class="modern-form-label">Pilih Nominal Cepat</label>
                                    <div class="preset-amounts">
                                        <button type="button" class="preset-btn" data-amount="100000">Rp100.000</button>
                                        <button type="button" class="preset-btn" data-amount="500000">Rp500.000</button>
                                        <button type="button" class="preset-btn" data-amount="1000000">Rp1.000.000</button>
                                        <button type="button" class="preset-btn" data-amount="5000000">Rp5.000.000</button>
                                    </div>
                                </div>
                                
                                <div class="bank-selection-area mt-4">
                                    <h5 class="form-section-title"><i class="fa fa-university me-2"></i>Informasi Rekening Bank</h5>
                                    
                                    <div class="bank-logos mb-3">
                                        <div class="bank-logo-item" data-bank="BCA">
                                            <img src="images/banks/bca.png" alt="BCA" onerror="this.src='images/banks/bank-placeholder.png';">
                                        </div>
                                        <div class="bank-logo-item" data-bank="Mandiri">
                                            <img src="images/banks/mandiri.png" alt="Mandiri" onerror="this.src='images/banks/bank-placeholder.png';">
                                        </div>
                                        <div class="bank-logo-item" data-bank="BNI">
                                            <img src="images/banks/bni.png" alt="BNI" onerror="this.src='images/banks/bank-placeholder.png';">
                                        </div>
                                        <div class="bank-logo-item" data-bank="BRI">
                                            <img src="images/banks/bri.png" alt="BRI" onerror="this.src='images/banks/bank-placeholder.png';">
                                        </div>
                                        <div class="bank-logo-item" data-bank="other">
                                            <i class="fa fa-ellipsis-h"></i>
                                        </div>
                                    </div>
                                    
                                    <div class="modern-form-group">
                                        <label class="modern-form-label" for="bank_name">Nama Bank</label>
                                        <select class="modern-form-control" id="bank_name" name="bank_name" required>
                                            <option value="">Pilih Bank</option>
                                            <option value="BCA">BCA</option>
                                            <option value="Mandiri">Mandiri</option>
                                            <option value="BNI">BNI</option>
                                            <option value="BRI">BRI</option>
                                            <option value="CIMB Niaga">CIMB Niaga</option>
                                            <option value="Permata">Permata</option>
                                            <option value="Danamon">Danamon</option>
                                            <option value="BTN">BTN</option>
                                            <option value="Lainnya">Lainnya</option>
                                        </select>
                                    </div>
                                    
                                    <div class="row">
                                        <div class="col-md-6">
                                            <div class="modern-form-group">
                                                <label class="modern-form-label" for="account_number">Nomor Rekening</label>
                                                <input type="text" class="modern-form-control" id="account_number" name="account_number" placeholder="Masukkan nomor rekening" required>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="modern-form-group">
                                                <label class="modern-form-label" for="account_name">Nama Pemilik Rekening</label>
                                                <input type="text" class="modern-form-control" id="account_name" name="account_name" placeholder="Nama sesuai buku tabungan" required>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <div class="modern-form-group">
                                        <label class="modern-form-label" for="notes">Catatan (Opsional)</label>
                                        <textarea class="modern-form-control" id="notes" name="notes" rows="2" placeholder="Tambahkan catatan jika diperlukan"></textarea>
                                    </div>
                                </div>
                                
                                <div class="withdrawal-confirmation mt-4">
                                    <div class="confirmation-checkbox mb-3">
                                        <div class="form-check">
                                            <input class="form-check-input" type="checkbox" id="confirm_withdrawal" required>
                                            <label class="form-check-label" for="confirm_withdrawal">
                                                Saya menyatakan bahwa informasi rekening di atas benar dan penarikan ini sesuai dengan <a href="#" class="text-primary">Syarat & Ketentuan</a> LelangMobil
                                            </label>
                                        </div>
                                    </div>
                                    
                                    <button type="submit" name="request_withdrawal" class="modern-button modern-button-primary btn-lg w-100">
                                        <i class="fa fa-check-circle me-2"></i>Ajukan Penarikan
                                    </button>
                                    
                                    <div class="security-notice text-center mt-3">
                                        <small><i class="fa fa-shield-alt me-1"></i> Transaksi Anda aman dengan enkripsi SSL 256-bit</small>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
                
                <!-- Recent Transactions -->
                <div class="col-lg-6 mb-4">
                    <div class="modern-card fade-in shadow-sm">
                        <div class="modern-card-header bg-gradient-secondary text-white">
                            <h3 class="modern-card-title"><i class="fa fa-history"></i> Riwayat Penarikan</h3>
                        </div>
                        <div class="modern-card-body p-0">
                            <!-- Status Filter -->
                            <div class="status-filter p-3 border-bottom">
                                <div class="d-flex justify-content-between align-items-center">
                                    <h6 class="mb-0">Status Penarikan</h6>
                                    <div class="btn-group btn-group-sm">
                                        <button type="button" class="btn btn-outline-primary active" data-filter="all">Semua</button>
                                        <button type="button" class="btn btn-outline-primary" data-filter="pending">Menunggu</button>
                                        <button type="button" class="btn btn-outline-primary" data-filter="completed">Disetujui</button>
                                        <button type="button" class="btn btn-outline-primary" data-filter="rejected">Ditolak</button>
                                    </div>
                                </div>
                            </div>
                            <div class="table-responsive">
                                <table class="table modern-table withdrawal-history">
                                    <thead>
                                        <tr>
                                            <th>Tanggal</th>
                                            <th>Jumlah</th>
                                            <th>Bank</th>
                                            <th>Status</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        if ($transactions_result && $transactions_result->num_rows > 0) {
                                            while ($transaction = $transactions_result->fetch_assoc()) {
                                                echo '<tr>';
                                                echo '<td>' . date('d M Y', strtotime($transaction['created_at'])) . '</td>';
                                                echo '<td>Rp' . number_format($transaction['amount'], 0, ',', '.') . '</td>';
                                                echo '<td>' . htmlspecialchars($transaction['bank_name']) . '</td>';
                                                
                                                // Status badge
                                                $status_class = '';
                                                switch ($transaction['status']) {
                                                    case 'completed':
                                                        $status_class = 'success';
                                                        break;
                                                    case 'pending':
                                                        $status_class = 'warning';
                                                        break;
                                                    case 'rejected':
                                                        $status_class = 'danger';
                                                        break;
                                                    default:
                                                        $status_class = 'secondary';
                                                }
                                                
                                                echo '<td><span class="badge bg-' . $status_class . '">' . ucfirst($transaction['status']) . '</span></td>';
                                                echo '</tr>';
                                            }
                                        } else {
                                            echo '<tr><td colspan="4" class="text-center">Belum ada riwayat penarikan.</td></tr>';
                                        }
                                        ?>
                                    </tbody>
                                </table>
                            </div>
                            
                            <div class="p-3 border-top text-center">
                                <a href="transactions-modern.php" class="modern-button modern-button-outline">
                                    <i class="fa fa-list me-2"></i>Lihat Semua Transaksi
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- Withdrawal Info -->
            <div class="modern-card fade-in">
                <div class="modern-card-header">
                    <h3 class="modern-card-title"><i class="fa fa-info-circle"></i> Informasi Penarikan</h3>
                </div>
                <div class="modern-card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <h5>Ketentuan Penarikan</h5>
                            <ul class="info-list">
                                <li>Minimal penarikan adalah Rp100.000</li>
                                <li>Penarikan diproses dalam 1-3 hari kerja</li>
                                <li>Biaya admin penarikan sebesar Rp5.000</li>
                                <li>Pastikan data rekening bank Anda benar</li>
                                <li>Penarikan hanya dapat dilakukan ke rekening atas nama sendiri</li>
                            </ul>
                        </div>
                        <div class="col-md-6">
                            <h5>Jam Operasional</h5>
                            <ul class="info-list">
                                <li>Senin - Jumat: 09:00 - 17:00 WIB</li>
                                <li>Sabtu: 09:00 - 15:00 WIB</li>
                                <li>Minggu & Hari Libur: Tidak ada proses penarikan</li>
                            </ul>
                            <p>Penarikan yang diajukan di luar jam operasional akan diproses pada hari kerja berikutnya.</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include "includes/footer.php"; ?>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Preset amount buttons
    const presetButtons = document.querySelectorAll('.preset-btn');
    const amountInput = document.getElementById('amount');
    const maxAmount = <?php echo $user['balance']; ?>;
    const bankItems = document.querySelectorAll('.bank-logo-item');
    const bankSelect = document.getElementById('bank_name');
    const confirmCheckbox = document.getElementById('confirm_withdrawal');
    const submitButton = document.querySelector('button[name="request_withdrawal"]');
    
    // Toggle bank selection
    bankItems.forEach(item => {
        item.addEventListener('click', function() {
            const bankValue = this.getAttribute('data-bank');
            
            // Remove active class from all items
            bankItems.forEach(b => b.classList.remove('active'));
            
            // Add active class to clicked item
            this.classList.add('active');
            
            // Set select value if not 'other'
            if (bankValue !== 'other') {
                bankSelect.value = bankValue;
            } else {
                // Focus on select for 'other'
                bankSelect.focus();
            }
        });
    });
    
    // Update bank logo when select changes
    bankSelect.addEventListener('change', function() {
        const selectedBank = this.value;
        
        // Remove active class from all items
        bankItems.forEach(b => b.classList.remove('active'));
        
        // Find matching bank item and activate it
        const matchingItem = document.querySelector(`.bank-logo-item[data-bank="${selectedBank}"]`);
        if (matchingItem) {
            matchingItem.classList.add('active');
        } else {
            // If no match, activate 'other'
            const otherItem = document.querySelector('.bank-logo-item[data-bank="other"]');
            if (otherItem) otherItem.classList.add('active');
        }
    });
    
    // Preset amount buttons
    presetButtons.forEach(button => {
        button.addEventListener('click', function() {
            const amount = parseInt(this.getAttribute('data-amount'));
            
            // Check if amount is greater than balance
            if (amount > maxAmount) {
                showToast('warning', 'Jumlah melebihi saldo Anda.');
                return;
            }
            
            amountInput.value = amount;
            
            // Remove active class from all buttons
            presetButtons.forEach(btn => btn.classList.remove('active'));
            
            // Add active class to clicked button
            this.classList.add('active');
            
            // Show estimated arrival
            updateEstimatedArrival();
        });
    });
    
    // Handle amount input changes
    amountInput.addEventListener('input', function() {
        updateEstimatedArrival();
        validateAmount();
    });
    
    // Show estimated arrival time based on current time
    function updateEstimatedArrival() {
        const amount = parseInt(amountInput.value) || 0;
        if (amount >= 50000) {
            // Get current date
            const now = new Date();
            const currentHour = now.getHours();
            const isWeekend = now.getDay() === 0 || now.getDay() === 6;
            
            // Calculate processing days
            let daysToAdd = 1;
            if (isWeekend || currentHour >= 15) {
                daysToAdd = 2;
            }
            
            // Add days to current date
            const estimatedDate = new Date(now);
            estimatedDate.setDate(now.getDate() + daysToAdd);
            
            // Format date
            const options = { weekday: 'long', day: 'numeric', month: 'long' };
            const formattedDate = estimatedDate.toLocaleDateString('id-ID', options);
            
            // Show estimation near the submit button
            const estimationElement = document.querySelector('.estimated-arrival');
            if (!estimationElement) {
                const newElement = document.createElement('div');
                newElement.className = 'estimated-arrival mt-2 text-center text-muted';
                newElement.innerHTML = `<small>Dana akan diterima sekitar <strong>${formattedDate}</strong> jika disetujui</small>`;
                submitButton.parentNode.appendChild(newElement);
            } else {
                estimationElement.innerHTML = `<small>Dana akan diterima sekitar <strong>${formattedDate}</strong> jika disetujui</small>`;
            }
        }
    }
    
    // Validate withdrawal amount
    function validateAmount() {
        const amount = parseInt(amountInput.value) || 0;
        
        if (amount < 50000 && amount > 0) {
            // Show minimum warning
            amountInput.classList.add('is-invalid');
            const feedbackElement = document.querySelector('.amount-feedback');
            if (!feedbackElement) {
                const newElement = document.createElement('div');
                newElement.className = 'invalid-feedback amount-feedback';
                newElement.innerHTML = 'Minimal penarikan Rp50.000';
                amountInput.parentNode.appendChild(newElement);
            }
            return false;
        } else if (amount > maxAmount) {
            // Show maximum warning
            amountInput.classList.add('is-invalid');
            const feedbackElement = document.querySelector('.amount-feedback');
            if (!feedbackElement) {
                const newElement = document.createElement('div');
                newElement.className = 'invalid-feedback amount-feedback';
                newElement.innerHTML = 'Jumlah melebihi saldo Anda';
                amountInput.parentNode.appendChild(newElement);
            } else {
                feedbackElement.innerHTML = 'Jumlah melebihi saldo Anda';
            }
            return false;
        } else {
            // Remove warnings
            amountInput.classList.remove('is-invalid');
            const feedbackElement = document.querySelector('.amount-feedback');
            if (feedbackElement) {
                feedbackElement.remove();
            }
            return true;
        }
    }
    
    // Show toast notification
    function showToast(type, message) {
        const toastContainer = document.querySelector('.toast-container');
        if (!toastContainer) {
            // Create toast container if it doesn't exist
            const newContainer = document.createElement('div');
            newContainer.className = 'toast-container position-fixed bottom-0 end-0 p-3';
            document.body.appendChild(newContainer);
            
            // Create toast
            const toast = document.createElement('div');
            toast.className = `toast bg-${type} text-white`;
            toast.setAttribute('role', 'alert');
            toast.setAttribute('aria-live', 'assertive');
            toast.setAttribute('aria-atomic', 'true');
            
            toast.innerHTML = `
                <div class="toast-header bg-${type} text-white">
                    <strong class="me-auto"><i class="fa fa-info-circle me-2"></i>Notifikasi</strong>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="toast" aria-label="Close"></button>
                </div>
                <div class="toast-body">
                    ${message}
                </div>
            `;
            
            newContainer.appendChild(toast);
            
            // Initialize and show toast
            const bsToast = new bootstrap.Toast(toast);
            bsToast.show();
        } else {
            // Use existing container
            const toast = document.createElement('div');
            toast.className = `toast bg-${type} text-white`;
            toast.setAttribute('role', 'alert');
            toast.setAttribute('aria-live', 'assertive');
            toast.setAttribute('aria-atomic', 'true');
            
            toast.innerHTML = `
                <div class="toast-header bg-${type} text-white">
                    <strong class="me-auto"><i class="fa fa-info-circle me-2"></i>Notifikasi</strong>
                    <button type="button" class="btn-close btn-close-white" data-bs-dismiss="toast" aria-label="Close"></button>
                </div>
                <div class="toast-body">
                    ${message}
                </div>
            `;
            
            toastContainer.appendChild(toast);
            
            // Initialize and show toast
            const bsToast = new bootstrap.Toast(toast);
            bsToast.show();
        }
    }
    
    // Status filter buttons
    const filterButtons = document.querySelectorAll('.status-filter button');
    const transactionRows = document.querySelectorAll('.withdrawal-history tbody tr');
    
    filterButtons.forEach(button => {
        button.addEventListener('click', function() {
            const filter = this.getAttribute('data-filter');
            
            // Remove active class from all buttons
            filterButtons.forEach(btn => btn.classList.remove('active'));
            
            // Add active class to clicked button
            this.classList.add('active');
            
            // Filter transactions
            if (filter === 'all') {
                transactionRows.forEach(row => row.style.display = '');
            } else {
                transactionRows.forEach(row => {
                    const statusCell = row.querySelector('td:last-child span');
                    if (statusCell && statusCell.textContent.toLowerCase() === filter) {
                        row.style.display = '';
                    } else {
                        row.style.display = 'none';
                    }
                });
            }
        });
    });
    
    // Form validation
    const withdrawForm = document.querySelector('form.withdrawal-form');
    
    if (withdrawForm) {
        withdrawForm.addEventListener('submit', function(e) {
            if (!validateAmount()) {
                e.preventDefault();
                return;
            }
            
            const amount = parseInt(amountInput.value) || 0;
            const bankValue = bankSelect.value;
            const accountNumber = document.getElementById('account_number').value;
            const accountName = document.getElementById('account_name').value;
            
            if (!bankValue) {
                e.preventDefault();
                showToast('warning', 'Silakan pilih bank terlebih dahulu.');
                bankSelect.focus();
                return;
            }
            
            if (!accountNumber) {
                e.preventDefault();
                showToast('warning', 'Silakan masukkan nomor rekening.');
                document.getElementById('account_number').focus();
                return;
            }
            
            if (!accountName) {
                e.preventDefault();
                showToast('warning', 'Silakan masukkan nama pemilik rekening.');
                document.getElementById('account_name').focus();
                return;
            }
            
            if (!confirmCheckbox.checked) {
                e.preventDefault();
                showToast('warning', 'Anda harus menyetujui syarat dan ketentuan.');
                confirmCheckbox.focus();
                return;
            }
            
            // Show confirmation if everything is valid
            e.preventDefault();
            if (confirm(`Anda akan mengajukan penarikan sebesar Rp${amount.toLocaleString('id-ID')} ke rekening ${bankValue} ${accountNumber} a.n ${accountName}. Lanjutkan?`)) {
                this.submit();
            }
        });
    }
    
    // Init on page load
    updateEstimatedArrival();
});
</script>

.preset-btn:hover {
    background-color: #e9ecef;
}

.preset-btn.active {
    background-color: rgba(74, 110, 224, 0.1);
    border-color: #4a6ee0;
    color: #4a6ee0;
}

.modern-table {
    margin-bottom: 0;
}

.modern-table th {
    border-top: none;
    font-weight: 600;
    color: #495057;
}

.modern-table td {
    vertical-align: middle;
}

.modern-form-value {
    font-size: 24px;
    font-weight: 700;
    color: #4a6ee0;
    margin-bottom: 20px;
}

.info-list {
    padding-left: 20px;
    margin-bottom: 20px;
}

.info-list li {
    margin-bottom: 8px;
    position: relative;
}

.info-list li::before {
    content: "•";
    color: #4a6ee0;
    font-weight: bold;
    display: inline-block;
    width: 1em;
    margin-left: -1em;
}
</style>

<?php include("includes/footer.php"); ?>