<?php
/**
 * Reset Password Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

$error = '';
$success = '';
$token_valid = false;
$user_id = 0;

// Check if token is provided
if (isset($_GET['token']) && !empty($_GET['token'])) {
    $token = clean_input($_GET['token']);
    
    // Check if token exists and is valid
    $token_sql = "SELECT * FROM users WHERE reset_token = ? AND reset_token_expiry > NOW()";
    $token_stmt = $conn->prepare($token_sql);
    $token_stmt->bind_param("s", $token);
    $token_stmt->execute();
    $token_result = $token_stmt->get_result();
    
    if ($token_result->num_rows > 0) {
        $user = $token_result->fetch_assoc();
        $token_valid = true;
        $user_id = $user['user_id'];
    } else {
        $error = "Token reset password tidak valid atau sudah kedaluwarsa. Silakan minta token baru.";
    }
} else {
    $error = "Token reset password tidak ditemukan. Silakan periksa link yang Anda klik.";
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['reset_password']) && $token_valid) {
    $new_password = clean_input($_POST['new_password'] ?? '');
    $confirm_password = clean_input($_POST['confirm_password'] ?? '');
    
    // Validate passwords
    if (empty($new_password) || empty($confirm_password)) {
        $error = "Semua field password harus diisi.";
    } elseif ($new_password !== $confirm_password) {
        $error = "Password baru dan konfirmasi password harus sama.";
    } elseif (!is_valid_password($new_password)) {
        $error = "Password baru minimal harus 8 karakter.";
    } else {
        // Hash new password
        $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);
        
        // Update password and clear reset token
        $update_sql = "UPDATE users SET password = ?, reset_token = NULL, reset_token_expiry = NULL WHERE user_id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param("si", $hashed_password, $user_id);
        
        if ($update_stmt->execute()) {
            $success = "Password berhasil diubah! Anda sekarang dapat login dengan password baru Anda.";
            $token_valid = false; // Hide the form
            
            // Redirect to login page after 3 seconds
            header("refresh:3;url=login.php?success=password_reset");
        } else {
            $error = "Gagal mengubah password. Silakan coba lagi.";
        }
    }
}

// Aktifkan flag untuk halaman login
$page_title = "Reset Password";
$is_auth_page = true;
$use_modern_auth = true;

// Custom CSS untuk halaman auth
$page_specific_css = '<link href="css/login-modern.css" rel="stylesheet" type="text/css">';

// Include header
include("includes/header.php");
?>

<div class="auth-container">
    <div class="auth-card animate">
        <div class="auth-card-header text-center">
            <h2><i class="fa fa-key"></i> Reset Password</h2>
            <p class="text-muted">Buat password baru untuk akun Anda</p>
        </div>
        
        <div class="auth-card-body">
            <?php if (!empty($error)): ?>
                <div class="auth-alert auth-alert-danger">
                    <i class="fa fa-exclamation-circle me-2"></i><?php echo $error; ?>
                </div>
                
                <?php if (!$token_valid): ?>
                    <div class="text-center mt-4">
                        <a href="forgot-password.php" class="auth-btn auth-btn-primary">
                            <i class="fa fa-paper-plane me-2"></i>Minta Reset Password Baru
                        </a>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
            
            <?php if (!empty($success)): ?>
                <div class="auth-alert auth-alert-success">
                    <i class="fa fa-check-circle me-2"></i><?php echo $success; ?>
                </div>
                
                <div class="text-center mt-4">
                    <div class="mb-4">
                        <i class="fa fa-check-circle fa-3x text-success"></i>
                    </div>
                    <h4>Password Berhasil Diubah!</h4>
                    <p>Password Anda telah berhasil diubah. Anda akan dialihkan ke halaman login dalam beberapa detik.</p>
                    
                    <div class="mt-4">
                        <a href="login.php" class="auth-btn auth-btn-primary">
                            <i class="fa fa-sign-in-alt me-2"></i>Login Sekarang
                        </a>
                    </div>
                </div>
            <?php endif; ?>
            
            <?php if ($token_valid && empty($success)): ?>
                <form method="post" action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>?token=<?php echo htmlspecialchars($token); ?>" id="resetPasswordForm" class="stagger-animate">
                    <div class="auth-form-group">
                        <label for="new_password" class="auth-form-label">Password Baru</label>
                        <div class="input-group">
                            <span class="input-group-text"><i class="fa fa-lock"></i></span>
                            <input type="password" class="auth-form-control" id="new_password" name="new_password" required>
                            <button class="btn btn-outline-secondary toggle-password" type="button">
                                <i class="fa fa-eye"></i>
                            </button>
                        </div>
                        <small class="text-muted">Minimal 8 karakter</small>
                    </div>
                    
                    <div class="auth-form-group">
                        <label for="confirm_password" class="auth-form-label">Konfirmasi Password</label>
                        <div class="input-group">
                            <span class="input-group-text"><i class="fa fa-lock"></i></span>
                            <input type="password" class="auth-form-control" id="confirm_password" name="confirm_password" required>
                            <button class="btn btn-outline-secondary toggle-password" type="button">
                                <i class="fa fa-eye"></i>
                            </button>
                        </div>
                    </div>
                    
                    <div class="d-grid mb-4">
                        <button type="submit" name="reset_password" class="auth-btn auth-btn-primary">
                            <i class="fa fa-key me-2"></i>Reset Password
                        </button>
                    </div>
                </form>
            <?php endif; ?>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Toggle password visibility
    const toggleButtons = document.querySelectorAll('.toggle-password');
    
    toggleButtons.forEach(button => {
        button.addEventListener('click', function() {
            const input = this.previousElementSibling;
            const icon = this.querySelector('i');
            
            if (input.type === 'password') {
                input.type = 'text';
                icon.classList.remove('fa-eye');
                icon.classList.add('fa-eye-slash');
            } else {
                input.type = 'password';
                icon.classList.remove('fa-eye-slash');
                icon.classList.add('fa-eye');
            }
        });
    });
    
    // Form validation
    const form = document.getElementById('resetPasswordForm');
    if (form) {
        form.addEventListener('submit', function(e) {
            const newPassword = document.getElementById('new_password').value;
            const confirmPassword = document.getElementById('confirm_password').value;
            
            if (newPassword.length < 8) {
                e.preventDefault();
                alert('Password minimal harus 8 karakter.');
                return false;
            }
            
            if (newPassword !== confirmPassword) {
                e.preventDefault();
                alert('Password baru dan konfirmasi password harus sama.');
                return false;
            }
            
            return true;
        });
    }
});
</script>

<?php include("includes/footer.php"); ?>