<?php
/**
 * Shipping Tab Component
 * LelangMobil Web App - Versi 2025
 */

// Get user addresses
$user_addresses = [];
try {
    $addresses_sql = "SELECT * FROM user_addresses WHERE user_id = ? ORDER BY is_default DESC, created_at DESC";
    $addresses_stmt = $conn->prepare($addresses_sql);
    $addresses_stmt->bind_param("i", $user_id);
    $addresses_stmt->execute();
    $addresses_result = $addresses_stmt->get_result();
    
    while ($row = $addresses_result->fetch_assoc()) {
        $user_addresses[] = $row;
    }
} catch (Throwable $e) {
    // Handle error silently
}
?>

<div class="tab-pane fade" id="shipping-tab" role="tabpanel" aria-labelledby="shipping-tab">
    <div class="tab-header d-flex justify-content-between align-items-center mb-4">
        <h4>Alamat Pengiriman</h4>
        <a href="shipping-address.php" class="modern-button modern-button-primary modern-button-sm">
            <i class="fa fa-edit me-2"></i>Kelola Alamat
        </a>
    </div>
    
    <?php if (empty($user_addresses)): ?>
    <div class="empty-state text-center py-5">
        <i class="fa fa-map-marker-alt fa-4x text-muted mb-3"></i>
        <h5>Belum Ada Alamat</h5>
        <p class="text-muted">Anda belum menambahkan alamat pengiriman.</p>
        <a href="shipping-address.php" class="modern-button modern-button-primary mt-3">
            <i class="fa fa-plus me-2"></i>Tambah Alamat
        </a>
    </div>
    <?php else: ?>
    <div class="row">
        <?php foreach ($user_addresses as $address): ?>
        <div class="col-md-6 mb-4">
            <div class="modern-card address-card h-100 <?php echo $address['is_default'] ? 'address-card-default' : ''; ?>">
                <?php if ($address['is_default']): ?>
                <div class="default-badge">
                    <i class="fa fa-check-circle me-1"></i> Utama
                </div>
                <?php endif; ?>
                
                <div class="modern-card-body">
                    <div class="d-flex justify-content-between align-items-start mb-3">
                        <div>
                            <h5 class="address-name"><?php echo htmlspecialchars($address['recipient_name']); ?></h5>
                            <p class="address-phone mb-0"><?php echo htmlspecialchars($address['phone']); ?></p>
                        </div>
                        <span class="address-type-badge <?php echo $address['address_type']; ?>">
                            <?php 
                            switch($address['address_type']) {
                                case 'home':
                                    echo '<i class="fa fa-home me-1"></i> Rumah';
                                    break;
                                case 'office':
                                    echo '<i class="fa fa-building me-1"></i> Kantor';
                                    break;
                                default:
                                    echo '<i class="fa fa-map-marker-alt me-1"></i> ' . htmlspecialchars($address['address_label']);
                            }
                            ?>
                        </span>
                    </div>
                    
                    <div class="address-details">
                        <p class="mb-1"><?php echo htmlspecialchars($address['full_address']); ?></p>
                        <p class="mb-1">
                            <?php 
                            echo htmlspecialchars($address['district'] ? $address['district'] . ', ' : '');
                            echo htmlspecialchars($address['city'] . ', ' . $address['province']); 
                            ?>
                        </p>
                        <?php if (!empty($address['postal_code'])): ?>
                        <p class="mb-0"><?php echo htmlspecialchars($address['postal_code']); ?></p>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <?php endforeach; ?>
    </div>
    <?php endif; ?>
</div>

<style>
.address-card {
    position: relative;
    transition: all 0.3s ease;
    border: 1px solid #dee2e6;
}

.address-card:hover {
    transform: translateY(-5px);
    box-shadow: 0 10px 20px rgba(0,0,0,0.1);
}

.address-card-default {
    border: 2px solid var(--success);
}

.default-badge {
    position: absolute;
    top: 10px;
    right: 10px;
    background-color: var(--success);
    color: white;
    padding: 3px 10px;
    border-radius: 20px;
    font-size: 0.75rem;
    font-weight: 600;
}

.address-type-badge {
    padding: 3px 10px;
    border-radius: 20px;
    font-size: 0.75rem;
    font-weight: 600;
}

.address-type-badge.home {
    background-color: rgba(74, 110, 224, 0.1);
    color: var(--primary);
}

.address-type-badge.office {
    background-color: rgba(40, 167, 69, 0.1);
    color: var(--success);
}

.address-type-badge.other {
    background-color: rgba(108, 117, 125, 0.1);
    color: var(--secondary);
}

.address-name {
    font-weight: 600;
    margin-bottom: 5px;
}

.address-phone {
    color: var(--secondary);
    font-size: 0.9rem;
}

.address-details {
    margin-top: 15px;
    padding-top: 15px;
    border-top: 1px solid #eee;
    color: var(--secondary);
    font-size: 0.9rem;
}

.empty-state i {
    color: #ccc;
}
</style>