-- Add notification columns to bids table
ALTER TABLE bids
ADD COLUMN notification_sent TINYINT(1) DEFAULT 0,
ADD COLUMN is_auto_bid TINYINT(1) DEFAULT 0;

-- Add notification columns to vehicles table
ALTER TABLE vehicles
ADD COLUMN ending_notification_sent TINYINT(1) DEFAULT 0,
ADD COLUMN ended_notification_sent TINYINT(1) DEFAULT 0;

-- Add notification preferences to users table
ALTER TABLE users
ADD COLUMN notification_preferences JSON DEFAULT '{"email": true, "websocket": true, "bid_alerts": true}',
ADD COLUMN websocket_token VARCHAR(255);

-- Create notifications table for persistent notifications
CREATE TABLE IF NOT EXISTS notifications (
    notification_id INT PRIMARY KEY AUTO_INCREMENT,
    user_id INT NOT NULL,
    type VARCHAR(50) NOT NULL,
    title VARCHAR(255) NOT NULL,
    message TEXT NOT NULL,
    is_read TINYINT(1) DEFAULT 0,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(user_id)
);

-- Create notification types table
CREATE TABLE IF NOT EXISTS notification_types (
    type_id INT PRIMARY KEY AUTO_INCREMENT,
    type_name VARCHAR(50) NOT NULL UNIQUE,
    description TEXT,
    template TEXT NOT NULL
);

-- Insert default notification types
INSERT INTO notification_types (type_name, description, template) VALUES
('new_bid', 'New bid placed on vehicle', 'A new bid of {amount} has been placed on {vehicle}'),
('outbid', 'User has been outbid', 'You have been outbid on {vehicle}. Current bid: {amount}'),
('auction_ending', 'Auction ending soon', 'Auction for {vehicle} will end in {time}'),
('auction_won', 'User won auction', 'Congratulations! You won the auction for {vehicle}'),
('auction_ended', 'Auction has ended', 'Your auction for {vehicle} has ended'),
('payment_received', 'Payment received', 'Payment of {amount} received for {vehicle}'),
('comment_approved', 'Comment approved', 'Your comment on {vehicle} has been approved');

-- Add indexes for performance
CREATE INDEX idx_notifications_user ON notifications(user_id, is_read);
CREATE INDEX idx_notifications_type ON notifications(type);
CREATE INDEX idx_bids_notification ON bids(notification_sent);
CREATE INDEX idx_vehicles_notifications ON vehicles(ending_notification_sent, ended_notification_sent);