<?php
namespace LelangMobil\WebSocket;

use Ratchet\MessageComponentInterface;
use Ratchet\ConnectionInterface;
use PDO;

class BidServer implements MessageComponentInterface {
    protected $clients;
    protected $pdo;
    
    public function __construct(PDO $pdo) {
        $this->clients = new \SplObjectStorage;
        $this->pdo = $pdo;
    }

    public function onOpen(ConnectionInterface $conn) {
        $this->clients->attach($conn);
        echo "New connection! ({$conn->resourceId})\n";
    }

    public function onMessage(ConnectionInterface $from, $msg) {
        $data = json_decode($msg, true);
        
        if (!$data) return;
        
        switch ($data['type']) {
            case 'auth':
                $this->handleAuth($from, $data);
                break;
            case 'subscribe':
                $this->handleSubscribe($from, $data);
                break;
            case 'bid':
                $this->handleBid($from, $data);
                break;
        }
    }

    protected function handleAuth($conn, $data) {
        if (isset($data['token'])) {
            $stmt = $this->pdo->prepare("SELECT user_id FROM users WHERE websocket_token = ?");
            $stmt->execute([$data['token']]);
            if ($user = $stmt->fetch()) {
                $conn->user_id = $user['user_id'];
                $conn->send(json_encode([
                    'type' => 'auth',
                    'status' => 'success'
                ]));
            }
        }
    }

    protected function handleSubscribe($conn, $data) {
        if (isset($data['vehicle_id'])) {
            $conn->subscribed_vehicles[] = $data['vehicle_id'];
        }
    }

    protected function handleBid($from, $data) {
        if (!isset($from->user_id)) return;
        
        // Broadcast bid to all subscribed clients
        foreach ($this->clients as $client) {
            if (isset($client->subscribed_vehicles) && 
                in_array($data['vehicle_id'], $client->subscribed_vehicles)) {
                $client->send(json_encode([
                    'type' => 'bid_update',
                    'vehicle_id' => $data['vehicle_id'],
                    'amount' => $data['amount'],
                    'bidder_name' => $data['bidder_name']
                ]));
            }
        }
    }

    public function onClose(ConnectionInterface $conn) {
        $this->clients->detach($conn);
        echo "Connection {$conn->resourceId} has disconnected\n";
    }

    public function onError(ConnectionInterface $conn, \Exception $e) {
        echo "An error has occurred: {$e->getMessage()}\n";
        $conn->close();
    }

    public function broadcastVehicleUpdate($vehicle_id, $data) {
        foreach ($this->clients as $client) {
            if (isset($client->subscribed_vehicles) && 
                in_array($vehicle_id, $client->subscribed_vehicles)) {
                $client->send(json_encode($data));
            }
        }
    }
}