<?php
/**
 * System Test
 * LelangMobil Web App - Versi 2025
 * 
 * File ini digunakan untuk menguji sistem
 */

// Include initialization file
require_once 'config/init.php';

// Set page title
$page_title = "System Test";

// Start test
echo "<h1>LelangMobil System Test</h1>";
echo "<p>Testing system components...</p>";

// Test database connection
echo "<h2>Database Connection</h2>";
try {
    $test_sql = "SELECT 1";
    $test_result = $conn->query($test_sql);
    
    if ($test_result) {
        echo "<p style='color: green;'>✓ Database connection successful</p>";
    } else {
        echo "<p style='color: red;'>✗ Database connection failed</p>";
    }
} catch (Exception $e) {
    echo "<p style='color: red;'>✗ Database connection error: " . $e->getMessage() . "</p>";
}

// Test cache system
echo "<h2>Cache System</h2>";
try {
    $cache_key = 'test_key';
    $cache_data = 'test_data_' . time();
    
    $cache->set($cache_key, $cache_data);
    $retrieved_data = $cache->get($cache_key);
    
    if ($retrieved_data === $cache_data) {
        echo "<p style='color: green;'>✓ Cache system working</p>";
    } else {
        echo "<p style='color: red;'>✗ Cache system not working</p>";
    }
    
    $cache->delete($cache_key);
} catch (Exception $e) {
    echo "<p style='color: red;'>✗ Cache system error: " . $e->getMessage() . "</p>";
}

// Test image optimizer
echo "<h2>Image Optimizer</h2>";
try {
    $test_image = 'images/logo.png';
    
    if (file_exists($test_image)) {
        $optimized_url = get_optimized_image($test_image, 100, 100);
        
        if ($optimized_url) {
            echo "<p style='color: green;'>✓ Image optimizer working</p>";
            echo "<p>Original image: <img src='$test_image' height='50'></p>";
            echo "<p>Optimized image: <img src='$optimized_url' height='50'></p>";
        } else {
            echo "<p style='color: red;'>✗ Image optimizer not working</p>";
        }
    } else {
        echo "<p style='color: orange;'>⚠ Test image not found</p>";
    }
} catch (Exception $e) {
    echo "<p style='color: red;'>✗ Image optimizer error: " . $e->getMessage() . "</p>";
}

// Test minifier
echo "<h2>Minifier</h2>";
try {
    $test_css = 'css/modern-integrated.css';
    $test_js = 'js/modern-theme-activator.js';
    
    if (file_exists($test_css) && file_exists($test_js)) {
        $minified_css = get_minified_css($test_css, 'test.min.css');
        $minified_js = get_minified_js($test_js, 'test.min.js');
        
        if ($minified_css && $minified_js) {
            echo "<p style='color: green;'>✓ Minifier working</p>";
            echo "<p>Minified CSS: <a href='$minified_css' target='_blank'>$minified_css</a></p>";
            echo "<p>Minified JS: <a href='$minified_js' target='_blank'>$minified_js</a></p>";
        } else {
            echo "<p style='color: red;'>✗ Minifier not working</p>";
        }
    } else {
        echo "<p style='color: orange;'>⚠ Test files not found</p>";
    }
} catch (Exception $e) {
    echo "<p style='color: red;'>✗ Minifier error: " . $e->getMessage() . "</p>";
}

// Test error monitoring
echo "<h2>Error Monitoring</h2>";
try {
    $log_file = 'logs/error.log';
    
    if (file_exists($log_file)) {
        $log_size = filesize($log_file);
        $log_modified = date('Y-m-d H:i:s', filemtime($log_file));
        
        echo "<p style='color: green;'>✓ Error log exists</p>";
        echo "<p>Log size: " . number_format($log_size / 1024, 2) . " KB</p>";
        echo "<p>Last modified: $log_modified</p>";
    } else {
        echo "<p style='color: orange;'>⚠ Error log not found</p>";
    }
    
    // Test error handler
    // Uncomment to test error handler
    // trigger_error("Test error", E_USER_NOTICE);
    
    echo "<p style='color: green;'>✓ Error monitoring working</p>";
} catch (Exception $e) {
    echo "<p style='color: red;'>✗ Error monitoring error: " . $e->getMessage() . "</p>";
}

// Test transaction helper
echo "<h2>Transaction Helper</h2>";
try {
    // Get user balance info
    $test_user_id = 1;
    $balance_info = get_user_balance_info($test_user_id);
    
    if (is_array($balance_info)) {
        echo "<p style='color: green;'>✓ Transaction helper working</p>";
        echo "<p>User balance: " . format_money($balance_info['balance']) . "</p>";
        echo "<p>Available balance: " . format_money($balance_info['available_balance']) . "</p>";
    } else {
        echo "<p style='color: red;'>✗ Transaction helper not working</p>";
    }
} catch (Exception $e) {
    echo "<p style='color: red;'>✗ Transaction helper error: " . $e->getMessage() . "</p>";
}

// Test database helper functions
echo "<h2>Database Helper Functions</h2>";
try {
    // Test db_query
    $test_sql = "SELECT COUNT(*) as count FROM users";
    $test_result = db_query($test_sql);
    
    if ($test_result) {
        $row = $test_result->fetch_assoc();
        echo "<p style='color: green;'>✓ db_query working</p>";
        echo "<p>User count: " . $row['count'] . "</p>";
    } else {
        echo "<p style='color: red;'>✗ db_query not working</p>";
    }
    
    // Test db_get_row
    $test_sql = "SELECT COUNT(*) as count FROM users";
    $row = db_get_row($test_sql);
    
    if ($row) {
        echo "<p style='color: green;'>✓ db_get_row working</p>";
        echo "<p>User count: " . $row['count'] . "</p>";
    } else {
        echo "<p style='color: red;'>✗ db_get_row not working</p>";
    }
    
    // Test db_get_rows
    $test_sql = "SELECT * FROM users LIMIT 5";
    $rows = db_get_rows($test_sql);
    
    if (is_array($rows)) {
        echo "<p style='color: green;'>✓ db_get_rows working</p>";
        echo "<p>User count: " . count($rows) . "</p>";
    } else {
        echo "<p style='color: red;'>✗ db_get_rows not working</p>";
    }
} catch (Exception $e) {
    echo "<p style='color: red;'>✗ Database helper error: " . $e->getMessage() . "</p>";
}

// Test cached database functions
echo "<h2>Cached Database Functions</h2>";
try {
    // Test db_get_row_cached
    $test_sql = "SELECT COUNT(*) as count FROM users";
    $row = db_get_row_cached($test_sql);
    
    if ($row) {
        echo "<p style='color: green;'>✓ db_get_row_cached working</p>";
        echo "<p>User count: " . $row['count'] . "</p>";
    } else {
        echo "<p style='color: red;'>✗ db_get_row_cached not working</p>";
    }
    
    // Test db_get_rows_cached
    $test_sql = "SELECT * FROM users LIMIT 5";
    $rows = db_get_rows_cached($test_sql);
    
    if (is_array($rows)) {
        echo "<p style='color: green;'>✓ db_get_rows_cached working</p>";
        echo "<p>User count: " . count($rows) . "</p>";
    } else {
        echo "<p style='color: red;'>✗ db_get_rows_cached not working</p>";
    }
} catch (Exception $e) {
    echo "<p style='color: red;'>✗ Cached database error: " . $e->getMessage() . "</p>";
}

// Test complete
echo "<h2>Test Complete</h2>";
echo "<p>All tests completed.</p>";
?>