<?php
/**
 * Modern Top Up Page
 * LelangMobil Web App - Versi 2025
 */

// Start session if not already started
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// Include database connection and functions
require_once 'config/database.php';
require_once 'config/functions.php';

// Redirect if not logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit;
}

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Check for success message from upload-payment.php
if (isset($_GET['success']) && $_GET['success'] == 'payment_uploaded') {
    $success = "Bukti pembayaran berhasil diunggah. Admin akan memverifikasi pembayaran Anda dalam 1x24 jam.";
}

// Get user information
try {
    $user_sql = "SELECT * FROM users WHERE user_id = ?";
    $user_stmt = $conn->prepare($user_sql);
    $user_stmt->bind_param("i", $user_id);
    $user_stmt->execute();
    $user_result = $user_stmt->get_result();
    $user = $user_result->fetch_assoc();
} catch (Throwable $e) {
    die("Error fetching user data: " . $e->getMessage());
}

// Process top up request
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['topup'])) {
    $amount = (float)$_POST['amount'];
    $payment_method = trim($_POST['payment_method'] ?? '');
    
    if ($amount <= 0) {
        $error = "Jumlah top up harus lebih dari 0.";
    } elseif (empty($payment_method)) {
        $error = "Metode pembayaran harus dipilih.";
    } else {
        // Generate reference number
        $reference = 'TU' . date('YmdHis') . rand(100, 999);
        
        // Insert transaction
        $transaction_sql = "INSERT INTO transactions (user_id, amount, type, status, reference_number, payment_method, created_at) 
                          VALUES (?, ?, 'deposit', 'pending', ?, ?, NOW())";
        $transaction_stmt = $conn->prepare($transaction_sql);
        $transaction_stmt->bind_param("idss", $user_id, $amount, $reference, $payment_method);
        
        if ($transaction_stmt->execute()) {
            $transaction_id = $conn->insert_id;
            $success = "Permintaan top up berhasil dibuat. Silakan lakukan pembayaran dan unggah bukti pembayaran.";
            
            // Redirect to upload payment proof page
            header("Location: upload-payment.php?id=" . $transaction_id);
            exit;
        } else {
            $error = "Gagal membuat permintaan top up: " . $conn->error;
        }
    }
}

// Get recent top up transactions
try {
    $transactions_sql = "SELECT * FROM transactions 
                        WHERE user_id = ? AND type = 'deposit' 
                        ORDER BY created_at DESC 
                        LIMIT 5";
    $transactions_stmt = $conn->prepare($transactions_sql);
    $transactions_stmt->bind_param("i", $user_id);
    $transactions_stmt->execute();
    $transactions_result = $transactions_stmt->get_result();
} catch (Throwable $e) {
    error_log("Error fetching transactions: " . $e->getMessage());
}

// Set page title and flags
$page_title = "Top Up Saldo";
$is_dashboard_page = true;
$use_ultra_modern = true;

// Include header
include("includes/header.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($error)): ?>
    <div class="modern-alert modern-alert-danger mb-4 fade-in">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($success)): ?>
    <div class="modern-alert modern-alert-success mb-4 fade-in">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php 
            try {
                include("includes/account-navbar.php"); 
            } catch (Throwable $e) {
                echo '<div class="modern-alert modern-alert-danger mb-4">
                    <i class="fa fa-exclamation-circle"></i>
                    <div>Error memuat navigasi: ' . htmlspecialchars($e->getMessage()) . '</div>
                </div>';
                
                // Tampilkan navbar alternatif simple
                echo '<div class="list-group mb-4">
                    <a href="account-modern.php" class="list-group-item list-group-item-action">Dashboard</a>
                    <a href="profile-modern.php" class="list-group-item list-group-item-action">Profil</a>
                    <a href="bids-modern.php" class="list-group-item list-group-item-action">Riwayat Bid</a>
                    <a href="transactions-modern.php" class="list-group-item list-group-item-action">Transaksi</a>
                    <a href="topup-modern.php" class="list-group-item list-group-item-action active">Top Up</a>
                    <a href="withdraw-modern.php" class="list-group-item list-group-item-action">Penarikan</a>
                </div>';
            }
            ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <h2 class="mb-4 fade-in">Top Up Saldo</h2>
            
            <div class="row">
                <!-- Top Up Form -->
                <div class="col-lg-6 mb-4">
                    <div class="modern-card fade-in">
                        <div class="modern-card-header">
                            <h3 class="modern-card-title"><i class="fa fa-plus-circle"></i> Top Up</h3>
                        </div>
                        <div class="modern-card-body">
                            <form method="post" action="">
                                <div class="modern-form-group">
                                    <label class="modern-form-label">Saldo Saat Ini</label>
                                    <div class="modern-form-value">Rp<?php echo number_format($user['balance'], 0, ',', '.'); ?></div>
                                </div>
                                
                                <div class="modern-form-group">
                                    <label class="modern-form-label" for="amount">Jumlah Top Up</label>
                                    <div class="input-group">
                                        <div class="input-group-prepend">
                                            <span class="input-group-text">Rp</span>
                                        </div>
                                        <input type="number" class="modern-form-control" id="amount" name="amount" placeholder="Masukkan jumlah" required>
                                    </div>
                                </div>
                                
                                <div class="modern-form-group">
                                    <label class="modern-form-label">Pilih Nominal</label>
                                    <div class="preset-amounts">
                                        <button type="button" class="preset-btn" data-amount="100000">Rp100.000</button>
                                        <button type="button" class="preset-btn" data-amount="500000">Rp500.000</button>
                                        <button type="button" class="preset-btn" data-amount="1000000">Rp1.000.000</button>
                                        <button type="button" class="preset-btn" data-amount="5000000">Rp5.000.000</button>
                                    </div>
                                </div>
                                
                                <div class="modern-form-group">
                                    <label class="modern-form-label">Metode Pembayaran</label>
                                    <div class="payment-methods">
                                        <div class="row">
                                            <div class="col-6 mb-3">
                                                <div class="bank-option">
                                                    <input type="radio" id="bank-bca" name="payment_method" value="BCA" required>
                                                    <label for="bank-bca">
                                                        <div class="bank-logo">
                                                            <img src="images/bank-icons/bca.png" alt="BCA">
                                                        </div>
                                                        <div class="bank-name">BCA</div>
                                                    </label>
                                                </div>
                                            </div>
                                            <div class="col-6 mb-3">
                                                <div class="bank-option">
                                                    <input type="radio" id="bank-mandiri" name="payment_method" value="Mandiri" required>
                                                    <label for="bank-mandiri">
                                                        <div class="bank-logo">
                                                            <img src="images/bank-icons/mandiri.png" alt="Mandiri">
                                                        </div>
                                                        <div class="bank-name">Mandiri</div>
                                                    </label>
                                                </div>
                                            </div>
                                            <div class="col-6 mb-3">
                                                <div class="bank-option">
                                                    <input type="radio" id="bank-bni" name="payment_method" value="BNI" required>
                                                    <label for="bank-bni">
                                                        <div class="bank-logo">
                                                            <img src="images/bank-icons/bni.png" alt="BNI">
                                                        </div>
                                                        <div class="bank-name">BNI</div>
                                                    </label>
                                                </div>
                                            </div>
                                            <div class="col-6 mb-3">
                                                <div class="bank-option">
                                                    <input type="radio" id="bank-bri" name="payment_method" value="BRI" required>
                                                    <label for="bank-bri">
                                                        <div class="bank-logo">
                                                            <img src="images/bank-icons/bri.png" alt="BRI">
                                                        </div>
                                                        <div class="bank-name">BRI</div>
                                                    </label>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                
                                <div class="mt-4">
                                    <button type="submit" name="topup" class="modern-button modern-button-primary btn-lg w-100">
                                        <i class="fa fa-check-circle me-2"></i>Lanjutkan Top Up
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
                
                <!-- Recent Transactions -->
                <div class="col-lg-6 mb-4">
                    <div class="modern-card fade-in">
                        <div class="modern-card-header">
                            <h3 class="modern-card-title"><i class="fa fa-history"></i> Riwayat Top Up</h3>
                        </div>
                        <div class="modern-card-body p-0">
                            <div class="table-responsive">
                                <table class="table modern-table">
                                    <thead>
                                        <tr>
                                            <th>Tanggal</th>
                                            <th>Jumlah</th>
                                            <th>Status</th>
                                            <th>Aksi</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        if ($transactions_result && $transactions_result->num_rows > 0) {
                                            while ($transaction = $transactions_result->fetch_assoc()) {
                                                echo '<tr>';
                                                echo '<td>' . date('d M Y', strtotime($transaction['created_at'])) . '</td>';
                                                echo '<td>Rp' . number_format($transaction['amount'], 0, ',', '.') . '</td>';
                                                
                                                // Status badge
                                                $status_class = '';
                                                $status_text = '';
                                                switch ($transaction['status']) {
                                                    case 'completed':
                                                        $status_class = 'success';
                                                        $status_text = 'Selesai';
                                                        break;
                                                    case 'pending':
                                                        $status_class = 'warning';
                                                        $status_text = 'Menunggu Konfirmasi';
                                                        break;
                                                    case 'rejected':
                                                        $status_class = 'danger';
                                                        $status_text = 'Ditolak';
                                                        break;
                                                    default:
                                                        $status_class = 'secondary';
                                                        $status_text = ucfirst($transaction['status']);
                                                }
                                                
                                                echo '<td><span class="badge bg-' . $status_class . '">' . $status_text . '</span></td>';
                                                
                                                // Action button
                                                if ($transaction['status'] == 'pending' && empty($transaction['payment_proof'])) {
                                                    echo '<td><a href="upload-payment.php?id=' . $transaction['transaction_id'] . '" class="btn btn-sm btn-primary">Upload Bukti</a></td>';
                                                } else {
                                                    echo '<td>-</td>';
                                                }
                                                
                                                echo '</tr>';
                                            }
                                        } else {
                                            echo '<tr><td colspan="4" class="text-center">Belum ada riwayat top up.</td></tr>';
                                        }
                                        ?>
                                    </tbody>
                                </table>
                            </div>
                            
                            <div class="p-3 border-top text-center">
                                <a href="transactions-modern.php" class="modern-button modern-button-outline">
                                    <i class="fa fa-list me-2"></i>Lihat Semua Transaksi
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <!-- How to Top Up -->
            <div class="modern-card fade-in">
                <div class="modern-card-header">
                    <h3 class="modern-card-title"><i class="fa fa-info-circle"></i> Cara Top Up</h3>
                </div>
                <div class="modern-card-body">
                    <div class="row">
                        <div class="col-md-3 text-center mb-4 mb-md-0">
                            <div class="step-icon">
                                <i class="fa fa-money-bill-wave fa-2x"></i>
                            </div>
                            <h5>1. Pilih Jumlah</h5>
                            <p>Masukkan jumlah yang ingin Anda top up.</p>
                        </div>
                        <div class="col-md-3 text-center mb-4 mb-md-0">
                            <div class="step-icon">
                                <i class="fa fa-credit-card fa-2x"></i>
                            </div>
                            <h5>2. Pilih Metode</h5>
                            <p>Pilih metode pembayaran yang Anda inginkan.</p>
                        </div>
                        <div class="col-md-3 text-center mb-4 mb-md-0">
                            <div class="step-icon">
                                <i class="fa fa-university fa-2x"></i>
                            </div>
                            <h5>3. Transfer</h5>
                            <p>Transfer dana sesuai dengan instruksi pembayaran.</p>
                        </div>
                        <div class="col-md-3 text-center">
                            <div class="step-icon">
                                <i class="fa fa-check-circle fa-2x"></i>
                            </div>
                            <h5>4. Konfirmasi</h5>
                            <p>Unggah bukti pembayaran untuk konfirmasi.</p>
                        </div>
                    </div>
                    
                    <div class="alert alert-info mt-4">
                        <i class="fa fa-info-circle me-2"></i>
                        <strong>Penting:</strong> Setelah Anda mengunggah bukti pembayaran, admin akan memverifikasi pembayaran Anda dalam waktu 1x24 jam. Saldo akan ditambahkan ke akun Anda setelah pembayaran diverifikasi.
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Preset amount buttons
    const presetButtons = document.querySelectorAll('.preset-btn');
    const amountInput = document.getElementById('amount');
    
    presetButtons.forEach(button => {
        button.addEventListener('click', function() {
            const amount = this.getAttribute('data-amount');
            amountInput.value = amount;
            
            // Remove active class from all buttons
            presetButtons.forEach(btn => btn.classList.remove('active'));
            
            // Add active class to clicked button
            this.classList.add('active');
        });
    });
    
    // Bank selection
    const bankOptions = document.querySelectorAll('.bank-option');
    
    bankOptions.forEach(option => {
        const radio = option.querySelector('input[type="radio"]');
        const label = option.querySelector('label');
        
        label.addEventListener('click', function() {
            radio.checked = true;
            
            // Remove active class from all options
            bankOptions.forEach(opt => opt.classList.remove('active'));
            
            // Add active class to clicked option
            option.classList.add('active');
        });
    });
});
</script>

<?php include("includes/footer.php"); ?>