<?php
// Script untuk menambahkan kolom role ke database

// Include database connection
require_once 'config/database.php';

// Tampilkan header
echo '<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Update Database - LelangMobil</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body { padding: 20px; font-family: Arial, sans-serif; }
        .container { max-width: 800px; }
        .card { margin-bottom: 20px; border-radius: 10px; box-shadow: 0 4px 8px rgba(0,0,0,0.1); }
        .card-header { background-color: #f8f9fa; font-weight: bold; }
        .alert-success { background-color: #d4edda; }
        .alert-danger { background-color: #f8d7da; }
        code { background-color: #f8f9fa; padding: 2px 4px; border-radius: 4px; }
    </style>
</head>
<body>
    <div class="container">
        <h1 class="mb-4">Update Database LelangMobil</h1>';

// Fungsi untuk memeriksa apakah kolom sudah ada
function columnExists($conn, $table, $column) {
    $query = "SHOW COLUMNS FROM $table LIKE '$column'";
    $result = $conn->query($query);
    return $result->num_rows > 0;
}

echo '<div class="card">
      <div class="card-header">Pembaruan Struktur Database</div>
      <div class="card-body">';

// 1. Tambahkan kolom role ke tabel users jika belum ada
if (!columnExists($conn, 'users', 'role')) {
    $add_role_query = "ALTER TABLE users ADD COLUMN role ENUM('user', 'admin', 'seller', 'moderator') DEFAULT 'user' AFTER is_admin";
    
    if ($conn->query($add_role_query)) {
        echo '<div class="alert alert-success">
              <strong>Berhasil!</strong> Kolom role telah ditambahkan ke tabel users.
              </div>';
        
        // Update role berdasarkan is_admin yang sudah ada
        $update_admin_roles = "UPDATE users SET role = 'admin' WHERE is_admin = TRUE";
        if ($conn->query($update_admin_roles)) {
            echo '<div class="alert alert-success">
                  <strong>Berhasil!</strong> User dengan is_admin = TRUE telah diupdate role-nya menjadi \'admin\'.
                  </div>';
        } else {
            echo '<div class="alert alert-danger">
                  <strong>Error!</strong> Gagal mengupdate role admin: ' . $conn->error . '
                  </div>';
        }
    } else {
        echo '<div class="alert alert-danger">
              <strong>Error!</strong> Gagal menambahkan kolom role: ' . $conn->error . '
              </div>';
    }
} else {
    echo '<div class="alert alert-info">
          <strong>Info:</strong> Kolom role sudah ada di tabel users.
          </div>';
}

echo '</div></div>';

// 2. Tambahkan tabel vehicle_features untuk fitur tambahan kendaraan
echo '<div class="card">
      <div class="card-header">Tabel Fitur Kendaraan</div>
      <div class="card-body">';

$create_features_table = "CREATE TABLE IF NOT EXISTS vehicle_features (
    feature_id INT AUTO_INCREMENT PRIMARY KEY,
    vehicle_id INT,
    feature_name VARCHAR(100) NOT NULL,
    feature_icon VARCHAR(50) DEFAULT 'fa-check',
    is_highlighted BOOLEAN DEFAULT FALSE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (vehicle_id) REFERENCES vehicles(vehicle_id) ON DELETE CASCADE
)";

if ($conn->query($create_features_table)) {
    echo '<div class="alert alert-success">
          <strong>Berhasil!</strong> Tabel vehicle_features telah dibuat (atau sudah ada).
          </div>';
} else {
    echo '<div class="alert alert-danger">
          <strong>Error!</strong> Gagal membuat tabel vehicle_features: ' . $conn->error . '
          </div>';
}

echo '</div></div>';

// 3. Tambahkan tabel inspection_reports untuk laporan inspeksi
echo '<div class="card">
      <div class="card-header">Tabel Laporan Inspeksi</div>
      <div class="card-body">';

$create_inspection_table = "CREATE TABLE IF NOT EXISTS inspection_reports (
    report_id INT AUTO_INCREMENT PRIMARY KEY,
    vehicle_id INT,
    inspector_name VARCHAR(100),
    inspection_date DATE,
    overall_condition VARCHAR(20),
    engine_condition VARCHAR(20),
    exterior_condition VARCHAR(20),
    interior_condition VARCHAR(20),
    transmission_condition VARCHAR(20),
    electrical_condition VARCHAR(20),
    notes TEXT,
    is_verified BOOLEAN DEFAULT FALSE,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (vehicle_id) REFERENCES vehicles(vehicle_id) ON DELETE CASCADE
)";

if ($conn->query($create_inspection_table)) {
    echo '<div class="alert alert-success">
          <strong>Berhasil!</strong> Tabel inspection_reports telah dibuat (atau sudah ada).
          </div>';
} else {
    echo '<div class="alert alert-danger">
          <strong>Error!</strong> Gagal membuat tabel inspection_reports: ' . $conn->error . '
          </div>';
}

echo '</div></div>';

// 4. Tambahkan kolom tambahan ke tabel vehicles
echo '<div class="card">
      <div class="card-header">Kolom Tambahan Kendaraan</div>
      <div class="card-body">';

$vehicle_columns = [
    ['body_type', "ADD COLUMN body_type VARCHAR(50) AFTER model"],
    ['fuel_type', "ADD COLUMN fuel_type VARCHAR(30) AFTER mileage"],
    ['transmission', "ADD COLUMN transmission VARCHAR(30) AFTER fuel_type"],
    ['color', "ADD COLUMN color VARCHAR(30) AFTER transmission"],
    ['engine_size', "ADD COLUMN engine_size VARCHAR(30) AFTER color"],
    ['license_plate', "ADD COLUMN license_plate VARCHAR(20) AFTER engine_size"],
    ['vin', "ADD COLUMN vin VARCHAR(50) AFTER license_plate"],
    ['reserve_price', "ADD COLUMN reserve_price DECIMAL(10, 2) DEFAULT NULL AFTER starting_price"],
    ['buy_now_price', "ADD COLUMN buy_now_price DECIMAL(10, 2) DEFAULT NULL AFTER reserve_price"],
    ['featured', "ADD COLUMN featured BOOLEAN DEFAULT FALSE AFTER status"],
    ['location', "ADD COLUMN location VARCHAR(100) AFTER featured"]
];

foreach ($vehicle_columns as $column_info) {
    list($column_name, $alter_query) = $column_info;
    
    if (!columnExists($conn, 'vehicles', $column_name)) {
        $full_query = "ALTER TABLE vehicles $alter_query";
        
        if ($conn->query($full_query)) {
            echo '<div class="alert alert-success">
                  <strong>Berhasil!</strong> Kolom ' . $column_name . ' telah ditambahkan ke tabel vehicles.
                  </div>';
        } else {
            echo '<div class="alert alert-danger">
                  <strong>Error!</strong> Gagal menambahkan kolom ' . $column_name . ': ' . $conn->error . '
                  </div>';
        }
    } else {
        echo '<div class="alert alert-info">
              <strong>Info:</strong> Kolom ' . $column_name . ' sudah ada di tabel vehicles.
              </div>';
    }
}

echo '</div></div>';

// Tampilkan tombol kembali dan tutup HTML
echo '<div class="text-center mt-4 mb-5">
        <a href="index.php" class="btn btn-primary">Kembali ke Halaman Utama</a>
      </div>
    </div>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.2.3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>';
?>
