<?php
// Include database connection
require_once 'config/database.php';
require_once 'config/functions.php';

// Check if user is admin
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

if (!isset($_SESSION['user_id']) || !isset($_SESSION['is_admin']) || $_SESSION['is_admin'] != 1) {
    die("Akses ditolak. Anda harus login sebagai admin untuk menjalankan script ini.");
}

// Vehicle data with image generation configurations
$vehicles = [
    [
        'make' => 'Toyota',
        'model' => 'Avanza Veloz',
        'colors' => ['#1a1a1a', '#d8d8d8', '#7e0000'],  // Black, Silver, Red
        'year' => 2022
    ],
    [
        'make' => 'Honda',
        'model' => 'Civic RS Turbo',
        'colors' => ['#c30000', '#1a1a1a', '#153a6e'], // Red, Black, Blue
        'year' => 2021
    ],
    [
        'make' => 'BMW',
        'model' => '320i Sport',
        'colors' => ['#f1f1f1', '#1a1a1a', '#a0a0a0'], // White, Black, Gray
        'year' => 2020
    ],
    [
        'make' => 'Toyota',
        'model' => 'Fortuner VRZ',
        'colors' => ['#1a1a1a', '#f1f1f1', '#4d5661'], // Black, White, Dark Gray
        'year' => 2021
    ],
    [
        'make' => 'Honda',
        'model' => 'HR-V',
        'colors' => ['#71797e', '#1a1a1a', '#f1f1f1'], // Gray, Black, White
        'year' => 2022
    ],
    [
        'make' => 'Mitsubishi',
        'model' => 'Pajero Sport',
        'colors' => ['#f1f1f1', '#0f0f0f', '#a0a0a0'], // White, Black, Gray
        'year' => 2020
    ],
    [
        'make' => 'Suzuki',
        'model' => 'XL7',
        'colors' => ['#c30000', '#1a1a1a', '#f1f1f1'], // Red, Black, White
        'year' => 2021
    ],
    [
        'make' => 'Mercedes-Benz',
        'model' => 'C200',
        'colors' => ['#1a1a1a', '#f1f1f1', '#a0a0a0'], // Black, White, Gray
        'year' => 2021
    ],
    [
        'make' => 'Wuling',
        'model' => 'Almaz',
        'colors' => ['#f1f1f1', '#1a1a1a', '#5c5c5c'], // White, Black, Gray
        'year' => 2022
    ],
    [
        'make' => 'Mazda',
        'model' => 'CX-5',
        'colors' => ['#c30000', '#1a1a1a', '#f1f1f1'], // Red, Black, White
        'year' => 2020
    ]
];

// Views to generate for each vehicle
$views = ['front', 'side', 'rear'];

// Function to generate realistic car image
function generate_car_image($make, $model, $color, $year, $view_type, $output_path) {
    // Convert color from hex to RGB
    list($r, $g, $b) = sscanf($color, "#%02x%02x%02x");
    
    // Create image
    $width = 800;
    $height = 500;
    $img = imagecreatetruecolor($width, $height);
    
    // Car body color based on input
    $car_color = imagecolorallocate($img, $r, $g, $b);
    
    // Other colors
    $bg_color = imagecolorallocate($img, 240, 240, 240); // Light gray background
    $dark_color = imagecolorallocate($img, max(0, $r-50), max(0, $g-50), max(0, $b-50)); // Darker shade of car color
    $light_color = imagecolorallocate($img, min(255, $r+30), min(255, $g+30), min(255, $b+30)); // Lighter shade
    $black = imagecolorallocate($img, 10, 10, 10);
    $white = imagecolorallocate($img, 250, 250, 250);
    $shadow = imagecolorallocate($img, 100, 100, 100);
    
    // Fill background
    imagefill($img, 0, 0, $bg_color);
    
    // Draw car based on view type
    if ($view_type == 'front') {
        // Front view
        // Car body shape
        $points = [
            // Main body
            300, 200,  // Top left
            500, 200,  // Top right
            550, 350,  // Bottom right
            250, 350   // Bottom left
        ];
        imagefilledpolygon($img, $points, $car_color);
        
        // Add headlights
        imagefilledellipse($img, 300, 270, 60, 40, $white);
        imagefilledellipse($img, 500, 270, 60, 40, $white);
        
        // Grille
        imagefilledrectangle($img, 350, 280, 450, 320, $black);
        
        // Logo area
        imagefilledellipse($img, 400, 250, 40, 40, $light_color);
        
    } else if ($view_type == 'side') {
        // Side view
        // Car body
        imagefilledrectangle($img, 200, 250, 600, 320, $car_color);
        
        // Car roof and windows
        $roof_points = [
            280, 250,  // Front top
            520, 250,  // Back top
            580, 200,  // Back roof
            220, 200   // Front roof
        ];
        imagefilledpolygon($img, $roof_points, $car_color);
        
        // Windows
        $window_points = [
            300, 210,  // Front window top
            450, 210,  // Back window top
            470, 250,  // Back window bottom
            320, 250   // Front window bottom
        ];
        imagefilledpolygon($img, $window_points, $light_color);
        
        // Wheels
        imagefilledellipse($img, 280, 320, 70, 70, $black);
        imagefilledellipse($img, 520, 320, 70, 70, $black);
        imagefilledellipse($img, 280, 320, 40, 40, $light_color);
        imagefilledellipse($img, 520, 320, 40, 40, $light_color);
        
    } else {
        // Rear view
        // Car body
        $points = [
            // Main body
            300, 200,  // Top left
            500, 200,  // Top right
            530, 350,  // Bottom right
            270, 350   // Bottom left
        ];
        imagefilledpolygon($img, $points, $car_color);
        
        // Rear window
        $window_points = [
            320, 210,
            480, 210,
            470, 250,
            330, 250
        ];
        imagefilledpolygon($img, $window_points, $light_color);
        
        // Taillights
        imagefilledrectangle($img, 280, 270, 330, 290, $dark_color);
        imagefilledrectangle($img, 470, 270, 520, 290, $dark_color);
    }
    
    // Add shadow
    imagefilledellipse($img, 400, 380, 400, 40, $shadow);
    
    // Add make and model text
    $text = "{$make} {$model} {$year}";
    $text_color = imagecolorallocate($img, 0, 0, 0);
    
    // Center text
    $font_size = 4;
    $text_width = strlen($text) * imagefontwidth($font_size);
    $text_x = ($width - $text_width) / 2;
    
    // Draw text
    imagestring($img, $font_size, $text_x, 30, $text, $text_color);
    
    // Add view type
    $view_text = "Tampak " . ucfirst($view_type);
    $view_text_width = strlen($view_text) * imagefontwidth(3);
    $view_text_x = intval(($width - $view_text_width) / 2);
    imagestring($img, 3, $view_text_x, 60, $view_text, $text_color);
    
    // Add LelangMobil watermark
    $watermark = "LelangMobil.com";
    imagestring($img, 2, $width - 120, $height - 30, $watermark, $text_color);
    
    // Create directory if it doesn't exist
    $dir = dirname($output_path);
    if (!file_exists($dir)) {
        mkdir($dir, 0755, true);
    }
    
    // Save image
    imagejpeg($img, $output_path, 90);
    imagedestroy($img);
    
    return true;
}

echo "<h1>LelangMobil - Generator Gambar Kendaraan</h1>";
echo "<p>Membuat gambar-gambar kendaraan untuk sistem lelang...</p>";

$count = 0;

// Generate images for all vehicles
foreach ($vehicles as $vehicle) {
    $make = $vehicle['make'];
    $model = $vehicle['model'];
    $year = $vehicle['year'];
    
    // Create safe directory name
    $make_safe = preg_replace('/[^a-z0-9]+/', '-', strtolower($make));
    $model_safe = preg_replace('/[^a-z0-9]+/', '-', strtolower($model));
    
    // Create base directory
    $dir = "images/cars/{$make_safe}";
    if (!file_exists($dir)) {
        mkdir($dir, 0755, true);
    }
    
    // Generate images for each color and view
    foreach ($vehicle['colors'] as $color_index => $color) {
        foreach ($views as $view_index => $view) {
            $filename = "{$make_safe}_{$model_safe}_{$color_index}_{$view}.jpg";
            $output_path = "{$dir}/{$filename}";
            
            if (generate_car_image($make, $model, $color, $year, $view, $output_path)) {
                echo "<p>✅ Berhasil membuat gambar: {$output_path}</p>";
                $count++;
                
                // Also copy to uploads directory for consistency
                $uploads_dir = "uploads/vehicles/{$make_safe}";
                if (!file_exists($uploads_dir)) {
                    mkdir($uploads_dir, 0755, true);
                }
                
                $uploads_path = "{$uploads_dir}/{$filename}";
                copy($output_path, $uploads_path);
            } else {
                echo "<p>❌ Gagal membuat gambar: {$output_path}</p>";
            }
        }
    }
}

echo "<h2>Ringkasan</h2>";
echo "<p>Total gambar yang dibuat: {$count}</p>";
echo "<p><a href='index.php' class='btn btn-primary'>Kembali ke Halaman Utama</a></p>";
echo "<p><a href='run_import.php' class='btn btn-success'>Lanjutkan ke Import Kendaraan</a></p>";
?>
