<?php
/**
 * Email Verification Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

$error = '';
$success = '';

// Check if token is provided
if (isset($_GET['token']) && !empty($_GET['token'])) {
    $token = clean_input($_GET['token']);
    
    // Check if token exists and is valid
    $token_sql = "SELECT * FROM users WHERE verification_token = ? AND token_expiry > NOW()";
    $token_stmt = $conn->prepare($token_sql);
    $token_stmt->bind_param("s", $token);
    $token_stmt->execute();
    $token_result = $token_stmt->get_result();
    
    if ($token_result->num_rows > 0) {
        $user = $token_result->fetch_assoc();
        
        // Update user as verified
        $update_sql = "UPDATE users SET is_verified = 1, verification_token = NULL, token_expiry = NULL WHERE user_id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param("i", $user['user_id']);
        
        if ($update_stmt->execute()) {
            $success = "Email berhasil diverifikasi! Anda sekarang dapat login ke akun Anda.";
            
            // Auto login user if not already logged in
            if (!is_logged_in()) {
                $_SESSION['user_id'] = $user['user_id'];
                $_SESSION['username'] = $user['username'];
                $_SESSION['is_admin'] = $user['is_admin'];
                
                // Redirect to account page after 3 seconds
                header("refresh:3;url=account-modern.php");
            }
        } else {
            $error = "Gagal memverifikasi email. Silakan coba lagi.";
        }
    } else {
        $error = "Token verifikasi tidak valid atau sudah kedaluwarsa. Silakan minta token baru.";
    }
} else {
    $error = "Token verifikasi tidak ditemukan. Silakan periksa link yang Anda klik.";
}

// Aktifkan flag untuk halaman login
$page_title = "Verifikasi Email";
$is_auth_page = true;
$use_modern_auth = true;

// Custom CSS untuk halaman auth
$page_specific_css = '<link href="css/login-modern.css" rel="stylesheet" type="text/css">';

// Include header
include("includes/header.php");
?>

<div class="auth-container">
    <div class="auth-card animate">
        <div class="auth-card-header text-center">
            <h2><i class="fa fa-envelope-open-text"></i> Verifikasi Email</h2>
            <p class="text-muted">Konfirmasi alamat email Anda</p>
        </div>
        
        <div class="auth-card-body">
            <?php if (!empty($error)): ?>
                <div class="auth-alert auth-alert-danger">
                    <i class="fa fa-exclamation-circle me-2"></i><?php echo $error; ?>
                </div>
                
                <div class="text-center mt-4">
                    <a href="resend-verification.php" class="auth-btn auth-btn-primary">
                        <i class="fa fa-paper-plane me-2"></i>Kirim Ulang Verifikasi
                    </a>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($success)): ?>
                <div class="auth-alert auth-alert-success">
                    <i class="fa fa-check-circle me-2"></i><?php echo $success; ?>
                </div>
                
                <div class="text-center mt-4">
                    <div class="mb-4">
                        <i class="fa fa-check-circle fa-3x text-success"></i>
                    </div>
                    <h4>Email Berhasil Diverifikasi!</h4>
                    <p>Terima kasih telah memverifikasi email Anda. Anda sekarang dapat menggunakan semua fitur LelangMobil.</p>
                    
                    <div class="mt-4">
                        <a href="account-modern.php" class="auth-btn auth-btn-primary">
                            <i class="fa fa-user me-2"></i>Ke Dashboard Akun
                        </a>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<?php include("includes/footer.php"); ?>