<?php
/**
 * Wallet Tab Component
 * LelangMobil Web App - Versi 2025
 */

// Pastikan user_id tersedia
if (!isset($user_id)) {
    echo '<div class="alert alert-danger">Error: User ID tidak tersedia.</div>';
    return;
}

// Get wallet balance
try {
    $wallet_query = "SELECT balance FROM users WHERE user_id = ?";
    $wallet_stmt = $conn->prepare($wallet_query);
    $wallet_stmt->bind_param("i", $user_id);
    $wallet_stmt->execute();
    $wallet_result = $wallet_stmt->get_result();
    $wallet_data = $wallet_result->fetch_assoc();
    $balance = $wallet_data['balance'] ?? 0;
} catch (Throwable $e) {
    error_log("Error getting wallet balance: " . $e->getMessage());
    $balance = 0;
}

// Get recent transactions
try {
    $transactions_query = "SELECT * FROM transactions WHERE user_id = ? ORDER BY created_at DESC LIMIT 5";
    $transactions_stmt = $conn->prepare($transactions_query);
    $transactions_stmt->bind_param("i", $user_id);
    $transactions_stmt->execute();
    $transactions_result = $transactions_stmt->get_result();
} catch (Throwable $e) {
    error_log("Error getting recent transactions: " . $e->getMessage());
    $transactions_result = false;
}
?>

<div class="wallet-tab-content">
    <div class="wallet-balance-card">
        <div class="balance-header">
            <h4>Saldo Anda</h4>
            <div class="balance-actions">
                <a href="topup-modern.php" class="btn btn-sm btn-success">
                    <i class="fa fa-plus-circle"></i> Top Up
                </a>
                <a href="withdraw-modern.php" class="btn btn-sm btn-primary">
                    <i class="fa fa-money-bill-wave"></i> Tarik
                </a>
            </div>
        </div>
        <div class="balance-amount">
            <span class="currency">Rp</span>
            <span class="amount"><?php echo number_format($balance, 0, ',', '.'); ?></span>
        </div>
        <div class="balance-update">
            <small>Update terakhir: <?php echo date('d M Y H:i'); ?></small>
        </div>
    </div>
    
    <div class="recent-transactions mt-4">
        <h5><i class="fa fa-history me-2"></i>Transaksi Terakhir</h5>
        
        <?php if (!$transactions_result || $transactions_result->num_rows == 0): ?>
            <div class="empty-transactions">
                <p class="text-muted">Belum ada transaksi.</p>
            </div>
        <?php else: ?>
            <div class="transaction-list">
                <?php while ($transaction = $transactions_result->fetch_assoc()): ?>
                    <div class="transaction-item">
                        <div class="transaction-icon">
                            <?php
                            switch ($transaction['type']) {
                                case 'deposit':
                                    echo '<i class="fa fa-arrow-down text-success"></i>';
                                    break;
                                case 'withdrawal':
                                    echo '<i class="fa fa-arrow-up text-danger"></i>';
                                    break;
                                case 'bid_hold':
                                    echo '<i class="fa fa-gavel text-warning"></i>';
                                    break;
                                case 'bid_release':
                                    echo '<i class="fa fa-undo text-info"></i>';
                                    break;
                                default:
                                    echo '<i class="fa fa-exchange-alt text-primary"></i>';
                            }
                            ?>
                        </div>
                        <div class="transaction-details">
                            <div class="transaction-type">
                                <?php
                                switch ($transaction['type']) {
                                    case 'deposit':
                                        echo 'Top Up';
                                        break;
                                    case 'withdrawal':
                                        echo 'Penarikan';
                                        break;
                                    case 'bid_hold':
                                        echo 'Bid Hold';
                                        break;
                                    case 'bid_release':
                                        echo 'Bid Release';
                                        break;
                                    default:
                                        echo ucfirst($transaction['type']);
                                }
                                ?>
                            </div>
                            <div class="transaction-date">
                                <?php echo date('d M Y, H:i', strtotime($transaction['created_at'])); ?>
                            </div>
                        </div>
                        <div class="transaction-amount <?php echo ($transaction['type'] == 'deposit' || $transaction['type'] == 'bid_release') ? 'text-success' : 'text-danger'; ?>">
                            <?php echo ($transaction['type'] == 'deposit' || $transaction['type'] == 'bid_release') ? '+' : '-'; ?>
                            Rp<?php echo number_format($transaction['amount'], 0, ',', '.'); ?>
                        </div>
                        <div class="transaction-status">
                            <?php
                            switch ($transaction['status']) {
                                case 'completed':
                                    echo '<span class="badge bg-success">Selesai</span>';
                                    break;
                                case 'pending':
                                    echo '<span class="badge bg-warning">Pending</span>';
                                    break;
                                case 'rejected':
                                    echo '<span class="badge bg-danger">Ditolak</span>';
                                    break;
                                default:
                                    echo '<span class="badge bg-secondary">' . ucfirst($transaction['status']) . '</span>';
                            }
                            ?>
                        </div>
                    </div>
                <?php endwhile; ?>
            </div>
            
            <div class="text-center mt-3">
                <a href="transactions-modern.php" class="btn btn-outline-primary btn-sm">
                    <i class="fa fa-list me-1"></i> Lihat Semua Transaksi
                </a>
            </div>
        <?php endif; ?>
    </div>
</div>

<style>
.wallet-balance-card {
    background: linear-gradient(135deg, #4a6ee0, #2b4db7);
    color: white;
    border-radius: 10px;
    padding: 20px;
    margin-bottom: 20px;
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
}

.balance-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-bottom: 15px;
}

.balance-header h4 {
    margin: 0;
    font-weight: 600;
}

.balance-actions {
    display: flex;
    gap: 10px;
}

.balance-amount {
    font-size: 2.5rem;
    font-weight: 700;
    margin-bottom: 10px;
}

.currency {
    font-size: 1.5rem;
    margin-right: 5px;
}

.balance-update {
    opacity: 0.8;
}

.transaction-list {
    margin-top: 15px;
}

.transaction-item {
    display: flex;
    align-items: center;
    padding: 12px 0;
    border-bottom: 1px solid rgba(0, 0, 0, 0.05);
}

.transaction-icon {
    width: 40px;
    height: 40px;
    border-radius: 50%;
    background-color: rgba(0, 0, 0, 0.05);
    display: flex;
    align-items: center;
    justify-content: center;
    margin-right: 15px;
}

.transaction-details {
    flex-grow: 1;
}

.transaction-type {
    font-weight: 600;
    margin-bottom: 3px;
}

.transaction-date {
    font-size: 0.8rem;
    color: #6c757d;
}

.transaction-amount {
    font-weight: 600;
    margin-right: 15px;
}

.empty-transactions {
    text-align: center;
    padding: 30px 0;
}
</style>